/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleApigeeAppGroupConfig extends cdktf.TerraformMetaArguments {
    /**
    * Channel identifier identifies the owner maintaing this grouping.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_apigee_app_group#channel_id GoogleApigeeAppGroup#channel_id}
    */
    readonly channelId?: string;
    /**
    * A reference to the associated storefront/marketplace.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_apigee_app_group#channel_uri GoogleApigeeAppGroup#channel_uri}
    */
    readonly channelUri?: string;
    /**
    * App group name displayed in the UI
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_apigee_app_group#display_name GoogleApigeeAppGroup#display_name}
    */
    readonly displayName?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_apigee_app_group#id GoogleApigeeAppGroup#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Name of the AppGroup. Characters you can use in the name are restricted to: A-Z0-9._-$ %.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_apigee_app_group#name GoogleApigeeAppGroup#name}
    */
    readonly name: string;
    /**
    * The Apigee Organization associated with the Apigee app group,
    * in the format 'organizations/{{org_name}}'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_apigee_app_group#org_id GoogleApigeeAppGroup#org_id}
    */
    readonly orgId: string;
    /**
    * Valid values are active or inactive. Note that the status of the AppGroup should be updated via UpdateAppGroupRequest by setting the action as active or inactive. Possible values: ["active", "inactive"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_apigee_app_group#status GoogleApigeeAppGroup#status}
    */
    readonly status?: string;
    /**
    * attributes block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_apigee_app_group#attributes GoogleApigeeAppGroup#attributes}
    */
    readonly attributes?: GoogleApigeeAppGroupAttributes[] | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_apigee_app_group#timeouts GoogleApigeeAppGroup#timeouts}
    */
    readonly timeouts?: GoogleApigeeAppGroupTimeouts;
}
export interface GoogleApigeeAppGroupAttributes {
    /**
    * Key of the attribute
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_apigee_app_group#name GoogleApigeeAppGroup#name}
    */
    readonly name?: string;
    /**
    * Value of the attribute
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_apigee_app_group#value GoogleApigeeAppGroup#value}
    */
    readonly value?: string;
}
export declare function googleApigeeAppGroupAttributesToTerraform(struct?: GoogleApigeeAppGroupAttributes | cdktf.IResolvable): any;
export declare function googleApigeeAppGroupAttributesToHclTerraform(struct?: GoogleApigeeAppGroupAttributes | cdktf.IResolvable): any;
export declare class GoogleApigeeAppGroupAttributesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleApigeeAppGroupAttributes | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleApigeeAppGroupAttributes | cdktf.IResolvable | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    resetValue(): void;
    get valueInput(): string | undefined;
}
export declare class GoogleApigeeAppGroupAttributesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleApigeeAppGroupAttributes[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleApigeeAppGroupAttributesOutputReference;
}
export interface GoogleApigeeAppGroupTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_apigee_app_group#create GoogleApigeeAppGroup#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_apigee_app_group#delete GoogleApigeeAppGroup#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_apigee_app_group#update GoogleApigeeAppGroup#update}
    */
    readonly update?: string;
}
export declare function googleApigeeAppGroupTimeoutsToTerraform(struct?: GoogleApigeeAppGroupTimeouts | cdktf.IResolvable): any;
export declare function googleApigeeAppGroupTimeoutsToHclTerraform(struct?: GoogleApigeeAppGroupTimeouts | cdktf.IResolvable): any;
export declare class GoogleApigeeAppGroupTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleApigeeAppGroupTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleApigeeAppGroupTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_apigee_app_group google_apigee_app_group}
*/
export declare class GoogleApigeeAppGroup extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_apigee_app_group";
    /**
    * Generates CDKTF code for importing a GoogleApigeeAppGroup resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleApigeeAppGroup to import
    * @param importFromId The id of the existing GoogleApigeeAppGroup that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_apigee_app_group#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleApigeeAppGroup to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_apigee_app_group google_apigee_app_group} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleApigeeAppGroupConfig
    */
    constructor(scope: Construct, id: string, config: GoogleApigeeAppGroupConfig);
    get appGroupId(): string;
    private _channelId?;
    get channelId(): string;
    set channelId(value: string);
    resetChannelId(): void;
    get channelIdInput(): string | undefined;
    private _channelUri?;
    get channelUri(): string;
    set channelUri(value: string);
    resetChannelUri(): void;
    get channelUriInput(): string | undefined;
    get createdAt(): string;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    resetDisplayName(): void;
    get displayNameInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get lastModifiedAt(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _orgId?;
    get orgId(): string;
    set orgId(value: string);
    get orgIdInput(): string | undefined;
    get organization(): string;
    private _status?;
    get status(): string;
    set status(value: string);
    resetStatus(): void;
    get statusInput(): string | undefined;
    private _attributes;
    get attributes(): GoogleApigeeAppGroupAttributesList;
    putAttributes(value: GoogleApigeeAppGroupAttributes[] | cdktf.IResolvable): void;
    resetAttributes(): void;
    get attributesInput(): cdktf.IResolvable | GoogleApigeeAppGroupAttributes[] | undefined;
    private _timeouts;
    get timeouts(): GoogleApigeeAppGroupTimeoutsOutputReference;
    putTimeouts(value: GoogleApigeeAppGroupTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleApigeeAppGroupTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
