/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleApigeeDeveloperConfig extends cdktf.TerraformMetaArguments {
    /**
    * Email address of the developer. This value is used to uniquely identify the developer in Apigee hybrid. Note that the email address has to be in lowercase only..
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_apigee_developer#email GoogleApigeeDeveloper#email}
    */
    readonly email: string;
    /**
    * First name of the developer.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_apigee_developer#first_name GoogleApigeeDeveloper#first_name}
    */
    readonly firstName: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_apigee_developer#id GoogleApigeeDeveloper#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Last name of the developer.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_apigee_developer#last_name GoogleApigeeDeveloper#last_name}
    */
    readonly lastName: string;
    /**
    * The Apigee Organization associated with the Apigee instance,
    * in the format 'organizations/{{org_name}}'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_apigee_developer#org_id GoogleApigeeDeveloper#org_id}
    */
    readonly orgId: string;
    /**
    * User name of the developer. Not used by Apigee hybrid.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_apigee_developer#user_name GoogleApigeeDeveloper#user_name}
    */
    readonly userName: string;
    /**
    * attributes block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_apigee_developer#attributes GoogleApigeeDeveloper#attributes}
    */
    readonly attributes?: GoogleApigeeDeveloperAttributes[] | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_apigee_developer#timeouts GoogleApigeeDeveloper#timeouts}
    */
    readonly timeouts?: GoogleApigeeDeveloperTimeouts;
}
export interface GoogleApigeeDeveloperAttributes {
    /**
    * Key of the attribute
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_apigee_developer#name GoogleApigeeDeveloper#name}
    */
    readonly name?: string;
    /**
    * Value of the attribute
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_apigee_developer#value GoogleApigeeDeveloper#value}
    */
    readonly value?: string;
}
export declare function googleApigeeDeveloperAttributesToTerraform(struct?: GoogleApigeeDeveloperAttributes | cdktf.IResolvable): any;
export declare function googleApigeeDeveloperAttributesToHclTerraform(struct?: GoogleApigeeDeveloperAttributes | cdktf.IResolvable): any;
export declare class GoogleApigeeDeveloperAttributesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleApigeeDeveloperAttributes | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleApigeeDeveloperAttributes | cdktf.IResolvable | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    resetValue(): void;
    get valueInput(): string | undefined;
}
export declare class GoogleApigeeDeveloperAttributesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleApigeeDeveloperAttributes[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleApigeeDeveloperAttributesOutputReference;
}
export interface GoogleApigeeDeveloperTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_apigee_developer#create GoogleApigeeDeveloper#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_apigee_developer#delete GoogleApigeeDeveloper#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_apigee_developer#update GoogleApigeeDeveloper#update}
    */
    readonly update?: string;
}
export declare function googleApigeeDeveloperTimeoutsToTerraform(struct?: GoogleApigeeDeveloperTimeouts | cdktf.IResolvable): any;
export declare function googleApigeeDeveloperTimeoutsToHclTerraform(struct?: GoogleApigeeDeveloperTimeouts | cdktf.IResolvable): any;
export declare class GoogleApigeeDeveloperTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleApigeeDeveloperTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleApigeeDeveloperTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_apigee_developer google_apigee_developer}
*/
export declare class GoogleApigeeDeveloper extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_apigee_developer";
    /**
    * Generates CDKTF code for importing a GoogleApigeeDeveloper resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleApigeeDeveloper to import
    * @param importFromId The id of the existing GoogleApigeeDeveloper that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_apigee_developer#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleApigeeDeveloper to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_apigee_developer google_apigee_developer} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleApigeeDeveloperConfig
    */
    constructor(scope: Construct, id: string, config: GoogleApigeeDeveloperConfig);
    get createdAt(): string;
    private _email?;
    get email(): string;
    set email(value: string);
    get emailInput(): string | undefined;
    private _firstName?;
    get firstName(): string;
    set firstName(value: string);
    get firstNameInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get lastModifiedAt(): string;
    private _lastName?;
    get lastName(): string;
    set lastName(value: string);
    get lastNameInput(): string | undefined;
    private _orgId?;
    get orgId(): string;
    set orgId(value: string);
    get orgIdInput(): string | undefined;
    get organizatioName(): string;
    get status(): string;
    private _userName?;
    get userName(): string;
    set userName(value: string);
    get userNameInput(): string | undefined;
    private _attributes;
    get attributes(): GoogleApigeeDeveloperAttributesList;
    putAttributes(value: GoogleApigeeDeveloperAttributes[] | cdktf.IResolvable): void;
    resetAttributes(): void;
    get attributesInput(): cdktf.IResolvable | GoogleApigeeDeveloperAttributes[] | undefined;
    private _timeouts;
    get timeouts(): GoogleApigeeDeveloperTimeoutsOutputReference;
    putTimeouts(value: GoogleApigeeDeveloperTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleApigeeDeveloperTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
