/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleBigqueryDatapolicyDataPolicyConfig extends cdktf.TerraformMetaArguments {
    /**
    * User-assigned (human readable) ID of the data policy that needs to be unique within a project. Used as {dataPolicyId} in part of the resource name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_datapolicy_data_policy#data_policy_id GoogleBigqueryDatapolicyDataPolicy#data_policy_id}
    */
    readonly dataPolicyId: string;
    /**
    * The enrollment level of the service. Possible values: ["COLUMN_LEVEL_SECURITY_POLICY", "DATA_MASKING_POLICY"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_datapolicy_data_policy#data_policy_type GoogleBigqueryDatapolicyDataPolicy#data_policy_type}
    */
    readonly dataPolicyType: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_datapolicy_data_policy#id GoogleBigqueryDatapolicyDataPolicy#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The name of the location of the data policy.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_datapolicy_data_policy#location GoogleBigqueryDatapolicyDataPolicy#location}
    */
    readonly location: string;
    /**
    * Policy tag resource name, in the format of projects/{project_number}/locations/{locationId}/taxonomies/{taxonomyId}/policyTags/{policyTag_id}.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_datapolicy_data_policy#policy_tag GoogleBigqueryDatapolicyDataPolicy#policy_tag}
    */
    readonly policyTag: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_datapolicy_data_policy#project GoogleBigqueryDatapolicyDataPolicy#project}
    */
    readonly project?: string;
    /**
    * data_masking_policy block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_datapolicy_data_policy#data_masking_policy GoogleBigqueryDatapolicyDataPolicy#data_masking_policy}
    */
    readonly dataMaskingPolicy?: GoogleBigqueryDatapolicyDataPolicyDataMaskingPolicy;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_datapolicy_data_policy#timeouts GoogleBigqueryDatapolicyDataPolicy#timeouts}
    */
    readonly timeouts?: GoogleBigqueryDatapolicyDataPolicyTimeouts;
}
export interface GoogleBigqueryDatapolicyDataPolicyDataMaskingPolicy {
    /**
    * The available masking rules. Learn more here: https://cloud.google.com/bigquery/docs/column-data-masking-intro#masking_options. Possible values: ["SHA256", "ALWAYS_NULL", "DEFAULT_MASKING_VALUE", "LAST_FOUR_CHARACTERS", "FIRST_FOUR_CHARACTERS", "EMAIL_MASK", "DATE_YEAR_MASK"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_datapolicy_data_policy#predefined_expression GoogleBigqueryDatapolicyDataPolicy#predefined_expression}
    */
    readonly predefinedExpression?: string;
    /**
    * The name of the BigQuery routine that contains the custom masking routine, in the format of projects/{projectNumber}/datasets/{dataset_id}/routines/{routine_id}.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_datapolicy_data_policy#routine GoogleBigqueryDatapolicyDataPolicy#routine}
    */
    readonly routine?: string;
}
export declare function googleBigqueryDatapolicyDataPolicyDataMaskingPolicyToTerraform(struct?: GoogleBigqueryDatapolicyDataPolicyDataMaskingPolicyOutputReference | GoogleBigqueryDatapolicyDataPolicyDataMaskingPolicy): any;
export declare function googleBigqueryDatapolicyDataPolicyDataMaskingPolicyToHclTerraform(struct?: GoogleBigqueryDatapolicyDataPolicyDataMaskingPolicyOutputReference | GoogleBigqueryDatapolicyDataPolicyDataMaskingPolicy): any;
export declare class GoogleBigqueryDatapolicyDataPolicyDataMaskingPolicyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleBigqueryDatapolicyDataPolicyDataMaskingPolicy | undefined;
    set internalValue(value: GoogleBigqueryDatapolicyDataPolicyDataMaskingPolicy | undefined);
    private _predefinedExpression?;
    get predefinedExpression(): string;
    set predefinedExpression(value: string);
    resetPredefinedExpression(): void;
    get predefinedExpressionInput(): string | undefined;
    private _routine?;
    get routine(): string;
    set routine(value: string);
    resetRoutine(): void;
    get routineInput(): string | undefined;
}
export interface GoogleBigqueryDatapolicyDataPolicyTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_datapolicy_data_policy#create GoogleBigqueryDatapolicyDataPolicy#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_datapolicy_data_policy#delete GoogleBigqueryDatapolicyDataPolicy#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_datapolicy_data_policy#update GoogleBigqueryDatapolicyDataPolicy#update}
    */
    readonly update?: string;
}
export declare function googleBigqueryDatapolicyDataPolicyTimeoutsToTerraform(struct?: GoogleBigqueryDatapolicyDataPolicyTimeouts | cdktf.IResolvable): any;
export declare function googleBigqueryDatapolicyDataPolicyTimeoutsToHclTerraform(struct?: GoogleBigqueryDatapolicyDataPolicyTimeouts | cdktf.IResolvable): any;
export declare class GoogleBigqueryDatapolicyDataPolicyTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleBigqueryDatapolicyDataPolicyTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleBigqueryDatapolicyDataPolicyTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_datapolicy_data_policy google_bigquery_datapolicy_data_policy}
*/
export declare class GoogleBigqueryDatapolicyDataPolicy extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_bigquery_datapolicy_data_policy";
    /**
    * Generates CDKTF code for importing a GoogleBigqueryDatapolicyDataPolicy resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleBigqueryDatapolicyDataPolicy to import
    * @param importFromId The id of the existing GoogleBigqueryDatapolicyDataPolicy that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_datapolicy_data_policy#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleBigqueryDatapolicyDataPolicy to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_datapolicy_data_policy google_bigquery_datapolicy_data_policy} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleBigqueryDatapolicyDataPolicyConfig
    */
    constructor(scope: Construct, id: string, config: GoogleBigqueryDatapolicyDataPolicyConfig);
    private _dataPolicyId?;
    get dataPolicyId(): string;
    set dataPolicyId(value: string);
    get dataPolicyIdInput(): string | undefined;
    private _dataPolicyType?;
    get dataPolicyType(): string;
    set dataPolicyType(value: string);
    get dataPolicyTypeInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    get name(): string;
    private _policyTag?;
    get policyTag(): string;
    set policyTag(value: string);
    get policyTagInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _dataMaskingPolicy;
    get dataMaskingPolicy(): GoogleBigqueryDatapolicyDataPolicyDataMaskingPolicyOutputReference;
    putDataMaskingPolicy(value: GoogleBigqueryDatapolicyDataPolicyDataMaskingPolicy): void;
    resetDataMaskingPolicy(): void;
    get dataMaskingPolicyInput(): GoogleBigqueryDatapolicyDataPolicyDataMaskingPolicy | undefined;
    private _timeouts;
    get timeouts(): GoogleBigqueryDatapolicyDataPolicyTimeoutsOutputReference;
    putTimeouts(value: GoogleBigqueryDatapolicyDataPolicyTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleBigqueryDatapolicyDataPolicyTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
