/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleBigqueryJobConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#id GoogleBigqueryJob#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The ID of the job. The ID must contain only letters (a-z, A-Z), numbers (0-9), underscores (_), or dashes (-). The maximum length is 1,024 characters.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#job_id GoogleBigqueryJob#job_id}
    */
    readonly jobId: string;
    /**
    * Job timeout in milliseconds. If this time limit is exceeded, BigQuery may attempt to terminate the job.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#job_timeout_ms GoogleBigqueryJob#job_timeout_ms}
    */
    readonly jobTimeoutMs?: string;
    /**
    * The labels associated with this job. You can use these to organize and group your jobs.
    *
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#labels GoogleBigqueryJob#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * The geographic location of the job. The default value is US.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#location GoogleBigqueryJob#location}
    */
    readonly location?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#project GoogleBigqueryJob#project}
    */
    readonly project?: string;
    /**
    * copy block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#copy GoogleBigqueryJob#copy}
    */
    readonly copy?: GoogleBigqueryJobCopy;
    /**
    * extract block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#extract GoogleBigqueryJob#extract}
    */
    readonly extract?: GoogleBigqueryJobExtract;
    /**
    * load block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#load GoogleBigqueryJob#load}
    */
    readonly load?: GoogleBigqueryJobLoad;
    /**
    * query block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#query GoogleBigqueryJob#query}
    */
    readonly query?: GoogleBigqueryJobQuery;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#timeouts GoogleBigqueryJob#timeouts}
    */
    readonly timeouts?: GoogleBigqueryJobTimeouts;
}
export interface GoogleBigqueryJobStatusErrorResult {
}
export declare function googleBigqueryJobStatusErrorResultToTerraform(struct?: GoogleBigqueryJobStatusErrorResult): any;
export declare function googleBigqueryJobStatusErrorResultToHclTerraform(struct?: GoogleBigqueryJobStatusErrorResult): any;
export declare class GoogleBigqueryJobStatusErrorResultOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleBigqueryJobStatusErrorResult | undefined;
    set internalValue(value: GoogleBigqueryJobStatusErrorResult | undefined);
    get location(): string;
    get message(): string;
    get reason(): string;
}
export declare class GoogleBigqueryJobStatusErrorResultList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleBigqueryJobStatusErrorResultOutputReference;
}
export interface GoogleBigqueryJobStatusErrors {
}
export declare function googleBigqueryJobStatusErrorsToTerraform(struct?: GoogleBigqueryJobStatusErrors): any;
export declare function googleBigqueryJobStatusErrorsToHclTerraform(struct?: GoogleBigqueryJobStatusErrors): any;
export declare class GoogleBigqueryJobStatusErrorsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleBigqueryJobStatusErrors | undefined;
    set internalValue(value: GoogleBigqueryJobStatusErrors | undefined);
    get location(): string;
    get message(): string;
    get reason(): string;
}
export declare class GoogleBigqueryJobStatusErrorsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleBigqueryJobStatusErrorsOutputReference;
}
export interface GoogleBigqueryJobStatus {
}
export declare function googleBigqueryJobStatusToTerraform(struct?: GoogleBigqueryJobStatus): any;
export declare function googleBigqueryJobStatusToHclTerraform(struct?: GoogleBigqueryJobStatus): any;
export declare class GoogleBigqueryJobStatusOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleBigqueryJobStatus | undefined;
    set internalValue(value: GoogleBigqueryJobStatus | undefined);
    private _errorResult;
    get errorResult(): GoogleBigqueryJobStatusErrorResultList;
    private _errors;
    get errors(): GoogleBigqueryJobStatusErrorsList;
    get state(): string;
}
export declare class GoogleBigqueryJobStatusList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleBigqueryJobStatusOutputReference;
}
export interface GoogleBigqueryJobCopyDestinationEncryptionConfiguration {
    /**
    * Describes the Cloud KMS encryption key that will be used to protect destination BigQuery table.
    * The BigQuery Service Account associated with your project requires access to this encryption key.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#kms_key_name GoogleBigqueryJob#kms_key_name}
    */
    readonly kmsKeyName: string;
}
export declare function googleBigqueryJobCopyDestinationEncryptionConfigurationToTerraform(struct?: GoogleBigqueryJobCopyDestinationEncryptionConfigurationOutputReference | GoogleBigqueryJobCopyDestinationEncryptionConfiguration): any;
export declare function googleBigqueryJobCopyDestinationEncryptionConfigurationToHclTerraform(struct?: GoogleBigqueryJobCopyDestinationEncryptionConfigurationOutputReference | GoogleBigqueryJobCopyDestinationEncryptionConfiguration): any;
export declare class GoogleBigqueryJobCopyDestinationEncryptionConfigurationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleBigqueryJobCopyDestinationEncryptionConfiguration | undefined;
    set internalValue(value: GoogleBigqueryJobCopyDestinationEncryptionConfiguration | undefined);
    private _kmsKeyName?;
    get kmsKeyName(): string;
    set kmsKeyName(value: string);
    get kmsKeyNameInput(): string | undefined;
    get kmsKeyVersion(): string;
}
export interface GoogleBigqueryJobCopyDestinationTable {
    /**
    * The ID of the dataset containing this table.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#dataset_id GoogleBigqueryJob#dataset_id}
    */
    readonly datasetId?: string;
    /**
    * The ID of the project containing this table.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#project_id GoogleBigqueryJob#project_id}
    */
    readonly projectId?: string;
    /**
    * The table. Can be specified '{{table_id}}' if 'project_id' and 'dataset_id' are also set,
    * or of the form 'projects/{{project}}/datasets/{{dataset_id}}/tables/{{table_id}}' if not.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#table_id GoogleBigqueryJob#table_id}
    */
    readonly tableId: string;
}
export declare function googleBigqueryJobCopyDestinationTableToTerraform(struct?: GoogleBigqueryJobCopyDestinationTableOutputReference | GoogleBigqueryJobCopyDestinationTable): any;
export declare function googleBigqueryJobCopyDestinationTableToHclTerraform(struct?: GoogleBigqueryJobCopyDestinationTableOutputReference | GoogleBigqueryJobCopyDestinationTable): any;
export declare class GoogleBigqueryJobCopyDestinationTableOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleBigqueryJobCopyDestinationTable | undefined;
    set internalValue(value: GoogleBigqueryJobCopyDestinationTable | undefined);
    private _datasetId?;
    get datasetId(): string;
    set datasetId(value: string);
    resetDatasetId(): void;
    get datasetIdInput(): string | undefined;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    resetProjectId(): void;
    get projectIdInput(): string | undefined;
    private _tableId?;
    get tableId(): string;
    set tableId(value: string);
    get tableIdInput(): string | undefined;
}
export interface GoogleBigqueryJobCopySourceTables {
    /**
    * The ID of the dataset containing this table.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#dataset_id GoogleBigqueryJob#dataset_id}
    */
    readonly datasetId?: string;
    /**
    * The ID of the project containing this table.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#project_id GoogleBigqueryJob#project_id}
    */
    readonly projectId?: string;
    /**
    * The table. Can be specified '{{table_id}}' if 'project_id' and 'dataset_id' are also set,
    * or of the form 'projects/{{project}}/datasets/{{dataset_id}}/tables/{{table_id}}' if not.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#table_id GoogleBigqueryJob#table_id}
    */
    readonly tableId: string;
}
export declare function googleBigqueryJobCopySourceTablesToTerraform(struct?: GoogleBigqueryJobCopySourceTables | cdktf.IResolvable): any;
export declare function googleBigqueryJobCopySourceTablesToHclTerraform(struct?: GoogleBigqueryJobCopySourceTables | cdktf.IResolvable): any;
export declare class GoogleBigqueryJobCopySourceTablesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleBigqueryJobCopySourceTables | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleBigqueryJobCopySourceTables | cdktf.IResolvable | undefined);
    private _datasetId?;
    get datasetId(): string;
    set datasetId(value: string);
    resetDatasetId(): void;
    get datasetIdInput(): string | undefined;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    resetProjectId(): void;
    get projectIdInput(): string | undefined;
    private _tableId?;
    get tableId(): string;
    set tableId(value: string);
    get tableIdInput(): string | undefined;
}
export declare class GoogleBigqueryJobCopySourceTablesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleBigqueryJobCopySourceTables[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleBigqueryJobCopySourceTablesOutputReference;
}
export interface GoogleBigqueryJobCopy {
    /**
    * Specifies whether the job is allowed to create new tables. The following values are supported:
    * CREATE_IF_NEEDED: If the table does not exist, BigQuery creates the table.
    * CREATE_NEVER: The table must already exist. If it does not, a 'notFound' error is returned in the job result.
    * Creation, truncation and append actions occur as one atomic update upon job completion Default value: "CREATE_IF_NEEDED" Possible values: ["CREATE_IF_NEEDED", "CREATE_NEVER"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#create_disposition GoogleBigqueryJob#create_disposition}
    */
    readonly createDisposition?: string;
    /**
    * Specifies the action that occurs if the destination table already exists. The following values are supported:
    * WRITE_TRUNCATE: If the table already exists, BigQuery overwrites the table data and uses the schema from the query result.
    * WRITE_APPEND: If the table already exists, BigQuery appends the data to the table.
    * WRITE_EMPTY: If the table already exists and contains data, a 'duplicate' error is returned in the job result.
    * Each action is atomic and only occurs if BigQuery is able to complete the job successfully.
    * Creation, truncation and append actions occur as one atomic update upon job completion. Default value: "WRITE_EMPTY" Possible values: ["WRITE_TRUNCATE", "WRITE_APPEND", "WRITE_EMPTY"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#write_disposition GoogleBigqueryJob#write_disposition}
    */
    readonly writeDisposition?: string;
    /**
    * destination_encryption_configuration block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#destination_encryption_configuration GoogleBigqueryJob#destination_encryption_configuration}
    */
    readonly destinationEncryptionConfiguration?: GoogleBigqueryJobCopyDestinationEncryptionConfiguration;
    /**
    * destination_table block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#destination_table GoogleBigqueryJob#destination_table}
    */
    readonly destinationTable?: GoogleBigqueryJobCopyDestinationTable;
    /**
    * source_tables block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#source_tables GoogleBigqueryJob#source_tables}
    */
    readonly sourceTables: GoogleBigqueryJobCopySourceTables[] | cdktf.IResolvable;
}
export declare function googleBigqueryJobCopyToTerraform(struct?: GoogleBigqueryJobCopyOutputReference | GoogleBigqueryJobCopy): any;
export declare function googleBigqueryJobCopyToHclTerraform(struct?: GoogleBigqueryJobCopyOutputReference | GoogleBigqueryJobCopy): any;
export declare class GoogleBigqueryJobCopyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleBigqueryJobCopy | undefined;
    set internalValue(value: GoogleBigqueryJobCopy | undefined);
    private _createDisposition?;
    get createDisposition(): string;
    set createDisposition(value: string);
    resetCreateDisposition(): void;
    get createDispositionInput(): string | undefined;
    private _writeDisposition?;
    get writeDisposition(): string;
    set writeDisposition(value: string);
    resetWriteDisposition(): void;
    get writeDispositionInput(): string | undefined;
    private _destinationEncryptionConfiguration;
    get destinationEncryptionConfiguration(): GoogleBigqueryJobCopyDestinationEncryptionConfigurationOutputReference;
    putDestinationEncryptionConfiguration(value: GoogleBigqueryJobCopyDestinationEncryptionConfiguration): void;
    resetDestinationEncryptionConfiguration(): void;
    get destinationEncryptionConfigurationInput(): GoogleBigqueryJobCopyDestinationEncryptionConfiguration | undefined;
    private _destinationTable;
    get destinationTable(): GoogleBigqueryJobCopyDestinationTableOutputReference;
    putDestinationTable(value: GoogleBigqueryJobCopyDestinationTable): void;
    resetDestinationTable(): void;
    get destinationTableInput(): GoogleBigqueryJobCopyDestinationTable | undefined;
    private _sourceTables;
    get sourceTables(): GoogleBigqueryJobCopySourceTablesList;
    putSourceTables(value: GoogleBigqueryJobCopySourceTables[] | cdktf.IResolvable): void;
    get sourceTablesInput(): cdktf.IResolvable | GoogleBigqueryJobCopySourceTables[] | undefined;
}
export interface GoogleBigqueryJobExtractSourceModel {
    /**
    * The ID of the dataset containing this model.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#dataset_id GoogleBigqueryJob#dataset_id}
    */
    readonly datasetId: string;
    /**
    * The ID of the model.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#model_id GoogleBigqueryJob#model_id}
    */
    readonly modelId: string;
    /**
    * The ID of the project containing this model.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#project_id GoogleBigqueryJob#project_id}
    */
    readonly projectId: string;
}
export declare function googleBigqueryJobExtractSourceModelToTerraform(struct?: GoogleBigqueryJobExtractSourceModelOutputReference | GoogleBigqueryJobExtractSourceModel): any;
export declare function googleBigqueryJobExtractSourceModelToHclTerraform(struct?: GoogleBigqueryJobExtractSourceModelOutputReference | GoogleBigqueryJobExtractSourceModel): any;
export declare class GoogleBigqueryJobExtractSourceModelOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleBigqueryJobExtractSourceModel | undefined;
    set internalValue(value: GoogleBigqueryJobExtractSourceModel | undefined);
    private _datasetId?;
    get datasetId(): string;
    set datasetId(value: string);
    get datasetIdInput(): string | undefined;
    private _modelId?;
    get modelId(): string;
    set modelId(value: string);
    get modelIdInput(): string | undefined;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    get projectIdInput(): string | undefined;
}
export interface GoogleBigqueryJobExtractSourceTable {
    /**
    * The ID of the dataset containing this table.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#dataset_id GoogleBigqueryJob#dataset_id}
    */
    readonly datasetId?: string;
    /**
    * The ID of the project containing this table.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#project_id GoogleBigqueryJob#project_id}
    */
    readonly projectId?: string;
    /**
    * The table. Can be specified '{{table_id}}' if 'project_id' and 'dataset_id' are also set,
    * or of the form 'projects/{{project}}/datasets/{{dataset_id}}/tables/{{table_id}}' if not.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#table_id GoogleBigqueryJob#table_id}
    */
    readonly tableId: string;
}
export declare function googleBigqueryJobExtractSourceTableToTerraform(struct?: GoogleBigqueryJobExtractSourceTableOutputReference | GoogleBigqueryJobExtractSourceTable): any;
export declare function googleBigqueryJobExtractSourceTableToHclTerraform(struct?: GoogleBigqueryJobExtractSourceTableOutputReference | GoogleBigqueryJobExtractSourceTable): any;
export declare class GoogleBigqueryJobExtractSourceTableOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleBigqueryJobExtractSourceTable | undefined;
    set internalValue(value: GoogleBigqueryJobExtractSourceTable | undefined);
    private _datasetId?;
    get datasetId(): string;
    set datasetId(value: string);
    resetDatasetId(): void;
    get datasetIdInput(): string | undefined;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    resetProjectId(): void;
    get projectIdInput(): string | undefined;
    private _tableId?;
    get tableId(): string;
    set tableId(value: string);
    get tableIdInput(): string | undefined;
}
export interface GoogleBigqueryJobExtract {
    /**
    * The compression type to use for exported files. Possible values include GZIP, DEFLATE, SNAPPY, and NONE.
    * The default value is NONE. DEFLATE and SNAPPY are only supported for Avro.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#compression GoogleBigqueryJob#compression}
    */
    readonly compression?: string;
    /**
    * The exported file format. Possible values include CSV, NEWLINE_DELIMITED_JSON and AVRO for tables and SAVED_MODEL for models.
    * The default value for tables is CSV. Tables with nested or repeated fields cannot be exported as CSV.
    * The default value for models is SAVED_MODEL.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#destination_format GoogleBigqueryJob#destination_format}
    */
    readonly destinationFormat?: string;
    /**
    * A list of fully-qualified Google Cloud Storage URIs where the extracted table should be written.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#destination_uris GoogleBigqueryJob#destination_uris}
    */
    readonly destinationUris: string[];
    /**
    * When extracting data in CSV format, this defines the delimiter to use between fields in the exported data.
    * Default is ','
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#field_delimiter GoogleBigqueryJob#field_delimiter}
    */
    readonly fieldDelimiter?: string;
    /**
    * Whether to print out a header row in the results. Default is true.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#print_header GoogleBigqueryJob#print_header}
    */
    readonly printHeader?: boolean | cdktf.IResolvable;
    /**
    * Whether to use logical types when extracting to AVRO format.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#use_avro_logical_types GoogleBigqueryJob#use_avro_logical_types}
    */
    readonly useAvroLogicalTypes?: boolean | cdktf.IResolvable;
    /**
    * source_model block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#source_model GoogleBigqueryJob#source_model}
    */
    readonly sourceModel?: GoogleBigqueryJobExtractSourceModel;
    /**
    * source_table block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#source_table GoogleBigqueryJob#source_table}
    */
    readonly sourceTable?: GoogleBigqueryJobExtractSourceTable;
}
export declare function googleBigqueryJobExtractToTerraform(struct?: GoogleBigqueryJobExtractOutputReference | GoogleBigqueryJobExtract): any;
export declare function googleBigqueryJobExtractToHclTerraform(struct?: GoogleBigqueryJobExtractOutputReference | GoogleBigqueryJobExtract): any;
export declare class GoogleBigqueryJobExtractOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleBigqueryJobExtract | undefined;
    set internalValue(value: GoogleBigqueryJobExtract | undefined);
    private _compression?;
    get compression(): string;
    set compression(value: string);
    resetCompression(): void;
    get compressionInput(): string | undefined;
    private _destinationFormat?;
    get destinationFormat(): string;
    set destinationFormat(value: string);
    resetDestinationFormat(): void;
    get destinationFormatInput(): string | undefined;
    private _destinationUris?;
    get destinationUris(): string[];
    set destinationUris(value: string[]);
    get destinationUrisInput(): string[] | undefined;
    private _fieldDelimiter?;
    get fieldDelimiter(): string;
    set fieldDelimiter(value: string);
    resetFieldDelimiter(): void;
    get fieldDelimiterInput(): string | undefined;
    private _printHeader?;
    get printHeader(): boolean | cdktf.IResolvable;
    set printHeader(value: boolean | cdktf.IResolvable);
    resetPrintHeader(): void;
    get printHeaderInput(): boolean | cdktf.IResolvable | undefined;
    private _useAvroLogicalTypes?;
    get useAvroLogicalTypes(): boolean | cdktf.IResolvable;
    set useAvroLogicalTypes(value: boolean | cdktf.IResolvable);
    resetUseAvroLogicalTypes(): void;
    get useAvroLogicalTypesInput(): boolean | cdktf.IResolvable | undefined;
    private _sourceModel;
    get sourceModel(): GoogleBigqueryJobExtractSourceModelOutputReference;
    putSourceModel(value: GoogleBigqueryJobExtractSourceModel): void;
    resetSourceModel(): void;
    get sourceModelInput(): GoogleBigqueryJobExtractSourceModel | undefined;
    private _sourceTable;
    get sourceTable(): GoogleBigqueryJobExtractSourceTableOutputReference;
    putSourceTable(value: GoogleBigqueryJobExtractSourceTable): void;
    resetSourceTable(): void;
    get sourceTableInput(): GoogleBigqueryJobExtractSourceTable | undefined;
}
export interface GoogleBigqueryJobLoadDestinationEncryptionConfiguration {
    /**
    * Describes the Cloud KMS encryption key that will be used to protect destination BigQuery table.
    * The BigQuery Service Account associated with your project requires access to this encryption key.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#kms_key_name GoogleBigqueryJob#kms_key_name}
    */
    readonly kmsKeyName: string;
}
export declare function googleBigqueryJobLoadDestinationEncryptionConfigurationToTerraform(struct?: GoogleBigqueryJobLoadDestinationEncryptionConfigurationOutputReference | GoogleBigqueryJobLoadDestinationEncryptionConfiguration): any;
export declare function googleBigqueryJobLoadDestinationEncryptionConfigurationToHclTerraform(struct?: GoogleBigqueryJobLoadDestinationEncryptionConfigurationOutputReference | GoogleBigqueryJobLoadDestinationEncryptionConfiguration): any;
export declare class GoogleBigqueryJobLoadDestinationEncryptionConfigurationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleBigqueryJobLoadDestinationEncryptionConfiguration | undefined;
    set internalValue(value: GoogleBigqueryJobLoadDestinationEncryptionConfiguration | undefined);
    private _kmsKeyName?;
    get kmsKeyName(): string;
    set kmsKeyName(value: string);
    get kmsKeyNameInput(): string | undefined;
    get kmsKeyVersion(): string;
}
export interface GoogleBigqueryJobLoadDestinationTable {
    /**
    * The ID of the dataset containing this table.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#dataset_id GoogleBigqueryJob#dataset_id}
    */
    readonly datasetId?: string;
    /**
    * The ID of the project containing this table.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#project_id GoogleBigqueryJob#project_id}
    */
    readonly projectId?: string;
    /**
    * The table. Can be specified '{{table_id}}' if 'project_id' and 'dataset_id' are also set,
    * or of the form 'projects/{{project}}/datasets/{{dataset_id}}/tables/{{table_id}}' if not.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#table_id GoogleBigqueryJob#table_id}
    */
    readonly tableId: string;
}
export declare function googleBigqueryJobLoadDestinationTableToTerraform(struct?: GoogleBigqueryJobLoadDestinationTableOutputReference | GoogleBigqueryJobLoadDestinationTable): any;
export declare function googleBigqueryJobLoadDestinationTableToHclTerraform(struct?: GoogleBigqueryJobLoadDestinationTableOutputReference | GoogleBigqueryJobLoadDestinationTable): any;
export declare class GoogleBigqueryJobLoadDestinationTableOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleBigqueryJobLoadDestinationTable | undefined;
    set internalValue(value: GoogleBigqueryJobLoadDestinationTable | undefined);
    private _datasetId?;
    get datasetId(): string;
    set datasetId(value: string);
    resetDatasetId(): void;
    get datasetIdInput(): string | undefined;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    resetProjectId(): void;
    get projectIdInput(): string | undefined;
    private _tableId?;
    get tableId(): string;
    set tableId(value: string);
    get tableIdInput(): string | undefined;
}
export interface GoogleBigqueryJobLoadParquetOptions {
    /**
    * If sourceFormat is set to PARQUET, indicates whether to use schema inference specifically for Parquet LIST logical type.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#enable_list_inference GoogleBigqueryJob#enable_list_inference}
    */
    readonly enableListInference?: boolean | cdktf.IResolvable;
    /**
    * If sourceFormat is set to PARQUET, indicates whether to infer Parquet ENUM logical type as STRING instead of BYTES by default.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#enum_as_string GoogleBigqueryJob#enum_as_string}
    */
    readonly enumAsString?: boolean | cdktf.IResolvable;
}
export declare function googleBigqueryJobLoadParquetOptionsToTerraform(struct?: GoogleBigqueryJobLoadParquetOptionsOutputReference | GoogleBigqueryJobLoadParquetOptions): any;
export declare function googleBigqueryJobLoadParquetOptionsToHclTerraform(struct?: GoogleBigqueryJobLoadParquetOptionsOutputReference | GoogleBigqueryJobLoadParquetOptions): any;
export declare class GoogleBigqueryJobLoadParquetOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleBigqueryJobLoadParquetOptions | undefined;
    set internalValue(value: GoogleBigqueryJobLoadParquetOptions | undefined);
    private _enableListInference?;
    get enableListInference(): boolean | cdktf.IResolvable;
    set enableListInference(value: boolean | cdktf.IResolvable);
    resetEnableListInference(): void;
    get enableListInferenceInput(): boolean | cdktf.IResolvable | undefined;
    private _enumAsString?;
    get enumAsString(): boolean | cdktf.IResolvable;
    set enumAsString(value: boolean | cdktf.IResolvable);
    resetEnumAsString(): void;
    get enumAsStringInput(): boolean | cdktf.IResolvable | undefined;
}
export interface GoogleBigqueryJobLoadTimePartitioning {
    /**
    * Number of milliseconds for which to keep the storage for a partition. A wrapper is used here because 0 is an invalid value.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#expiration_ms GoogleBigqueryJob#expiration_ms}
    */
    readonly expirationMs?: string;
    /**
    * If not set, the table is partitioned by pseudo column '_PARTITIONTIME'; if set, the table is partitioned by this field.
    * The field must be a top-level TIMESTAMP or DATE field. Its mode must be NULLABLE or REQUIRED.
    * A wrapper is used here because an empty string is an invalid value.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#field GoogleBigqueryJob#field}
    */
    readonly field?: string;
    /**
    * The only type supported is DAY, which will generate one partition per day. Providing an empty string used to cause an error,
    * but in OnePlatform the field will be treated as unset.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#type GoogleBigqueryJob#type}
    */
    readonly type: string;
}
export declare function googleBigqueryJobLoadTimePartitioningToTerraform(struct?: GoogleBigqueryJobLoadTimePartitioningOutputReference | GoogleBigqueryJobLoadTimePartitioning): any;
export declare function googleBigqueryJobLoadTimePartitioningToHclTerraform(struct?: GoogleBigqueryJobLoadTimePartitioningOutputReference | GoogleBigqueryJobLoadTimePartitioning): any;
export declare class GoogleBigqueryJobLoadTimePartitioningOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleBigqueryJobLoadTimePartitioning | undefined;
    set internalValue(value: GoogleBigqueryJobLoadTimePartitioning | undefined);
    private _expirationMs?;
    get expirationMs(): string;
    set expirationMs(value: string);
    resetExpirationMs(): void;
    get expirationMsInput(): string | undefined;
    private _field?;
    get field(): string;
    set field(value: string);
    resetField(): void;
    get fieldInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
}
export interface GoogleBigqueryJobLoad {
    /**
    * Accept rows that are missing trailing optional columns. The missing values are treated as nulls.
    * If false, records with missing trailing columns are treated as bad records, and if there are too many bad records,
    * an invalid error is returned in the job result. The default value is false. Only applicable to CSV, ignored for other formats.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#allow_jagged_rows GoogleBigqueryJob#allow_jagged_rows}
    */
    readonly allowJaggedRows?: boolean | cdktf.IResolvable;
    /**
    * Indicates if BigQuery should allow quoted data sections that contain newline characters in a CSV file.
    * The default value is false.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#allow_quoted_newlines GoogleBigqueryJob#allow_quoted_newlines}
    */
    readonly allowQuotedNewlines?: boolean | cdktf.IResolvable;
    /**
    * Indicates if we should automatically infer the options and schema for CSV and JSON sources.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#autodetect GoogleBigqueryJob#autodetect}
    */
    readonly autodetect?: boolean | cdktf.IResolvable;
    /**
    * Specifies whether the job is allowed to create new tables. The following values are supported:
    * CREATE_IF_NEEDED: If the table does not exist, BigQuery creates the table.
    * CREATE_NEVER: The table must already exist. If it does not, a 'notFound' error is returned in the job result.
    * Creation, truncation and append actions occur as one atomic update upon job completion Default value: "CREATE_IF_NEEDED" Possible values: ["CREATE_IF_NEEDED", "CREATE_NEVER"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#create_disposition GoogleBigqueryJob#create_disposition}
    */
    readonly createDisposition?: string;
    /**
    * The character encoding of the data. The supported values are UTF-8 or ISO-8859-1.
    * The default value is UTF-8. BigQuery decodes the data after the raw, binary data
    * has been split using the values of the quote and fieldDelimiter properties.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#encoding GoogleBigqueryJob#encoding}
    */
    readonly encoding?: string;
    /**
    * The separator for fields in a CSV file. The separator can be any ISO-8859-1 single-byte character.
    * To use a character in the range 128-255, you must encode the character as UTF8. BigQuery converts
    * the string to ISO-8859-1 encoding, and then uses the first byte of the encoded string to split the
    * data in its raw, binary state. BigQuery also supports the escape sequence "\t" to specify a tab separator.
    * The default value is a comma (',').
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#field_delimiter GoogleBigqueryJob#field_delimiter}
    */
    readonly fieldDelimiter?: string;
    /**
    * Indicates if BigQuery should allow extra values that are not represented in the table schema.
    * If true, the extra values are ignored. If false, records with extra columns are treated as bad records,
    * and if there are too many bad records, an invalid error is returned in the job result.
    * The default value is false. The sourceFormat property determines what BigQuery treats as an extra value:
    * CSV: Trailing columns
    * JSON: Named values that don't match any column names
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#ignore_unknown_values GoogleBigqueryJob#ignore_unknown_values}
    */
    readonly ignoreUnknownValues?: boolean | cdktf.IResolvable;
    /**
    * If sourceFormat is set to newline-delimited JSON, indicates whether it should be processed as a JSON variant such as GeoJSON.
    * For a sourceFormat other than JSON, omit this field. If the sourceFormat is newline-delimited JSON: - for newline-delimited
    * GeoJSON: set to GEOJSON.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#json_extension GoogleBigqueryJob#json_extension}
    */
    readonly jsonExtension?: string;
    /**
    * The maximum number of bad records that BigQuery can ignore when running the job. If the number of bad records exceeds this value,
    * an invalid error is returned in the job result. The default value is 0, which requires that all records are valid.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#max_bad_records GoogleBigqueryJob#max_bad_records}
    */
    readonly maxBadRecords?: number;
    /**
    * Specifies a string that represents a null value in a CSV file. For example, if you specify "\N", BigQuery interprets "\N" as a null value
    * when loading a CSV file. The default value is the empty string. If you set this property to a custom value, BigQuery throws an error if an
    * empty string is present for all data types except for STRING and BYTE. For STRING and BYTE columns, BigQuery interprets the empty string as
    * an empty value.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#null_marker GoogleBigqueryJob#null_marker}
    */
    readonly nullMarker?: string;
    /**
    * If sourceFormat is set to "DATASTORE_BACKUP", indicates which entity properties to load into BigQuery from a Cloud Datastore backup.
    * Property names are case sensitive and must be top-level properties. If no properties are specified, BigQuery loads all properties.
    * If any named property isn't found in the Cloud Datastore backup, an invalid error is returned in the job result.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#projection_fields GoogleBigqueryJob#projection_fields}
    */
    readonly projectionFields?: string[];
    /**
    * The value that is used to quote data sections in a CSV file. BigQuery converts the string to ISO-8859-1 encoding,
    * and then uses the first byte of the encoded string to split the data in its raw, binary state.
    * The default value is a double-quote ('"'). If your data does not contain quoted sections, set the property value to an empty string.
    * If your data contains quoted newline characters, you must also set the allowQuotedNewlines property to true.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#quote GoogleBigqueryJob#quote}
    */
    readonly quote?: string;
    /**
    * Allows the schema of the destination table to be updated as a side effect of the load job if a schema is autodetected or
    * supplied in the job configuration. Schema update options are supported in two cases: when writeDisposition is WRITE_APPEND;
    * when writeDisposition is WRITE_TRUNCATE and the destination table is a partition of a table, specified by partition decorators.
    * For normal tables, WRITE_TRUNCATE will always overwrite the schema. One or more of the following values are specified:
    * ALLOW_FIELD_ADDITION: allow adding a nullable field to the schema.
    * ALLOW_FIELD_RELAXATION: allow relaxing a required field in the original schema to nullable.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#schema_update_options GoogleBigqueryJob#schema_update_options}
    */
    readonly schemaUpdateOptions?: string[];
    /**
    * The number of rows at the top of a CSV file that BigQuery will skip when loading the data.
    * The default value is 0. This property is useful if you have header rows in the file that should be skipped.
    * When autodetect is on, the behavior is the following:
    * skipLeadingRows unspecified - Autodetect tries to detect headers in the first row. If they are not detected,
    * the row is read as data. Otherwise data is read starting from the second row.
    * skipLeadingRows is 0 - Instructs autodetect that there are no headers and data should be read starting from the first row.
    * skipLeadingRows = N > 0 - Autodetect skips N-1 rows and tries to detect headers in row N. If headers are not detected,
    * row N is just skipped. Otherwise row N is used to extract column names for the detected schema.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#skip_leading_rows GoogleBigqueryJob#skip_leading_rows}
    */
    readonly skipLeadingRows?: number;
    /**
    * The format of the data files. For CSV files, specify "CSV". For datastore backups, specify "DATASTORE_BACKUP".
    * For newline-delimited JSON, specify "NEWLINE_DELIMITED_JSON". For Avro, specify "AVRO". For parquet, specify "PARQUET".
    * For orc, specify "ORC". [Beta] For Bigtable, specify "BIGTABLE".
    * The default value is CSV.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#source_format GoogleBigqueryJob#source_format}
    */
    readonly sourceFormat?: string;
    /**
    * The fully-qualified URIs that point to your data in Google Cloud.
    * For Google Cloud Storage URIs: Each URI can contain one '\*' wildcard character
    * and it must come after the 'bucket' name. Size limits related to load jobs apply
    * to external data sources. For Google Cloud Bigtable URIs: Exactly one URI can be
    * specified and it has be a fully specified and valid HTTPS URL for a Google Cloud Bigtable table.
    * For Google Cloud Datastore backups: Exactly one URI can be specified. Also, the '\*' wildcard character is not allowed.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#source_uris GoogleBigqueryJob#source_uris}
    */
    readonly sourceUris: string[];
    /**
    * Specifies the action that occurs if the destination table already exists. The following values are supported:
    * WRITE_TRUNCATE: If the table already exists, BigQuery overwrites the table data and uses the schema from the query result.
    * WRITE_APPEND: If the table already exists, BigQuery appends the data to the table.
    * WRITE_EMPTY: If the table already exists and contains data, a 'duplicate' error is returned in the job result.
    * Each action is atomic and only occurs if BigQuery is able to complete the job successfully.
    * Creation, truncation and append actions occur as one atomic update upon job completion. Default value: "WRITE_EMPTY" Possible values: ["WRITE_TRUNCATE", "WRITE_APPEND", "WRITE_EMPTY"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#write_disposition GoogleBigqueryJob#write_disposition}
    */
    readonly writeDisposition?: string;
    /**
    * destination_encryption_configuration block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#destination_encryption_configuration GoogleBigqueryJob#destination_encryption_configuration}
    */
    readonly destinationEncryptionConfiguration?: GoogleBigqueryJobLoadDestinationEncryptionConfiguration;
    /**
    * destination_table block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#destination_table GoogleBigqueryJob#destination_table}
    */
    readonly destinationTable: GoogleBigqueryJobLoadDestinationTable;
    /**
    * parquet_options block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#parquet_options GoogleBigqueryJob#parquet_options}
    */
    readonly parquetOptions?: GoogleBigqueryJobLoadParquetOptions;
    /**
    * time_partitioning block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#time_partitioning GoogleBigqueryJob#time_partitioning}
    */
    readonly timePartitioning?: GoogleBigqueryJobLoadTimePartitioning;
}
export declare function googleBigqueryJobLoadToTerraform(struct?: GoogleBigqueryJobLoadOutputReference | GoogleBigqueryJobLoad): any;
export declare function googleBigqueryJobLoadToHclTerraform(struct?: GoogleBigqueryJobLoadOutputReference | GoogleBigqueryJobLoad): any;
export declare class GoogleBigqueryJobLoadOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleBigqueryJobLoad | undefined;
    set internalValue(value: GoogleBigqueryJobLoad | undefined);
    private _allowJaggedRows?;
    get allowJaggedRows(): boolean | cdktf.IResolvable;
    set allowJaggedRows(value: boolean | cdktf.IResolvable);
    resetAllowJaggedRows(): void;
    get allowJaggedRowsInput(): boolean | cdktf.IResolvable | undefined;
    private _allowQuotedNewlines?;
    get allowQuotedNewlines(): boolean | cdktf.IResolvable;
    set allowQuotedNewlines(value: boolean | cdktf.IResolvable);
    resetAllowQuotedNewlines(): void;
    get allowQuotedNewlinesInput(): boolean | cdktf.IResolvable | undefined;
    private _autodetect?;
    get autodetect(): boolean | cdktf.IResolvable;
    set autodetect(value: boolean | cdktf.IResolvable);
    resetAutodetect(): void;
    get autodetectInput(): boolean | cdktf.IResolvable | undefined;
    private _createDisposition?;
    get createDisposition(): string;
    set createDisposition(value: string);
    resetCreateDisposition(): void;
    get createDispositionInput(): string | undefined;
    private _encoding?;
    get encoding(): string;
    set encoding(value: string);
    resetEncoding(): void;
    get encodingInput(): string | undefined;
    private _fieldDelimiter?;
    get fieldDelimiter(): string;
    set fieldDelimiter(value: string);
    resetFieldDelimiter(): void;
    get fieldDelimiterInput(): string | undefined;
    private _ignoreUnknownValues?;
    get ignoreUnknownValues(): boolean | cdktf.IResolvable;
    set ignoreUnknownValues(value: boolean | cdktf.IResolvable);
    resetIgnoreUnknownValues(): void;
    get ignoreUnknownValuesInput(): boolean | cdktf.IResolvable | undefined;
    private _jsonExtension?;
    get jsonExtension(): string;
    set jsonExtension(value: string);
    resetJsonExtension(): void;
    get jsonExtensionInput(): string | undefined;
    private _maxBadRecords?;
    get maxBadRecords(): number;
    set maxBadRecords(value: number);
    resetMaxBadRecords(): void;
    get maxBadRecordsInput(): number | undefined;
    private _nullMarker?;
    get nullMarker(): string;
    set nullMarker(value: string);
    resetNullMarker(): void;
    get nullMarkerInput(): string | undefined;
    private _projectionFields?;
    get projectionFields(): string[];
    set projectionFields(value: string[]);
    resetProjectionFields(): void;
    get projectionFieldsInput(): string[] | undefined;
    private _quote?;
    get quote(): string;
    set quote(value: string);
    resetQuote(): void;
    get quoteInput(): string | undefined;
    private _schemaUpdateOptions?;
    get schemaUpdateOptions(): string[];
    set schemaUpdateOptions(value: string[]);
    resetSchemaUpdateOptions(): void;
    get schemaUpdateOptionsInput(): string[] | undefined;
    private _skipLeadingRows?;
    get skipLeadingRows(): number;
    set skipLeadingRows(value: number);
    resetSkipLeadingRows(): void;
    get skipLeadingRowsInput(): number | undefined;
    private _sourceFormat?;
    get sourceFormat(): string;
    set sourceFormat(value: string);
    resetSourceFormat(): void;
    get sourceFormatInput(): string | undefined;
    private _sourceUris?;
    get sourceUris(): string[];
    set sourceUris(value: string[]);
    get sourceUrisInput(): string[] | undefined;
    private _writeDisposition?;
    get writeDisposition(): string;
    set writeDisposition(value: string);
    resetWriteDisposition(): void;
    get writeDispositionInput(): string | undefined;
    private _destinationEncryptionConfiguration;
    get destinationEncryptionConfiguration(): GoogleBigqueryJobLoadDestinationEncryptionConfigurationOutputReference;
    putDestinationEncryptionConfiguration(value: GoogleBigqueryJobLoadDestinationEncryptionConfiguration): void;
    resetDestinationEncryptionConfiguration(): void;
    get destinationEncryptionConfigurationInput(): GoogleBigqueryJobLoadDestinationEncryptionConfiguration | undefined;
    private _destinationTable;
    get destinationTable(): GoogleBigqueryJobLoadDestinationTableOutputReference;
    putDestinationTable(value: GoogleBigqueryJobLoadDestinationTable): void;
    get destinationTableInput(): GoogleBigqueryJobLoadDestinationTable | undefined;
    private _parquetOptions;
    get parquetOptions(): GoogleBigqueryJobLoadParquetOptionsOutputReference;
    putParquetOptions(value: GoogleBigqueryJobLoadParquetOptions): void;
    resetParquetOptions(): void;
    get parquetOptionsInput(): GoogleBigqueryJobLoadParquetOptions | undefined;
    private _timePartitioning;
    get timePartitioning(): GoogleBigqueryJobLoadTimePartitioningOutputReference;
    putTimePartitioning(value: GoogleBigqueryJobLoadTimePartitioning): void;
    resetTimePartitioning(): void;
    get timePartitioningInput(): GoogleBigqueryJobLoadTimePartitioning | undefined;
}
export interface GoogleBigqueryJobQueryDefaultDataset {
    /**
    * The dataset. Can be specified '{{dataset_id}}' if 'project_id' is also set,
    * or of the form 'projects/{{project}}/datasets/{{dataset_id}}' if not.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#dataset_id GoogleBigqueryJob#dataset_id}
    */
    readonly datasetId: string;
    /**
    * The ID of the project containing this table.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#project_id GoogleBigqueryJob#project_id}
    */
    readonly projectId?: string;
}
export declare function googleBigqueryJobQueryDefaultDatasetToTerraform(struct?: GoogleBigqueryJobQueryDefaultDatasetOutputReference | GoogleBigqueryJobQueryDefaultDataset): any;
export declare function googleBigqueryJobQueryDefaultDatasetToHclTerraform(struct?: GoogleBigqueryJobQueryDefaultDatasetOutputReference | GoogleBigqueryJobQueryDefaultDataset): any;
export declare class GoogleBigqueryJobQueryDefaultDatasetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleBigqueryJobQueryDefaultDataset | undefined;
    set internalValue(value: GoogleBigqueryJobQueryDefaultDataset | undefined);
    private _datasetId?;
    get datasetId(): string;
    set datasetId(value: string);
    get datasetIdInput(): string | undefined;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    resetProjectId(): void;
    get projectIdInput(): string | undefined;
}
export interface GoogleBigqueryJobQueryDestinationEncryptionConfiguration {
    /**
    * Describes the Cloud KMS encryption key that will be used to protect destination BigQuery table.
    * The BigQuery Service Account associated with your project requires access to this encryption key.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#kms_key_name GoogleBigqueryJob#kms_key_name}
    */
    readonly kmsKeyName: string;
}
export declare function googleBigqueryJobQueryDestinationEncryptionConfigurationToTerraform(struct?: GoogleBigqueryJobQueryDestinationEncryptionConfigurationOutputReference | GoogleBigqueryJobQueryDestinationEncryptionConfiguration): any;
export declare function googleBigqueryJobQueryDestinationEncryptionConfigurationToHclTerraform(struct?: GoogleBigqueryJobQueryDestinationEncryptionConfigurationOutputReference | GoogleBigqueryJobQueryDestinationEncryptionConfiguration): any;
export declare class GoogleBigqueryJobQueryDestinationEncryptionConfigurationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleBigqueryJobQueryDestinationEncryptionConfiguration | undefined;
    set internalValue(value: GoogleBigqueryJobQueryDestinationEncryptionConfiguration | undefined);
    private _kmsKeyName?;
    get kmsKeyName(): string;
    set kmsKeyName(value: string);
    get kmsKeyNameInput(): string | undefined;
    get kmsKeyVersion(): string;
}
export interface GoogleBigqueryJobQueryDestinationTable {
    /**
    * The ID of the dataset containing this table.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#dataset_id GoogleBigqueryJob#dataset_id}
    */
    readonly datasetId?: string;
    /**
    * The ID of the project containing this table.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#project_id GoogleBigqueryJob#project_id}
    */
    readonly projectId?: string;
    /**
    * The table. Can be specified '{{table_id}}' if 'project_id' and 'dataset_id' are also set,
    * or of the form 'projects/{{project}}/datasets/{{dataset_id}}/tables/{{table_id}}' if not.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#table_id GoogleBigqueryJob#table_id}
    */
    readonly tableId: string;
}
export declare function googleBigqueryJobQueryDestinationTableToTerraform(struct?: GoogleBigqueryJobQueryDestinationTableOutputReference | GoogleBigqueryJobQueryDestinationTable): any;
export declare function googleBigqueryJobQueryDestinationTableToHclTerraform(struct?: GoogleBigqueryJobQueryDestinationTableOutputReference | GoogleBigqueryJobQueryDestinationTable): any;
export declare class GoogleBigqueryJobQueryDestinationTableOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleBigqueryJobQueryDestinationTable | undefined;
    set internalValue(value: GoogleBigqueryJobQueryDestinationTable | undefined);
    private _datasetId?;
    get datasetId(): string;
    set datasetId(value: string);
    resetDatasetId(): void;
    get datasetIdInput(): string | undefined;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    resetProjectId(): void;
    get projectIdInput(): string | undefined;
    private _tableId?;
    get tableId(): string;
    set tableId(value: string);
    get tableIdInput(): string | undefined;
}
export interface GoogleBigqueryJobQueryScriptOptions {
    /**
    * Determines which statement in the script represents the "key result",
    * used to populate the schema and query results of the script job. Possible values: ["LAST", "FIRST_SELECT"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#key_result_statement GoogleBigqueryJob#key_result_statement}
    */
    readonly keyResultStatement?: string;
    /**
    * Limit on the number of bytes billed per statement. Exceeding this budget results in an error.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#statement_byte_budget GoogleBigqueryJob#statement_byte_budget}
    */
    readonly statementByteBudget?: string;
    /**
    * Timeout period for each statement in a script.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#statement_timeout_ms GoogleBigqueryJob#statement_timeout_ms}
    */
    readonly statementTimeoutMs?: string;
}
export declare function googleBigqueryJobQueryScriptOptionsToTerraform(struct?: GoogleBigqueryJobQueryScriptOptionsOutputReference | GoogleBigqueryJobQueryScriptOptions): any;
export declare function googleBigqueryJobQueryScriptOptionsToHclTerraform(struct?: GoogleBigqueryJobQueryScriptOptionsOutputReference | GoogleBigqueryJobQueryScriptOptions): any;
export declare class GoogleBigqueryJobQueryScriptOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleBigqueryJobQueryScriptOptions | undefined;
    set internalValue(value: GoogleBigqueryJobQueryScriptOptions | undefined);
    private _keyResultStatement?;
    get keyResultStatement(): string;
    set keyResultStatement(value: string);
    resetKeyResultStatement(): void;
    get keyResultStatementInput(): string | undefined;
    private _statementByteBudget?;
    get statementByteBudget(): string;
    set statementByteBudget(value: string);
    resetStatementByteBudget(): void;
    get statementByteBudgetInput(): string | undefined;
    private _statementTimeoutMs?;
    get statementTimeoutMs(): string;
    set statementTimeoutMs(value: string);
    resetStatementTimeoutMs(): void;
    get statementTimeoutMsInput(): string | undefined;
}
export interface GoogleBigqueryJobQueryUserDefinedFunctionResources {
    /**
    * An inline resource that contains code for a user-defined function (UDF).
    * Providing a inline code resource is equivalent to providing a URI for a file containing the same code.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#inline_code GoogleBigqueryJob#inline_code}
    */
    readonly inlineCode?: string;
    /**
    * A code resource to load from a Google Cloud Storage URI (gs://bucket/path).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#resource_uri GoogleBigqueryJob#resource_uri}
    */
    readonly resourceUri?: string;
}
export declare function googleBigqueryJobQueryUserDefinedFunctionResourcesToTerraform(struct?: GoogleBigqueryJobQueryUserDefinedFunctionResources | cdktf.IResolvable): any;
export declare function googleBigqueryJobQueryUserDefinedFunctionResourcesToHclTerraform(struct?: GoogleBigqueryJobQueryUserDefinedFunctionResources | cdktf.IResolvable): any;
export declare class GoogleBigqueryJobQueryUserDefinedFunctionResourcesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleBigqueryJobQueryUserDefinedFunctionResources | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleBigqueryJobQueryUserDefinedFunctionResources | cdktf.IResolvable | undefined);
    private _inlineCode?;
    get inlineCode(): string;
    set inlineCode(value: string);
    resetInlineCode(): void;
    get inlineCodeInput(): string | undefined;
    private _resourceUri?;
    get resourceUri(): string;
    set resourceUri(value: string);
    resetResourceUri(): void;
    get resourceUriInput(): string | undefined;
}
export declare class GoogleBigqueryJobQueryUserDefinedFunctionResourcesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleBigqueryJobQueryUserDefinedFunctionResources[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleBigqueryJobQueryUserDefinedFunctionResourcesOutputReference;
}
export interface GoogleBigqueryJobQuery {
    /**
    * If true and query uses legacy SQL dialect, allows the query to produce arbitrarily large result tables at a slight cost in performance.
    * Requires destinationTable to be set. For standard SQL queries, this flag is ignored and large results are always allowed.
    * However, you must still set destinationTable when result size exceeds the allowed maximum response size.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#allow_large_results GoogleBigqueryJob#allow_large_results}
    */
    readonly allowLargeResults?: boolean | cdktf.IResolvable;
    /**
    * Specifies whether the job is allowed to create new tables. The following values are supported:
    * CREATE_IF_NEEDED: If the table does not exist, BigQuery creates the table.
    * CREATE_NEVER: The table must already exist. If it does not, a 'notFound' error is returned in the job result.
    * Creation, truncation and append actions occur as one atomic update upon job completion Default value: "CREATE_IF_NEEDED" Possible values: ["CREATE_IF_NEEDED", "CREATE_NEVER"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#create_disposition GoogleBigqueryJob#create_disposition}
    */
    readonly createDisposition?: string;
    /**
    * If true and query uses legacy SQL dialect, flattens all nested and repeated fields in the query results.
    * allowLargeResults must be true if this is set to false. For standard SQL queries, this flag is ignored and results are never flattened.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#flatten_results GoogleBigqueryJob#flatten_results}
    */
    readonly flattenResults?: boolean | cdktf.IResolvable;
    /**
    * Limits the billing tier for this job. Queries that have resource usage beyond this tier will fail (without incurring a charge).
    * If unspecified, this will be set to your project default.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#maximum_billing_tier GoogleBigqueryJob#maximum_billing_tier}
    */
    readonly maximumBillingTier?: number;
    /**
    * Limits the bytes billed for this job. Queries that will have bytes billed beyond this limit will fail (without incurring a charge).
    * If unspecified, this will be set to your project default.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#maximum_bytes_billed GoogleBigqueryJob#maximum_bytes_billed}
    */
    readonly maximumBytesBilled?: string;
    /**
    * Standard SQL only. Set to POSITIONAL to use positional (?) query parameters or to NAMED to use named (@myparam) query parameters in this query.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#parameter_mode GoogleBigqueryJob#parameter_mode}
    */
    readonly parameterMode?: string;
    /**
    * Specifies a priority for the query. Default value: "INTERACTIVE" Possible values: ["INTERACTIVE", "BATCH"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#priority GoogleBigqueryJob#priority}
    */
    readonly priority?: string;
    /**
    * SQL query text to execute. The useLegacySql field can be used to indicate whether the query uses legacy SQL or standard SQL.
    * *NOTE*: queries containing [DML language](https://cloud.google.com/bigquery/docs/reference/standard-sql/data-manipulation-language)
    * ('DELETE', 'UPDATE', 'MERGE', 'INSERT') must specify 'create_disposition = ""' and 'write_disposition = ""'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#query GoogleBigqueryJob#query}
    */
    readonly query: string;
    /**
    * Allows the schema of the destination table to be updated as a side effect of the query job.
    * Schema update options are supported in two cases: when writeDisposition is WRITE_APPEND;
    * when writeDisposition is WRITE_TRUNCATE and the destination table is a partition of a table,
    * specified by partition decorators. For normal tables, WRITE_TRUNCATE will always overwrite the schema.
    * One or more of the following values are specified:
    * ALLOW_FIELD_ADDITION: allow adding a nullable field to the schema.
    * ALLOW_FIELD_RELAXATION: allow relaxing a required field in the original schema to nullable.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#schema_update_options GoogleBigqueryJob#schema_update_options}
    */
    readonly schemaUpdateOptions?: string[];
    /**
    * Specifies whether to use BigQuery's legacy SQL dialect for this query. The default value is true.
    * If set to false, the query will use BigQuery's standard SQL.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#use_legacy_sql GoogleBigqueryJob#use_legacy_sql}
    */
    readonly useLegacySql?: boolean | cdktf.IResolvable;
    /**
    * Whether to look for the result in the query cache. The query cache is a best-effort cache that will be flushed whenever
    * tables in the query are modified. Moreover, the query cache is only available when a query does not have a destination table specified.
    * The default value is true.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#use_query_cache GoogleBigqueryJob#use_query_cache}
    */
    readonly useQueryCache?: boolean | cdktf.IResolvable;
    /**
    * Specifies the action that occurs if the destination table already exists. The following values are supported:
    * WRITE_TRUNCATE: If the table already exists, BigQuery overwrites the table data and uses the schema from the query result.
    * WRITE_APPEND: If the table already exists, BigQuery appends the data to the table.
    * WRITE_EMPTY: If the table already exists and contains data, a 'duplicate' error is returned in the job result.
    * Each action is atomic and only occurs if BigQuery is able to complete the job successfully.
    * Creation, truncation and append actions occur as one atomic update upon job completion. Default value: "WRITE_EMPTY" Possible values: ["WRITE_TRUNCATE", "WRITE_APPEND", "WRITE_EMPTY"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#write_disposition GoogleBigqueryJob#write_disposition}
    */
    readonly writeDisposition?: string;
    /**
    * default_dataset block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#default_dataset GoogleBigqueryJob#default_dataset}
    */
    readonly defaultDataset?: GoogleBigqueryJobQueryDefaultDataset;
    /**
    * destination_encryption_configuration block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#destination_encryption_configuration GoogleBigqueryJob#destination_encryption_configuration}
    */
    readonly destinationEncryptionConfiguration?: GoogleBigqueryJobQueryDestinationEncryptionConfiguration;
    /**
    * destination_table block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#destination_table GoogleBigqueryJob#destination_table}
    */
    readonly destinationTable?: GoogleBigqueryJobQueryDestinationTable;
    /**
    * script_options block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#script_options GoogleBigqueryJob#script_options}
    */
    readonly scriptOptions?: GoogleBigqueryJobQueryScriptOptions;
    /**
    * user_defined_function_resources block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#user_defined_function_resources GoogleBigqueryJob#user_defined_function_resources}
    */
    readonly userDefinedFunctionResources?: GoogleBigqueryJobQueryUserDefinedFunctionResources[] | cdktf.IResolvable;
}
export declare function googleBigqueryJobQueryToTerraform(struct?: GoogleBigqueryJobQueryOutputReference | GoogleBigqueryJobQuery): any;
export declare function googleBigqueryJobQueryToHclTerraform(struct?: GoogleBigqueryJobQueryOutputReference | GoogleBigqueryJobQuery): any;
export declare class GoogleBigqueryJobQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleBigqueryJobQuery | undefined;
    set internalValue(value: GoogleBigqueryJobQuery | undefined);
    private _allowLargeResults?;
    get allowLargeResults(): boolean | cdktf.IResolvable;
    set allowLargeResults(value: boolean | cdktf.IResolvable);
    resetAllowLargeResults(): void;
    get allowLargeResultsInput(): boolean | cdktf.IResolvable | undefined;
    private _createDisposition?;
    get createDisposition(): string;
    set createDisposition(value: string);
    resetCreateDisposition(): void;
    get createDispositionInput(): string | undefined;
    private _flattenResults?;
    get flattenResults(): boolean | cdktf.IResolvable;
    set flattenResults(value: boolean | cdktf.IResolvable);
    resetFlattenResults(): void;
    get flattenResultsInput(): boolean | cdktf.IResolvable | undefined;
    private _maximumBillingTier?;
    get maximumBillingTier(): number;
    set maximumBillingTier(value: number);
    resetMaximumBillingTier(): void;
    get maximumBillingTierInput(): number | undefined;
    private _maximumBytesBilled?;
    get maximumBytesBilled(): string;
    set maximumBytesBilled(value: string);
    resetMaximumBytesBilled(): void;
    get maximumBytesBilledInput(): string | undefined;
    private _parameterMode?;
    get parameterMode(): string;
    set parameterMode(value: string);
    resetParameterMode(): void;
    get parameterModeInput(): string | undefined;
    private _priority?;
    get priority(): string;
    set priority(value: string);
    resetPriority(): void;
    get priorityInput(): string | undefined;
    private _query?;
    get query(): string;
    set query(value: string);
    get queryInput(): string | undefined;
    private _schemaUpdateOptions?;
    get schemaUpdateOptions(): string[];
    set schemaUpdateOptions(value: string[]);
    resetSchemaUpdateOptions(): void;
    get schemaUpdateOptionsInput(): string[] | undefined;
    private _useLegacySql?;
    get useLegacySql(): boolean | cdktf.IResolvable;
    set useLegacySql(value: boolean | cdktf.IResolvable);
    resetUseLegacySql(): void;
    get useLegacySqlInput(): boolean | cdktf.IResolvable | undefined;
    private _useQueryCache?;
    get useQueryCache(): boolean | cdktf.IResolvable;
    set useQueryCache(value: boolean | cdktf.IResolvable);
    resetUseQueryCache(): void;
    get useQueryCacheInput(): boolean | cdktf.IResolvable | undefined;
    private _writeDisposition?;
    get writeDisposition(): string;
    set writeDisposition(value: string);
    resetWriteDisposition(): void;
    get writeDispositionInput(): string | undefined;
    private _defaultDataset;
    get defaultDataset(): GoogleBigqueryJobQueryDefaultDatasetOutputReference;
    putDefaultDataset(value: GoogleBigqueryJobQueryDefaultDataset): void;
    resetDefaultDataset(): void;
    get defaultDatasetInput(): GoogleBigqueryJobQueryDefaultDataset | undefined;
    private _destinationEncryptionConfiguration;
    get destinationEncryptionConfiguration(): GoogleBigqueryJobQueryDestinationEncryptionConfigurationOutputReference;
    putDestinationEncryptionConfiguration(value: GoogleBigqueryJobQueryDestinationEncryptionConfiguration): void;
    resetDestinationEncryptionConfiguration(): void;
    get destinationEncryptionConfigurationInput(): GoogleBigqueryJobQueryDestinationEncryptionConfiguration | undefined;
    private _destinationTable;
    get destinationTable(): GoogleBigqueryJobQueryDestinationTableOutputReference;
    putDestinationTable(value: GoogleBigqueryJobQueryDestinationTable): void;
    resetDestinationTable(): void;
    get destinationTableInput(): GoogleBigqueryJobQueryDestinationTable | undefined;
    private _scriptOptions;
    get scriptOptions(): GoogleBigqueryJobQueryScriptOptionsOutputReference;
    putScriptOptions(value: GoogleBigqueryJobQueryScriptOptions): void;
    resetScriptOptions(): void;
    get scriptOptionsInput(): GoogleBigqueryJobQueryScriptOptions | undefined;
    private _userDefinedFunctionResources;
    get userDefinedFunctionResources(): GoogleBigqueryJobQueryUserDefinedFunctionResourcesList;
    putUserDefinedFunctionResources(value: GoogleBigqueryJobQueryUserDefinedFunctionResources[] | cdktf.IResolvable): void;
    resetUserDefinedFunctionResources(): void;
    get userDefinedFunctionResourcesInput(): cdktf.IResolvable | GoogleBigqueryJobQueryUserDefinedFunctionResources[] | undefined;
}
export interface GoogleBigqueryJobTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#create GoogleBigqueryJob#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#delete GoogleBigqueryJob#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#update GoogleBigqueryJob#update}
    */
    readonly update?: string;
}
export declare function googleBigqueryJobTimeoutsToTerraform(struct?: GoogleBigqueryJobTimeouts | cdktf.IResolvable): any;
export declare function googleBigqueryJobTimeoutsToHclTerraform(struct?: GoogleBigqueryJobTimeouts | cdktf.IResolvable): any;
export declare class GoogleBigqueryJobTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleBigqueryJobTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleBigqueryJobTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job google_bigquery_job}
*/
export declare class GoogleBigqueryJob extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_bigquery_job";
    /**
    * Generates CDKTF code for importing a GoogleBigqueryJob resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleBigqueryJob to import
    * @param importFromId The id of the existing GoogleBigqueryJob that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleBigqueryJob to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_bigquery_job google_bigquery_job} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleBigqueryJobConfig
    */
    constructor(scope: Construct, id: string, config: GoogleBigqueryJobConfig);
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _jobId?;
    get jobId(): string;
    set jobId(value: string);
    get jobIdInput(): string | undefined;
    private _jobTimeoutMs?;
    get jobTimeoutMs(): string;
    set jobTimeoutMs(value: string);
    resetJobTimeoutMs(): void;
    get jobTimeoutMsInput(): string | undefined;
    get jobType(): string;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    resetLocation(): void;
    get locationInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _status;
    get status(): GoogleBigqueryJobStatusList;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    get userEmail(): string;
    private _copy;
    get copy(): GoogleBigqueryJobCopyOutputReference;
    putCopy(value: GoogleBigqueryJobCopy): void;
    resetCopy(): void;
    get copyInput(): GoogleBigqueryJobCopy | undefined;
    private _extract;
    get extract(): GoogleBigqueryJobExtractOutputReference;
    putExtract(value: GoogleBigqueryJobExtract): void;
    resetExtract(): void;
    get extractInput(): GoogleBigqueryJobExtract | undefined;
    private _load;
    get load(): GoogleBigqueryJobLoadOutputReference;
    putLoad(value: GoogleBigqueryJobLoad): void;
    resetLoad(): void;
    get loadInput(): GoogleBigqueryJobLoad | undefined;
    private _query;
    get query(): GoogleBigqueryJobQueryOutputReference;
    putQuery(value: GoogleBigqueryJobQuery): void;
    resetQuery(): void;
    get queryInput(): GoogleBigqueryJobQuery | undefined;
    private _timeouts;
    get timeouts(): GoogleBigqueryJobTimeoutsOutputReference;
    putTimeouts(value: GoogleBigqueryJobTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleBigqueryJobTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
