/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleCloudTasksQueueConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_cloud_tasks_queue#id GoogleCloudTasksQueue#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The location of the queue
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_cloud_tasks_queue#location GoogleCloudTasksQueue#location}
    */
    readonly location: string;
    /**
    * The queue name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_cloud_tasks_queue#name GoogleCloudTasksQueue#name}
    */
    readonly name?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_cloud_tasks_queue#project GoogleCloudTasksQueue#project}
    */
    readonly project?: string;
    /**
    * app_engine_routing_override block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_cloud_tasks_queue#app_engine_routing_override GoogleCloudTasksQueue#app_engine_routing_override}
    */
    readonly appEngineRoutingOverride?: GoogleCloudTasksQueueAppEngineRoutingOverride;
    /**
    * http_target block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_cloud_tasks_queue#http_target GoogleCloudTasksQueue#http_target}
    */
    readonly httpTarget?: GoogleCloudTasksQueueHttpTarget;
    /**
    * rate_limits block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_cloud_tasks_queue#rate_limits GoogleCloudTasksQueue#rate_limits}
    */
    readonly rateLimits?: GoogleCloudTasksQueueRateLimits;
    /**
    * retry_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_cloud_tasks_queue#retry_config GoogleCloudTasksQueue#retry_config}
    */
    readonly retryConfig?: GoogleCloudTasksQueueRetryConfig;
    /**
    * stackdriver_logging_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_cloud_tasks_queue#stackdriver_logging_config GoogleCloudTasksQueue#stackdriver_logging_config}
    */
    readonly stackdriverLoggingConfig?: GoogleCloudTasksQueueStackdriverLoggingConfig;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_cloud_tasks_queue#timeouts GoogleCloudTasksQueue#timeouts}
    */
    readonly timeouts?: GoogleCloudTasksQueueTimeouts;
}
export interface GoogleCloudTasksQueueAppEngineRoutingOverride {
    /**
    * App instance.
    *
    * By default, the task is sent to an instance which is available when the task is attempted.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_cloud_tasks_queue#instance GoogleCloudTasksQueue#instance}
    */
    readonly instance?: string;
    /**
    * App service.
    *
    * By default, the task is sent to the service which is the default service when the task is attempted.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_cloud_tasks_queue#service GoogleCloudTasksQueue#service}
    */
    readonly service?: string;
    /**
    * App version.
    *
    * By default, the task is sent to the version which is the default version when the task is attempted.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_cloud_tasks_queue#version GoogleCloudTasksQueue#version}
    */
    readonly version?: string;
}
export declare function googleCloudTasksQueueAppEngineRoutingOverrideToTerraform(struct?: GoogleCloudTasksQueueAppEngineRoutingOverrideOutputReference | GoogleCloudTasksQueueAppEngineRoutingOverride): any;
export declare function googleCloudTasksQueueAppEngineRoutingOverrideToHclTerraform(struct?: GoogleCloudTasksQueueAppEngineRoutingOverrideOutputReference | GoogleCloudTasksQueueAppEngineRoutingOverride): any;
export declare class GoogleCloudTasksQueueAppEngineRoutingOverrideOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleCloudTasksQueueAppEngineRoutingOverride | undefined;
    set internalValue(value: GoogleCloudTasksQueueAppEngineRoutingOverride | undefined);
    get host(): string;
    private _instance?;
    get instance(): string;
    set instance(value: string);
    resetInstance(): void;
    get instanceInput(): string | undefined;
    private _service?;
    get service(): string;
    set service(value: string);
    resetService(): void;
    get serviceInput(): string | undefined;
    private _version?;
    get version(): string;
    set version(value: string);
    resetVersion(): void;
    get versionInput(): string | undefined;
}
export interface GoogleCloudTasksQueueHttpTargetHeaderOverridesHeader {
    /**
    * The Key of the header.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_cloud_tasks_queue#key GoogleCloudTasksQueue#key}
    */
    readonly key: string;
    /**
    * The Value of the header.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_cloud_tasks_queue#value GoogleCloudTasksQueue#value}
    */
    readonly value: string;
}
export declare function googleCloudTasksQueueHttpTargetHeaderOverridesHeaderToTerraform(struct?: GoogleCloudTasksQueueHttpTargetHeaderOverridesHeaderOutputReference | GoogleCloudTasksQueueHttpTargetHeaderOverridesHeader): any;
export declare function googleCloudTasksQueueHttpTargetHeaderOverridesHeaderToHclTerraform(struct?: GoogleCloudTasksQueueHttpTargetHeaderOverridesHeaderOutputReference | GoogleCloudTasksQueueHttpTargetHeaderOverridesHeader): any;
export declare class GoogleCloudTasksQueueHttpTargetHeaderOverridesHeaderOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleCloudTasksQueueHttpTargetHeaderOverridesHeader | undefined;
    set internalValue(value: GoogleCloudTasksQueueHttpTargetHeaderOverridesHeader | undefined);
    private _key?;
    get key(): string;
    set key(value: string);
    get keyInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    get valueInput(): string | undefined;
}
export interface GoogleCloudTasksQueueHttpTargetHeaderOverrides {
    /**
    * header block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_cloud_tasks_queue#header GoogleCloudTasksQueue#header}
    */
    readonly header: GoogleCloudTasksQueueHttpTargetHeaderOverridesHeader;
}
export declare function googleCloudTasksQueueHttpTargetHeaderOverridesToTerraform(struct?: GoogleCloudTasksQueueHttpTargetHeaderOverrides | cdktf.IResolvable): any;
export declare function googleCloudTasksQueueHttpTargetHeaderOverridesToHclTerraform(struct?: GoogleCloudTasksQueueHttpTargetHeaderOverrides | cdktf.IResolvable): any;
export declare class GoogleCloudTasksQueueHttpTargetHeaderOverridesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleCloudTasksQueueHttpTargetHeaderOverrides | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleCloudTasksQueueHttpTargetHeaderOverrides | cdktf.IResolvable | undefined);
    private _header;
    get header(): GoogleCloudTasksQueueHttpTargetHeaderOverridesHeaderOutputReference;
    putHeader(value: GoogleCloudTasksQueueHttpTargetHeaderOverridesHeader): void;
    get headerInput(): GoogleCloudTasksQueueHttpTargetHeaderOverridesHeader | undefined;
}
export declare class GoogleCloudTasksQueueHttpTargetHeaderOverridesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleCloudTasksQueueHttpTargetHeaderOverrides[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleCloudTasksQueueHttpTargetHeaderOverridesOutputReference;
}
export interface GoogleCloudTasksQueueHttpTargetOauthToken {
    /**
    * OAuth scope to be used for generating OAuth access token.
    * If not specified, "https://www.googleapis.com/auth/cloud-platform" will be used.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_cloud_tasks_queue#scope GoogleCloudTasksQueue#scope}
    */
    readonly scope?: string;
    /**
    * Service account email to be used for generating OAuth token.
    * The service account must be within the same project as the queue.
    * The caller must have iam.serviceAccounts.actAs permission for the service account.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_cloud_tasks_queue#service_account_email GoogleCloudTasksQueue#service_account_email}
    */
    readonly serviceAccountEmail: string;
}
export declare function googleCloudTasksQueueHttpTargetOauthTokenToTerraform(struct?: GoogleCloudTasksQueueHttpTargetOauthTokenOutputReference | GoogleCloudTasksQueueHttpTargetOauthToken): any;
export declare function googleCloudTasksQueueHttpTargetOauthTokenToHclTerraform(struct?: GoogleCloudTasksQueueHttpTargetOauthTokenOutputReference | GoogleCloudTasksQueueHttpTargetOauthToken): any;
export declare class GoogleCloudTasksQueueHttpTargetOauthTokenOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleCloudTasksQueueHttpTargetOauthToken | undefined;
    set internalValue(value: GoogleCloudTasksQueueHttpTargetOauthToken | undefined);
    private _scope?;
    get scope(): string;
    set scope(value: string);
    resetScope(): void;
    get scopeInput(): string | undefined;
    private _serviceAccountEmail?;
    get serviceAccountEmail(): string;
    set serviceAccountEmail(value: string);
    get serviceAccountEmailInput(): string | undefined;
}
export interface GoogleCloudTasksQueueHttpTargetOidcToken {
    /**
    * Audience to be used when generating OIDC token. If not specified, the URI specified in target will be used.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_cloud_tasks_queue#audience GoogleCloudTasksQueue#audience}
    */
    readonly audience?: string;
    /**
    * Service account email to be used for generating OIDC token.
    * The service account must be within the same project as the queue.
    * The caller must have iam.serviceAccounts.actAs permission for the service account.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_cloud_tasks_queue#service_account_email GoogleCloudTasksQueue#service_account_email}
    */
    readonly serviceAccountEmail: string;
}
export declare function googleCloudTasksQueueHttpTargetOidcTokenToTerraform(struct?: GoogleCloudTasksQueueHttpTargetOidcTokenOutputReference | GoogleCloudTasksQueueHttpTargetOidcToken): any;
export declare function googleCloudTasksQueueHttpTargetOidcTokenToHclTerraform(struct?: GoogleCloudTasksQueueHttpTargetOidcTokenOutputReference | GoogleCloudTasksQueueHttpTargetOidcToken): any;
export declare class GoogleCloudTasksQueueHttpTargetOidcTokenOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleCloudTasksQueueHttpTargetOidcToken | undefined;
    set internalValue(value: GoogleCloudTasksQueueHttpTargetOidcToken | undefined);
    private _audience?;
    get audience(): string;
    set audience(value: string);
    resetAudience(): void;
    get audienceInput(): string | undefined;
    private _serviceAccountEmail?;
    get serviceAccountEmail(): string;
    set serviceAccountEmail(value: string);
    get serviceAccountEmailInput(): string | undefined;
}
export interface GoogleCloudTasksQueueHttpTargetUriOverridePathOverride {
    /**
    * The URI path (e.g., /users/1234). Default is an empty string.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_cloud_tasks_queue#path GoogleCloudTasksQueue#path}
    */
    readonly path?: string;
}
export declare function googleCloudTasksQueueHttpTargetUriOverridePathOverrideToTerraform(struct?: GoogleCloudTasksQueueHttpTargetUriOverridePathOverrideOutputReference | GoogleCloudTasksQueueHttpTargetUriOverridePathOverride): any;
export declare function googleCloudTasksQueueHttpTargetUriOverridePathOverrideToHclTerraform(struct?: GoogleCloudTasksQueueHttpTargetUriOverridePathOverrideOutputReference | GoogleCloudTasksQueueHttpTargetUriOverridePathOverride): any;
export declare class GoogleCloudTasksQueueHttpTargetUriOverridePathOverrideOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleCloudTasksQueueHttpTargetUriOverridePathOverride | undefined;
    set internalValue(value: GoogleCloudTasksQueueHttpTargetUriOverridePathOverride | undefined);
    private _path?;
    get path(): string;
    set path(value: string);
    resetPath(): void;
    get pathInput(): string | undefined;
}
export interface GoogleCloudTasksQueueHttpTargetUriOverrideQueryOverride {
    /**
    * The query parameters (e.g., qparam1=123&qparam2=456). Default is an empty string.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_cloud_tasks_queue#query_params GoogleCloudTasksQueue#query_params}
    */
    readonly queryParams?: string;
}
export declare function googleCloudTasksQueueHttpTargetUriOverrideQueryOverrideToTerraform(struct?: GoogleCloudTasksQueueHttpTargetUriOverrideQueryOverrideOutputReference | GoogleCloudTasksQueueHttpTargetUriOverrideQueryOverride): any;
export declare function googleCloudTasksQueueHttpTargetUriOverrideQueryOverrideToHclTerraform(struct?: GoogleCloudTasksQueueHttpTargetUriOverrideQueryOverrideOutputReference | GoogleCloudTasksQueueHttpTargetUriOverrideQueryOverride): any;
export declare class GoogleCloudTasksQueueHttpTargetUriOverrideQueryOverrideOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleCloudTasksQueueHttpTargetUriOverrideQueryOverride | undefined;
    set internalValue(value: GoogleCloudTasksQueueHttpTargetUriOverrideQueryOverride | undefined);
    private _queryParams?;
    get queryParams(): string;
    set queryParams(value: string);
    resetQueryParams(): void;
    get queryParamsInput(): string | undefined;
}
export interface GoogleCloudTasksQueueHttpTargetUriOverride {
    /**
    * Host override.
    *
    * When specified, replaces the host part of the task URL.
    * For example, if the task URL is "https://www.google.com", and host value
    * is set to "example.net", the overridden URI will be changed to "https://example.net".
    * Host value cannot be an empty string (INVALID_ARGUMENT).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_cloud_tasks_queue#host GoogleCloudTasksQueue#host}
    */
    readonly host?: string;
    /**
    * Port override.
    *
    * When specified, replaces the port part of the task URI.
    * For instance, for a URI http://www.google.com/foo and port=123, the overridden URI becomes http://www.google.com:123/foo.
    * Note that the port value must be a positive integer.
    * Setting the port to 0 (Zero) clears the URI port.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_cloud_tasks_queue#port GoogleCloudTasksQueue#port}
    */
    readonly port?: string;
    /**
    * Scheme override.
    *
    * When specified, the task URI scheme is replaced by the provided value (HTTP or HTTPS). Possible values: ["HTTP", "HTTPS"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_cloud_tasks_queue#scheme GoogleCloudTasksQueue#scheme}
    */
    readonly scheme?: string;
    /**
    * URI Override Enforce Mode
    *
    * When specified, determines the Target UriOverride mode. If not specified, it defaults to ALWAYS. Possible values: ["ALWAYS", "IF_NOT_EXISTS"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_cloud_tasks_queue#uri_override_enforce_mode GoogleCloudTasksQueue#uri_override_enforce_mode}
    */
    readonly uriOverrideEnforceMode?: string;
    /**
    * path_override block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_cloud_tasks_queue#path_override GoogleCloudTasksQueue#path_override}
    */
    readonly pathOverride?: GoogleCloudTasksQueueHttpTargetUriOverridePathOverride;
    /**
    * query_override block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_cloud_tasks_queue#query_override GoogleCloudTasksQueue#query_override}
    */
    readonly queryOverride?: GoogleCloudTasksQueueHttpTargetUriOverrideQueryOverride;
}
export declare function googleCloudTasksQueueHttpTargetUriOverrideToTerraform(struct?: GoogleCloudTasksQueueHttpTargetUriOverrideOutputReference | GoogleCloudTasksQueueHttpTargetUriOverride): any;
export declare function googleCloudTasksQueueHttpTargetUriOverrideToHclTerraform(struct?: GoogleCloudTasksQueueHttpTargetUriOverrideOutputReference | GoogleCloudTasksQueueHttpTargetUriOverride): any;
export declare class GoogleCloudTasksQueueHttpTargetUriOverrideOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleCloudTasksQueueHttpTargetUriOverride | undefined;
    set internalValue(value: GoogleCloudTasksQueueHttpTargetUriOverride | undefined);
    private _host?;
    get host(): string;
    set host(value: string);
    resetHost(): void;
    get hostInput(): string | undefined;
    private _port?;
    get port(): string;
    set port(value: string);
    resetPort(): void;
    get portInput(): string | undefined;
    private _scheme?;
    get scheme(): string;
    set scheme(value: string);
    resetScheme(): void;
    get schemeInput(): string | undefined;
    private _uriOverrideEnforceMode?;
    get uriOverrideEnforceMode(): string;
    set uriOverrideEnforceMode(value: string);
    resetUriOverrideEnforceMode(): void;
    get uriOverrideEnforceModeInput(): string | undefined;
    private _pathOverride;
    get pathOverride(): GoogleCloudTasksQueueHttpTargetUriOverridePathOverrideOutputReference;
    putPathOverride(value: GoogleCloudTasksQueueHttpTargetUriOverridePathOverride): void;
    resetPathOverride(): void;
    get pathOverrideInput(): GoogleCloudTasksQueueHttpTargetUriOverridePathOverride | undefined;
    private _queryOverride;
    get queryOverride(): GoogleCloudTasksQueueHttpTargetUriOverrideQueryOverrideOutputReference;
    putQueryOverride(value: GoogleCloudTasksQueueHttpTargetUriOverrideQueryOverride): void;
    resetQueryOverride(): void;
    get queryOverrideInput(): GoogleCloudTasksQueueHttpTargetUriOverrideQueryOverride | undefined;
}
export interface GoogleCloudTasksQueueHttpTarget {
    /**
    * The HTTP method to use for the request.
    *
    * When specified, it overrides HttpRequest for the task.
    * Note that if the value is set to GET the body of the task will be ignored at execution time. Possible values: ["HTTP_METHOD_UNSPECIFIED", "POST", "GET", "HEAD", "PUT", "DELETE", "PATCH", "OPTIONS"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_cloud_tasks_queue#http_method GoogleCloudTasksQueue#http_method}
    */
    readonly httpMethod?: string;
    /**
    * header_overrides block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_cloud_tasks_queue#header_overrides GoogleCloudTasksQueue#header_overrides}
    */
    readonly headerOverrides?: GoogleCloudTasksQueueHttpTargetHeaderOverrides[] | cdktf.IResolvable;
    /**
    * oauth_token block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_cloud_tasks_queue#oauth_token GoogleCloudTasksQueue#oauth_token}
    */
    readonly oauthToken?: GoogleCloudTasksQueueHttpTargetOauthToken;
    /**
    * oidc_token block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_cloud_tasks_queue#oidc_token GoogleCloudTasksQueue#oidc_token}
    */
    readonly oidcToken?: GoogleCloudTasksQueueHttpTargetOidcToken;
    /**
    * uri_override block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_cloud_tasks_queue#uri_override GoogleCloudTasksQueue#uri_override}
    */
    readonly uriOverride?: GoogleCloudTasksQueueHttpTargetUriOverride;
}
export declare function googleCloudTasksQueueHttpTargetToTerraform(struct?: GoogleCloudTasksQueueHttpTargetOutputReference | GoogleCloudTasksQueueHttpTarget): any;
export declare function googleCloudTasksQueueHttpTargetToHclTerraform(struct?: GoogleCloudTasksQueueHttpTargetOutputReference | GoogleCloudTasksQueueHttpTarget): any;
export declare class GoogleCloudTasksQueueHttpTargetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleCloudTasksQueueHttpTarget | undefined;
    set internalValue(value: GoogleCloudTasksQueueHttpTarget | undefined);
    private _httpMethod?;
    get httpMethod(): string;
    set httpMethod(value: string);
    resetHttpMethod(): void;
    get httpMethodInput(): string | undefined;
    private _headerOverrides;
    get headerOverrides(): GoogleCloudTasksQueueHttpTargetHeaderOverridesList;
    putHeaderOverrides(value: GoogleCloudTasksQueueHttpTargetHeaderOverrides[] | cdktf.IResolvable): void;
    resetHeaderOverrides(): void;
    get headerOverridesInput(): cdktf.IResolvable | GoogleCloudTasksQueueHttpTargetHeaderOverrides[] | undefined;
    private _oauthToken;
    get oauthToken(): GoogleCloudTasksQueueHttpTargetOauthTokenOutputReference;
    putOauthToken(value: GoogleCloudTasksQueueHttpTargetOauthToken): void;
    resetOauthToken(): void;
    get oauthTokenInput(): GoogleCloudTasksQueueHttpTargetOauthToken | undefined;
    private _oidcToken;
    get oidcToken(): GoogleCloudTasksQueueHttpTargetOidcTokenOutputReference;
    putOidcToken(value: GoogleCloudTasksQueueHttpTargetOidcToken): void;
    resetOidcToken(): void;
    get oidcTokenInput(): GoogleCloudTasksQueueHttpTargetOidcToken | undefined;
    private _uriOverride;
    get uriOverride(): GoogleCloudTasksQueueHttpTargetUriOverrideOutputReference;
    putUriOverride(value: GoogleCloudTasksQueueHttpTargetUriOverride): void;
    resetUriOverride(): void;
    get uriOverrideInput(): GoogleCloudTasksQueueHttpTargetUriOverride | undefined;
}
export interface GoogleCloudTasksQueueRateLimits {
    /**
    * The maximum number of concurrent tasks that Cloud Tasks allows to
    * be dispatched for this queue. After this threshold has been
    * reached, Cloud Tasks stops dispatching tasks until the number of
    * concurrent requests decreases.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_cloud_tasks_queue#max_concurrent_dispatches GoogleCloudTasksQueue#max_concurrent_dispatches}
    */
    readonly maxConcurrentDispatches?: number;
    /**
    * The maximum rate at which tasks are dispatched from this queue.
    *
    * If unspecified when the queue is created, Cloud Tasks will pick the default.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_cloud_tasks_queue#max_dispatches_per_second GoogleCloudTasksQueue#max_dispatches_per_second}
    */
    readonly maxDispatchesPerSecond?: number;
}
export declare function googleCloudTasksQueueRateLimitsToTerraform(struct?: GoogleCloudTasksQueueRateLimitsOutputReference | GoogleCloudTasksQueueRateLimits): any;
export declare function googleCloudTasksQueueRateLimitsToHclTerraform(struct?: GoogleCloudTasksQueueRateLimitsOutputReference | GoogleCloudTasksQueueRateLimits): any;
export declare class GoogleCloudTasksQueueRateLimitsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleCloudTasksQueueRateLimits | undefined;
    set internalValue(value: GoogleCloudTasksQueueRateLimits | undefined);
    get maxBurstSize(): number;
    private _maxConcurrentDispatches?;
    get maxConcurrentDispatches(): number;
    set maxConcurrentDispatches(value: number);
    resetMaxConcurrentDispatches(): void;
    get maxConcurrentDispatchesInput(): number | undefined;
    private _maxDispatchesPerSecond?;
    get maxDispatchesPerSecond(): number;
    set maxDispatchesPerSecond(value: number);
    resetMaxDispatchesPerSecond(): void;
    get maxDispatchesPerSecondInput(): number | undefined;
}
export interface GoogleCloudTasksQueueRetryConfig {
    /**
    * Number of attempts per task.
    *
    * Cloud Tasks will attempt the task maxAttempts times (that is, if
    * the first attempt fails, then there will be maxAttempts - 1
    * retries). Must be >= -1.
    *
    * If unspecified when the queue is created, Cloud Tasks will pick
    * the default.
    *
    * -1 indicates unlimited attempts.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_cloud_tasks_queue#max_attempts GoogleCloudTasksQueue#max_attempts}
    */
    readonly maxAttempts?: number;
    /**
    * A task will be scheduled for retry between minBackoff and
    * maxBackoff duration after it fails, if the queue's RetryConfig
    * specifies that the task should be retried.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_cloud_tasks_queue#max_backoff GoogleCloudTasksQueue#max_backoff}
    */
    readonly maxBackoff?: string;
    /**
    * The time between retries will double maxDoublings times.
    *
    * A task's retry interval starts at minBackoff, then doubles maxDoublings times,
    * then increases linearly, and finally retries retries at intervals of maxBackoff
    * up to maxAttempts times.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_cloud_tasks_queue#max_doublings GoogleCloudTasksQueue#max_doublings}
    */
    readonly maxDoublings?: number;
    /**
    * If positive, maxRetryDuration specifies the time limit for
    * retrying a failed task, measured from when the task was first
    * attempted. Once maxRetryDuration time has passed and the task has
    * been attempted maxAttempts times, no further attempts will be
    * made and the task will be deleted.
    *
    * If zero, then the task age is unlimited.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_cloud_tasks_queue#max_retry_duration GoogleCloudTasksQueue#max_retry_duration}
    */
    readonly maxRetryDuration?: string;
    /**
    * A task will be scheduled for retry between minBackoff and
    * maxBackoff duration after it fails, if the queue's RetryConfig
    * specifies that the task should be retried.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_cloud_tasks_queue#min_backoff GoogleCloudTasksQueue#min_backoff}
    */
    readonly minBackoff?: string;
}
export declare function googleCloudTasksQueueRetryConfigToTerraform(struct?: GoogleCloudTasksQueueRetryConfigOutputReference | GoogleCloudTasksQueueRetryConfig): any;
export declare function googleCloudTasksQueueRetryConfigToHclTerraform(struct?: GoogleCloudTasksQueueRetryConfigOutputReference | GoogleCloudTasksQueueRetryConfig): any;
export declare class GoogleCloudTasksQueueRetryConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleCloudTasksQueueRetryConfig | undefined;
    set internalValue(value: GoogleCloudTasksQueueRetryConfig | undefined);
    private _maxAttempts?;
    get maxAttempts(): number;
    set maxAttempts(value: number);
    resetMaxAttempts(): void;
    get maxAttemptsInput(): number | undefined;
    private _maxBackoff?;
    get maxBackoff(): string;
    set maxBackoff(value: string);
    resetMaxBackoff(): void;
    get maxBackoffInput(): string | undefined;
    private _maxDoublings?;
    get maxDoublings(): number;
    set maxDoublings(value: number);
    resetMaxDoublings(): void;
    get maxDoublingsInput(): number | undefined;
    private _maxRetryDuration?;
    get maxRetryDuration(): string;
    set maxRetryDuration(value: string);
    resetMaxRetryDuration(): void;
    get maxRetryDurationInput(): string | undefined;
    private _minBackoff?;
    get minBackoff(): string;
    set minBackoff(value: string);
    resetMinBackoff(): void;
    get minBackoffInput(): string | undefined;
}
export interface GoogleCloudTasksQueueStackdriverLoggingConfig {
    /**
    * Specifies the fraction of operations to write to Stackdriver Logging.
    * This field may contain any value between 0.0 and 1.0, inclusive. 0.0 is the
    * default and means that no operations are logged.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_cloud_tasks_queue#sampling_ratio GoogleCloudTasksQueue#sampling_ratio}
    */
    readonly samplingRatio: number;
}
export declare function googleCloudTasksQueueStackdriverLoggingConfigToTerraform(struct?: GoogleCloudTasksQueueStackdriverLoggingConfigOutputReference | GoogleCloudTasksQueueStackdriverLoggingConfig): any;
export declare function googleCloudTasksQueueStackdriverLoggingConfigToHclTerraform(struct?: GoogleCloudTasksQueueStackdriverLoggingConfigOutputReference | GoogleCloudTasksQueueStackdriverLoggingConfig): any;
export declare class GoogleCloudTasksQueueStackdriverLoggingConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleCloudTasksQueueStackdriverLoggingConfig | undefined;
    set internalValue(value: GoogleCloudTasksQueueStackdriverLoggingConfig | undefined);
    private _samplingRatio?;
    get samplingRatio(): number;
    set samplingRatio(value: number);
    get samplingRatioInput(): number | undefined;
}
export interface GoogleCloudTasksQueueTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_cloud_tasks_queue#create GoogleCloudTasksQueue#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_cloud_tasks_queue#delete GoogleCloudTasksQueue#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_cloud_tasks_queue#update GoogleCloudTasksQueue#update}
    */
    readonly update?: string;
}
export declare function googleCloudTasksQueueTimeoutsToTerraform(struct?: GoogleCloudTasksQueueTimeouts | cdktf.IResolvable): any;
export declare function googleCloudTasksQueueTimeoutsToHclTerraform(struct?: GoogleCloudTasksQueueTimeouts | cdktf.IResolvable): any;
export declare class GoogleCloudTasksQueueTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleCloudTasksQueueTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleCloudTasksQueueTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_cloud_tasks_queue google_cloud_tasks_queue}
*/
export declare class GoogleCloudTasksQueue extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_cloud_tasks_queue";
    /**
    * Generates CDKTF code for importing a GoogleCloudTasksQueue resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleCloudTasksQueue to import
    * @param importFromId The id of the existing GoogleCloudTasksQueue that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_cloud_tasks_queue#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleCloudTasksQueue to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_cloud_tasks_queue google_cloud_tasks_queue} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleCloudTasksQueueConfig
    */
    constructor(scope: Construct, id: string, config: GoogleCloudTasksQueueConfig);
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _appEngineRoutingOverride;
    get appEngineRoutingOverride(): GoogleCloudTasksQueueAppEngineRoutingOverrideOutputReference;
    putAppEngineRoutingOverride(value: GoogleCloudTasksQueueAppEngineRoutingOverride): void;
    resetAppEngineRoutingOverride(): void;
    get appEngineRoutingOverrideInput(): GoogleCloudTasksQueueAppEngineRoutingOverride | undefined;
    private _httpTarget;
    get httpTarget(): GoogleCloudTasksQueueHttpTargetOutputReference;
    putHttpTarget(value: GoogleCloudTasksQueueHttpTarget): void;
    resetHttpTarget(): void;
    get httpTargetInput(): GoogleCloudTasksQueueHttpTarget | undefined;
    private _rateLimits;
    get rateLimits(): GoogleCloudTasksQueueRateLimitsOutputReference;
    putRateLimits(value: GoogleCloudTasksQueueRateLimits): void;
    resetRateLimits(): void;
    get rateLimitsInput(): GoogleCloudTasksQueueRateLimits | undefined;
    private _retryConfig;
    get retryConfig(): GoogleCloudTasksQueueRetryConfigOutputReference;
    putRetryConfig(value: GoogleCloudTasksQueueRetryConfig): void;
    resetRetryConfig(): void;
    get retryConfigInput(): GoogleCloudTasksQueueRetryConfig | undefined;
    private _stackdriverLoggingConfig;
    get stackdriverLoggingConfig(): GoogleCloudTasksQueueStackdriverLoggingConfigOutputReference;
    putStackdriverLoggingConfig(value: GoogleCloudTasksQueueStackdriverLoggingConfig): void;
    resetStackdriverLoggingConfig(): void;
    get stackdriverLoggingConfigInput(): GoogleCloudTasksQueueStackdriverLoggingConfig | undefined;
    private _timeouts;
    get timeouts(): GoogleCloudTasksQueueTimeoutsOutputReference;
    putTimeouts(value: GoogleCloudTasksQueueTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleCloudTasksQueueTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
