/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleClouddeployTargetConfig extends cdktf.TerraformMetaArguments {
    /**
    * Optional. User annotations. These attributes can only be set and used by the user, and not by Google Cloud Deploy. See https://google.aip.dev/128#annotations for more details such as format and size limitations.
    *
    * **Note**: This field is non-authoritative, and will only manage the annotations present in your configuration.
    * Please refer to the field `effective_annotations` for all of the annotations present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_clouddeploy_target#annotations GoogleClouddeployTarget#annotations}
    */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
    * Optional. The deploy parameters to use for this target.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_clouddeploy_target#deploy_parameters GoogleClouddeployTarget#deploy_parameters}
    */
    readonly deployParameters?: {
        [key: string]: string;
    };
    /**
    * Optional. Description of the `Target`. Max length is 255 characters.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_clouddeploy_target#description GoogleClouddeployTarget#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_clouddeploy_target#id GoogleClouddeployTarget#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Optional. Labels are attributes that can be set and used by both the user and by Google Cloud Deploy. Labels must meet the following constraints: * Keys and values can contain only lowercase letters, numeric characters, underscores, and dashes. * All characters must use UTF-8 encoding, and international characters are allowed. * Keys must start with a lowercase letter or international character. * Each resource is limited to a maximum of 64 labels. Both keys and values are additionally constrained to be <= 128 bytes.
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field `effective_labels` for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_clouddeploy_target#labels GoogleClouddeployTarget#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * The location for the resource
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_clouddeploy_target#location GoogleClouddeployTarget#location}
    */
    readonly location: string;
    /**
    * Name of the `Target`. Format is `[a-z]([a-z0-9-]{0,61}[a-z0-9])?`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_clouddeploy_target#name GoogleClouddeployTarget#name}
    */
    readonly name: string;
    /**
    * The project for the resource
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_clouddeploy_target#project GoogleClouddeployTarget#project}
    */
    readonly project?: string;
    /**
    * Optional. Whether or not the `Target` requires approval.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_clouddeploy_target#require_approval GoogleClouddeployTarget#require_approval}
    */
    readonly requireApproval?: boolean | cdktf.IResolvable;
    /**
    * anthos_cluster block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_clouddeploy_target#anthos_cluster GoogleClouddeployTarget#anthos_cluster}
    */
    readonly anthosCluster?: GoogleClouddeployTargetAnthosCluster;
    /**
    * custom_target block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_clouddeploy_target#custom_target GoogleClouddeployTarget#custom_target}
    */
    readonly customTarget?: GoogleClouddeployTargetCustomTarget;
    /**
    * execution_configs block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_clouddeploy_target#execution_configs GoogleClouddeployTarget#execution_configs}
    */
    readonly executionConfigs?: GoogleClouddeployTargetExecutionConfigs[] | cdktf.IResolvable;
    /**
    * gke block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_clouddeploy_target#gke GoogleClouddeployTarget#gke}
    */
    readonly gke?: GoogleClouddeployTargetGke;
    /**
    * multi_target block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_clouddeploy_target#multi_target GoogleClouddeployTarget#multi_target}
    */
    readonly multiTarget?: GoogleClouddeployTargetMultiTarget;
    /**
    * run block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_clouddeploy_target#run GoogleClouddeployTarget#run}
    */
    readonly run?: GoogleClouddeployTargetRun;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_clouddeploy_target#timeouts GoogleClouddeployTarget#timeouts}
    */
    readonly timeouts?: GoogleClouddeployTargetTimeouts;
}
export interface GoogleClouddeployTargetAnthosCluster {
    /**
    * Membership of the GKE Hub-registered cluster to which to apply the Skaffold configuration. Format is `projects/{project}/locations/{location}/memberships/{membership_name}`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_clouddeploy_target#membership GoogleClouddeployTarget#membership}
    */
    readonly membership?: string;
}
export declare function googleClouddeployTargetAnthosClusterToTerraform(struct?: GoogleClouddeployTargetAnthosClusterOutputReference | GoogleClouddeployTargetAnthosCluster): any;
export declare function googleClouddeployTargetAnthosClusterToHclTerraform(struct?: GoogleClouddeployTargetAnthosClusterOutputReference | GoogleClouddeployTargetAnthosCluster): any;
export declare class GoogleClouddeployTargetAnthosClusterOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleClouddeployTargetAnthosCluster | undefined;
    set internalValue(value: GoogleClouddeployTargetAnthosCluster | undefined);
    private _membership?;
    get membership(): string;
    set membership(value: string);
    resetMembership(): void;
    get membershipInput(): string | undefined;
}
export interface GoogleClouddeployTargetCustomTarget {
    /**
    * Required. The name of the CustomTargetType. Format must be `projects/{project}/locations/{location}/customTargetTypes/{custom_target_type}`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_clouddeploy_target#custom_target_type GoogleClouddeployTarget#custom_target_type}
    */
    readonly customTargetType: string;
}
export declare function googleClouddeployTargetCustomTargetToTerraform(struct?: GoogleClouddeployTargetCustomTargetOutputReference | GoogleClouddeployTargetCustomTarget): any;
export declare function googleClouddeployTargetCustomTargetToHclTerraform(struct?: GoogleClouddeployTargetCustomTargetOutputReference | GoogleClouddeployTargetCustomTarget): any;
export declare class GoogleClouddeployTargetCustomTargetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleClouddeployTargetCustomTarget | undefined;
    set internalValue(value: GoogleClouddeployTargetCustomTarget | undefined);
    private _customTargetType?;
    get customTargetType(): string;
    set customTargetType(value: string);
    get customTargetTypeInput(): string | undefined;
}
export interface GoogleClouddeployTargetExecutionConfigs {
    /**
    * Optional. Cloud Storage location in which to store execution outputs. This can either be a bucket ("gs://my-bucket") or a path within a bucket ("gs://my-bucket/my-dir"). If unspecified, a default bucket located in the same region will be used.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_clouddeploy_target#artifact_storage GoogleClouddeployTarget#artifact_storage}
    */
    readonly artifactStorage?: string;
    /**
    * Optional. Execution timeout for a Cloud Build Execution. This must be between 10m and 24h in seconds format. If unspecified, a default timeout of 1h is used.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_clouddeploy_target#execution_timeout GoogleClouddeployTarget#execution_timeout}
    */
    readonly executionTimeout?: string;
    /**
    * Optional. Google service account to use for execution. If unspecified, the project execution service account (-compute@developer.gserviceaccount.com) is used.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_clouddeploy_target#service_account GoogleClouddeployTarget#service_account}
    */
    readonly serviceAccount?: string;
    /**
    * Required. Usages when this configuration should be applied.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_clouddeploy_target#usages GoogleClouddeployTarget#usages}
    */
    readonly usages: string[];
    /**
    * Optional. If true, additional logging will be enabled when running builds in this execution environment.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_clouddeploy_target#verbose GoogleClouddeployTarget#verbose}
    */
    readonly verbose?: boolean | cdktf.IResolvable;
    /**
    * Optional. The resource name of the `WorkerPool`, with the format `projects/{project}/locations/{location}/workerPools/{worker_pool}`. If this optional field is unspecified, the default Cloud Build pool will be used.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_clouddeploy_target#worker_pool GoogleClouddeployTarget#worker_pool}
    */
    readonly workerPool?: string;
}
export declare function googleClouddeployTargetExecutionConfigsToTerraform(struct?: GoogleClouddeployTargetExecutionConfigs | cdktf.IResolvable): any;
export declare function googleClouddeployTargetExecutionConfigsToHclTerraform(struct?: GoogleClouddeployTargetExecutionConfigs | cdktf.IResolvable): any;
export declare class GoogleClouddeployTargetExecutionConfigsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleClouddeployTargetExecutionConfigs | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleClouddeployTargetExecutionConfigs | cdktf.IResolvable | undefined);
    private _artifactStorage?;
    get artifactStorage(): string;
    set artifactStorage(value: string);
    resetArtifactStorage(): void;
    get artifactStorageInput(): string | undefined;
    private _executionTimeout?;
    get executionTimeout(): string;
    set executionTimeout(value: string);
    resetExecutionTimeout(): void;
    get executionTimeoutInput(): string | undefined;
    private _serviceAccount?;
    get serviceAccount(): string;
    set serviceAccount(value: string);
    resetServiceAccount(): void;
    get serviceAccountInput(): string | undefined;
    private _usages?;
    get usages(): string[];
    set usages(value: string[]);
    get usagesInput(): string[] | undefined;
    private _verbose?;
    get verbose(): boolean | cdktf.IResolvable;
    set verbose(value: boolean | cdktf.IResolvable);
    resetVerbose(): void;
    get verboseInput(): boolean | cdktf.IResolvable | undefined;
    private _workerPool?;
    get workerPool(): string;
    set workerPool(value: string);
    resetWorkerPool(): void;
    get workerPoolInput(): string | undefined;
}
export declare class GoogleClouddeployTargetExecutionConfigsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleClouddeployTargetExecutionConfigs[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleClouddeployTargetExecutionConfigsOutputReference;
}
export interface GoogleClouddeployTargetGke {
    /**
    * Information specifying a GKE Cluster. Format is `projects/{project_id}/locations/{location_id}/clusters/{cluster_id}.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_clouddeploy_target#cluster GoogleClouddeployTarget#cluster}
    */
    readonly cluster?: string;
    /**
    * Optional. If true, `cluster` is accessed using the private IP address of the control plane endpoint. Otherwise, the default IP address of the control plane endpoint is used. The default IP address is the private IP address for clusters with private control-plane endpoints and the public IP address otherwise. Only specify this option when `cluster` is a [private GKE cluster](https://cloud.google.com/kubernetes-engine/docs/concepts/private-cluster-concept).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_clouddeploy_target#internal_ip GoogleClouddeployTarget#internal_ip}
    */
    readonly internalIp?: boolean | cdktf.IResolvable;
    /**
    * Optional. If set, used to configure a [proxy](https://kubernetes.io/docs/concepts/configuration/organize-cluster-access-kubeconfig/#proxy) to the Kubernetes server.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_clouddeploy_target#proxy_url GoogleClouddeployTarget#proxy_url}
    */
    readonly proxyUrl?: string;
}
export declare function googleClouddeployTargetGkeToTerraform(struct?: GoogleClouddeployTargetGkeOutputReference | GoogleClouddeployTargetGke): any;
export declare function googleClouddeployTargetGkeToHclTerraform(struct?: GoogleClouddeployTargetGkeOutputReference | GoogleClouddeployTargetGke): any;
export declare class GoogleClouddeployTargetGkeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleClouddeployTargetGke | undefined;
    set internalValue(value: GoogleClouddeployTargetGke | undefined);
    private _cluster?;
    get cluster(): string;
    set cluster(value: string);
    resetCluster(): void;
    get clusterInput(): string | undefined;
    private _internalIp?;
    get internalIp(): boolean | cdktf.IResolvable;
    set internalIp(value: boolean | cdktf.IResolvable);
    resetInternalIp(): void;
    get internalIpInput(): boolean | cdktf.IResolvable | undefined;
    private _proxyUrl?;
    get proxyUrl(): string;
    set proxyUrl(value: string);
    resetProxyUrl(): void;
    get proxyUrlInput(): string | undefined;
}
export interface GoogleClouddeployTargetMultiTarget {
    /**
    * Required. The target_ids of this multiTarget.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_clouddeploy_target#target_ids GoogleClouddeployTarget#target_ids}
    */
    readonly targetIds: string[];
}
export declare function googleClouddeployTargetMultiTargetToTerraform(struct?: GoogleClouddeployTargetMultiTargetOutputReference | GoogleClouddeployTargetMultiTarget): any;
export declare function googleClouddeployTargetMultiTargetToHclTerraform(struct?: GoogleClouddeployTargetMultiTargetOutputReference | GoogleClouddeployTargetMultiTarget): any;
export declare class GoogleClouddeployTargetMultiTargetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleClouddeployTargetMultiTarget | undefined;
    set internalValue(value: GoogleClouddeployTargetMultiTarget | undefined);
    private _targetIds?;
    get targetIds(): string[];
    set targetIds(value: string[]);
    get targetIdsInput(): string[] | undefined;
}
export interface GoogleClouddeployTargetRun {
    /**
    * Required. The location where the Cloud Run Service should be located. Format is `projects/{project}/locations/{location}`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_clouddeploy_target#location GoogleClouddeployTarget#location}
    */
    readonly location: string;
}
export declare function googleClouddeployTargetRunToTerraform(struct?: GoogleClouddeployTargetRunOutputReference | GoogleClouddeployTargetRun): any;
export declare function googleClouddeployTargetRunToHclTerraform(struct?: GoogleClouddeployTargetRunOutputReference | GoogleClouddeployTargetRun): any;
export declare class GoogleClouddeployTargetRunOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleClouddeployTargetRun | undefined;
    set internalValue(value: GoogleClouddeployTargetRun | undefined);
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
}
export interface GoogleClouddeployTargetTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_clouddeploy_target#create GoogleClouddeployTarget#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_clouddeploy_target#delete GoogleClouddeployTarget#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_clouddeploy_target#update GoogleClouddeployTarget#update}
    */
    readonly update?: string;
}
export declare function googleClouddeployTargetTimeoutsToTerraform(struct?: GoogleClouddeployTargetTimeouts | cdktf.IResolvable): any;
export declare function googleClouddeployTargetTimeoutsToHclTerraform(struct?: GoogleClouddeployTargetTimeouts | cdktf.IResolvable): any;
export declare class GoogleClouddeployTargetTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleClouddeployTargetTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleClouddeployTargetTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_clouddeploy_target google_clouddeploy_target}
*/
export declare class GoogleClouddeployTarget extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_clouddeploy_target";
    /**
    * Generates CDKTF code for importing a GoogleClouddeployTarget resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleClouddeployTarget to import
    * @param importFromId The id of the existing GoogleClouddeployTarget that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_clouddeploy_target#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleClouddeployTarget to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_clouddeploy_target google_clouddeploy_target} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleClouddeployTargetConfig
    */
    constructor(scope: Construct, id: string, config: GoogleClouddeployTargetConfig);
    private _annotations?;
    get annotations(): {
        [key: string]: string;
    };
    set annotations(value: {
        [key: string]: string;
    });
    resetAnnotations(): void;
    get annotationsInput(): {
        [key: string]: string;
    } | undefined;
    get createTime(): string;
    private _deployParameters?;
    get deployParameters(): {
        [key: string]: string;
    };
    set deployParameters(value: {
        [key: string]: string;
    });
    resetDeployParameters(): void;
    get deployParametersInput(): {
        [key: string]: string;
    } | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _effectiveAnnotations;
    get effectiveAnnotations(): cdktf.StringMap;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    get etag(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _requireApproval?;
    get requireApproval(): boolean | cdktf.IResolvable;
    set requireApproval(value: boolean | cdktf.IResolvable);
    resetRequireApproval(): void;
    get requireApprovalInput(): boolean | cdktf.IResolvable | undefined;
    get targetId(): string;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    get uid(): string;
    get updateTime(): string;
    private _anthosCluster;
    get anthosCluster(): GoogleClouddeployTargetAnthosClusterOutputReference;
    putAnthosCluster(value: GoogleClouddeployTargetAnthosCluster): void;
    resetAnthosCluster(): void;
    get anthosClusterInput(): GoogleClouddeployTargetAnthosCluster | undefined;
    private _customTarget;
    get customTarget(): GoogleClouddeployTargetCustomTargetOutputReference;
    putCustomTarget(value: GoogleClouddeployTargetCustomTarget): void;
    resetCustomTarget(): void;
    get customTargetInput(): GoogleClouddeployTargetCustomTarget | undefined;
    private _executionConfigs;
    get executionConfigs(): GoogleClouddeployTargetExecutionConfigsList;
    putExecutionConfigs(value: GoogleClouddeployTargetExecutionConfigs[] | cdktf.IResolvable): void;
    resetExecutionConfigs(): void;
    get executionConfigsInput(): cdktf.IResolvable | GoogleClouddeployTargetExecutionConfigs[] | undefined;
    private _gke;
    get gke(): GoogleClouddeployTargetGkeOutputReference;
    putGke(value: GoogleClouddeployTargetGke): void;
    resetGke(): void;
    get gkeInput(): GoogleClouddeployTargetGke | undefined;
    private _multiTarget;
    get multiTarget(): GoogleClouddeployTargetMultiTargetOutputReference;
    putMultiTarget(value: GoogleClouddeployTargetMultiTarget): void;
    resetMultiTarget(): void;
    get multiTargetInput(): GoogleClouddeployTargetMultiTarget | undefined;
    private _run;
    get run(): GoogleClouddeployTargetRunOutputReference;
    putRun(value: GoogleClouddeployTargetRun): void;
    resetRun(): void;
    get runInput(): GoogleClouddeployTargetRun | undefined;
    private _timeouts;
    get timeouts(): GoogleClouddeployTargetTimeoutsOutputReference;
    putTimeouts(value: GoogleClouddeployTargetTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleClouddeployTargetTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
