/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleComposerEnvironmentConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#id GoogleComposerEnvironment#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * User-defined labels for this environment. The labels map can contain no more than 64 entries. Entries of the labels map are UTF8 strings that comply with the following restrictions: Label keys must be between 1 and 63 characters long and must conform to the following regular expression: [a-z]([-a-z0-9]*[a-z0-9])?. Label values must be between 0 and 63 characters long and must conform to the regular expression ([a-z]([-a-z0-9]*[a-z0-9])?)?. No more than 64 labels can be associated with a given environment. Both keys and values must be <= 128 bytes in size.
    *
    * 				**Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * 				Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#labels GoogleComposerEnvironment#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * Name of the environment.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#name GoogleComposerEnvironment#name}
    */
    readonly name: string;
    /**
    * The ID of the project in which the resource belongs. If it is not provided, the provider project is used.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#project GoogleComposerEnvironment#project}
    */
    readonly project?: string;
    /**
    * The location or Compute Engine region for the environment.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#region GoogleComposerEnvironment#region}
    */
    readonly region?: string;
    /**
    * config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#config GoogleComposerEnvironment#config}
    */
    readonly config?: GoogleComposerEnvironmentConfigA;
    /**
    * storage_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#storage_config GoogleComposerEnvironment#storage_config}
    */
    readonly storageConfig?: GoogleComposerEnvironmentStorageConfig;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#timeouts GoogleComposerEnvironment#timeouts}
    */
    readonly timeouts?: GoogleComposerEnvironmentTimeouts;
}
export interface GoogleComposerEnvironmentConfigDataRetentionConfigTaskLogsRetentionConfig {
    /**
    * Whether logs in cloud logging only is enabled or not. This field is supported for Cloud Composer environments in versions composer-2.0.32-airflow-2.1.4 and newer.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#storage_mode GoogleComposerEnvironment#storage_mode}
    */
    readonly storageMode?: string;
}
export declare function googleComposerEnvironmentConfigDataRetentionConfigTaskLogsRetentionConfigToTerraform(struct?: GoogleComposerEnvironmentConfigDataRetentionConfigTaskLogsRetentionConfig | cdktf.IResolvable): any;
export declare function googleComposerEnvironmentConfigDataRetentionConfigTaskLogsRetentionConfigToHclTerraform(struct?: GoogleComposerEnvironmentConfigDataRetentionConfigTaskLogsRetentionConfig | cdktf.IResolvable): any;
export declare class GoogleComposerEnvironmentConfigDataRetentionConfigTaskLogsRetentionConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleComposerEnvironmentConfigDataRetentionConfigTaskLogsRetentionConfig | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleComposerEnvironmentConfigDataRetentionConfigTaskLogsRetentionConfig | cdktf.IResolvable | undefined);
    private _storageMode?;
    get storageMode(): string;
    set storageMode(value: string);
    resetStorageMode(): void;
    get storageModeInput(): string | undefined;
}
export declare class GoogleComposerEnvironmentConfigDataRetentionConfigTaskLogsRetentionConfigList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleComposerEnvironmentConfigDataRetentionConfigTaskLogsRetentionConfig[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleComposerEnvironmentConfigDataRetentionConfigTaskLogsRetentionConfigOutputReference;
}
export interface GoogleComposerEnvironmentConfigDataRetentionConfig {
    /**
    * task_logs_retention_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#task_logs_retention_config GoogleComposerEnvironment#task_logs_retention_config}
    */
    readonly taskLogsRetentionConfig: GoogleComposerEnvironmentConfigDataRetentionConfigTaskLogsRetentionConfig[] | cdktf.IResolvable;
}
export declare function googleComposerEnvironmentConfigDataRetentionConfigToTerraform(struct?: GoogleComposerEnvironmentConfigDataRetentionConfigOutputReference | GoogleComposerEnvironmentConfigDataRetentionConfig): any;
export declare function googleComposerEnvironmentConfigDataRetentionConfigToHclTerraform(struct?: GoogleComposerEnvironmentConfigDataRetentionConfigOutputReference | GoogleComposerEnvironmentConfigDataRetentionConfig): any;
export declare class GoogleComposerEnvironmentConfigDataRetentionConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleComposerEnvironmentConfigDataRetentionConfig | undefined;
    set internalValue(value: GoogleComposerEnvironmentConfigDataRetentionConfig | undefined);
    private _taskLogsRetentionConfig;
    get taskLogsRetentionConfig(): GoogleComposerEnvironmentConfigDataRetentionConfigTaskLogsRetentionConfigList;
    putTaskLogsRetentionConfig(value: GoogleComposerEnvironmentConfigDataRetentionConfigTaskLogsRetentionConfig[] | cdktf.IResolvable): void;
    get taskLogsRetentionConfigInput(): cdktf.IResolvable | GoogleComposerEnvironmentConfigDataRetentionConfigTaskLogsRetentionConfig[] | undefined;
}
export interface GoogleComposerEnvironmentConfigDatabaseConfig {
    /**
    * Optional. Cloud SQL machine type used by Airflow database. It has to be one of: db-n1-standard-2, db-n1-standard-4, db-n1-standard-8 or db-n1-standard-16. If not specified, db-n1-standard-2 will be used.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#machine_type GoogleComposerEnvironment#machine_type}
    */
    readonly machineType?: string;
    /**
    * Optional. Cloud SQL database preferred zone.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#zone GoogleComposerEnvironment#zone}
    */
    readonly zone?: string;
}
export declare function googleComposerEnvironmentConfigDatabaseConfigToTerraform(struct?: GoogleComposerEnvironmentConfigDatabaseConfigOutputReference | GoogleComposerEnvironmentConfigDatabaseConfig): any;
export declare function googleComposerEnvironmentConfigDatabaseConfigToHclTerraform(struct?: GoogleComposerEnvironmentConfigDatabaseConfigOutputReference | GoogleComposerEnvironmentConfigDatabaseConfig): any;
export declare class GoogleComposerEnvironmentConfigDatabaseConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleComposerEnvironmentConfigDatabaseConfig | undefined;
    set internalValue(value: GoogleComposerEnvironmentConfigDatabaseConfig | undefined);
    private _machineType?;
    get machineType(): string;
    set machineType(value: string);
    resetMachineType(): void;
    get machineTypeInput(): string | undefined;
    private _zone?;
    get zone(): string;
    set zone(value: string);
    resetZone(): void;
    get zoneInput(): string | undefined;
}
export interface GoogleComposerEnvironmentConfigEncryptionConfig {
    /**
    * Optional. Customer-managed Encryption Key available through Google's Key Management Service. Cannot be updated.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#kms_key_name GoogleComposerEnvironment#kms_key_name}
    */
    readonly kmsKeyName: string;
}
export declare function googleComposerEnvironmentConfigEncryptionConfigToTerraform(struct?: GoogleComposerEnvironmentConfigEncryptionConfigOutputReference | GoogleComposerEnvironmentConfigEncryptionConfig): any;
export declare function googleComposerEnvironmentConfigEncryptionConfigToHclTerraform(struct?: GoogleComposerEnvironmentConfigEncryptionConfigOutputReference | GoogleComposerEnvironmentConfigEncryptionConfig): any;
export declare class GoogleComposerEnvironmentConfigEncryptionConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleComposerEnvironmentConfigEncryptionConfig | undefined;
    set internalValue(value: GoogleComposerEnvironmentConfigEncryptionConfig | undefined);
    private _kmsKeyName?;
    get kmsKeyName(): string;
    set kmsKeyName(value: string);
    get kmsKeyNameInput(): string | undefined;
}
export interface GoogleComposerEnvironmentConfigMaintenanceWindow {
    /**
    * Maintenance window end time. It is used only to calculate the duration of the maintenance window. The value for end-time must be in the future, relative to 'start_time'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#end_time GoogleComposerEnvironment#end_time}
    */
    readonly endTime: string;
    /**
    * Maintenance window recurrence. Format is a subset of RFC-5545 (https://tools.ietf.org/html/rfc5545) 'RRULE'. The only allowed values for 'FREQ' field are 'FREQ=DAILY' and 'FREQ=WEEKLY;BYDAY=...'. Example values: 'FREQ=WEEKLY;BYDAY=TU,WE', 'FREQ=DAILY'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#recurrence GoogleComposerEnvironment#recurrence}
    */
    readonly recurrence: string;
    /**
    * Start time of the first recurrence of the maintenance window.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#start_time GoogleComposerEnvironment#start_time}
    */
    readonly startTime: string;
}
export declare function googleComposerEnvironmentConfigMaintenanceWindowToTerraform(struct?: GoogleComposerEnvironmentConfigMaintenanceWindowOutputReference | GoogleComposerEnvironmentConfigMaintenanceWindow): any;
export declare function googleComposerEnvironmentConfigMaintenanceWindowToHclTerraform(struct?: GoogleComposerEnvironmentConfigMaintenanceWindowOutputReference | GoogleComposerEnvironmentConfigMaintenanceWindow): any;
export declare class GoogleComposerEnvironmentConfigMaintenanceWindowOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleComposerEnvironmentConfigMaintenanceWindow | undefined;
    set internalValue(value: GoogleComposerEnvironmentConfigMaintenanceWindow | undefined);
    private _endTime?;
    get endTime(): string;
    set endTime(value: string);
    get endTimeInput(): string | undefined;
    private _recurrence?;
    get recurrence(): string;
    set recurrence(value: string);
    get recurrenceInput(): string | undefined;
    private _startTime?;
    get startTime(): string;
    set startTime(value: string);
    get startTimeInput(): string | undefined;
}
export interface GoogleComposerEnvironmentConfigMasterAuthorizedNetworksConfigCidrBlocks {
    /**
    * cidr_block must be specified in CIDR notation.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#cidr_block GoogleComposerEnvironment#cidr_block}
    */
    readonly cidrBlock: string;
    /**
    * display_name is a field for users to identify CIDR blocks.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#display_name GoogleComposerEnvironment#display_name}
    */
    readonly displayName?: string;
}
export declare function googleComposerEnvironmentConfigMasterAuthorizedNetworksConfigCidrBlocksToTerraform(struct?: GoogleComposerEnvironmentConfigMasterAuthorizedNetworksConfigCidrBlocks | cdktf.IResolvable): any;
export declare function googleComposerEnvironmentConfigMasterAuthorizedNetworksConfigCidrBlocksToHclTerraform(struct?: GoogleComposerEnvironmentConfigMasterAuthorizedNetworksConfigCidrBlocks | cdktf.IResolvable): any;
export declare class GoogleComposerEnvironmentConfigMasterAuthorizedNetworksConfigCidrBlocksOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleComposerEnvironmentConfigMasterAuthorizedNetworksConfigCidrBlocks | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleComposerEnvironmentConfigMasterAuthorizedNetworksConfigCidrBlocks | cdktf.IResolvable | undefined);
    private _cidrBlock?;
    get cidrBlock(): string;
    set cidrBlock(value: string);
    get cidrBlockInput(): string | undefined;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    resetDisplayName(): void;
    get displayNameInput(): string | undefined;
}
export declare class GoogleComposerEnvironmentConfigMasterAuthorizedNetworksConfigCidrBlocksList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleComposerEnvironmentConfigMasterAuthorizedNetworksConfigCidrBlocks[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleComposerEnvironmentConfigMasterAuthorizedNetworksConfigCidrBlocksOutputReference;
}
export interface GoogleComposerEnvironmentConfigMasterAuthorizedNetworksConfig {
    /**
    * Whether or not master authorized networks is enabled.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#enabled GoogleComposerEnvironment#enabled}
    */
    readonly enabled: boolean | cdktf.IResolvable;
    /**
    * cidr_blocks block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#cidr_blocks GoogleComposerEnvironment#cidr_blocks}
    */
    readonly cidrBlocks?: GoogleComposerEnvironmentConfigMasterAuthorizedNetworksConfigCidrBlocks[] | cdktf.IResolvable;
}
export declare function googleComposerEnvironmentConfigMasterAuthorizedNetworksConfigToTerraform(struct?: GoogleComposerEnvironmentConfigMasterAuthorizedNetworksConfigOutputReference | GoogleComposerEnvironmentConfigMasterAuthorizedNetworksConfig): any;
export declare function googleComposerEnvironmentConfigMasterAuthorizedNetworksConfigToHclTerraform(struct?: GoogleComposerEnvironmentConfigMasterAuthorizedNetworksConfigOutputReference | GoogleComposerEnvironmentConfigMasterAuthorizedNetworksConfig): any;
export declare class GoogleComposerEnvironmentConfigMasterAuthorizedNetworksConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleComposerEnvironmentConfigMasterAuthorizedNetworksConfig | undefined;
    set internalValue(value: GoogleComposerEnvironmentConfigMasterAuthorizedNetworksConfig | undefined);
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _cidrBlocks;
    get cidrBlocks(): GoogleComposerEnvironmentConfigMasterAuthorizedNetworksConfigCidrBlocksList;
    putCidrBlocks(value: GoogleComposerEnvironmentConfigMasterAuthorizedNetworksConfigCidrBlocks[] | cdktf.IResolvable): void;
    resetCidrBlocks(): void;
    get cidrBlocksInput(): cdktf.IResolvable | GoogleComposerEnvironmentConfigMasterAuthorizedNetworksConfigCidrBlocks[] | undefined;
}
export interface GoogleComposerEnvironmentConfigNodeConfigIpAllocationPolicy {
    /**
    * The IP address range used to allocate IP addresses to pods in the cluster. For Cloud Composer environments in versions composer-1.*.*-airflow-*.*.*, this field is applicable only when use_ip_aliases is true. Set to blank to have GKE choose a range with the default size. Set to /netmask (e.g. /14) to have GKE choose a range with a specific netmask. Set to a CIDR notation (e.g. 10.96.0.0/14) from the RFC-1918 private networks (e.g. 10.0.0.0/8, 172.16.0.0/12, 192.168.0.0/16) to pick a specific range to use. Specify either cluster_secondary_range_name or cluster_ipv4_cidr_block but not both.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#cluster_ipv4_cidr_block GoogleComposerEnvironment#cluster_ipv4_cidr_block}
    */
    readonly clusterIpv4CidrBlock?: string;
    /**
    * The name of the cluster's secondary range used to allocate IP addresses to pods. Specify either cluster_secondary_range_name or cluster_ipv4_cidr_block but not both. For Cloud Composer environments in versions composer-1.*.*-airflow-*.*.*, this field is applicable only when use_ip_aliases is true.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#cluster_secondary_range_name GoogleComposerEnvironment#cluster_secondary_range_name}
    */
    readonly clusterSecondaryRangeName?: string;
    /**
    * The IP address range used to allocate IP addresses in this cluster. For Cloud Composer environments in versions composer-1.*.*-airflow-*.*.*, this field is applicable only when use_ip_aliases is true. Set to blank to have GKE choose a range with the default size. Set to /netmask (e.g. /14) to have GKE choose a range with a specific netmask. Set to a CIDR notation (e.g. 10.96.0.0/14) from the RFC-1918 private networks (e.g. 10.0.0.0/8, 172.16.0.0/12, 192.168.0.0/16) to pick a specific range to use. Specify either services_secondary_range_name or services_ipv4_cidr_block but not both.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#services_ipv4_cidr_block GoogleComposerEnvironment#services_ipv4_cidr_block}
    */
    readonly servicesIpv4CidrBlock?: string;
    /**
    * The name of the services' secondary range used to allocate IP addresses to the cluster. Specify either services_secondary_range_name or services_ipv4_cidr_block but not both. For Cloud Composer environments in versions composer-1.*.*-airflow-*.*.*, this field is applicable only when use_ip_aliases is true.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#services_secondary_range_name GoogleComposerEnvironment#services_secondary_range_name}
    */
    readonly servicesSecondaryRangeName?: string;
    /**
    * Whether or not to enable Alias IPs in the GKE cluster. If true, a VPC-native cluster is created. Defaults to true if the ip_allocation_policy block is present in config. This field is only supported for Cloud Composer environments in versions composer-1.*.*-airflow-*.*.*. Environments in newer versions always use VPC-native GKE clusters.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#use_ip_aliases GoogleComposerEnvironment#use_ip_aliases}
    */
    readonly useIpAliases?: boolean | cdktf.IResolvable;
}
export declare function googleComposerEnvironmentConfigNodeConfigIpAllocationPolicyToTerraform(struct?: GoogleComposerEnvironmentConfigNodeConfigIpAllocationPolicyOutputReference | GoogleComposerEnvironmentConfigNodeConfigIpAllocationPolicy): any;
export declare function googleComposerEnvironmentConfigNodeConfigIpAllocationPolicyToHclTerraform(struct?: GoogleComposerEnvironmentConfigNodeConfigIpAllocationPolicyOutputReference | GoogleComposerEnvironmentConfigNodeConfigIpAllocationPolicy): any;
export declare class GoogleComposerEnvironmentConfigNodeConfigIpAllocationPolicyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleComposerEnvironmentConfigNodeConfigIpAllocationPolicy | undefined;
    set internalValue(value: GoogleComposerEnvironmentConfigNodeConfigIpAllocationPolicy | undefined);
    private _clusterIpv4CidrBlock?;
    get clusterIpv4CidrBlock(): string;
    set clusterIpv4CidrBlock(value: string);
    resetClusterIpv4CidrBlock(): void;
    get clusterIpv4CidrBlockInput(): string | undefined;
    private _clusterSecondaryRangeName?;
    get clusterSecondaryRangeName(): string;
    set clusterSecondaryRangeName(value: string);
    resetClusterSecondaryRangeName(): void;
    get clusterSecondaryRangeNameInput(): string | undefined;
    private _servicesIpv4CidrBlock?;
    get servicesIpv4CidrBlock(): string;
    set servicesIpv4CidrBlock(value: string);
    resetServicesIpv4CidrBlock(): void;
    get servicesIpv4CidrBlockInput(): string | undefined;
    private _servicesSecondaryRangeName?;
    get servicesSecondaryRangeName(): string;
    set servicesSecondaryRangeName(value: string);
    resetServicesSecondaryRangeName(): void;
    get servicesSecondaryRangeNameInput(): string | undefined;
    private _useIpAliases?;
    get useIpAliases(): boolean | cdktf.IResolvable;
    set useIpAliases(value: boolean | cdktf.IResolvable);
    resetUseIpAliases(): void;
    get useIpAliasesInput(): boolean | cdktf.IResolvable | undefined;
}
export interface GoogleComposerEnvironmentConfigNodeConfig {
    /**
    * IPv4 cidr range that will be used by Composer internal components.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#composer_internal_ipv4_cidr_block GoogleComposerEnvironment#composer_internal_ipv4_cidr_block}
    */
    readonly composerInternalIpv4CidrBlock?: string;
    /**
    * PSC (Private Service Connect) Network entry point. Customers can pre-create the Network Attachment and point Cloud Composer environment to use. It is possible to share network attachment among many environments, provided enough IP addresses are available.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#composer_network_attachment GoogleComposerEnvironment#composer_network_attachment}
    */
    readonly composerNetworkAttachment?: string;
    /**
    * The disk size in GB used for node VMs. Minimum size is 20GB. If unspecified, defaults to 100GB. Cannot be updated. This field is supported for Cloud Composer environments in versions composer-1.*.*-airflow-*.*.*.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#disk_size_gb GoogleComposerEnvironment#disk_size_gb}
    */
    readonly diskSizeGb?: number;
    /**
    * Deploys 'ip-masq-agent' daemon set in the GKE cluster and defines nonMasqueradeCIDRs equals to pod IP range so IP masquerading is used for all destination addresses, except between pods traffic. See: https://cloud.google.com/kubernetes-engine/docs/how-to/ip-masquerade-agent
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#enable_ip_masq_agent GoogleComposerEnvironment#enable_ip_masq_agent}
    */
    readonly enableIpMasqAgent?: boolean | cdktf.IResolvable;
    /**
    * The Compute Engine machine type used for cluster instances, specified as a name or relative resource name. For example: "projects/{project}/zones/{zone}/machineTypes/{machineType}". Must belong to the enclosing environment's project and region/zone. This field is supported for Cloud Composer environments in versions composer-1.*.*-airflow-*.*.*.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#machine_type GoogleComposerEnvironment#machine_type}
    */
    readonly machineType?: string;
    /**
    * The maximum pods per node in the GKE cluster allocated during environment creation. Lowering this value reduces IP address consumption by the Cloud Composer Kubernetes cluster. This value can only be set during environment creation, and only if the environment is VPC-Native. The range of possible values is 8-110, and the default is 32. Cannot be updated. This field is supported for Cloud Composer environments in versions composer-1.*.*-airflow-*.*.*.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#max_pods_per_node GoogleComposerEnvironment#max_pods_per_node}
    */
    readonly maxPodsPerNode?: number;
    /**
    * The Compute Engine machine type used for cluster instances, specified as a name or relative resource name. For example: "projects/{project}/zones/{zone}/machineTypes/{machineType}". Must belong to the enclosing environment's project and region/zone. The network must belong to the environment's project. If unspecified, the "default" network ID in the environment's project is used. If a Custom Subnet Network is provided, subnetwork must also be provided.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#network GoogleComposerEnvironment#network}
    */
    readonly network?: string;
    /**
    * The set of Google API scopes to be made available on all node VMs. Cannot be updated. If empty, defaults to ["https://www.googleapis.com/auth/cloud-platform"]. This field is supported for Cloud Composer environments in versions composer-1.*.*-airflow-*.*.*.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#oauth_scopes GoogleComposerEnvironment#oauth_scopes}
    */
    readonly oauthScopes?: string[];
    /**
    * The Google Cloud Platform Service Account to be used by the node VMs. If a service account is not specified, the "default" Compute Engine service account is used. Cannot be updated. If given, note that the service account must have roles/composer.worker for any GCP resources created under the Cloud Composer Environment.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#service_account GoogleComposerEnvironment#service_account}
    */
    readonly serviceAccount?: string;
    /**
    * The Compute Engine subnetwork to be used for machine communications, specified as a self-link, relative resource name (e.g. "projects/{project}/regions/{region}/subnetworks/{subnetwork}"), or by name. If subnetwork is provided, network must also be provided and the subnetwork must belong to the enclosing environment's project and region.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#subnetwork GoogleComposerEnvironment#subnetwork}
    */
    readonly subnetwork?: string;
    /**
    * The list of instance tags applied to all node VMs. Tags are used to identify valid sources or targets for network firewalls. Each tag within the list must comply with RFC1035. Cannot be updated.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#tags GoogleComposerEnvironment#tags}
    */
    readonly tags?: string[];
    /**
    * The Compute Engine zone in which to deploy the VMs running the Apache Airflow software, specified as the zone name or relative resource name (e.g. "projects/{project}/zones/{zone}"). Must belong to the enclosing environment's project and region. This field is supported for Cloud Composer environments in versions composer-1.*.*-airflow-*.*.*.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#zone GoogleComposerEnvironment#zone}
    */
    readonly zone?: string;
    /**
    * ip_allocation_policy block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#ip_allocation_policy GoogleComposerEnvironment#ip_allocation_policy}
    */
    readonly ipAllocationPolicy?: GoogleComposerEnvironmentConfigNodeConfigIpAllocationPolicy;
}
export declare function googleComposerEnvironmentConfigNodeConfigToTerraform(struct?: GoogleComposerEnvironmentConfigNodeConfigOutputReference | GoogleComposerEnvironmentConfigNodeConfig): any;
export declare function googleComposerEnvironmentConfigNodeConfigToHclTerraform(struct?: GoogleComposerEnvironmentConfigNodeConfigOutputReference | GoogleComposerEnvironmentConfigNodeConfig): any;
export declare class GoogleComposerEnvironmentConfigNodeConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleComposerEnvironmentConfigNodeConfig | undefined;
    set internalValue(value: GoogleComposerEnvironmentConfigNodeConfig | undefined);
    private _composerInternalIpv4CidrBlock?;
    get composerInternalIpv4CidrBlock(): string;
    set composerInternalIpv4CidrBlock(value: string);
    resetComposerInternalIpv4CidrBlock(): void;
    get composerInternalIpv4CidrBlockInput(): string | undefined;
    private _composerNetworkAttachment?;
    get composerNetworkAttachment(): string;
    set composerNetworkAttachment(value: string);
    resetComposerNetworkAttachment(): void;
    get composerNetworkAttachmentInput(): string | undefined;
    private _diskSizeGb?;
    get diskSizeGb(): number;
    set diskSizeGb(value: number);
    resetDiskSizeGb(): void;
    get diskSizeGbInput(): number | undefined;
    private _enableIpMasqAgent?;
    get enableIpMasqAgent(): boolean | cdktf.IResolvable;
    set enableIpMasqAgent(value: boolean | cdktf.IResolvable);
    resetEnableIpMasqAgent(): void;
    get enableIpMasqAgentInput(): boolean | cdktf.IResolvable | undefined;
    private _machineType?;
    get machineType(): string;
    set machineType(value: string);
    resetMachineType(): void;
    get machineTypeInput(): string | undefined;
    private _maxPodsPerNode?;
    get maxPodsPerNode(): number;
    set maxPodsPerNode(value: number);
    resetMaxPodsPerNode(): void;
    get maxPodsPerNodeInput(): number | undefined;
    private _network?;
    get network(): string;
    set network(value: string);
    resetNetwork(): void;
    get networkInput(): string | undefined;
    private _oauthScopes?;
    get oauthScopes(): string[];
    set oauthScopes(value: string[]);
    resetOauthScopes(): void;
    get oauthScopesInput(): string[] | undefined;
    private _serviceAccount?;
    get serviceAccount(): string;
    set serviceAccount(value: string);
    resetServiceAccount(): void;
    get serviceAccountInput(): string | undefined;
    private _subnetwork?;
    get subnetwork(): string;
    set subnetwork(value: string);
    resetSubnetwork(): void;
    get subnetworkInput(): string | undefined;
    private _tags?;
    get tags(): string[];
    set tags(value: string[]);
    resetTags(): void;
    get tagsInput(): string[] | undefined;
    private _zone?;
    get zone(): string;
    set zone(value: string);
    resetZone(): void;
    get zoneInput(): string | undefined;
    private _ipAllocationPolicy;
    get ipAllocationPolicy(): GoogleComposerEnvironmentConfigNodeConfigIpAllocationPolicyOutputReference;
    putIpAllocationPolicy(value: GoogleComposerEnvironmentConfigNodeConfigIpAllocationPolicy): void;
    resetIpAllocationPolicy(): void;
    get ipAllocationPolicyInput(): GoogleComposerEnvironmentConfigNodeConfigIpAllocationPolicy | undefined;
}
export interface GoogleComposerEnvironmentConfigPrivateEnvironmentConfig {
    /**
    * When specified, the environment will use Private Service Connect instead of VPC peerings to connect to Cloud SQL in the Tenant Project, and the PSC endpoint in the Customer Project will use an IP address from this subnetwork. This field is supported for Cloud Composer environments in versions composer-2.*.*-airflow-*.*.* and newer.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#cloud_composer_connection_subnetwork GoogleComposerEnvironment#cloud_composer_connection_subnetwork}
    */
    readonly cloudComposerConnectionSubnetwork?: string;
    /**
    * The CIDR block from which IP range for Cloud Composer Network in tenant project will be reserved. Needs to be disjoint from private_cluster_config.master_ipv4_cidr_block and cloud_sql_ipv4_cidr_block. This field is supported for Cloud Composer environments in versions composer-2.*.*-airflow-*.*.* and newer.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#cloud_composer_network_ipv4_cidr_block GoogleComposerEnvironment#cloud_composer_network_ipv4_cidr_block}
    */
    readonly cloudComposerNetworkIpv4CidrBlock?: string;
    /**
    * The CIDR block from which IP range in tenant project will be reserved for Cloud SQL. Needs to be disjoint from web_server_ipv4_cidr_block.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#cloud_sql_ipv4_cidr_block GoogleComposerEnvironment#cloud_sql_ipv4_cidr_block}
    */
    readonly cloudSqlIpv4CidrBlock?: string;
    /**
    * Mode of internal communication within the Composer environment. Must be one of "VPC_PEERING" or "PRIVATE_SERVICE_CONNECT".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#connection_type GoogleComposerEnvironment#connection_type}
    */
    readonly connectionType?: string;
    /**
    * If true, access to the public endpoint of the GKE cluster is denied. If this field is set to true, ip_allocation_policy.use_ip_aliases must be set to true for Cloud Composer environments in versions composer-1.*.*-airflow-*.*.*.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#enable_private_endpoint GoogleComposerEnvironment#enable_private_endpoint}
    */
    readonly enablePrivateEndpoint?: boolean | cdktf.IResolvable;
    /**
    * When enabled, IPs from public (non-RFC1918) ranges can be used for ip_allocation_policy.cluster_ipv4_cidr_block and ip_allocation_policy.service_ipv4_cidr_block.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#enable_privately_used_public_ips GoogleComposerEnvironment#enable_privately_used_public_ips}
    */
    readonly enablePrivatelyUsedPublicIps?: boolean | cdktf.IResolvable;
    /**
    * The IP range in CIDR notation to use for the hosted master network. This range is used for assigning internal IP addresses to the cluster master or set of masters and to the internal load balancer virtual IP. This range must not overlap with any other ranges in use within the cluster's network. If left blank, the default value of '172.16.0.0/28' is used.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#master_ipv4_cidr_block GoogleComposerEnvironment#master_ipv4_cidr_block}
    */
    readonly masterIpv4CidrBlock?: string;
    /**
    * The CIDR block from which IP range for web server will be reserved. Needs to be disjoint from master_ipv4_cidr_block and cloud_sql_ipv4_cidr_block. This field is supported for Cloud Composer environments in versions composer-1.*.*-airflow-*.*.*.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#web_server_ipv4_cidr_block GoogleComposerEnvironment#web_server_ipv4_cidr_block}
    */
    readonly webServerIpv4CidrBlock?: string;
}
export declare function googleComposerEnvironmentConfigPrivateEnvironmentConfigToTerraform(struct?: GoogleComposerEnvironmentConfigPrivateEnvironmentConfigOutputReference | GoogleComposerEnvironmentConfigPrivateEnvironmentConfig): any;
export declare function googleComposerEnvironmentConfigPrivateEnvironmentConfigToHclTerraform(struct?: GoogleComposerEnvironmentConfigPrivateEnvironmentConfigOutputReference | GoogleComposerEnvironmentConfigPrivateEnvironmentConfig): any;
export declare class GoogleComposerEnvironmentConfigPrivateEnvironmentConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleComposerEnvironmentConfigPrivateEnvironmentConfig | undefined;
    set internalValue(value: GoogleComposerEnvironmentConfigPrivateEnvironmentConfig | undefined);
    private _cloudComposerConnectionSubnetwork?;
    get cloudComposerConnectionSubnetwork(): string;
    set cloudComposerConnectionSubnetwork(value: string);
    resetCloudComposerConnectionSubnetwork(): void;
    get cloudComposerConnectionSubnetworkInput(): string | undefined;
    private _cloudComposerNetworkIpv4CidrBlock?;
    get cloudComposerNetworkIpv4CidrBlock(): string;
    set cloudComposerNetworkIpv4CidrBlock(value: string);
    resetCloudComposerNetworkIpv4CidrBlock(): void;
    get cloudComposerNetworkIpv4CidrBlockInput(): string | undefined;
    private _cloudSqlIpv4CidrBlock?;
    get cloudSqlIpv4CidrBlock(): string;
    set cloudSqlIpv4CidrBlock(value: string);
    resetCloudSqlIpv4CidrBlock(): void;
    get cloudSqlIpv4CidrBlockInput(): string | undefined;
    private _connectionType?;
    get connectionType(): string;
    set connectionType(value: string);
    resetConnectionType(): void;
    get connectionTypeInput(): string | undefined;
    private _enablePrivateEndpoint?;
    get enablePrivateEndpoint(): boolean | cdktf.IResolvable;
    set enablePrivateEndpoint(value: boolean | cdktf.IResolvable);
    resetEnablePrivateEndpoint(): void;
    get enablePrivateEndpointInput(): boolean | cdktf.IResolvable | undefined;
    private _enablePrivatelyUsedPublicIps?;
    get enablePrivatelyUsedPublicIps(): boolean | cdktf.IResolvable;
    set enablePrivatelyUsedPublicIps(value: boolean | cdktf.IResolvable);
    resetEnablePrivatelyUsedPublicIps(): void;
    get enablePrivatelyUsedPublicIpsInput(): boolean | cdktf.IResolvable | undefined;
    private _masterIpv4CidrBlock?;
    get masterIpv4CidrBlock(): string;
    set masterIpv4CidrBlock(value: string);
    resetMasterIpv4CidrBlock(): void;
    get masterIpv4CidrBlockInput(): string | undefined;
    private _webServerIpv4CidrBlock?;
    get webServerIpv4CidrBlock(): string;
    set webServerIpv4CidrBlock(value: string);
    resetWebServerIpv4CidrBlock(): void;
    get webServerIpv4CidrBlockInput(): string | undefined;
}
export interface GoogleComposerEnvironmentConfigRecoveryConfigScheduledSnapshotsConfig {
    /**
    * When enabled, Cloud Composer periodically saves snapshots of your environment to a Cloud Storage bucket.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#enabled GoogleComposerEnvironment#enabled}
    */
    readonly enabled: boolean | cdktf.IResolvable;
    /**
    * Snapshot schedule, in the unix-cron format.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#snapshot_creation_schedule GoogleComposerEnvironment#snapshot_creation_schedule}
    */
    readonly snapshotCreationSchedule?: string;
    /**
    * the URI of a bucket folder where to save the snapshot.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#snapshot_location GoogleComposerEnvironment#snapshot_location}
    */
    readonly snapshotLocation?: string;
    /**
    * A time zone for the schedule. This value is a time offset and does not take into account daylight saving time changes. Valid values are from UTC-12 to UTC+12. Examples: UTC, UTC-01, UTC+03.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#time_zone GoogleComposerEnvironment#time_zone}
    */
    readonly timeZone?: string;
}
export declare function googleComposerEnvironmentConfigRecoveryConfigScheduledSnapshotsConfigToTerraform(struct?: GoogleComposerEnvironmentConfigRecoveryConfigScheduledSnapshotsConfigOutputReference | GoogleComposerEnvironmentConfigRecoveryConfigScheduledSnapshotsConfig): any;
export declare function googleComposerEnvironmentConfigRecoveryConfigScheduledSnapshotsConfigToHclTerraform(struct?: GoogleComposerEnvironmentConfigRecoveryConfigScheduledSnapshotsConfigOutputReference | GoogleComposerEnvironmentConfigRecoveryConfigScheduledSnapshotsConfig): any;
export declare class GoogleComposerEnvironmentConfigRecoveryConfigScheduledSnapshotsConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleComposerEnvironmentConfigRecoveryConfigScheduledSnapshotsConfig | undefined;
    set internalValue(value: GoogleComposerEnvironmentConfigRecoveryConfigScheduledSnapshotsConfig | undefined);
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _snapshotCreationSchedule?;
    get snapshotCreationSchedule(): string;
    set snapshotCreationSchedule(value: string);
    resetSnapshotCreationSchedule(): void;
    get snapshotCreationScheduleInput(): string | undefined;
    private _snapshotLocation?;
    get snapshotLocation(): string;
    set snapshotLocation(value: string);
    resetSnapshotLocation(): void;
    get snapshotLocationInput(): string | undefined;
    private _timeZone?;
    get timeZone(): string;
    set timeZone(value: string);
    resetTimeZone(): void;
    get timeZoneInput(): string | undefined;
}
export interface GoogleComposerEnvironmentConfigRecoveryConfig {
    /**
    * scheduled_snapshots_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#scheduled_snapshots_config GoogleComposerEnvironment#scheduled_snapshots_config}
    */
    readonly scheduledSnapshotsConfig?: GoogleComposerEnvironmentConfigRecoveryConfigScheduledSnapshotsConfig;
}
export declare function googleComposerEnvironmentConfigRecoveryConfigToTerraform(struct?: GoogleComposerEnvironmentConfigRecoveryConfigOutputReference | GoogleComposerEnvironmentConfigRecoveryConfig): any;
export declare function googleComposerEnvironmentConfigRecoveryConfigToHclTerraform(struct?: GoogleComposerEnvironmentConfigRecoveryConfigOutputReference | GoogleComposerEnvironmentConfigRecoveryConfig): any;
export declare class GoogleComposerEnvironmentConfigRecoveryConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleComposerEnvironmentConfigRecoveryConfig | undefined;
    set internalValue(value: GoogleComposerEnvironmentConfigRecoveryConfig | undefined);
    private _scheduledSnapshotsConfig;
    get scheduledSnapshotsConfig(): GoogleComposerEnvironmentConfigRecoveryConfigScheduledSnapshotsConfigOutputReference;
    putScheduledSnapshotsConfig(value: GoogleComposerEnvironmentConfigRecoveryConfigScheduledSnapshotsConfig): void;
    resetScheduledSnapshotsConfig(): void;
    get scheduledSnapshotsConfigInput(): GoogleComposerEnvironmentConfigRecoveryConfigScheduledSnapshotsConfig | undefined;
}
export interface GoogleComposerEnvironmentConfigSoftwareConfigCloudDataLineageIntegration {
    /**
    * Whether or not Cloud Data Lineage integration is enabled.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#enabled GoogleComposerEnvironment#enabled}
    */
    readonly enabled: boolean | cdktf.IResolvable;
}
export declare function googleComposerEnvironmentConfigSoftwareConfigCloudDataLineageIntegrationToTerraform(struct?: GoogleComposerEnvironmentConfigSoftwareConfigCloudDataLineageIntegrationOutputReference | GoogleComposerEnvironmentConfigSoftwareConfigCloudDataLineageIntegration): any;
export declare function googleComposerEnvironmentConfigSoftwareConfigCloudDataLineageIntegrationToHclTerraform(struct?: GoogleComposerEnvironmentConfigSoftwareConfigCloudDataLineageIntegrationOutputReference | GoogleComposerEnvironmentConfigSoftwareConfigCloudDataLineageIntegration): any;
export declare class GoogleComposerEnvironmentConfigSoftwareConfigCloudDataLineageIntegrationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleComposerEnvironmentConfigSoftwareConfigCloudDataLineageIntegration | undefined;
    set internalValue(value: GoogleComposerEnvironmentConfigSoftwareConfigCloudDataLineageIntegration | undefined);
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
}
export interface GoogleComposerEnvironmentConfigSoftwareConfig {
    /**
    * Apache Airflow configuration properties to override. Property keys contain the section and property names, separated by a hyphen, for example "core-dags_are_paused_at_creation". Section names must not contain hyphens ("-"), opening square brackets ("["), or closing square brackets ("]"). The property name must not be empty and cannot contain "=" or ";". Section and property names cannot contain characters: "." Apache Airflow configuration property names must be written in snake_case. Property values can contain any character, and can be written in any lower/upper case format. Certain Apache Airflow configuration property values are blacklisted, and cannot be overridden.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#airflow_config_overrides GoogleComposerEnvironment#airflow_config_overrides}
    */
    readonly airflowConfigOverrides?: {
        [key: string]: string;
    };
    /**
    * Additional environment variables to provide to the Apache Airflow scheduler, worker, and webserver processes. Environment variable names must match the regular expression [a-zA-Z_][a-zA-Z0-9_]*. They cannot specify Apache Airflow software configuration overrides (they cannot match the regular expression AIRFLOW__[A-Z0-9_]+__[A-Z0-9_]+), and they cannot match any of the following reserved names: AIRFLOW_HOME C_FORCE_ROOT CONTAINER_NAME DAGS_FOLDER GCP_PROJECT GCS_BUCKET GKE_CLUSTER_NAME SQL_DATABASE SQL_INSTANCE SQL_PASSWORD SQL_PROJECT SQL_REGION SQL_USER.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#env_variables GoogleComposerEnvironment#env_variables}
    */
    readonly envVariables?: {
        [key: string]: string;
    };
    /**
    * The version of the software running in the environment. This encapsulates both the version of Cloud Composer functionality and the version of Apache Airflow. It must match the regular expression composer-([0-9]+(\.[0-9]+\.[0-9]+(-preview\.[0-9]+)?)?|latest)-airflow-([0-9]+(\.[0-9]+(\.[0-9]+)?)?). The Cloud Composer portion of the image version is a full semantic version, or an alias in the form of major version number or 'latest'. The Apache Airflow portion of the image version is a full semantic version that points to one of the supported Apache Airflow versions, or an alias in the form of only major or major.minor versions specified. See documentation for more details and version list.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#image_version GoogleComposerEnvironment#image_version}
    */
    readonly imageVersion?: string;
    /**
    * Custom Python Package Index (PyPI) packages to be installed in the environment. Keys refer to the lowercase package name (e.g. "numpy"). Values are the lowercase extras and version specifier (e.g. "==1.12.0", "[devel,gcp_api]", "[devel]>=1.8.2, <1.9.2"). To specify a package without pinning it to a version specifier, use the empty string as the value.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#pypi_packages GoogleComposerEnvironment#pypi_packages}
    */
    readonly pypiPackages?: {
        [key: string]: string;
    };
    /**
    * The major version of Python used to run the Apache Airflow scheduler, worker, and webserver processes. Can be set to '2' or '3'. If not specified, the default is '2'. Cannot be updated. This field is supported for Cloud Composer environments in versions composer-1.*.*-airflow-*.*.*. Environments in newer versions always use Python major version 3.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#python_version GoogleComposerEnvironment#python_version}
    */
    readonly pythonVersion?: string;
    /**
    * The number of schedulers for Airflow. This field is supported for Cloud Composer environments in versions composer-1.*.*-airflow-2.*.*.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#scheduler_count GoogleComposerEnvironment#scheduler_count}
    */
    readonly schedulerCount?: number;
    /**
    * Should be either 'ENABLED' or 'DISABLED'. Defaults to 'ENABLED'. Used in Composer 3.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#web_server_plugins_mode GoogleComposerEnvironment#web_server_plugins_mode}
    */
    readonly webServerPluginsMode?: string;
    /**
    * cloud_data_lineage_integration block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#cloud_data_lineage_integration GoogleComposerEnvironment#cloud_data_lineage_integration}
    */
    readonly cloudDataLineageIntegration?: GoogleComposerEnvironmentConfigSoftwareConfigCloudDataLineageIntegration;
}
export declare function googleComposerEnvironmentConfigSoftwareConfigToTerraform(struct?: GoogleComposerEnvironmentConfigSoftwareConfigOutputReference | GoogleComposerEnvironmentConfigSoftwareConfig): any;
export declare function googleComposerEnvironmentConfigSoftwareConfigToHclTerraform(struct?: GoogleComposerEnvironmentConfigSoftwareConfigOutputReference | GoogleComposerEnvironmentConfigSoftwareConfig): any;
export declare class GoogleComposerEnvironmentConfigSoftwareConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleComposerEnvironmentConfigSoftwareConfig | undefined;
    set internalValue(value: GoogleComposerEnvironmentConfigSoftwareConfig | undefined);
    private _airflowConfigOverrides?;
    get airflowConfigOverrides(): {
        [key: string]: string;
    };
    set airflowConfigOverrides(value: {
        [key: string]: string;
    });
    resetAirflowConfigOverrides(): void;
    get airflowConfigOverridesInput(): {
        [key: string]: string;
    } | undefined;
    private _envVariables?;
    get envVariables(): {
        [key: string]: string;
    };
    set envVariables(value: {
        [key: string]: string;
    });
    resetEnvVariables(): void;
    get envVariablesInput(): {
        [key: string]: string;
    } | undefined;
    private _imageVersion?;
    get imageVersion(): string;
    set imageVersion(value: string);
    resetImageVersion(): void;
    get imageVersionInput(): string | undefined;
    private _pypiPackages?;
    get pypiPackages(): {
        [key: string]: string;
    };
    set pypiPackages(value: {
        [key: string]: string;
    });
    resetPypiPackages(): void;
    get pypiPackagesInput(): {
        [key: string]: string;
    } | undefined;
    private _pythonVersion?;
    get pythonVersion(): string;
    set pythonVersion(value: string);
    resetPythonVersion(): void;
    get pythonVersionInput(): string | undefined;
    private _schedulerCount?;
    get schedulerCount(): number;
    set schedulerCount(value: number);
    resetSchedulerCount(): void;
    get schedulerCountInput(): number | undefined;
    private _webServerPluginsMode?;
    get webServerPluginsMode(): string;
    set webServerPluginsMode(value: string);
    resetWebServerPluginsMode(): void;
    get webServerPluginsModeInput(): string | undefined;
    private _cloudDataLineageIntegration;
    get cloudDataLineageIntegration(): GoogleComposerEnvironmentConfigSoftwareConfigCloudDataLineageIntegrationOutputReference;
    putCloudDataLineageIntegration(value: GoogleComposerEnvironmentConfigSoftwareConfigCloudDataLineageIntegration): void;
    resetCloudDataLineageIntegration(): void;
    get cloudDataLineageIntegrationInput(): GoogleComposerEnvironmentConfigSoftwareConfigCloudDataLineageIntegration | undefined;
}
export interface GoogleComposerEnvironmentConfigWebServerConfig {
    /**
    * Optional. Machine type on which Airflow web server is running. It has to be one of: composer-n1-webserver-2, composer-n1-webserver-4 or composer-n1-webserver-8. If not specified, composer-n1-webserver-2 will be used. Value custom is returned only in response, if Airflow web server parameters were manually changed to a non-standard values.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#machine_type GoogleComposerEnvironment#machine_type}
    */
    readonly machineType: string;
}
export declare function googleComposerEnvironmentConfigWebServerConfigToTerraform(struct?: GoogleComposerEnvironmentConfigWebServerConfigOutputReference | GoogleComposerEnvironmentConfigWebServerConfig): any;
export declare function googleComposerEnvironmentConfigWebServerConfigToHclTerraform(struct?: GoogleComposerEnvironmentConfigWebServerConfigOutputReference | GoogleComposerEnvironmentConfigWebServerConfig): any;
export declare class GoogleComposerEnvironmentConfigWebServerConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleComposerEnvironmentConfigWebServerConfig | undefined;
    set internalValue(value: GoogleComposerEnvironmentConfigWebServerConfig | undefined);
    private _machineType?;
    get machineType(): string;
    set machineType(value: string);
    get machineTypeInput(): string | undefined;
}
export interface GoogleComposerEnvironmentConfigWebServerNetworkAccessControlAllowedIpRange {
    /**
    * A description of this ip range.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#description GoogleComposerEnvironment#description}
    */
    readonly description?: string;
    /**
    * IP address or range, defined using CIDR notation, of requests that this rule applies to. Examples: 192.168.1.1 or 192.168.0.0/16 or 2001:db8::/32 or 2001:0db8:0000:0042:0000:8a2e:0370:7334. IP range prefixes should be properly truncated. For example, 1.2.3.4/24 should be truncated to 1.2.3.0/24. Similarly, for IPv6, 2001:db8::1/32 should be truncated to 2001:db8::/32.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#value GoogleComposerEnvironment#value}
    */
    readonly value: string;
}
export declare function googleComposerEnvironmentConfigWebServerNetworkAccessControlAllowedIpRangeToTerraform(struct?: GoogleComposerEnvironmentConfigWebServerNetworkAccessControlAllowedIpRange | cdktf.IResolvable): any;
export declare function googleComposerEnvironmentConfigWebServerNetworkAccessControlAllowedIpRangeToHclTerraform(struct?: GoogleComposerEnvironmentConfigWebServerNetworkAccessControlAllowedIpRange | cdktf.IResolvable): any;
export declare class GoogleComposerEnvironmentConfigWebServerNetworkAccessControlAllowedIpRangeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleComposerEnvironmentConfigWebServerNetworkAccessControlAllowedIpRange | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleComposerEnvironmentConfigWebServerNetworkAccessControlAllowedIpRange | cdktf.IResolvable | undefined);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    get valueInput(): string | undefined;
}
export declare class GoogleComposerEnvironmentConfigWebServerNetworkAccessControlAllowedIpRangeList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleComposerEnvironmentConfigWebServerNetworkAccessControlAllowedIpRange[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleComposerEnvironmentConfigWebServerNetworkAccessControlAllowedIpRangeOutputReference;
}
export interface GoogleComposerEnvironmentConfigWebServerNetworkAccessControl {
    /**
    * allowed_ip_range block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#allowed_ip_range GoogleComposerEnvironment#allowed_ip_range}
    */
    readonly allowedIpRange?: GoogleComposerEnvironmentConfigWebServerNetworkAccessControlAllowedIpRange[] | cdktf.IResolvable;
}
export declare function googleComposerEnvironmentConfigWebServerNetworkAccessControlToTerraform(struct?: GoogleComposerEnvironmentConfigWebServerNetworkAccessControlOutputReference | GoogleComposerEnvironmentConfigWebServerNetworkAccessControl): any;
export declare function googleComposerEnvironmentConfigWebServerNetworkAccessControlToHclTerraform(struct?: GoogleComposerEnvironmentConfigWebServerNetworkAccessControlOutputReference | GoogleComposerEnvironmentConfigWebServerNetworkAccessControl): any;
export declare class GoogleComposerEnvironmentConfigWebServerNetworkAccessControlOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleComposerEnvironmentConfigWebServerNetworkAccessControl | undefined;
    set internalValue(value: GoogleComposerEnvironmentConfigWebServerNetworkAccessControl | undefined);
    private _allowedIpRange;
    get allowedIpRange(): GoogleComposerEnvironmentConfigWebServerNetworkAccessControlAllowedIpRangeList;
    putAllowedIpRange(value: GoogleComposerEnvironmentConfigWebServerNetworkAccessControlAllowedIpRange[] | cdktf.IResolvable): void;
    resetAllowedIpRange(): void;
    get allowedIpRangeInput(): cdktf.IResolvable | GoogleComposerEnvironmentConfigWebServerNetworkAccessControlAllowedIpRange[] | undefined;
}
export interface GoogleComposerEnvironmentConfigWorkloadsConfigDagProcessor {
    /**
    * Number of DAG processors.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#count GoogleComposerEnvironment#count}
    */
    readonly count?: number;
    /**
    * CPU request and limit for DAG processor.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#cpu GoogleComposerEnvironment#cpu}
    */
    readonly cpu?: number;
    /**
    * Memory (GB) request and limit for DAG processor.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#memory_gb GoogleComposerEnvironment#memory_gb}
    */
    readonly memoryGb?: number;
    /**
    * Storage (GB) request and limit for DAG processor.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#storage_gb GoogleComposerEnvironment#storage_gb}
    */
    readonly storageGb?: number;
}
export declare function googleComposerEnvironmentConfigWorkloadsConfigDagProcessorToTerraform(struct?: GoogleComposerEnvironmentConfigWorkloadsConfigDagProcessorOutputReference | GoogleComposerEnvironmentConfigWorkloadsConfigDagProcessor): any;
export declare function googleComposerEnvironmentConfigWorkloadsConfigDagProcessorToHclTerraform(struct?: GoogleComposerEnvironmentConfigWorkloadsConfigDagProcessorOutputReference | GoogleComposerEnvironmentConfigWorkloadsConfigDagProcessor): any;
export declare class GoogleComposerEnvironmentConfigWorkloadsConfigDagProcessorOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleComposerEnvironmentConfigWorkloadsConfigDagProcessor | undefined;
    set internalValue(value: GoogleComposerEnvironmentConfigWorkloadsConfigDagProcessor | undefined);
    private _count?;
    get count(): number;
    set count(value: number);
    resetCount(): void;
    get countInput(): number | undefined;
    private _cpu?;
    get cpu(): number;
    set cpu(value: number);
    resetCpu(): void;
    get cpuInput(): number | undefined;
    private _memoryGb?;
    get memoryGb(): number;
    set memoryGb(value: number);
    resetMemoryGb(): void;
    get memoryGbInput(): number | undefined;
    private _storageGb?;
    get storageGb(): number;
    set storageGb(value: number);
    resetStorageGb(): void;
    get storageGbInput(): number | undefined;
}
export interface GoogleComposerEnvironmentConfigWorkloadsConfigScheduler {
    /**
    * The number of schedulers.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#count GoogleComposerEnvironment#count}
    */
    readonly count?: number;
    /**
    * CPU request and limit for a single Airflow scheduler replica
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#cpu GoogleComposerEnvironment#cpu}
    */
    readonly cpu?: number;
    /**
    * Memory (GB) request and limit for a single Airflow scheduler replica.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#memory_gb GoogleComposerEnvironment#memory_gb}
    */
    readonly memoryGb?: number;
    /**
    * Storage (GB) request and limit for a single Airflow scheduler replica.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#storage_gb GoogleComposerEnvironment#storage_gb}
    */
    readonly storageGb?: number;
}
export declare function googleComposerEnvironmentConfigWorkloadsConfigSchedulerToTerraform(struct?: GoogleComposerEnvironmentConfigWorkloadsConfigSchedulerOutputReference | GoogleComposerEnvironmentConfigWorkloadsConfigScheduler): any;
export declare function googleComposerEnvironmentConfigWorkloadsConfigSchedulerToHclTerraform(struct?: GoogleComposerEnvironmentConfigWorkloadsConfigSchedulerOutputReference | GoogleComposerEnvironmentConfigWorkloadsConfigScheduler): any;
export declare class GoogleComposerEnvironmentConfigWorkloadsConfigSchedulerOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleComposerEnvironmentConfigWorkloadsConfigScheduler | undefined;
    set internalValue(value: GoogleComposerEnvironmentConfigWorkloadsConfigScheduler | undefined);
    private _count?;
    get count(): number;
    set count(value: number);
    resetCount(): void;
    get countInput(): number | undefined;
    private _cpu?;
    get cpu(): number;
    set cpu(value: number);
    resetCpu(): void;
    get cpuInput(): number | undefined;
    private _memoryGb?;
    get memoryGb(): number;
    set memoryGb(value: number);
    resetMemoryGb(): void;
    get memoryGbInput(): number | undefined;
    private _storageGb?;
    get storageGb(): number;
    set storageGb(value: number);
    resetStorageGb(): void;
    get storageGbInput(): number | undefined;
}
export interface GoogleComposerEnvironmentConfigWorkloadsConfigTriggerer {
    /**
    * The number of triggerers.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#count GoogleComposerEnvironment#count}
    */
    readonly count: number;
    /**
    * CPU request and limit for a single Airflow triggerer replica.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#cpu GoogleComposerEnvironment#cpu}
    */
    readonly cpu: number;
    /**
    * Memory (GB) request and limit for a single Airflow triggerer replica.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#memory_gb GoogleComposerEnvironment#memory_gb}
    */
    readonly memoryGb: number;
}
export declare function googleComposerEnvironmentConfigWorkloadsConfigTriggererToTerraform(struct?: GoogleComposerEnvironmentConfigWorkloadsConfigTriggererOutputReference | GoogleComposerEnvironmentConfigWorkloadsConfigTriggerer): any;
export declare function googleComposerEnvironmentConfigWorkloadsConfigTriggererToHclTerraform(struct?: GoogleComposerEnvironmentConfigWorkloadsConfigTriggererOutputReference | GoogleComposerEnvironmentConfigWorkloadsConfigTriggerer): any;
export declare class GoogleComposerEnvironmentConfigWorkloadsConfigTriggererOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleComposerEnvironmentConfigWorkloadsConfigTriggerer | undefined;
    set internalValue(value: GoogleComposerEnvironmentConfigWorkloadsConfigTriggerer | undefined);
    private _count?;
    get count(): number;
    set count(value: number);
    get countInput(): number | undefined;
    private _cpu?;
    get cpu(): number;
    set cpu(value: number);
    get cpuInput(): number | undefined;
    private _memoryGb?;
    get memoryGb(): number;
    set memoryGb(value: number);
    get memoryGbInput(): number | undefined;
}
export interface GoogleComposerEnvironmentConfigWorkloadsConfigWebServer {
    /**
    * CPU request and limit for Airflow web server.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#cpu GoogleComposerEnvironment#cpu}
    */
    readonly cpu?: number;
    /**
    * Memory (GB) request and limit for Airflow web server.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#memory_gb GoogleComposerEnvironment#memory_gb}
    */
    readonly memoryGb?: number;
    /**
    * Storage (GB) request and limit for Airflow web server.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#storage_gb GoogleComposerEnvironment#storage_gb}
    */
    readonly storageGb?: number;
}
export declare function googleComposerEnvironmentConfigWorkloadsConfigWebServerToTerraform(struct?: GoogleComposerEnvironmentConfigWorkloadsConfigWebServerOutputReference | GoogleComposerEnvironmentConfigWorkloadsConfigWebServer): any;
export declare function googleComposerEnvironmentConfigWorkloadsConfigWebServerToHclTerraform(struct?: GoogleComposerEnvironmentConfigWorkloadsConfigWebServerOutputReference | GoogleComposerEnvironmentConfigWorkloadsConfigWebServer): any;
export declare class GoogleComposerEnvironmentConfigWorkloadsConfigWebServerOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleComposerEnvironmentConfigWorkloadsConfigWebServer | undefined;
    set internalValue(value: GoogleComposerEnvironmentConfigWorkloadsConfigWebServer | undefined);
    private _cpu?;
    get cpu(): number;
    set cpu(value: number);
    resetCpu(): void;
    get cpuInput(): number | undefined;
    private _memoryGb?;
    get memoryGb(): number;
    set memoryGb(value: number);
    resetMemoryGb(): void;
    get memoryGbInput(): number | undefined;
    private _storageGb?;
    get storageGb(): number;
    set storageGb(value: number);
    resetStorageGb(): void;
    get storageGbInput(): number | undefined;
}
export interface GoogleComposerEnvironmentConfigWorkloadsConfigWorker {
    /**
    * CPU request and limit for a single Airflow worker replica.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#cpu GoogleComposerEnvironment#cpu}
    */
    readonly cpu?: number;
    /**
    * Maximum number of workers for autoscaling.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#max_count GoogleComposerEnvironment#max_count}
    */
    readonly maxCount?: number;
    /**
    * Memory (GB) request and limit for a single Airflow worker replica.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#memory_gb GoogleComposerEnvironment#memory_gb}
    */
    readonly memoryGb?: number;
    /**
    * Minimum number of workers for autoscaling.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#min_count GoogleComposerEnvironment#min_count}
    */
    readonly minCount?: number;
    /**
    * Storage (GB) request and limit for a single Airflow worker replica.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#storage_gb GoogleComposerEnvironment#storage_gb}
    */
    readonly storageGb?: number;
}
export declare function googleComposerEnvironmentConfigWorkloadsConfigWorkerToTerraform(struct?: GoogleComposerEnvironmentConfigWorkloadsConfigWorkerOutputReference | GoogleComposerEnvironmentConfigWorkloadsConfigWorker): any;
export declare function googleComposerEnvironmentConfigWorkloadsConfigWorkerToHclTerraform(struct?: GoogleComposerEnvironmentConfigWorkloadsConfigWorkerOutputReference | GoogleComposerEnvironmentConfigWorkloadsConfigWorker): any;
export declare class GoogleComposerEnvironmentConfigWorkloadsConfigWorkerOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleComposerEnvironmentConfigWorkloadsConfigWorker | undefined;
    set internalValue(value: GoogleComposerEnvironmentConfigWorkloadsConfigWorker | undefined);
    private _cpu?;
    get cpu(): number;
    set cpu(value: number);
    resetCpu(): void;
    get cpuInput(): number | undefined;
    private _maxCount?;
    get maxCount(): number;
    set maxCount(value: number);
    resetMaxCount(): void;
    get maxCountInput(): number | undefined;
    private _memoryGb?;
    get memoryGb(): number;
    set memoryGb(value: number);
    resetMemoryGb(): void;
    get memoryGbInput(): number | undefined;
    private _minCount?;
    get minCount(): number;
    set minCount(value: number);
    resetMinCount(): void;
    get minCountInput(): number | undefined;
    private _storageGb?;
    get storageGb(): number;
    set storageGb(value: number);
    resetStorageGb(): void;
    get storageGbInput(): number | undefined;
}
export interface GoogleComposerEnvironmentConfigWorkloadsConfig {
    /**
    * dag_processor block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#dag_processor GoogleComposerEnvironment#dag_processor}
    */
    readonly dagProcessor?: GoogleComposerEnvironmentConfigWorkloadsConfigDagProcessor;
    /**
    * scheduler block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#scheduler GoogleComposerEnvironment#scheduler}
    */
    readonly scheduler?: GoogleComposerEnvironmentConfigWorkloadsConfigScheduler;
    /**
    * triggerer block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#triggerer GoogleComposerEnvironment#triggerer}
    */
    readonly triggerer?: GoogleComposerEnvironmentConfigWorkloadsConfigTriggerer;
    /**
    * web_server block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#web_server GoogleComposerEnvironment#web_server}
    */
    readonly webServer?: GoogleComposerEnvironmentConfigWorkloadsConfigWebServer;
    /**
    * worker block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#worker GoogleComposerEnvironment#worker}
    */
    readonly worker?: GoogleComposerEnvironmentConfigWorkloadsConfigWorker;
}
export declare function googleComposerEnvironmentConfigWorkloadsConfigToTerraform(struct?: GoogleComposerEnvironmentConfigWorkloadsConfigOutputReference | GoogleComposerEnvironmentConfigWorkloadsConfig): any;
export declare function googleComposerEnvironmentConfigWorkloadsConfigToHclTerraform(struct?: GoogleComposerEnvironmentConfigWorkloadsConfigOutputReference | GoogleComposerEnvironmentConfigWorkloadsConfig): any;
export declare class GoogleComposerEnvironmentConfigWorkloadsConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleComposerEnvironmentConfigWorkloadsConfig | undefined;
    set internalValue(value: GoogleComposerEnvironmentConfigWorkloadsConfig | undefined);
    private _dagProcessor;
    get dagProcessor(): GoogleComposerEnvironmentConfigWorkloadsConfigDagProcessorOutputReference;
    putDagProcessor(value: GoogleComposerEnvironmentConfigWorkloadsConfigDagProcessor): void;
    resetDagProcessor(): void;
    get dagProcessorInput(): GoogleComposerEnvironmentConfigWorkloadsConfigDagProcessor | undefined;
    private _scheduler;
    get scheduler(): GoogleComposerEnvironmentConfigWorkloadsConfigSchedulerOutputReference;
    putScheduler(value: GoogleComposerEnvironmentConfigWorkloadsConfigScheduler): void;
    resetScheduler(): void;
    get schedulerInput(): GoogleComposerEnvironmentConfigWorkloadsConfigScheduler | undefined;
    private _triggerer;
    get triggerer(): GoogleComposerEnvironmentConfigWorkloadsConfigTriggererOutputReference;
    putTriggerer(value: GoogleComposerEnvironmentConfigWorkloadsConfigTriggerer): void;
    resetTriggerer(): void;
    get triggererInput(): GoogleComposerEnvironmentConfigWorkloadsConfigTriggerer | undefined;
    private _webServer;
    get webServer(): GoogleComposerEnvironmentConfigWorkloadsConfigWebServerOutputReference;
    putWebServer(value: GoogleComposerEnvironmentConfigWorkloadsConfigWebServer): void;
    resetWebServer(): void;
    get webServerInput(): GoogleComposerEnvironmentConfigWorkloadsConfigWebServer | undefined;
    private _worker;
    get worker(): GoogleComposerEnvironmentConfigWorkloadsConfigWorkerOutputReference;
    putWorker(value: GoogleComposerEnvironmentConfigWorkloadsConfigWorker): void;
    resetWorker(): void;
    get workerInput(): GoogleComposerEnvironmentConfigWorkloadsConfigWorker | undefined;
}
export interface GoogleComposerEnvironmentConfigA {
    /**
    * Optional. If true, builds performed during operations that install Python packages have only private connectivity to Google services. If false, the builds also have access to the internet.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#enable_private_builds_only GoogleComposerEnvironment#enable_private_builds_only}
    */
    readonly enablePrivateBuildsOnly?: boolean | cdktf.IResolvable;
    /**
    * Optional. If true, a private Composer environment will be created.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#enable_private_environment GoogleComposerEnvironment#enable_private_environment}
    */
    readonly enablePrivateEnvironment?: boolean | cdktf.IResolvable;
    /**
    * The size of the Cloud Composer environment. This field is supported for Cloud Composer environments in versions composer-2.*.*-airflow-*.*.* and newer.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#environment_size GoogleComposerEnvironment#environment_size}
    */
    readonly environmentSize?: string;
    /**
    * The number of nodes in the Kubernetes Engine cluster that will be used to run this environment. This field is supported for Cloud Composer environments in versions composer-1.*.*-airflow-*.*.*.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#node_count GoogleComposerEnvironment#node_count}
    */
    readonly nodeCount?: number;
    /**
    * Whether high resilience is enabled or not. This field is supported for Cloud Composer environments in versions composer-2.1.15-airflow-*.*.* and newer.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#resilience_mode GoogleComposerEnvironment#resilience_mode}
    */
    readonly resilienceMode?: string;
    /**
    * data_retention_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#data_retention_config GoogleComposerEnvironment#data_retention_config}
    */
    readonly dataRetentionConfig?: GoogleComposerEnvironmentConfigDataRetentionConfig;
    /**
    * database_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#database_config GoogleComposerEnvironment#database_config}
    */
    readonly databaseConfig?: GoogleComposerEnvironmentConfigDatabaseConfig;
    /**
    * encryption_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#encryption_config GoogleComposerEnvironment#encryption_config}
    */
    readonly encryptionConfig?: GoogleComposerEnvironmentConfigEncryptionConfig;
    /**
    * maintenance_window block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#maintenance_window GoogleComposerEnvironment#maintenance_window}
    */
    readonly maintenanceWindow?: GoogleComposerEnvironmentConfigMaintenanceWindow;
    /**
    * master_authorized_networks_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#master_authorized_networks_config GoogleComposerEnvironment#master_authorized_networks_config}
    */
    readonly masterAuthorizedNetworksConfig?: GoogleComposerEnvironmentConfigMasterAuthorizedNetworksConfig;
    /**
    * node_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#node_config GoogleComposerEnvironment#node_config}
    */
    readonly nodeConfig?: GoogleComposerEnvironmentConfigNodeConfig;
    /**
    * private_environment_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#private_environment_config GoogleComposerEnvironment#private_environment_config}
    */
    readonly privateEnvironmentConfig?: GoogleComposerEnvironmentConfigPrivateEnvironmentConfig;
    /**
    * recovery_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#recovery_config GoogleComposerEnvironment#recovery_config}
    */
    readonly recoveryConfig?: GoogleComposerEnvironmentConfigRecoveryConfig;
    /**
    * software_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#software_config GoogleComposerEnvironment#software_config}
    */
    readonly softwareConfig?: GoogleComposerEnvironmentConfigSoftwareConfig;
    /**
    * web_server_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#web_server_config GoogleComposerEnvironment#web_server_config}
    */
    readonly webServerConfig?: GoogleComposerEnvironmentConfigWebServerConfig;
    /**
    * web_server_network_access_control block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#web_server_network_access_control GoogleComposerEnvironment#web_server_network_access_control}
    */
    readonly webServerNetworkAccessControl?: GoogleComposerEnvironmentConfigWebServerNetworkAccessControl;
    /**
    * workloads_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#workloads_config GoogleComposerEnvironment#workloads_config}
    */
    readonly workloadsConfig?: GoogleComposerEnvironmentConfigWorkloadsConfig;
}
export declare function googleComposerEnvironmentConfigAToTerraform(struct?: GoogleComposerEnvironmentConfigAOutputReference | GoogleComposerEnvironmentConfigA): any;
export declare function googleComposerEnvironmentConfigAToHclTerraform(struct?: GoogleComposerEnvironmentConfigAOutputReference | GoogleComposerEnvironmentConfigA): any;
export declare class GoogleComposerEnvironmentConfigAOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleComposerEnvironmentConfigA | undefined;
    set internalValue(value: GoogleComposerEnvironmentConfigA | undefined);
    get airflowUri(): string;
    get dagGcsPrefix(): string;
    private _enablePrivateBuildsOnly?;
    get enablePrivateBuildsOnly(): boolean | cdktf.IResolvable;
    set enablePrivateBuildsOnly(value: boolean | cdktf.IResolvable);
    resetEnablePrivateBuildsOnly(): void;
    get enablePrivateBuildsOnlyInput(): boolean | cdktf.IResolvable | undefined;
    private _enablePrivateEnvironment?;
    get enablePrivateEnvironment(): boolean | cdktf.IResolvable;
    set enablePrivateEnvironment(value: boolean | cdktf.IResolvable);
    resetEnablePrivateEnvironment(): void;
    get enablePrivateEnvironmentInput(): boolean | cdktf.IResolvable | undefined;
    private _environmentSize?;
    get environmentSize(): string;
    set environmentSize(value: string);
    resetEnvironmentSize(): void;
    get environmentSizeInput(): string | undefined;
    get gkeCluster(): string;
    private _nodeCount?;
    get nodeCount(): number;
    set nodeCount(value: number);
    resetNodeCount(): void;
    get nodeCountInput(): number | undefined;
    private _resilienceMode?;
    get resilienceMode(): string;
    set resilienceMode(value: string);
    resetResilienceMode(): void;
    get resilienceModeInput(): string | undefined;
    private _dataRetentionConfig;
    get dataRetentionConfig(): GoogleComposerEnvironmentConfigDataRetentionConfigOutputReference;
    putDataRetentionConfig(value: GoogleComposerEnvironmentConfigDataRetentionConfig): void;
    resetDataRetentionConfig(): void;
    get dataRetentionConfigInput(): GoogleComposerEnvironmentConfigDataRetentionConfig | undefined;
    private _databaseConfig;
    get databaseConfig(): GoogleComposerEnvironmentConfigDatabaseConfigOutputReference;
    putDatabaseConfig(value: GoogleComposerEnvironmentConfigDatabaseConfig): void;
    resetDatabaseConfig(): void;
    get databaseConfigInput(): GoogleComposerEnvironmentConfigDatabaseConfig | undefined;
    private _encryptionConfig;
    get encryptionConfig(): GoogleComposerEnvironmentConfigEncryptionConfigOutputReference;
    putEncryptionConfig(value: GoogleComposerEnvironmentConfigEncryptionConfig): void;
    resetEncryptionConfig(): void;
    get encryptionConfigInput(): GoogleComposerEnvironmentConfigEncryptionConfig | undefined;
    private _maintenanceWindow;
    get maintenanceWindow(): GoogleComposerEnvironmentConfigMaintenanceWindowOutputReference;
    putMaintenanceWindow(value: GoogleComposerEnvironmentConfigMaintenanceWindow): void;
    resetMaintenanceWindow(): void;
    get maintenanceWindowInput(): GoogleComposerEnvironmentConfigMaintenanceWindow | undefined;
    private _masterAuthorizedNetworksConfig;
    get masterAuthorizedNetworksConfig(): GoogleComposerEnvironmentConfigMasterAuthorizedNetworksConfigOutputReference;
    putMasterAuthorizedNetworksConfig(value: GoogleComposerEnvironmentConfigMasterAuthorizedNetworksConfig): void;
    resetMasterAuthorizedNetworksConfig(): void;
    get masterAuthorizedNetworksConfigInput(): GoogleComposerEnvironmentConfigMasterAuthorizedNetworksConfig | undefined;
    private _nodeConfig;
    get nodeConfig(): GoogleComposerEnvironmentConfigNodeConfigOutputReference;
    putNodeConfig(value: GoogleComposerEnvironmentConfigNodeConfig): void;
    resetNodeConfig(): void;
    get nodeConfigInput(): GoogleComposerEnvironmentConfigNodeConfig | undefined;
    private _privateEnvironmentConfig;
    get privateEnvironmentConfig(): GoogleComposerEnvironmentConfigPrivateEnvironmentConfigOutputReference;
    putPrivateEnvironmentConfig(value: GoogleComposerEnvironmentConfigPrivateEnvironmentConfig): void;
    resetPrivateEnvironmentConfig(): void;
    get privateEnvironmentConfigInput(): GoogleComposerEnvironmentConfigPrivateEnvironmentConfig | undefined;
    private _recoveryConfig;
    get recoveryConfig(): GoogleComposerEnvironmentConfigRecoveryConfigOutputReference;
    putRecoveryConfig(value: GoogleComposerEnvironmentConfigRecoveryConfig): void;
    resetRecoveryConfig(): void;
    get recoveryConfigInput(): GoogleComposerEnvironmentConfigRecoveryConfig | undefined;
    private _softwareConfig;
    get softwareConfig(): GoogleComposerEnvironmentConfigSoftwareConfigOutputReference;
    putSoftwareConfig(value: GoogleComposerEnvironmentConfigSoftwareConfig): void;
    resetSoftwareConfig(): void;
    get softwareConfigInput(): GoogleComposerEnvironmentConfigSoftwareConfig | undefined;
    private _webServerConfig;
    get webServerConfig(): GoogleComposerEnvironmentConfigWebServerConfigOutputReference;
    putWebServerConfig(value: GoogleComposerEnvironmentConfigWebServerConfig): void;
    resetWebServerConfig(): void;
    get webServerConfigInput(): GoogleComposerEnvironmentConfigWebServerConfig | undefined;
    private _webServerNetworkAccessControl;
    get webServerNetworkAccessControl(): GoogleComposerEnvironmentConfigWebServerNetworkAccessControlOutputReference;
    putWebServerNetworkAccessControl(value: GoogleComposerEnvironmentConfigWebServerNetworkAccessControl): void;
    resetWebServerNetworkAccessControl(): void;
    get webServerNetworkAccessControlInput(): GoogleComposerEnvironmentConfigWebServerNetworkAccessControl | undefined;
    private _workloadsConfig;
    get workloadsConfig(): GoogleComposerEnvironmentConfigWorkloadsConfigOutputReference;
    putWorkloadsConfig(value: GoogleComposerEnvironmentConfigWorkloadsConfig): void;
    resetWorkloadsConfig(): void;
    get workloadsConfigInput(): GoogleComposerEnvironmentConfigWorkloadsConfig | undefined;
}
export interface GoogleComposerEnvironmentStorageConfig {
    /**
    * Optional. Name of an existing Cloud Storage bucket to be used by the environment.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#bucket GoogleComposerEnvironment#bucket}
    */
    readonly bucket: string;
}
export declare function googleComposerEnvironmentStorageConfigToTerraform(struct?: GoogleComposerEnvironmentStorageConfigOutputReference | GoogleComposerEnvironmentStorageConfig): any;
export declare function googleComposerEnvironmentStorageConfigToHclTerraform(struct?: GoogleComposerEnvironmentStorageConfigOutputReference | GoogleComposerEnvironmentStorageConfig): any;
export declare class GoogleComposerEnvironmentStorageConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleComposerEnvironmentStorageConfig | undefined;
    set internalValue(value: GoogleComposerEnvironmentStorageConfig | undefined);
    private _bucket?;
    get bucket(): string;
    set bucket(value: string);
    get bucketInput(): string | undefined;
}
export interface GoogleComposerEnvironmentTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#create GoogleComposerEnvironment#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#delete GoogleComposerEnvironment#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#update GoogleComposerEnvironment#update}
    */
    readonly update?: string;
}
export declare function googleComposerEnvironmentTimeoutsToTerraform(struct?: GoogleComposerEnvironmentTimeouts | cdktf.IResolvable): any;
export declare function googleComposerEnvironmentTimeoutsToHclTerraform(struct?: GoogleComposerEnvironmentTimeouts | cdktf.IResolvable): any;
export declare class GoogleComposerEnvironmentTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleComposerEnvironmentTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleComposerEnvironmentTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment google_composer_environment}
*/
export declare class GoogleComposerEnvironment extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_composer_environment";
    /**
    * Generates CDKTF code for importing a GoogleComposerEnvironment resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleComposerEnvironment to import
    * @param importFromId The id of the existing GoogleComposerEnvironment that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleComposerEnvironment to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_environment google_composer_environment} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleComposerEnvironmentConfig
    */
    constructor(scope: Construct, id: string, config: GoogleComposerEnvironmentConfig);
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _region?;
    get region(): string;
    set region(value: string);
    resetRegion(): void;
    get regionInput(): string | undefined;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    private _config;
    get config(): GoogleComposerEnvironmentConfigAOutputReference;
    putConfig(value: GoogleComposerEnvironmentConfigA): void;
    resetConfig(): void;
    get configInput(): GoogleComposerEnvironmentConfigA | undefined;
    private _storageConfig;
    get storageConfig(): GoogleComposerEnvironmentStorageConfigOutputReference;
    putStorageConfig(value: GoogleComposerEnvironmentStorageConfig): void;
    resetStorageConfig(): void;
    get storageConfigInput(): GoogleComposerEnvironmentStorageConfig | undefined;
    private _timeouts;
    get timeouts(): GoogleComposerEnvironmentTimeoutsOutputReference;
    putTimeouts(value: GoogleComposerEnvironmentTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleComposerEnvironmentTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
