/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleComposerUserWorkloadsSecretConfig extends cdktf.TerraformMetaArguments {
    /**
    * A map of the secret data.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_user_workloads_secret#data GoogleComposerUserWorkloadsSecret#data}
    */
    readonly data?: {
        [key: string]: string;
    };
    /**
    * Name of the environment.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_user_workloads_secret#environment GoogleComposerUserWorkloadsSecret#environment}
    */
    readonly environment: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_user_workloads_secret#id GoogleComposerUserWorkloadsSecret#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Name of the secret.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_user_workloads_secret#name GoogleComposerUserWorkloadsSecret#name}
    */
    readonly name: string;
    /**
    * The ID of the project in which the resource belongs. If it is not provided, the provider project is used.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_user_workloads_secret#project GoogleComposerUserWorkloadsSecret#project}
    */
    readonly project?: string;
    /**
    * The location or Compute Engine region for the environment.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_user_workloads_secret#region GoogleComposerUserWorkloadsSecret#region}
    */
    readonly region?: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_user_workloads_secret#timeouts GoogleComposerUserWorkloadsSecret#timeouts}
    */
    readonly timeouts?: GoogleComposerUserWorkloadsSecretTimeouts;
}
export interface GoogleComposerUserWorkloadsSecretTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_user_workloads_secret#create GoogleComposerUserWorkloadsSecret#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_user_workloads_secret#delete GoogleComposerUserWorkloadsSecret#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_user_workloads_secret#update GoogleComposerUserWorkloadsSecret#update}
    */
    readonly update?: string;
}
export declare function googleComposerUserWorkloadsSecretTimeoutsToTerraform(struct?: GoogleComposerUserWorkloadsSecretTimeouts | cdktf.IResolvable): any;
export declare function googleComposerUserWorkloadsSecretTimeoutsToHclTerraform(struct?: GoogleComposerUserWorkloadsSecretTimeouts | cdktf.IResolvable): any;
export declare class GoogleComposerUserWorkloadsSecretTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleComposerUserWorkloadsSecretTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleComposerUserWorkloadsSecretTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_user_workloads_secret google_composer_user_workloads_secret}
*/
export declare class GoogleComposerUserWorkloadsSecret extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_composer_user_workloads_secret";
    /**
    * Generates CDKTF code for importing a GoogleComposerUserWorkloadsSecret resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleComposerUserWorkloadsSecret to import
    * @param importFromId The id of the existing GoogleComposerUserWorkloadsSecret that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_user_workloads_secret#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleComposerUserWorkloadsSecret to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_composer_user_workloads_secret google_composer_user_workloads_secret} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleComposerUserWorkloadsSecretConfig
    */
    constructor(scope: Construct, id: string, config: GoogleComposerUserWorkloadsSecretConfig);
    private _data?;
    get data(): {
        [key: string]: string;
    };
    set data(value: {
        [key: string]: string;
    });
    resetData(): void;
    get dataInput(): {
        [key: string]: string;
    } | undefined;
    private _environment?;
    get environment(): string;
    set environment(value: string);
    get environmentInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _region?;
    get region(): string;
    set region(value: string);
    resetRegion(): void;
    get regionInput(): string | undefined;
    private _timeouts;
    get timeouts(): GoogleComposerUserWorkloadsSecretTimeoutsOutputReference;
    putTimeouts(value: GoogleComposerUserWorkloadsSecretTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleComposerUserWorkloadsSecretTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
