/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleComputePerInstanceConfigConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_per_instance_config#id GoogleComputePerInstanceConfig#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The instance group manager this instance config is part of.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_per_instance_config#instance_group_manager GoogleComputePerInstanceConfig#instance_group_manager}
    */
    readonly instanceGroupManager: string;
    /**
    * The minimal action to perform on the instance during an update.
    * Default is 'NONE'. Possible values are:
    * * REPLACE
    * * RESTART
    * * REFRESH
    * * NONE
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_per_instance_config#minimal_action GoogleComputePerInstanceConfig#minimal_action}
    */
    readonly minimalAction?: string;
    /**
    * The most disruptive action to perform on the instance during an update.
    * Default is 'REPLACE'. Possible values are:
    * * REPLACE
    * * RESTART
    * * REFRESH
    * * NONE
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_per_instance_config#most_disruptive_allowed_action GoogleComputePerInstanceConfig#most_disruptive_allowed_action}
    */
    readonly mostDisruptiveAllowedAction?: string;
    /**
    * The name for this per-instance config and its corresponding instance.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_per_instance_config#name GoogleComputePerInstanceConfig#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_per_instance_config#project GoogleComputePerInstanceConfig#project}
    */
    readonly project?: string;
    /**
    * When true, deleting this config will immediately remove the underlying instance.
    * When false, deleting this config will use the behavior as determined by remove_instance_on_destroy.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_per_instance_config#remove_instance_on_destroy GoogleComputePerInstanceConfig#remove_instance_on_destroy}
    */
    readonly removeInstanceOnDestroy?: boolean | cdktf.IResolvable;
    /**
    * When true, deleting this config will immediately remove any specified state from the underlying instance.
    * When false, deleting this config will *not* immediately remove any state from the underlying instance.
    * State will be removed on the next instance recreation or update.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_per_instance_config#remove_instance_state_on_destroy GoogleComputePerInstanceConfig#remove_instance_state_on_destroy}
    */
    readonly removeInstanceStateOnDestroy?: boolean | cdktf.IResolvable;
    /**
    * Zone where the containing instance group manager is located
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_per_instance_config#zone GoogleComputePerInstanceConfig#zone}
    */
    readonly zone?: string;
    /**
    * preserved_state block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_per_instance_config#preserved_state GoogleComputePerInstanceConfig#preserved_state}
    */
    readonly preservedState?: GoogleComputePerInstanceConfigPreservedState;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_per_instance_config#timeouts GoogleComputePerInstanceConfig#timeouts}
    */
    readonly timeouts?: GoogleComputePerInstanceConfigTimeouts;
}
export interface GoogleComputePerInstanceConfigPreservedStateDisk {
    /**
    * A value that prescribes what should happen to the stateful disk when the VM instance is deleted.
    * The available options are 'NEVER' and 'ON_PERMANENT_INSTANCE_DELETION'.
    * 'NEVER' - detach the disk when the VM is deleted, but do not delete the disk.
    * 'ON_PERMANENT_INSTANCE_DELETION' will delete the stateful disk when the VM is permanently
    * deleted from the instance group. Default value: "NEVER" Possible values: ["NEVER", "ON_PERMANENT_INSTANCE_DELETION"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_per_instance_config#delete_rule GoogleComputePerInstanceConfig#delete_rule}
    */
    readonly deleteRule?: string;
    /**
    * A unique device name that is reflected into the /dev/ tree of a Linux operating system running within the instance.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_per_instance_config#device_name GoogleComputePerInstanceConfig#device_name}
    */
    readonly deviceName: string;
    /**
    * The mode of the disk. Default value: "READ_WRITE" Possible values: ["READ_ONLY", "READ_WRITE"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_per_instance_config#mode GoogleComputePerInstanceConfig#mode}
    */
    readonly mode?: string;
    /**
    * The URI of an existing persistent disk to attach under the specified device-name in the format
    * 'projects/project-id/zones/zone/disks/disk-name'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_per_instance_config#source GoogleComputePerInstanceConfig#source}
    */
    readonly source: string;
}
export declare function googleComputePerInstanceConfigPreservedStateDiskToTerraform(struct?: GoogleComputePerInstanceConfigPreservedStateDisk | cdktf.IResolvable): any;
export declare function googleComputePerInstanceConfigPreservedStateDiskToHclTerraform(struct?: GoogleComputePerInstanceConfigPreservedStateDisk | cdktf.IResolvable): any;
export declare class GoogleComputePerInstanceConfigPreservedStateDiskOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleComputePerInstanceConfigPreservedStateDisk | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleComputePerInstanceConfigPreservedStateDisk | cdktf.IResolvable | undefined);
    private _deleteRule?;
    get deleteRule(): string;
    set deleteRule(value: string);
    resetDeleteRule(): void;
    get deleteRuleInput(): string | undefined;
    private _deviceName?;
    get deviceName(): string;
    set deviceName(value: string);
    get deviceNameInput(): string | undefined;
    private _mode?;
    get mode(): string;
    set mode(value: string);
    resetMode(): void;
    get modeInput(): string | undefined;
    private _source?;
    get source(): string;
    set source(value: string);
    get sourceInput(): string | undefined;
}
export declare class GoogleComputePerInstanceConfigPreservedStateDiskList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleComputePerInstanceConfigPreservedStateDisk[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleComputePerInstanceConfigPreservedStateDiskOutputReference;
}
export interface GoogleComputePerInstanceConfigPreservedStateExternalIpIpAddress {
    /**
    * The URL of the reservation for this IP address.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_per_instance_config#address GoogleComputePerInstanceConfig#address}
    */
    readonly address?: string;
}
export declare function googleComputePerInstanceConfigPreservedStateExternalIpIpAddressToTerraform(struct?: GoogleComputePerInstanceConfigPreservedStateExternalIpIpAddressOutputReference | GoogleComputePerInstanceConfigPreservedStateExternalIpIpAddress): any;
export declare function googleComputePerInstanceConfigPreservedStateExternalIpIpAddressToHclTerraform(struct?: GoogleComputePerInstanceConfigPreservedStateExternalIpIpAddressOutputReference | GoogleComputePerInstanceConfigPreservedStateExternalIpIpAddress): any;
export declare class GoogleComputePerInstanceConfigPreservedStateExternalIpIpAddressOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleComputePerInstanceConfigPreservedStateExternalIpIpAddress | undefined;
    set internalValue(value: GoogleComputePerInstanceConfigPreservedStateExternalIpIpAddress | undefined);
    private _address?;
    get address(): string;
    set address(value: string);
    resetAddress(): void;
    get addressInput(): string | undefined;
}
export interface GoogleComputePerInstanceConfigPreservedStateExternalIp {
    /**
    * These stateful IPs will never be released during autohealing, update or VM instance recreate operations. This flag is used to configure if the IP reservation should be deleted after it is no longer used by the group, e.g. when the given instance or the whole group is deleted. Default value: "NEVER" Possible values: ["NEVER", "ON_PERMANENT_INSTANCE_DELETION"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_per_instance_config#auto_delete GoogleComputePerInstanceConfig#auto_delete}
    */
    readonly autoDelete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_per_instance_config#interface_name GoogleComputePerInstanceConfig#interface_name}
    */
    readonly interfaceName: string;
    /**
    * ip_address block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_per_instance_config#ip_address GoogleComputePerInstanceConfig#ip_address}
    */
    readonly ipAddress?: GoogleComputePerInstanceConfigPreservedStateExternalIpIpAddress;
}
export declare function googleComputePerInstanceConfigPreservedStateExternalIpToTerraform(struct?: GoogleComputePerInstanceConfigPreservedStateExternalIp | cdktf.IResolvable): any;
export declare function googleComputePerInstanceConfigPreservedStateExternalIpToHclTerraform(struct?: GoogleComputePerInstanceConfigPreservedStateExternalIp | cdktf.IResolvable): any;
export declare class GoogleComputePerInstanceConfigPreservedStateExternalIpOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleComputePerInstanceConfigPreservedStateExternalIp | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleComputePerInstanceConfigPreservedStateExternalIp | cdktf.IResolvable | undefined);
    private _autoDelete?;
    get autoDelete(): string;
    set autoDelete(value: string);
    resetAutoDelete(): void;
    get autoDeleteInput(): string | undefined;
    private _interfaceName?;
    get interfaceName(): string;
    set interfaceName(value: string);
    get interfaceNameInput(): string | undefined;
    private _ipAddress;
    get ipAddress(): GoogleComputePerInstanceConfigPreservedStateExternalIpIpAddressOutputReference;
    putIpAddress(value: GoogleComputePerInstanceConfigPreservedStateExternalIpIpAddress): void;
    resetIpAddress(): void;
    get ipAddressInput(): GoogleComputePerInstanceConfigPreservedStateExternalIpIpAddress | undefined;
}
export declare class GoogleComputePerInstanceConfigPreservedStateExternalIpList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleComputePerInstanceConfigPreservedStateExternalIp[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleComputePerInstanceConfigPreservedStateExternalIpOutputReference;
}
export interface GoogleComputePerInstanceConfigPreservedStateInternalIpIpAddress {
    /**
    * The URL of the reservation for this IP address.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_per_instance_config#address GoogleComputePerInstanceConfig#address}
    */
    readonly address?: string;
}
export declare function googleComputePerInstanceConfigPreservedStateInternalIpIpAddressToTerraform(struct?: GoogleComputePerInstanceConfigPreservedStateInternalIpIpAddressOutputReference | GoogleComputePerInstanceConfigPreservedStateInternalIpIpAddress): any;
export declare function googleComputePerInstanceConfigPreservedStateInternalIpIpAddressToHclTerraform(struct?: GoogleComputePerInstanceConfigPreservedStateInternalIpIpAddressOutputReference | GoogleComputePerInstanceConfigPreservedStateInternalIpIpAddress): any;
export declare class GoogleComputePerInstanceConfigPreservedStateInternalIpIpAddressOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleComputePerInstanceConfigPreservedStateInternalIpIpAddress | undefined;
    set internalValue(value: GoogleComputePerInstanceConfigPreservedStateInternalIpIpAddress | undefined);
    private _address?;
    get address(): string;
    set address(value: string);
    resetAddress(): void;
    get addressInput(): string | undefined;
}
export interface GoogleComputePerInstanceConfigPreservedStateInternalIp {
    /**
    * These stateful IPs will never be released during autohealing, update or VM instance recreate operations. This flag is used to configure if the IP reservation should be deleted after it is no longer used by the group, e.g. when the given instance or the whole group is deleted. Default value: "NEVER" Possible values: ["NEVER", "ON_PERMANENT_INSTANCE_DELETION"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_per_instance_config#auto_delete GoogleComputePerInstanceConfig#auto_delete}
    */
    readonly autoDelete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_per_instance_config#interface_name GoogleComputePerInstanceConfig#interface_name}
    */
    readonly interfaceName: string;
    /**
    * ip_address block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_per_instance_config#ip_address GoogleComputePerInstanceConfig#ip_address}
    */
    readonly ipAddress?: GoogleComputePerInstanceConfigPreservedStateInternalIpIpAddress;
}
export declare function googleComputePerInstanceConfigPreservedStateInternalIpToTerraform(struct?: GoogleComputePerInstanceConfigPreservedStateInternalIp | cdktf.IResolvable): any;
export declare function googleComputePerInstanceConfigPreservedStateInternalIpToHclTerraform(struct?: GoogleComputePerInstanceConfigPreservedStateInternalIp | cdktf.IResolvable): any;
export declare class GoogleComputePerInstanceConfigPreservedStateInternalIpOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleComputePerInstanceConfigPreservedStateInternalIp | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleComputePerInstanceConfigPreservedStateInternalIp | cdktf.IResolvable | undefined);
    private _autoDelete?;
    get autoDelete(): string;
    set autoDelete(value: string);
    resetAutoDelete(): void;
    get autoDeleteInput(): string | undefined;
    private _interfaceName?;
    get interfaceName(): string;
    set interfaceName(value: string);
    get interfaceNameInput(): string | undefined;
    private _ipAddress;
    get ipAddress(): GoogleComputePerInstanceConfigPreservedStateInternalIpIpAddressOutputReference;
    putIpAddress(value: GoogleComputePerInstanceConfigPreservedStateInternalIpIpAddress): void;
    resetIpAddress(): void;
    get ipAddressInput(): GoogleComputePerInstanceConfigPreservedStateInternalIpIpAddress | undefined;
}
export declare class GoogleComputePerInstanceConfigPreservedStateInternalIpList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleComputePerInstanceConfigPreservedStateInternalIp[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleComputePerInstanceConfigPreservedStateInternalIpOutputReference;
}
export interface GoogleComputePerInstanceConfigPreservedState {
    /**
    * Preserved metadata defined for this instance. This is a list of key->value pairs.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_per_instance_config#metadata GoogleComputePerInstanceConfig#metadata}
    */
    readonly metadata?: {
        [key: string]: string;
    };
    /**
    * disk block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_per_instance_config#disk GoogleComputePerInstanceConfig#disk}
    */
    readonly disk?: GoogleComputePerInstanceConfigPreservedStateDisk[] | cdktf.IResolvable;
    /**
    * external_ip block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_per_instance_config#external_ip GoogleComputePerInstanceConfig#external_ip}
    */
    readonly externalIp?: GoogleComputePerInstanceConfigPreservedStateExternalIp[] | cdktf.IResolvable;
    /**
    * internal_ip block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_per_instance_config#internal_ip GoogleComputePerInstanceConfig#internal_ip}
    */
    readonly internalIp?: GoogleComputePerInstanceConfigPreservedStateInternalIp[] | cdktf.IResolvable;
}
export declare function googleComputePerInstanceConfigPreservedStateToTerraform(struct?: GoogleComputePerInstanceConfigPreservedStateOutputReference | GoogleComputePerInstanceConfigPreservedState): any;
export declare function googleComputePerInstanceConfigPreservedStateToHclTerraform(struct?: GoogleComputePerInstanceConfigPreservedStateOutputReference | GoogleComputePerInstanceConfigPreservedState): any;
export declare class GoogleComputePerInstanceConfigPreservedStateOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleComputePerInstanceConfigPreservedState | undefined;
    set internalValue(value: GoogleComputePerInstanceConfigPreservedState | undefined);
    private _metadata?;
    get metadata(): {
        [key: string]: string;
    };
    set metadata(value: {
        [key: string]: string;
    });
    resetMetadata(): void;
    get metadataInput(): {
        [key: string]: string;
    } | undefined;
    private _disk;
    get disk(): GoogleComputePerInstanceConfigPreservedStateDiskList;
    putDisk(value: GoogleComputePerInstanceConfigPreservedStateDisk[] | cdktf.IResolvable): void;
    resetDisk(): void;
    get diskInput(): cdktf.IResolvable | GoogleComputePerInstanceConfigPreservedStateDisk[] | undefined;
    private _externalIp;
    get externalIp(): GoogleComputePerInstanceConfigPreservedStateExternalIpList;
    putExternalIp(value: GoogleComputePerInstanceConfigPreservedStateExternalIp[] | cdktf.IResolvable): void;
    resetExternalIp(): void;
    get externalIpInput(): cdktf.IResolvable | GoogleComputePerInstanceConfigPreservedStateExternalIp[] | undefined;
    private _internalIp;
    get internalIp(): GoogleComputePerInstanceConfigPreservedStateInternalIpList;
    putInternalIp(value: GoogleComputePerInstanceConfigPreservedStateInternalIp[] | cdktf.IResolvable): void;
    resetInternalIp(): void;
    get internalIpInput(): cdktf.IResolvable | GoogleComputePerInstanceConfigPreservedStateInternalIp[] | undefined;
}
export interface GoogleComputePerInstanceConfigTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_per_instance_config#create GoogleComputePerInstanceConfig#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_per_instance_config#delete GoogleComputePerInstanceConfig#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_per_instance_config#update GoogleComputePerInstanceConfig#update}
    */
    readonly update?: string;
}
export declare function googleComputePerInstanceConfigTimeoutsToTerraform(struct?: GoogleComputePerInstanceConfigTimeouts | cdktf.IResolvable): any;
export declare function googleComputePerInstanceConfigTimeoutsToHclTerraform(struct?: GoogleComputePerInstanceConfigTimeouts | cdktf.IResolvable): any;
export declare class GoogleComputePerInstanceConfigTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleComputePerInstanceConfigTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleComputePerInstanceConfigTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_per_instance_config google_compute_per_instance_config}
*/
export declare class GoogleComputePerInstanceConfig extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_compute_per_instance_config";
    /**
    * Generates CDKTF code for importing a GoogleComputePerInstanceConfig resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleComputePerInstanceConfig to import
    * @param importFromId The id of the existing GoogleComputePerInstanceConfig that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_per_instance_config#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleComputePerInstanceConfig to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_per_instance_config google_compute_per_instance_config} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleComputePerInstanceConfigConfig
    */
    constructor(scope: Construct, id: string, config: GoogleComputePerInstanceConfigConfig);
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _instanceGroupManager?;
    get instanceGroupManager(): string;
    set instanceGroupManager(value: string);
    get instanceGroupManagerInput(): string | undefined;
    private _minimalAction?;
    get minimalAction(): string;
    set minimalAction(value: string);
    resetMinimalAction(): void;
    get minimalActionInput(): string | undefined;
    private _mostDisruptiveAllowedAction?;
    get mostDisruptiveAllowedAction(): string;
    set mostDisruptiveAllowedAction(value: string);
    resetMostDisruptiveAllowedAction(): void;
    get mostDisruptiveAllowedActionInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _removeInstanceOnDestroy?;
    get removeInstanceOnDestroy(): boolean | cdktf.IResolvable;
    set removeInstanceOnDestroy(value: boolean | cdktf.IResolvable);
    resetRemoveInstanceOnDestroy(): void;
    get removeInstanceOnDestroyInput(): boolean | cdktf.IResolvable | undefined;
    private _removeInstanceStateOnDestroy?;
    get removeInstanceStateOnDestroy(): boolean | cdktf.IResolvable;
    set removeInstanceStateOnDestroy(value: boolean | cdktf.IResolvable);
    resetRemoveInstanceStateOnDestroy(): void;
    get removeInstanceStateOnDestroyInput(): boolean | cdktf.IResolvable | undefined;
    private _zone?;
    get zone(): string;
    set zone(value: string);
    resetZone(): void;
    get zoneInput(): string | undefined;
    private _preservedState;
    get preservedState(): GoogleComputePerInstanceConfigPreservedStateOutputReference;
    putPreservedState(value: GoogleComputePerInstanceConfigPreservedState): void;
    resetPreservedState(): void;
    get preservedStateInput(): GoogleComputePerInstanceConfigPreservedState | undefined;
    private _timeouts;
    get timeouts(): GoogleComputePerInstanceConfigTimeoutsOutputReference;
    putTimeouts(value: GoogleComputePerInstanceConfigTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleComputePerInstanceConfigTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
