/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleComputeResizeRequestConfig extends cdktf.TerraformMetaArguments {
    /**
    * An optional description of this resize-request.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_resize_request#description GoogleComputeResizeRequest#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_resize_request#id GoogleComputeResizeRequest#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The name of the managed instance group. The name should conform to RFC1035 or be a resource ID.
    * Authorization requires the following IAM permission on the specified resource instanceGroupManager:
    * *compute.instanceGroupManagers.update
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_resize_request#instance_group_manager GoogleComputeResizeRequest#instance_group_manager}
    */
    readonly instanceGroupManager: string;
    /**
    * The name of this resize request. The name must be 1-63 characters long, and comply with RFC1035.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_resize_request#name GoogleComputeResizeRequest#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_resize_request#project GoogleComputeResizeRequest#project}
    */
    readonly project?: string;
    /**
    * The number of instances to be created by this resize request. The group's target size will be increased by this number.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_resize_request#resize_by GoogleComputeResizeRequest#resize_by}
    */
    readonly resizeBy: number;
    /**
    * Name of the compute zone scoping this request. Name should conform to RFC1035.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_resize_request#zone GoogleComputeResizeRequest#zone}
    */
    readonly zone: string;
    /**
    * requested_run_duration block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_resize_request#requested_run_duration GoogleComputeResizeRequest#requested_run_duration}
    */
    readonly requestedRunDuration?: GoogleComputeResizeRequestRequestedRunDuration;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_resize_request#timeouts GoogleComputeResizeRequest#timeouts}
    */
    readonly timeouts?: GoogleComputeResizeRequestTimeouts;
}
export interface GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsErrorInfo {
}
export declare function googleComputeResizeRequestStatusErrorErrorsErrorDetailsErrorInfoToTerraform(struct?: GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsErrorInfo): any;
export declare function googleComputeResizeRequestStatusErrorErrorsErrorDetailsErrorInfoToHclTerraform(struct?: GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsErrorInfo): any;
export declare class GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsErrorInfoOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsErrorInfo | undefined;
    set internalValue(value: GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsErrorInfo | undefined);
    get domain(): string;
    private _metadatas;
    get metadatas(): cdktf.StringMap;
    get reason(): string;
}
export declare class GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsErrorInfoList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsErrorInfoOutputReference;
}
export interface GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsHelpLinks {
}
export declare function googleComputeResizeRequestStatusErrorErrorsErrorDetailsHelpLinksToTerraform(struct?: GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsHelpLinks): any;
export declare function googleComputeResizeRequestStatusErrorErrorsErrorDetailsHelpLinksToHclTerraform(struct?: GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsHelpLinks): any;
export declare class GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsHelpLinksOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsHelpLinks | undefined;
    set internalValue(value: GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsHelpLinks | undefined);
    get description(): string;
    get url(): string;
}
export declare class GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsHelpLinksList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsHelpLinksOutputReference;
}
export interface GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsHelp {
}
export declare function googleComputeResizeRequestStatusErrorErrorsErrorDetailsHelpToTerraform(struct?: GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsHelp): any;
export declare function googleComputeResizeRequestStatusErrorErrorsErrorDetailsHelpToHclTerraform(struct?: GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsHelp): any;
export declare class GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsHelpOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsHelp | undefined;
    set internalValue(value: GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsHelp | undefined);
    private _links;
    get links(): GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsHelpLinksList;
}
export declare class GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsHelpList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsHelpOutputReference;
}
export interface GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsLocalizedMessage {
}
export declare function googleComputeResizeRequestStatusErrorErrorsErrorDetailsLocalizedMessageToTerraform(struct?: GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsLocalizedMessage): any;
export declare function googleComputeResizeRequestStatusErrorErrorsErrorDetailsLocalizedMessageToHclTerraform(struct?: GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsLocalizedMessage): any;
export declare class GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsLocalizedMessageOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsLocalizedMessage | undefined;
    set internalValue(value: GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsLocalizedMessage | undefined);
    get locale(): string;
    get message(): string;
}
export declare class GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsLocalizedMessageList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsLocalizedMessageOutputReference;
}
export interface GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsQuotaInfo {
}
export declare function googleComputeResizeRequestStatusErrorErrorsErrorDetailsQuotaInfoToTerraform(struct?: GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsQuotaInfo): any;
export declare function googleComputeResizeRequestStatusErrorErrorsErrorDetailsQuotaInfoToHclTerraform(struct?: GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsQuotaInfo): any;
export declare class GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsQuotaInfoOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsQuotaInfo | undefined;
    set internalValue(value: GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsQuotaInfo | undefined);
    private _dimensions;
    get dimensions(): cdktf.StringMap;
    get futureLimit(): number;
    get limit(): number;
    get limitName(): string;
    get metricName(): string;
    get rolloutStatus(): string;
}
export declare class GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsQuotaInfoList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsQuotaInfoOutputReference;
}
export interface GoogleComputeResizeRequestStatusErrorErrorsErrorDetails {
}
export declare function googleComputeResizeRequestStatusErrorErrorsErrorDetailsToTerraform(struct?: GoogleComputeResizeRequestStatusErrorErrorsErrorDetails): any;
export declare function googleComputeResizeRequestStatusErrorErrorsErrorDetailsToHclTerraform(struct?: GoogleComputeResizeRequestStatusErrorErrorsErrorDetails): any;
export declare class GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleComputeResizeRequestStatusErrorErrorsErrorDetails | undefined;
    set internalValue(value: GoogleComputeResizeRequestStatusErrorErrorsErrorDetails | undefined);
    private _errorInfo;
    get errorInfo(): GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsErrorInfoList;
    private _help;
    get help(): GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsHelpList;
    private _localizedMessage;
    get localizedMessage(): GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsLocalizedMessageList;
    private _quotaInfo;
    get quotaInfo(): GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsQuotaInfoList;
}
export declare class GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsOutputReference;
}
export interface GoogleComputeResizeRequestStatusErrorErrors {
}
export declare function googleComputeResizeRequestStatusErrorErrorsToTerraform(struct?: GoogleComputeResizeRequestStatusErrorErrors): any;
export declare function googleComputeResizeRequestStatusErrorErrorsToHclTerraform(struct?: GoogleComputeResizeRequestStatusErrorErrors): any;
export declare class GoogleComputeResizeRequestStatusErrorErrorsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleComputeResizeRequestStatusErrorErrors | undefined;
    set internalValue(value: GoogleComputeResizeRequestStatusErrorErrors | undefined);
    get code(): string;
    private _errorDetails;
    get errorDetails(): GoogleComputeResizeRequestStatusErrorErrorsErrorDetailsList;
    get location(): string;
    get message(): string;
}
export declare class GoogleComputeResizeRequestStatusErrorErrorsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleComputeResizeRequestStatusErrorErrorsOutputReference;
}
export interface GoogleComputeResizeRequestStatusError {
}
export declare function googleComputeResizeRequestStatusErrorToTerraform(struct?: GoogleComputeResizeRequestStatusError): any;
export declare function googleComputeResizeRequestStatusErrorToHclTerraform(struct?: GoogleComputeResizeRequestStatusError): any;
export declare class GoogleComputeResizeRequestStatusErrorOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleComputeResizeRequestStatusError | undefined;
    set internalValue(value: GoogleComputeResizeRequestStatusError | undefined);
    private _errors;
    get errors(): GoogleComputeResizeRequestStatusErrorErrorsList;
}
export declare class GoogleComputeResizeRequestStatusErrorList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleComputeResizeRequestStatusErrorOutputReference;
}
export interface GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsErrorInfo {
}
export declare function googleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsErrorInfoToTerraform(struct?: GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsErrorInfo): any;
export declare function googleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsErrorInfoToHclTerraform(struct?: GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsErrorInfo): any;
export declare class GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsErrorInfoOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsErrorInfo | undefined;
    set internalValue(value: GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsErrorInfo | undefined);
    get domain(): string;
    private _metadatas;
    get metadatas(): cdktf.StringMap;
    get reason(): string;
}
export declare class GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsErrorInfoList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsErrorInfoOutputReference;
}
export interface GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsHelpLinks {
}
export declare function googleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsHelpLinksToTerraform(struct?: GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsHelpLinks): any;
export declare function googleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsHelpLinksToHclTerraform(struct?: GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsHelpLinks): any;
export declare class GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsHelpLinksOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsHelpLinks | undefined;
    set internalValue(value: GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsHelpLinks | undefined);
    get description(): string;
    get url(): string;
}
export declare class GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsHelpLinksList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsHelpLinksOutputReference;
}
export interface GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsHelp {
}
export declare function googleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsHelpToTerraform(struct?: GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsHelp): any;
export declare function googleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsHelpToHclTerraform(struct?: GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsHelp): any;
export declare class GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsHelpOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsHelp | undefined;
    set internalValue(value: GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsHelp | undefined);
    private _links;
    get links(): GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsHelpLinksList;
}
export declare class GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsHelpList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsHelpOutputReference;
}
export interface GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsLocalizedMessage {
}
export declare function googleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsLocalizedMessageToTerraform(struct?: GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsLocalizedMessage): any;
export declare function googleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsLocalizedMessageToHclTerraform(struct?: GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsLocalizedMessage): any;
export declare class GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsLocalizedMessageOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsLocalizedMessage | undefined;
    set internalValue(value: GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsLocalizedMessage | undefined);
    get locale(): string;
    get message(): string;
}
export declare class GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsLocalizedMessageList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsLocalizedMessageOutputReference;
}
export interface GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsQuotaInfo {
}
export declare function googleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsQuotaInfoToTerraform(struct?: GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsQuotaInfo): any;
export declare function googleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsQuotaInfoToHclTerraform(struct?: GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsQuotaInfo): any;
export declare class GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsQuotaInfoOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsQuotaInfo | undefined;
    set internalValue(value: GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsQuotaInfo | undefined);
    private _dimensions;
    get dimensions(): cdktf.StringMap;
    get futureLimit(): number;
    get limit(): number;
    get limitName(): string;
    get metricName(): string;
    get rolloutStatus(): string;
}
export declare class GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsQuotaInfoList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsQuotaInfoOutputReference;
}
export interface GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetails {
}
export declare function googleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsToTerraform(struct?: GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetails): any;
export declare function googleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsToHclTerraform(struct?: GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetails): any;
export declare class GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetails | undefined;
    set internalValue(value: GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetails | undefined);
    private _errorInfo;
    get errorInfo(): GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsErrorInfoList;
    private _help;
    get help(): GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsHelpList;
    private _localizedMessage;
    get localizedMessage(): GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsLocalizedMessageList;
    private _quotaInfo;
    get quotaInfo(): GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsQuotaInfoList;
}
export declare class GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsOutputReference;
}
export interface GoogleComputeResizeRequestStatusLastAttemptErrorErrors {
}
export declare function googleComputeResizeRequestStatusLastAttemptErrorErrorsToTerraform(struct?: GoogleComputeResizeRequestStatusLastAttemptErrorErrors): any;
export declare function googleComputeResizeRequestStatusLastAttemptErrorErrorsToHclTerraform(struct?: GoogleComputeResizeRequestStatusLastAttemptErrorErrors): any;
export declare class GoogleComputeResizeRequestStatusLastAttemptErrorErrorsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleComputeResizeRequestStatusLastAttemptErrorErrors | undefined;
    set internalValue(value: GoogleComputeResizeRequestStatusLastAttemptErrorErrors | undefined);
    get code(): string;
    private _errorDetails;
    get errorDetails(): GoogleComputeResizeRequestStatusLastAttemptErrorErrorsErrorDetailsList;
    get location(): string;
    get message(): string;
}
export declare class GoogleComputeResizeRequestStatusLastAttemptErrorErrorsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleComputeResizeRequestStatusLastAttemptErrorErrorsOutputReference;
}
export interface GoogleComputeResizeRequestStatusLastAttemptError {
}
export declare function googleComputeResizeRequestStatusLastAttemptErrorToTerraform(struct?: GoogleComputeResizeRequestStatusLastAttemptError): any;
export declare function googleComputeResizeRequestStatusLastAttemptErrorToHclTerraform(struct?: GoogleComputeResizeRequestStatusLastAttemptError): any;
export declare class GoogleComputeResizeRequestStatusLastAttemptErrorOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleComputeResizeRequestStatusLastAttemptError | undefined;
    set internalValue(value: GoogleComputeResizeRequestStatusLastAttemptError | undefined);
    private _errors;
    get errors(): GoogleComputeResizeRequestStatusLastAttemptErrorErrorsList;
}
export declare class GoogleComputeResizeRequestStatusLastAttemptErrorList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleComputeResizeRequestStatusLastAttemptErrorOutputReference;
}
export interface GoogleComputeResizeRequestStatusLastAttempt {
}
export declare function googleComputeResizeRequestStatusLastAttemptToTerraform(struct?: GoogleComputeResizeRequestStatusLastAttempt): any;
export declare function googleComputeResizeRequestStatusLastAttemptToHclTerraform(struct?: GoogleComputeResizeRequestStatusLastAttempt): any;
export declare class GoogleComputeResizeRequestStatusLastAttemptOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleComputeResizeRequestStatusLastAttempt | undefined;
    set internalValue(value: GoogleComputeResizeRequestStatusLastAttempt | undefined);
    private _error;
    get error(): GoogleComputeResizeRequestStatusLastAttemptErrorList;
}
export declare class GoogleComputeResizeRequestStatusLastAttemptList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleComputeResizeRequestStatusLastAttemptOutputReference;
}
export interface GoogleComputeResizeRequestStatus {
}
export declare function googleComputeResizeRequestStatusToTerraform(struct?: GoogleComputeResizeRequestStatus): any;
export declare function googleComputeResizeRequestStatusToHclTerraform(struct?: GoogleComputeResizeRequestStatus): any;
export declare class GoogleComputeResizeRequestStatusOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleComputeResizeRequestStatus | undefined;
    set internalValue(value: GoogleComputeResizeRequestStatus | undefined);
    private _error;
    get error(): GoogleComputeResizeRequestStatusErrorList;
    private _lastAttempt;
    get lastAttempt(): GoogleComputeResizeRequestStatusLastAttemptList;
}
export declare class GoogleComputeResizeRequestStatusList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleComputeResizeRequestStatusOutputReference;
}
export interface GoogleComputeResizeRequestRequestedRunDuration {
    /**
    * Span of time that's a fraction of a second at nanosecond resolution. Durations less than one second are represented with a 0 seconds field and a positive nanos field. Must be from 0 to 999,999,999 inclusive.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_resize_request#nanos GoogleComputeResizeRequest#nanos}
    */
    readonly nanos?: number;
    /**
    * Span of time at a resolution of a second. Must be from 0 to 315,576,000,000 inclusive. Note: these bounds are computed from: 60 sec/min * 60 min/hr * 24 hr/day * 365.25 days/year * 10000 years
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_resize_request#seconds GoogleComputeResizeRequest#seconds}
    */
    readonly seconds: string;
}
export declare function googleComputeResizeRequestRequestedRunDurationToTerraform(struct?: GoogleComputeResizeRequestRequestedRunDurationOutputReference | GoogleComputeResizeRequestRequestedRunDuration): any;
export declare function googleComputeResizeRequestRequestedRunDurationToHclTerraform(struct?: GoogleComputeResizeRequestRequestedRunDurationOutputReference | GoogleComputeResizeRequestRequestedRunDuration): any;
export declare class GoogleComputeResizeRequestRequestedRunDurationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleComputeResizeRequestRequestedRunDuration | undefined;
    set internalValue(value: GoogleComputeResizeRequestRequestedRunDuration | undefined);
    private _nanos?;
    get nanos(): number;
    set nanos(value: number);
    resetNanos(): void;
    get nanosInput(): number | undefined;
    private _seconds?;
    get seconds(): string;
    set seconds(value: string);
    get secondsInput(): string | undefined;
}
export interface GoogleComputeResizeRequestTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_resize_request#create GoogleComputeResizeRequest#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_resize_request#delete GoogleComputeResizeRequest#delete}
    */
    readonly delete?: string;
}
export declare function googleComputeResizeRequestTimeoutsToTerraform(struct?: GoogleComputeResizeRequestTimeouts | cdktf.IResolvable): any;
export declare function googleComputeResizeRequestTimeoutsToHclTerraform(struct?: GoogleComputeResizeRequestTimeouts | cdktf.IResolvable): any;
export declare class GoogleComputeResizeRequestTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleComputeResizeRequestTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleComputeResizeRequestTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_resize_request google_compute_resize_request}
*/
export declare class GoogleComputeResizeRequest extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_compute_resize_request";
    /**
    * Generates CDKTF code for importing a GoogleComputeResizeRequest resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleComputeResizeRequest to import
    * @param importFromId The id of the existing GoogleComputeResizeRequest that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_resize_request#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleComputeResizeRequest to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_resize_request google_compute_resize_request} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleComputeResizeRequestConfig
    */
    constructor(scope: Construct, id: string, config: GoogleComputeResizeRequestConfig);
    get creationTimestamp(): string;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _instanceGroupManager?;
    get instanceGroupManager(): string;
    set instanceGroupManager(value: string);
    get instanceGroupManagerInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _resizeBy?;
    get resizeBy(): number;
    set resizeBy(value: number);
    get resizeByInput(): number | undefined;
    get state(): string;
    private _status;
    get status(): GoogleComputeResizeRequestStatusList;
    private _zone?;
    get zone(): string;
    set zone(value: string);
    get zoneInput(): string | undefined;
    private _requestedRunDuration;
    get requestedRunDuration(): GoogleComputeResizeRequestRequestedRunDurationOutputReference;
    putRequestedRunDuration(value: GoogleComputeResizeRequestRequestedRunDuration): void;
    resetRequestedRunDuration(): void;
    get requestedRunDurationInput(): GoogleComputeResizeRequestRequestedRunDuration | undefined;
    private _timeouts;
    get timeouts(): GoogleComputeResizeRequestTimeoutsOutputReference;
    putTimeouts(value: GoogleComputeResizeRequestTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleComputeResizeRequestTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
