/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleComputeRouterRoutePolicyConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_router_route_policy#id GoogleComputeRouterRoutePolicy#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Name of the route policy. This policy's name, which must be a resource ID segment and unique within all policies owned by the Router
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_router_route_policy#name GoogleComputeRouterRoutePolicy#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_router_route_policy#project GoogleComputeRouterRoutePolicy#project}
    */
    readonly project?: string;
    /**
    * Region where the router and NAT reside.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_router_route_policy#region GoogleComputeRouterRoutePolicy#region}
    */
    readonly region?: string;
    /**
    * The name of the Cloud Router in which this route policy will be configured.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_router_route_policy#router GoogleComputeRouterRoutePolicy#router}
    */
    readonly router: string;
    /**
    * This is policy's type, which is one of IMPORT or EXPORT Possible values: ["ROUTE_POLICY_TYPE_IMPORT", "ROUTE_POLICY_TYPE_EXPORT"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_router_route_policy#type GoogleComputeRouterRoutePolicy#type}
    */
    readonly type?: string;
    /**
    * terms block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_router_route_policy#terms GoogleComputeRouterRoutePolicy#terms}
    */
    readonly terms: GoogleComputeRouterRoutePolicyTerms[] | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_router_route_policy#timeouts GoogleComputeRouterRoutePolicy#timeouts}
    */
    readonly timeouts?: GoogleComputeRouterRoutePolicyTimeouts;
}
export interface GoogleComputeRouterRoutePolicyTermsActions {
    /**
    * Description of the expression
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_router_route_policy#description GoogleComputeRouterRoutePolicy#description}
    */
    readonly description?: string;
    /**
    * Textual representation of an expression in Common Expression
    * Language syntax.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_router_route_policy#expression GoogleComputeRouterRoutePolicy#expression}
    */
    readonly expression: string;
    /**
    * String indicating the location of the expression for error
    * reporting, e.g. a file name and a position in the file
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_router_route_policy#location GoogleComputeRouterRoutePolicy#location}
    */
    readonly location?: string;
    /**
    * Title for the expression, i.e. a short string describing its
    * purpose.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_router_route_policy#title GoogleComputeRouterRoutePolicy#title}
    */
    readonly title?: string;
}
export declare function googleComputeRouterRoutePolicyTermsActionsToTerraform(struct?: GoogleComputeRouterRoutePolicyTermsActions | cdktf.IResolvable): any;
export declare function googleComputeRouterRoutePolicyTermsActionsToHclTerraform(struct?: GoogleComputeRouterRoutePolicyTermsActions | cdktf.IResolvable): any;
export declare class GoogleComputeRouterRoutePolicyTermsActionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleComputeRouterRoutePolicyTermsActions | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleComputeRouterRoutePolicyTermsActions | cdktf.IResolvable | undefined);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _expression?;
    get expression(): string;
    set expression(value: string);
    get expressionInput(): string | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    resetLocation(): void;
    get locationInput(): string | undefined;
    private _title?;
    get title(): string;
    set title(value: string);
    resetTitle(): void;
    get titleInput(): string | undefined;
}
export declare class GoogleComputeRouterRoutePolicyTermsActionsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleComputeRouterRoutePolicyTermsActions[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleComputeRouterRoutePolicyTermsActionsOutputReference;
}
export interface GoogleComputeRouterRoutePolicyTermsMatch {
    /**
    * Description of the expression
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_router_route_policy#description GoogleComputeRouterRoutePolicy#description}
    */
    readonly description?: string;
    /**
    * Textual representation of an expression in Common Expression Language syntax.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_router_route_policy#expression GoogleComputeRouterRoutePolicy#expression}
    */
    readonly expression: string;
    /**
    * String indicating the location of the expression for error reporting, e.g. a file name and a position in the file
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_router_route_policy#location GoogleComputeRouterRoutePolicy#location}
    */
    readonly location?: string;
    /**
    * Title for the expression, i.e. a short string describing its purpose.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_router_route_policy#title GoogleComputeRouterRoutePolicy#title}
    */
    readonly title?: string;
}
export declare function googleComputeRouterRoutePolicyTermsMatchToTerraform(struct?: GoogleComputeRouterRoutePolicyTermsMatchOutputReference | GoogleComputeRouterRoutePolicyTermsMatch): any;
export declare function googleComputeRouterRoutePolicyTermsMatchToHclTerraform(struct?: GoogleComputeRouterRoutePolicyTermsMatchOutputReference | GoogleComputeRouterRoutePolicyTermsMatch): any;
export declare class GoogleComputeRouterRoutePolicyTermsMatchOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleComputeRouterRoutePolicyTermsMatch | undefined;
    set internalValue(value: GoogleComputeRouterRoutePolicyTermsMatch | undefined);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _expression?;
    get expression(): string;
    set expression(value: string);
    get expressionInput(): string | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    resetLocation(): void;
    get locationInput(): string | undefined;
    private _title?;
    get title(): string;
    set title(value: string);
    resetTitle(): void;
    get titleInput(): string | undefined;
}
export interface GoogleComputeRouterRoutePolicyTerms {
    /**
    * The evaluation priority for this term, which must be between 0 (inclusive) and 231 (exclusive), and unique within the list.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_router_route_policy#priority GoogleComputeRouterRoutePolicy#priority}
    */
    readonly priority: number;
    /**
    * actions block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_router_route_policy#actions GoogleComputeRouterRoutePolicy#actions}
    */
    readonly actions?: GoogleComputeRouterRoutePolicyTermsActions[] | cdktf.IResolvable;
    /**
    * match block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_router_route_policy#match GoogleComputeRouterRoutePolicy#match}
    */
    readonly match?: GoogleComputeRouterRoutePolicyTermsMatch;
}
export declare function googleComputeRouterRoutePolicyTermsToTerraform(struct?: GoogleComputeRouterRoutePolicyTerms | cdktf.IResolvable): any;
export declare function googleComputeRouterRoutePolicyTermsToHclTerraform(struct?: GoogleComputeRouterRoutePolicyTerms | cdktf.IResolvable): any;
export declare class GoogleComputeRouterRoutePolicyTermsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleComputeRouterRoutePolicyTerms | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleComputeRouterRoutePolicyTerms | cdktf.IResolvable | undefined);
    private _priority?;
    get priority(): number;
    set priority(value: number);
    get priorityInput(): number | undefined;
    private _actions;
    get actions(): GoogleComputeRouterRoutePolicyTermsActionsList;
    putActions(value: GoogleComputeRouterRoutePolicyTermsActions[] | cdktf.IResolvable): void;
    resetActions(): void;
    get actionsInput(): cdktf.IResolvable | GoogleComputeRouterRoutePolicyTermsActions[] | undefined;
    private _match;
    get match(): GoogleComputeRouterRoutePolicyTermsMatchOutputReference;
    putMatch(value: GoogleComputeRouterRoutePolicyTermsMatch): void;
    resetMatch(): void;
    get matchInput(): GoogleComputeRouterRoutePolicyTermsMatch | undefined;
}
export declare class GoogleComputeRouterRoutePolicyTermsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleComputeRouterRoutePolicyTerms[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleComputeRouterRoutePolicyTermsOutputReference;
}
export interface GoogleComputeRouterRoutePolicyTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_router_route_policy#create GoogleComputeRouterRoutePolicy#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_router_route_policy#delete GoogleComputeRouterRoutePolicy#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_router_route_policy#update GoogleComputeRouterRoutePolicy#update}
    */
    readonly update?: string;
}
export declare function googleComputeRouterRoutePolicyTimeoutsToTerraform(struct?: GoogleComputeRouterRoutePolicyTimeouts | cdktf.IResolvable): any;
export declare function googleComputeRouterRoutePolicyTimeoutsToHclTerraform(struct?: GoogleComputeRouterRoutePolicyTimeouts | cdktf.IResolvable): any;
export declare class GoogleComputeRouterRoutePolicyTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleComputeRouterRoutePolicyTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleComputeRouterRoutePolicyTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_router_route_policy google_compute_router_route_policy}
*/
export declare class GoogleComputeRouterRoutePolicy extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_compute_router_route_policy";
    /**
    * Generates CDKTF code for importing a GoogleComputeRouterRoutePolicy resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleComputeRouterRoutePolicy to import
    * @param importFromId The id of the existing GoogleComputeRouterRoutePolicy that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_router_route_policy#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleComputeRouterRoutePolicy to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_compute_router_route_policy google_compute_router_route_policy} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleComputeRouterRoutePolicyConfig
    */
    constructor(scope: Construct, id: string, config: GoogleComputeRouterRoutePolicyConfig);
    get fingerprint(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _region?;
    get region(): string;
    set region(value: string);
    resetRegion(): void;
    get regionInput(): string | undefined;
    private _router?;
    get router(): string;
    set router(value: string);
    get routerInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    resetType(): void;
    get typeInput(): string | undefined;
    private _terms;
    get terms(): GoogleComputeRouterRoutePolicyTermsList;
    putTerms(value: GoogleComputeRouterRoutePolicyTerms[] | cdktf.IResolvable): void;
    get termsInput(): cdktf.IResolvable | GoogleComputeRouterRoutePolicyTerms[] | undefined;
    private _timeouts;
    get timeouts(): GoogleComputeRouterRoutePolicyTimeoutsOutputReference;
    putTimeouts(value: GoogleComputeRouterRoutePolicyTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleComputeRouterRoutePolicyTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
