/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleDataLossPreventionDiscoveryConfigConfig extends cdktf.TerraformMetaArguments {
    /**
    * Display Name (max 1000 Chars)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#display_name GoogleDataLossPreventionDiscoveryConfig#display_name}
    */
    readonly displayName?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#id GoogleDataLossPreventionDiscoveryConfig#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Detection logic for profile generation
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#inspect_templates GoogleDataLossPreventionDiscoveryConfig#inspect_templates}
    */
    readonly inspectTemplates?: string[];
    /**
    * Location to create the discovery config in.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#location GoogleDataLossPreventionDiscoveryConfig#location}
    */
    readonly location: string;
    /**
    * The parent of the discovery config in any of the following formats:
    *
    * * 'projects/{{project}}/locations/{{location}}'
    * * 'organizations/{{organization_id}}/locations/{{location}}'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#parent GoogleDataLossPreventionDiscoveryConfig#parent}
    */
    readonly parent: string;
    /**
    * Required. A status for this configuration Possible values: ["RUNNING", "PAUSED"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#status GoogleDataLossPreventionDiscoveryConfig#status}
    */
    readonly status?: string;
    /**
    * actions block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#actions GoogleDataLossPreventionDiscoveryConfig#actions}
    */
    readonly actions?: GoogleDataLossPreventionDiscoveryConfigActions[] | cdktf.IResolvable;
    /**
    * org_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#org_config GoogleDataLossPreventionDiscoveryConfig#org_config}
    */
    readonly orgConfig?: GoogleDataLossPreventionDiscoveryConfigOrgConfig;
    /**
    * targets block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#targets GoogleDataLossPreventionDiscoveryConfig#targets}
    */
    readonly targets?: GoogleDataLossPreventionDiscoveryConfigTargets[] | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#timeouts GoogleDataLossPreventionDiscoveryConfig#timeouts}
    */
    readonly timeouts?: GoogleDataLossPreventionDiscoveryConfigTimeouts;
}
export interface GoogleDataLossPreventionDiscoveryConfigErrorsDetails {
}
export declare function googleDataLossPreventionDiscoveryConfigErrorsDetailsToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigErrorsDetails): any;
export declare function googleDataLossPreventionDiscoveryConfigErrorsDetailsToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigErrorsDetails): any;
export declare class GoogleDataLossPreventionDiscoveryConfigErrorsDetailsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigErrorsDetails | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigErrorsDetails | undefined);
    get code(): number;
    private _details;
    get details(): cdktf.StringMapList;
    get message(): string;
}
export declare class GoogleDataLossPreventionDiscoveryConfigErrorsDetailsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDataLossPreventionDiscoveryConfigErrorsDetailsOutputReference;
}
export interface GoogleDataLossPreventionDiscoveryConfigErrors {
}
export declare function googleDataLossPreventionDiscoveryConfigErrorsToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigErrors): any;
export declare function googleDataLossPreventionDiscoveryConfigErrorsToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigErrors): any;
export declare class GoogleDataLossPreventionDiscoveryConfigErrorsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigErrors | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigErrors | undefined);
    private _details;
    get details(): GoogleDataLossPreventionDiscoveryConfigErrorsDetailsList;
    get timestamp(): string;
}
export declare class GoogleDataLossPreventionDiscoveryConfigErrorsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDataLossPreventionDiscoveryConfigErrorsOutputReference;
}
export interface GoogleDataLossPreventionDiscoveryConfigActionsExportDataProfileTable {
    /**
    * Dataset Id of the table
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#dataset_id GoogleDataLossPreventionDiscoveryConfig#dataset_id}
    */
    readonly datasetId?: string;
    /**
    * The Google Cloud Platform project ID of the project containing the table. If omitted, the project ID is inferred from the API call.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#project_id GoogleDataLossPreventionDiscoveryConfig#project_id}
    */
    readonly projectId?: string;
    /**
    * Name of the table
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#table_id GoogleDataLossPreventionDiscoveryConfig#table_id}
    */
    readonly tableId?: string;
}
export declare function googleDataLossPreventionDiscoveryConfigActionsExportDataProfileTableToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigActionsExportDataProfileTableOutputReference | GoogleDataLossPreventionDiscoveryConfigActionsExportDataProfileTable): any;
export declare function googleDataLossPreventionDiscoveryConfigActionsExportDataProfileTableToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigActionsExportDataProfileTableOutputReference | GoogleDataLossPreventionDiscoveryConfigActionsExportDataProfileTable): any;
export declare class GoogleDataLossPreventionDiscoveryConfigActionsExportDataProfileTableOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigActionsExportDataProfileTable | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigActionsExportDataProfileTable | undefined);
    private _datasetId?;
    get datasetId(): string;
    set datasetId(value: string);
    resetDatasetId(): void;
    get datasetIdInput(): string | undefined;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    resetProjectId(): void;
    get projectIdInput(): string | undefined;
    private _tableId?;
    get tableId(): string;
    set tableId(value: string);
    resetTableId(): void;
    get tableIdInput(): string | undefined;
}
export interface GoogleDataLossPreventionDiscoveryConfigActionsExportData {
    /**
    * profile_table block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#profile_table GoogleDataLossPreventionDiscoveryConfig#profile_table}
    */
    readonly profileTable?: GoogleDataLossPreventionDiscoveryConfigActionsExportDataProfileTable;
}
export declare function googleDataLossPreventionDiscoveryConfigActionsExportDataToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigActionsExportDataOutputReference | GoogleDataLossPreventionDiscoveryConfigActionsExportData): any;
export declare function googleDataLossPreventionDiscoveryConfigActionsExportDataToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigActionsExportDataOutputReference | GoogleDataLossPreventionDiscoveryConfigActionsExportData): any;
export declare class GoogleDataLossPreventionDiscoveryConfigActionsExportDataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigActionsExportData | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigActionsExportData | undefined);
    private _profileTable;
    get profileTable(): GoogleDataLossPreventionDiscoveryConfigActionsExportDataProfileTableOutputReference;
    putProfileTable(value: GoogleDataLossPreventionDiscoveryConfigActionsExportDataProfileTable): void;
    resetProfileTable(): void;
    get profileTableInput(): GoogleDataLossPreventionDiscoveryConfigActionsExportDataProfileTable | undefined;
}
export interface GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotificationPubsubConditionExpressionsConditions {
    /**
    * The minimum data risk score that triggers the condition. Possible values: ["HIGH", "MEDIUM_OR_HIGH"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#minimum_risk_score GoogleDataLossPreventionDiscoveryConfig#minimum_risk_score}
    */
    readonly minimumRiskScore?: string;
    /**
    * The minimum sensitivity level that triggers the condition. Possible values: ["HIGH", "MEDIUM_OR_HIGH"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#minimum_sensitivity_score GoogleDataLossPreventionDiscoveryConfig#minimum_sensitivity_score}
    */
    readonly minimumSensitivityScore?: string;
}
export declare function googleDataLossPreventionDiscoveryConfigActionsPubSubNotificationPubsubConditionExpressionsConditionsToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotificationPubsubConditionExpressionsConditions | cdktf.IResolvable): any;
export declare function googleDataLossPreventionDiscoveryConfigActionsPubSubNotificationPubsubConditionExpressionsConditionsToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotificationPubsubConditionExpressionsConditions | cdktf.IResolvable): any;
export declare class GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotificationPubsubConditionExpressionsConditionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotificationPubsubConditionExpressionsConditions | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotificationPubsubConditionExpressionsConditions | cdktf.IResolvable | undefined);
    private _minimumRiskScore?;
    get minimumRiskScore(): string;
    set minimumRiskScore(value: string);
    resetMinimumRiskScore(): void;
    get minimumRiskScoreInput(): string | undefined;
    private _minimumSensitivityScore?;
    get minimumSensitivityScore(): string;
    set minimumSensitivityScore(value: string);
    resetMinimumSensitivityScore(): void;
    get minimumSensitivityScoreInput(): string | undefined;
}
export declare class GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotificationPubsubConditionExpressionsConditionsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotificationPubsubConditionExpressionsConditions[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotificationPubsubConditionExpressionsConditionsOutputReference;
}
export interface GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotificationPubsubConditionExpressions {
    /**
    * The operator to apply to the collection of conditions Possible values: ["OR", "AND"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#logical_operator GoogleDataLossPreventionDiscoveryConfig#logical_operator}
    */
    readonly logicalOperator?: string;
    /**
    * conditions block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#conditions GoogleDataLossPreventionDiscoveryConfig#conditions}
    */
    readonly conditions?: GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotificationPubsubConditionExpressionsConditions[] | cdktf.IResolvable;
}
export declare function googleDataLossPreventionDiscoveryConfigActionsPubSubNotificationPubsubConditionExpressionsToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotificationPubsubConditionExpressionsOutputReference | GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotificationPubsubConditionExpressions): any;
export declare function googleDataLossPreventionDiscoveryConfigActionsPubSubNotificationPubsubConditionExpressionsToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotificationPubsubConditionExpressionsOutputReference | GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotificationPubsubConditionExpressions): any;
export declare class GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotificationPubsubConditionExpressionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotificationPubsubConditionExpressions | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotificationPubsubConditionExpressions | undefined);
    private _logicalOperator?;
    get logicalOperator(): string;
    set logicalOperator(value: string);
    resetLogicalOperator(): void;
    get logicalOperatorInput(): string | undefined;
    private _conditions;
    get conditions(): GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotificationPubsubConditionExpressionsConditionsList;
    putConditions(value: GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotificationPubsubConditionExpressionsConditions[] | cdktf.IResolvable): void;
    resetConditions(): void;
    get conditionsInput(): cdktf.IResolvable | GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotificationPubsubConditionExpressionsConditions[] | undefined;
}
export interface GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotificationPubsubCondition {
    /**
    * expressions block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#expressions GoogleDataLossPreventionDiscoveryConfig#expressions}
    */
    readonly expressions?: GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotificationPubsubConditionExpressions;
}
export declare function googleDataLossPreventionDiscoveryConfigActionsPubSubNotificationPubsubConditionToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotificationPubsubConditionOutputReference | GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotificationPubsubCondition): any;
export declare function googleDataLossPreventionDiscoveryConfigActionsPubSubNotificationPubsubConditionToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotificationPubsubConditionOutputReference | GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotificationPubsubCondition): any;
export declare class GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotificationPubsubConditionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotificationPubsubCondition | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotificationPubsubCondition | undefined);
    private _expressions;
    get expressions(): GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotificationPubsubConditionExpressionsOutputReference;
    putExpressions(value: GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotificationPubsubConditionExpressions): void;
    resetExpressions(): void;
    get expressionsInput(): GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotificationPubsubConditionExpressions | undefined;
}
export interface GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotification {
    /**
    * How much data to include in the pub/sub message. Possible values: ["TABLE_PROFILE", "RESOURCE_NAME"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#detail_of_message GoogleDataLossPreventionDiscoveryConfig#detail_of_message}
    */
    readonly detailOfMessage?: string;
    /**
    * The type of event that triggers a Pub/Sub. At most one PubSubNotification per EventType is permitted. Possible values: ["NEW_PROFILE", "CHANGED_PROFILE", "SCORE_INCREASED", "ERROR_CHANGED"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#event GoogleDataLossPreventionDiscoveryConfig#event}
    */
    readonly event?: string;
    /**
    * Cloud Pub/Sub topic to send notifications to. Format is projects/{project}/topics/{topic}.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#topic GoogleDataLossPreventionDiscoveryConfig#topic}
    */
    readonly topic?: string;
    /**
    * pubsub_condition block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#pubsub_condition GoogleDataLossPreventionDiscoveryConfig#pubsub_condition}
    */
    readonly pubsubCondition?: GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotificationPubsubCondition;
}
export declare function googleDataLossPreventionDiscoveryConfigActionsPubSubNotificationToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotificationOutputReference | GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotification): any;
export declare function googleDataLossPreventionDiscoveryConfigActionsPubSubNotificationToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotificationOutputReference | GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotification): any;
export declare class GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotificationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotification | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotification | undefined);
    private _detailOfMessage?;
    get detailOfMessage(): string;
    set detailOfMessage(value: string);
    resetDetailOfMessage(): void;
    get detailOfMessageInput(): string | undefined;
    private _event?;
    get event(): string;
    set event(value: string);
    resetEvent(): void;
    get eventInput(): string | undefined;
    private _topic?;
    get topic(): string;
    set topic(value: string);
    resetTopic(): void;
    get topicInput(): string | undefined;
    private _pubsubCondition;
    get pubsubCondition(): GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotificationPubsubConditionOutputReference;
    putPubsubCondition(value: GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotificationPubsubCondition): void;
    resetPubsubCondition(): void;
    get pubsubConditionInput(): GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotificationPubsubCondition | undefined;
}
export interface GoogleDataLossPreventionDiscoveryConfigActionsTagResourcesTagConditionsSensitivityScore {
    /**
    * The sensitivity score applied to the resource. Possible values: ["SENSITIVITY_LOW", "SENSITIVITY_MODERATE", "SENSITIVITY_HIGH"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#score GoogleDataLossPreventionDiscoveryConfig#score}
    */
    readonly score: string;
}
export declare function googleDataLossPreventionDiscoveryConfigActionsTagResourcesTagConditionsSensitivityScoreToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigActionsTagResourcesTagConditionsSensitivityScoreOutputReference | GoogleDataLossPreventionDiscoveryConfigActionsTagResourcesTagConditionsSensitivityScore): any;
export declare function googleDataLossPreventionDiscoveryConfigActionsTagResourcesTagConditionsSensitivityScoreToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigActionsTagResourcesTagConditionsSensitivityScoreOutputReference | GoogleDataLossPreventionDiscoveryConfigActionsTagResourcesTagConditionsSensitivityScore): any;
export declare class GoogleDataLossPreventionDiscoveryConfigActionsTagResourcesTagConditionsSensitivityScoreOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigActionsTagResourcesTagConditionsSensitivityScore | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigActionsTagResourcesTagConditionsSensitivityScore | undefined);
    private _score?;
    get score(): string;
    set score(value: string);
    get scoreInput(): string | undefined;
}
export interface GoogleDataLossPreventionDiscoveryConfigActionsTagResourcesTagConditionsTag {
    /**
    * The namespaced name for the tag value to attach to resources. Must be in the format '{parent_id}/{tag_key_short_name}/{short_name}', for example, "123456/environment/prod".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#namespaced_value GoogleDataLossPreventionDiscoveryConfig#namespaced_value}
    */
    readonly namespacedValue?: string;
}
export declare function googleDataLossPreventionDiscoveryConfigActionsTagResourcesTagConditionsTagToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigActionsTagResourcesTagConditionsTagOutputReference | GoogleDataLossPreventionDiscoveryConfigActionsTagResourcesTagConditionsTag): any;
export declare function googleDataLossPreventionDiscoveryConfigActionsTagResourcesTagConditionsTagToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigActionsTagResourcesTagConditionsTagOutputReference | GoogleDataLossPreventionDiscoveryConfigActionsTagResourcesTagConditionsTag): any;
export declare class GoogleDataLossPreventionDiscoveryConfigActionsTagResourcesTagConditionsTagOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigActionsTagResourcesTagConditionsTag | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigActionsTagResourcesTagConditionsTag | undefined);
    private _namespacedValue?;
    get namespacedValue(): string;
    set namespacedValue(value: string);
    resetNamespacedValue(): void;
    get namespacedValueInput(): string | undefined;
}
export interface GoogleDataLossPreventionDiscoveryConfigActionsTagResourcesTagConditions {
    /**
    * sensitivity_score block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#sensitivity_score GoogleDataLossPreventionDiscoveryConfig#sensitivity_score}
    */
    readonly sensitivityScore?: GoogleDataLossPreventionDiscoveryConfigActionsTagResourcesTagConditionsSensitivityScore;
    /**
    * tag block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#tag GoogleDataLossPreventionDiscoveryConfig#tag}
    */
    readonly tag?: GoogleDataLossPreventionDiscoveryConfigActionsTagResourcesTagConditionsTag;
}
export declare function googleDataLossPreventionDiscoveryConfigActionsTagResourcesTagConditionsToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigActionsTagResourcesTagConditions | cdktf.IResolvable): any;
export declare function googleDataLossPreventionDiscoveryConfigActionsTagResourcesTagConditionsToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigActionsTagResourcesTagConditions | cdktf.IResolvable): any;
export declare class GoogleDataLossPreventionDiscoveryConfigActionsTagResourcesTagConditionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigActionsTagResourcesTagConditions | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigActionsTagResourcesTagConditions | cdktf.IResolvable | undefined);
    private _sensitivityScore;
    get sensitivityScore(): GoogleDataLossPreventionDiscoveryConfigActionsTagResourcesTagConditionsSensitivityScoreOutputReference;
    putSensitivityScore(value: GoogleDataLossPreventionDiscoveryConfigActionsTagResourcesTagConditionsSensitivityScore): void;
    resetSensitivityScore(): void;
    get sensitivityScoreInput(): GoogleDataLossPreventionDiscoveryConfigActionsTagResourcesTagConditionsSensitivityScore | undefined;
    private _tag;
    get tag(): GoogleDataLossPreventionDiscoveryConfigActionsTagResourcesTagConditionsTagOutputReference;
    putTag(value: GoogleDataLossPreventionDiscoveryConfigActionsTagResourcesTagConditionsTag): void;
    resetTag(): void;
    get tagInput(): GoogleDataLossPreventionDiscoveryConfigActionsTagResourcesTagConditionsTag | undefined;
}
export declare class GoogleDataLossPreventionDiscoveryConfigActionsTagResourcesTagConditionsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleDataLossPreventionDiscoveryConfigActionsTagResourcesTagConditions[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDataLossPreventionDiscoveryConfigActionsTagResourcesTagConditionsOutputReference;
}
export interface GoogleDataLossPreventionDiscoveryConfigActionsTagResources {
    /**
    * Whether applying a tag to a resource should lower the risk of the profile for that resource. For example, in conjunction with an [IAM deny policy](https://cloud.google.com/iam/docs/deny-overview), you can deny all principals a permission if a tag value is present, mitigating the risk of the resource. This also lowers the data risk of resources at the lower levels of the resource hierarchy. For example, reducing the data risk of a table data profile also reduces the data risk of the constituent column data profiles.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#lower_data_risk_to_low GoogleDataLossPreventionDiscoveryConfig#lower_data_risk_to_low}
    */
    readonly lowerDataRiskToLow?: boolean | cdktf.IResolvable;
    /**
    * The profile generations for which the tag should be attached to resources. If you attach a tag to only new profiles, then if the sensitivity score of a profile subsequently changes, its tag doesn't change. By default, this field includes only new profiles. To include both new and updated profiles for tagging, this field should explicitly include both 'PROFILE_GENERATION_NEW' and 'PROFILE_GENERATION_UPDATE'. Possible values: ["PROFILE_GENERATION_NEW", "PROFILE_GENERATION_UPDATE"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#profile_generations_to_tag GoogleDataLossPreventionDiscoveryConfig#profile_generations_to_tag}
    */
    readonly profileGenerationsToTag?: string[];
    /**
    * tag_conditions block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#tag_conditions GoogleDataLossPreventionDiscoveryConfig#tag_conditions}
    */
    readonly tagConditions?: GoogleDataLossPreventionDiscoveryConfigActionsTagResourcesTagConditions[] | cdktf.IResolvable;
}
export declare function googleDataLossPreventionDiscoveryConfigActionsTagResourcesToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigActionsTagResourcesOutputReference | GoogleDataLossPreventionDiscoveryConfigActionsTagResources): any;
export declare function googleDataLossPreventionDiscoveryConfigActionsTagResourcesToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigActionsTagResourcesOutputReference | GoogleDataLossPreventionDiscoveryConfigActionsTagResources): any;
export declare class GoogleDataLossPreventionDiscoveryConfigActionsTagResourcesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigActionsTagResources | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigActionsTagResources | undefined);
    private _lowerDataRiskToLow?;
    get lowerDataRiskToLow(): boolean | cdktf.IResolvable;
    set lowerDataRiskToLow(value: boolean | cdktf.IResolvable);
    resetLowerDataRiskToLow(): void;
    get lowerDataRiskToLowInput(): boolean | cdktf.IResolvable | undefined;
    private _profileGenerationsToTag?;
    get profileGenerationsToTag(): string[];
    set profileGenerationsToTag(value: string[]);
    resetProfileGenerationsToTag(): void;
    get profileGenerationsToTagInput(): string[] | undefined;
    private _tagConditions;
    get tagConditions(): GoogleDataLossPreventionDiscoveryConfigActionsTagResourcesTagConditionsList;
    putTagConditions(value: GoogleDataLossPreventionDiscoveryConfigActionsTagResourcesTagConditions[] | cdktf.IResolvable): void;
    resetTagConditions(): void;
    get tagConditionsInput(): cdktf.IResolvable | GoogleDataLossPreventionDiscoveryConfigActionsTagResourcesTagConditions[] | undefined;
}
export interface GoogleDataLossPreventionDiscoveryConfigActions {
    /**
    * export_data block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#export_data GoogleDataLossPreventionDiscoveryConfig#export_data}
    */
    readonly exportData?: GoogleDataLossPreventionDiscoveryConfigActionsExportData;
    /**
    * pub_sub_notification block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#pub_sub_notification GoogleDataLossPreventionDiscoveryConfig#pub_sub_notification}
    */
    readonly pubSubNotification?: GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotification;
    /**
    * tag_resources block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#tag_resources GoogleDataLossPreventionDiscoveryConfig#tag_resources}
    */
    readonly tagResources?: GoogleDataLossPreventionDiscoveryConfigActionsTagResources;
}
export declare function googleDataLossPreventionDiscoveryConfigActionsToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigActions | cdktf.IResolvable): any;
export declare function googleDataLossPreventionDiscoveryConfigActionsToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigActions | cdktf.IResolvable): any;
export declare class GoogleDataLossPreventionDiscoveryConfigActionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigActions | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigActions | cdktf.IResolvable | undefined);
    private _exportData;
    get exportData(): GoogleDataLossPreventionDiscoveryConfigActionsExportDataOutputReference;
    putExportData(value: GoogleDataLossPreventionDiscoveryConfigActionsExportData): void;
    resetExportData(): void;
    get exportDataInput(): GoogleDataLossPreventionDiscoveryConfigActionsExportData | undefined;
    private _pubSubNotification;
    get pubSubNotification(): GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotificationOutputReference;
    putPubSubNotification(value: GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotification): void;
    resetPubSubNotification(): void;
    get pubSubNotificationInput(): GoogleDataLossPreventionDiscoveryConfigActionsPubSubNotification | undefined;
    private _tagResources;
    get tagResources(): GoogleDataLossPreventionDiscoveryConfigActionsTagResourcesOutputReference;
    putTagResources(value: GoogleDataLossPreventionDiscoveryConfigActionsTagResources): void;
    resetTagResources(): void;
    get tagResourcesInput(): GoogleDataLossPreventionDiscoveryConfigActionsTagResources | undefined;
}
export declare class GoogleDataLossPreventionDiscoveryConfigActionsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleDataLossPreventionDiscoveryConfigActions[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDataLossPreventionDiscoveryConfigActionsOutputReference;
}
export interface GoogleDataLossPreventionDiscoveryConfigOrgConfigLocation {
    /**
    * The ID for the folder within an organization to scan
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#folder_id GoogleDataLossPreventionDiscoveryConfig#folder_id}
    */
    readonly folderId?: string;
    /**
    * The ID of an organization to scan
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#organization_id GoogleDataLossPreventionDiscoveryConfig#organization_id}
    */
    readonly organizationId?: string;
}
export declare function googleDataLossPreventionDiscoveryConfigOrgConfigLocationToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigOrgConfigLocationOutputReference | GoogleDataLossPreventionDiscoveryConfigOrgConfigLocation): any;
export declare function googleDataLossPreventionDiscoveryConfigOrgConfigLocationToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigOrgConfigLocationOutputReference | GoogleDataLossPreventionDiscoveryConfigOrgConfigLocation): any;
export declare class GoogleDataLossPreventionDiscoveryConfigOrgConfigLocationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigOrgConfigLocation | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigOrgConfigLocation | undefined);
    private _folderId?;
    get folderId(): string;
    set folderId(value: string);
    resetFolderId(): void;
    get folderIdInput(): string | undefined;
    private _organizationId?;
    get organizationId(): string;
    set organizationId(value: string);
    resetOrganizationId(): void;
    get organizationIdInput(): string | undefined;
}
export interface GoogleDataLossPreventionDiscoveryConfigOrgConfig {
    /**
    * The project that will run the scan. The DLP service account that exists within this project must have access to all resources that are profiled, and the cloud DLP API must be enabled.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#project_id GoogleDataLossPreventionDiscoveryConfig#project_id}
    */
    readonly projectId?: string;
    /**
    * location block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#location GoogleDataLossPreventionDiscoveryConfig#location}
    */
    readonly location?: GoogleDataLossPreventionDiscoveryConfigOrgConfigLocation;
}
export declare function googleDataLossPreventionDiscoveryConfigOrgConfigToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigOrgConfigOutputReference | GoogleDataLossPreventionDiscoveryConfigOrgConfig): any;
export declare function googleDataLossPreventionDiscoveryConfigOrgConfigToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigOrgConfigOutputReference | GoogleDataLossPreventionDiscoveryConfigOrgConfig): any;
export declare class GoogleDataLossPreventionDiscoveryConfigOrgConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigOrgConfig | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigOrgConfig | undefined);
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    resetProjectId(): void;
    get projectIdInput(): string | undefined;
    private _location;
    get location(): GoogleDataLossPreventionDiscoveryConfigOrgConfigLocationOutputReference;
    putLocation(value: GoogleDataLossPreventionDiscoveryConfigOrgConfigLocation): void;
    resetLocation(): void;
    get locationInput(): GoogleDataLossPreventionDiscoveryConfigOrgConfigLocation | undefined;
}
export interface GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceInspectTemplateModifiedCadence {
    /**
    * How frequently data profiles can be updated when the template is modified. Defaults to never. Possible values: ["UPDATE_FREQUENCY_NEVER", "UPDATE_FREQUENCY_DAILY", "UPDATE_FREQUENCY_MONTHLY"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#frequency GoogleDataLossPreventionDiscoveryConfig#frequency}
    */
    readonly frequency?: string;
}
export declare function googleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceInspectTemplateModifiedCadenceToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceInspectTemplateModifiedCadenceOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceInspectTemplateModifiedCadence): any;
export declare function googleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceInspectTemplateModifiedCadenceToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceInspectTemplateModifiedCadenceOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceInspectTemplateModifiedCadence): any;
export declare class GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceInspectTemplateModifiedCadenceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceInspectTemplateModifiedCadence | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceInspectTemplateModifiedCadence | undefined);
    private _frequency?;
    get frequency(): string;
    set frequency(value: string);
    resetFrequency(): void;
    get frequencyInput(): string | undefined;
}
export interface GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceSchemaModifiedCadence {
    /**
    * How frequently profiles may be updated when schemas are modified. Default to monthly Possible values: ["UPDATE_FREQUENCY_NEVER", "UPDATE_FREQUENCY_DAILY", "UPDATE_FREQUENCY_MONTHLY"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#frequency GoogleDataLossPreventionDiscoveryConfig#frequency}
    */
    readonly frequency?: string;
    /**
    * The type of events to consider when deciding if the table's schema has been modified and should have the profile updated. Defaults to NEW_COLUMN. Possible values: ["SCHEMA_NEW_COLUMNS", "SCHEMA_REMOVED_COLUMNS"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#types GoogleDataLossPreventionDiscoveryConfig#types}
    */
    readonly types?: string[];
}
export declare function googleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceSchemaModifiedCadenceToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceSchemaModifiedCadenceOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceSchemaModifiedCadence): any;
export declare function googleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceSchemaModifiedCadenceToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceSchemaModifiedCadenceOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceSchemaModifiedCadence): any;
export declare class GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceSchemaModifiedCadenceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceSchemaModifiedCadence | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceSchemaModifiedCadence | undefined);
    private _frequency?;
    get frequency(): string;
    set frequency(value: string);
    resetFrequency(): void;
    get frequencyInput(): string | undefined;
    private _types?;
    get types(): string[];
    set types(value: string[]);
    resetTypes(): void;
    get typesInput(): string[] | undefined;
}
export interface GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceTableModifiedCadence {
    /**
    * How frequently data profiles can be updated when tables are modified. Defaults to never. Possible values: ["UPDATE_FREQUENCY_NEVER", "UPDATE_FREQUENCY_DAILY", "UPDATE_FREQUENCY_MONTHLY"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#frequency GoogleDataLossPreventionDiscoveryConfig#frequency}
    */
    readonly frequency?: string;
    /**
    * The type of events to consider when deciding if the table has been modified and should have the profile updated. Defaults to MODIFIED_TIMESTAMP Possible values: ["TABLE_MODIFIED_TIMESTAMP"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#types GoogleDataLossPreventionDiscoveryConfig#types}
    */
    readonly types?: string[];
}
export declare function googleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceTableModifiedCadenceToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceTableModifiedCadenceOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceTableModifiedCadence): any;
export declare function googleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceTableModifiedCadenceToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceTableModifiedCadenceOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceTableModifiedCadence): any;
export declare class GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceTableModifiedCadenceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceTableModifiedCadence | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceTableModifiedCadence | undefined);
    private _frequency?;
    get frequency(): string;
    set frequency(value: string);
    resetFrequency(): void;
    get frequencyInput(): string | undefined;
    private _types?;
    get types(): string[];
    set types(value: string[]);
    resetTypes(): void;
    get typesInput(): string[] | undefined;
}
export interface GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadence {
    /**
    * inspect_template_modified_cadence block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#inspect_template_modified_cadence GoogleDataLossPreventionDiscoveryConfig#inspect_template_modified_cadence}
    */
    readonly inspectTemplateModifiedCadence?: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceInspectTemplateModifiedCadence;
    /**
    * schema_modified_cadence block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#schema_modified_cadence GoogleDataLossPreventionDiscoveryConfig#schema_modified_cadence}
    */
    readonly schemaModifiedCadence?: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceSchemaModifiedCadence;
    /**
    * table_modified_cadence block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#table_modified_cadence GoogleDataLossPreventionDiscoveryConfig#table_modified_cadence}
    */
    readonly tableModifiedCadence?: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceTableModifiedCadence;
}
export declare function googleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadence): any;
export declare function googleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadence): any;
export declare class GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadence | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadence | undefined);
    private _inspectTemplateModifiedCadence;
    get inspectTemplateModifiedCadence(): GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceInspectTemplateModifiedCadenceOutputReference;
    putInspectTemplateModifiedCadence(value: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceInspectTemplateModifiedCadence): void;
    resetInspectTemplateModifiedCadence(): void;
    get inspectTemplateModifiedCadenceInput(): GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceInspectTemplateModifiedCadence | undefined;
    private _schemaModifiedCadence;
    get schemaModifiedCadence(): GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceSchemaModifiedCadenceOutputReference;
    putSchemaModifiedCadence(value: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceSchemaModifiedCadence): void;
    resetSchemaModifiedCadence(): void;
    get schemaModifiedCadenceInput(): GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceSchemaModifiedCadence | undefined;
    private _tableModifiedCadence;
    get tableModifiedCadence(): GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceTableModifiedCadenceOutputReference;
    putTableModifiedCadence(value: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceTableModifiedCadence): void;
    resetTableModifiedCadence(): void;
    get tableModifiedCadenceInput(): GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceTableModifiedCadence | undefined;
}
export interface GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetConditionsOrConditions {
    /**
    * Duration format. The minimum age a table must have before Cloud DLP can profile it. Value greater than 1.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#min_age GoogleDataLossPreventionDiscoveryConfig#min_age}
    */
    readonly minAge?: string;
    /**
    * Minimum number of rows that should be present before Cloud DLP profiles as a table.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#min_row_count GoogleDataLossPreventionDiscoveryConfig#min_row_count}
    */
    readonly minRowCount?: number;
}
export declare function googleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetConditionsOrConditionsToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetConditionsOrConditionsOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetConditionsOrConditions): any;
export declare function googleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetConditionsOrConditionsToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetConditionsOrConditionsOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetConditionsOrConditions): any;
export declare class GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetConditionsOrConditionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetConditionsOrConditions | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetConditionsOrConditions | undefined);
    private _minAge?;
    get minAge(): string;
    set minAge(value: string);
    resetMinAge(): void;
    get minAgeInput(): string | undefined;
    private _minRowCount?;
    get minRowCount(): number;
    set minRowCount(value: number);
    resetMinRowCount(): void;
    get minRowCountInput(): number | undefined;
}
export interface GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetConditionsTypes {
    /**
    * A set of BiqQuery table types Possible values: ["BIG_QUERY_TABLE_TYPE_TABLE", "BIG_QUERY_TABLE_TYPE_EXTERNAL_BIG_LAKE"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#types GoogleDataLossPreventionDiscoveryConfig#types}
    */
    readonly types?: string[];
}
export declare function googleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetConditionsTypesToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetConditionsTypesOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetConditionsTypes): any;
export declare function googleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetConditionsTypesToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetConditionsTypesOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetConditionsTypes): any;
export declare class GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetConditionsTypesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetConditionsTypes | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetConditionsTypes | undefined);
    private _types?;
    get types(): string[];
    set types(value: string[]);
    resetTypes(): void;
    get typesInput(): string[] | undefined;
}
export interface GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetConditions {
    /**
    * A timestamp in RFC3339 UTC "Zulu" format with nanosecond resolution and upto nine fractional digits.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#created_after GoogleDataLossPreventionDiscoveryConfig#created_after}
    */
    readonly createdAfter?: string;
    /**
    * Restrict discovery to categories of table types. Currently view, materialized view, snapshot and non-biglake external tables are supported. Possible values: ["BIG_QUERY_COLLECTION_ALL_TYPES", "BIG_QUERY_COLLECTION_ONLY_SUPPORTED_TYPES"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#type_collection GoogleDataLossPreventionDiscoveryConfig#type_collection}
    */
    readonly typeCollection?: string;
    /**
    * or_conditions block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#or_conditions GoogleDataLossPreventionDiscoveryConfig#or_conditions}
    */
    readonly orConditions?: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetConditionsOrConditions;
    /**
    * types block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#types GoogleDataLossPreventionDiscoveryConfig#types}
    */
    readonly types?: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetConditionsTypes;
}
export declare function googleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetConditionsToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetConditionsOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetConditions): any;
export declare function googleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetConditionsToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetConditionsOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetConditions): any;
export declare class GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetConditionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetConditions | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetConditions | undefined);
    private _createdAfter?;
    get createdAfter(): string;
    set createdAfter(value: string);
    resetCreatedAfter(): void;
    get createdAfterInput(): string | undefined;
    private _typeCollection?;
    get typeCollection(): string;
    set typeCollection(value: string);
    resetTypeCollection(): void;
    get typeCollectionInput(): string | undefined;
    private _orConditions;
    get orConditions(): GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetConditionsOrConditionsOutputReference;
    putOrConditions(value: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetConditionsOrConditions): void;
    resetOrConditions(): void;
    get orConditionsInput(): GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetConditionsOrConditions | undefined;
    private _types;
    get types(): GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetConditionsTypesOutputReference;
    putTypes(value: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetConditionsTypes): void;
    resetTypes(): void;
    get typesInput(): GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetConditionsTypes | undefined;
}
export interface GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetDisabled {
}
export declare function googleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetDisabledToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetDisabledOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetDisabled): any;
export declare function googleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetDisabledToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetDisabledOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetDisabled): any;
export declare class GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetDisabledOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetDisabled | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetDisabled | undefined);
}
export interface GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterOtherTables {
}
export declare function googleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterOtherTablesToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterOtherTablesOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterOtherTables): any;
export declare function googleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterOtherTablesToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterOtherTablesOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterOtherTables): any;
export declare class GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterOtherTablesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterOtherTables | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterOtherTables | undefined);
}
export interface GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTableReference {
    /**
    * Dataset ID of the table.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#dataset_id GoogleDataLossPreventionDiscoveryConfig#dataset_id}
    */
    readonly datasetId: string;
    /**
    * Name of the table.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#table_id GoogleDataLossPreventionDiscoveryConfig#table_id}
    */
    readonly tableId: string;
}
export declare function googleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTableReferenceToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTableReferenceOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTableReference): any;
export declare function googleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTableReferenceToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTableReferenceOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTableReference): any;
export declare class GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTableReferenceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTableReference | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTableReference | undefined);
    private _datasetId?;
    get datasetId(): string;
    set datasetId(value: string);
    get datasetIdInput(): string | undefined;
    private _tableId?;
    get tableId(): string;
    set tableId(value: string);
    get tableIdInput(): string | undefined;
}
export interface GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTablesIncludeRegexesPatterns {
    /**
    * if unset, this property matches all datasets
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#dataset_id_regex GoogleDataLossPreventionDiscoveryConfig#dataset_id_regex}
    */
    readonly datasetIdRegex?: string;
    /**
    * For organizations, if unset, will match all projects. Has no effect for data profile configurations created within a project.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#project_id_regex GoogleDataLossPreventionDiscoveryConfig#project_id_regex}
    */
    readonly projectIdRegex?: string;
    /**
    * if unset, this property matches all tables
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#table_id_regex GoogleDataLossPreventionDiscoveryConfig#table_id_regex}
    */
    readonly tableIdRegex?: string;
}
export declare function googleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTablesIncludeRegexesPatternsToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTablesIncludeRegexesPatterns | cdktf.IResolvable): any;
export declare function googleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTablesIncludeRegexesPatternsToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTablesIncludeRegexesPatterns | cdktf.IResolvable): any;
export declare class GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTablesIncludeRegexesPatternsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTablesIncludeRegexesPatterns | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTablesIncludeRegexesPatterns | cdktf.IResolvable | undefined);
    private _datasetIdRegex?;
    get datasetIdRegex(): string;
    set datasetIdRegex(value: string);
    resetDatasetIdRegex(): void;
    get datasetIdRegexInput(): string | undefined;
    private _projectIdRegex?;
    get projectIdRegex(): string;
    set projectIdRegex(value: string);
    resetProjectIdRegex(): void;
    get projectIdRegexInput(): string | undefined;
    private _tableIdRegex?;
    get tableIdRegex(): string;
    set tableIdRegex(value: string);
    resetTableIdRegex(): void;
    get tableIdRegexInput(): string | undefined;
}
export declare class GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTablesIncludeRegexesPatternsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTablesIncludeRegexesPatterns[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTablesIncludeRegexesPatternsOutputReference;
}
export interface GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTablesIncludeRegexes {
    /**
    * patterns block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#patterns GoogleDataLossPreventionDiscoveryConfig#patterns}
    */
    readonly patterns?: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTablesIncludeRegexesPatterns[] | cdktf.IResolvable;
}
export declare function googleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTablesIncludeRegexesToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTablesIncludeRegexesOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTablesIncludeRegexes): any;
export declare function googleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTablesIncludeRegexesToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTablesIncludeRegexesOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTablesIncludeRegexes): any;
export declare class GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTablesIncludeRegexesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTablesIncludeRegexes | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTablesIncludeRegexes | undefined);
    private _patterns;
    get patterns(): GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTablesIncludeRegexesPatternsList;
    putPatterns(value: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTablesIncludeRegexesPatterns[] | cdktf.IResolvable): void;
    resetPatterns(): void;
    get patternsInput(): cdktf.IResolvable | GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTablesIncludeRegexesPatterns[] | undefined;
}
export interface GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTables {
    /**
    * include_regexes block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#include_regexes GoogleDataLossPreventionDiscoveryConfig#include_regexes}
    */
    readonly includeRegexes?: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTablesIncludeRegexes;
}
export declare function googleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTablesToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTablesOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTables): any;
export declare function googleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTablesToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTablesOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTables): any;
export declare class GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTablesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTables | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTables | undefined);
    private _includeRegexes;
    get includeRegexes(): GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTablesIncludeRegexesOutputReference;
    putIncludeRegexes(value: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTablesIncludeRegexes): void;
    resetIncludeRegexes(): void;
    get includeRegexesInput(): GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTablesIncludeRegexes | undefined;
}
export interface GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilter {
    /**
    * other_tables block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#other_tables GoogleDataLossPreventionDiscoveryConfig#other_tables}
    */
    readonly otherTables?: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterOtherTables;
    /**
    * table_reference block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#table_reference GoogleDataLossPreventionDiscoveryConfig#table_reference}
    */
    readonly tableReference?: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTableReference;
    /**
    * tables block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#tables GoogleDataLossPreventionDiscoveryConfig#tables}
    */
    readonly tables?: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTables;
}
export declare function googleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilter): any;
export declare function googleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilter): any;
export declare class GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilter | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilter | undefined);
    private _otherTables;
    get otherTables(): GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterOtherTablesOutputReference;
    putOtherTables(value: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterOtherTables): void;
    resetOtherTables(): void;
    get otherTablesInput(): GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterOtherTables | undefined;
    private _tableReference;
    get tableReference(): GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTableReferenceOutputReference;
    putTableReference(value: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTableReference): void;
    resetTableReference(): void;
    get tableReferenceInput(): GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTableReference | undefined;
    private _tables;
    get tables(): GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTablesOutputReference;
    putTables(value: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTables): void;
    resetTables(): void;
    get tablesInput(): GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterTables | undefined;
}
export interface GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTarget {
    /**
    * cadence block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#cadence GoogleDataLossPreventionDiscoveryConfig#cadence}
    */
    readonly cadence?: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadence;
    /**
    * conditions block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#conditions GoogleDataLossPreventionDiscoveryConfig#conditions}
    */
    readonly conditions?: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetConditions;
    /**
    * disabled block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#disabled GoogleDataLossPreventionDiscoveryConfig#disabled}
    */
    readonly disabled?: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetDisabled;
    /**
    * filter block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#filter GoogleDataLossPreventionDiscoveryConfig#filter}
    */
    readonly filter?: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilter;
}
export declare function googleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTarget): any;
export declare function googleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTarget): any;
export declare class GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTarget | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTarget | undefined);
    private _cadence;
    get cadence(): GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadenceOutputReference;
    putCadence(value: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadence): void;
    resetCadence(): void;
    get cadenceInput(): GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetCadence | undefined;
    private _conditions;
    get conditions(): GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetConditionsOutputReference;
    putConditions(value: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetConditions): void;
    resetConditions(): void;
    get conditionsInput(): GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetConditions | undefined;
    private _disabled;
    get disabled(): GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetDisabledOutputReference;
    putDisabled(value: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetDisabled): void;
    resetDisabled(): void;
    get disabledInput(): GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetDisabled | undefined;
    private _filter;
    get filter(): GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilterOutputReference;
    putFilter(value: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilter): void;
    resetFilter(): void;
    get filterInput(): GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetFilter | undefined;
}
export interface GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetConditions {
    /**
    * Database engines that should be profiled. Optional. Defaults to ALL_SUPPORTED_DATABASE_ENGINES if unspecified. Possible values: ["ALL_SUPPORTED_DATABASE_ENGINES", "MYSQL", "POSTGRES"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#database_engines GoogleDataLossPreventionDiscoveryConfig#database_engines}
    */
    readonly databaseEngines?: string[];
    /**
    * Data profiles will only be generated for the database resource types specified in this field. If not specified, defaults to [DATABASE_RESOURCE_TYPE_ALL_SUPPORTED_TYPES]. Possible values: ["DATABASE_RESOURCE_TYPE_ALL_SUPPORTED_TYPES", "DATABASE_RESOURCE_TYPE_TABLE"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#types GoogleDataLossPreventionDiscoveryConfig#types}
    */
    readonly types?: string[];
}
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetConditionsToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetConditionsOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetConditions): any;
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetConditionsToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetConditionsOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetConditions): any;
export declare class GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetConditionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetConditions | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetConditions | undefined);
    private _databaseEngines?;
    get databaseEngines(): string[];
    set databaseEngines(value: string[]);
    resetDatabaseEngines(): void;
    get databaseEnginesInput(): string[] | undefined;
    private _types?;
    get types(): string[];
    set types(value: string[]);
    resetTypes(): void;
    get typesInput(): string[] | undefined;
}
export interface GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetDisabled {
}
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetDisabledToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetDisabledOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetDisabled): any;
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetDisabledToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetDisabledOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetDisabled): any;
export declare class GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetDisabledOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetDisabled | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetDisabled | undefined);
}
export interface GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterCollectionIncludeRegexesPatterns {
    /**
    * Regex to test the database name against. If empty, all databases match.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#database_regex GoogleDataLossPreventionDiscoveryConfig#database_regex}
    */
    readonly databaseRegex?: string;
    /**
    * Regex to test the database resource's name against. An example of a database resource name is a table's name. Other database resource names like view names could be included in the future. If empty, all database resources match.'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#database_resource_name_regex GoogleDataLossPreventionDiscoveryConfig#database_resource_name_regex}
    */
    readonly databaseResourceNameRegex?: string;
    /**
    * Regex to test the instance name against. If empty, all instances match.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#instance_regex GoogleDataLossPreventionDiscoveryConfig#instance_regex}
    */
    readonly instanceRegex?: string;
    /**
    * For organizations, if unset, will match all projects. Has no effect for data profile configurations created within a project.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#project_id_regex GoogleDataLossPreventionDiscoveryConfig#project_id_regex}
    */
    readonly projectIdRegex?: string;
}
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterCollectionIncludeRegexesPatternsToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterCollectionIncludeRegexesPatterns | cdktf.IResolvable): any;
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterCollectionIncludeRegexesPatternsToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterCollectionIncludeRegexesPatterns | cdktf.IResolvable): any;
export declare class GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterCollectionIncludeRegexesPatternsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterCollectionIncludeRegexesPatterns | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterCollectionIncludeRegexesPatterns | cdktf.IResolvable | undefined);
    private _databaseRegex?;
    get databaseRegex(): string;
    set databaseRegex(value: string);
    resetDatabaseRegex(): void;
    get databaseRegexInput(): string | undefined;
    private _databaseResourceNameRegex?;
    get databaseResourceNameRegex(): string;
    set databaseResourceNameRegex(value: string);
    resetDatabaseResourceNameRegex(): void;
    get databaseResourceNameRegexInput(): string | undefined;
    private _instanceRegex?;
    get instanceRegex(): string;
    set instanceRegex(value: string);
    resetInstanceRegex(): void;
    get instanceRegexInput(): string | undefined;
    private _projectIdRegex?;
    get projectIdRegex(): string;
    set projectIdRegex(value: string);
    resetProjectIdRegex(): void;
    get projectIdRegexInput(): string | undefined;
}
export declare class GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterCollectionIncludeRegexesPatternsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterCollectionIncludeRegexesPatterns[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterCollectionIncludeRegexesPatternsOutputReference;
}
export interface GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterCollectionIncludeRegexes {
    /**
    * patterns block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#patterns GoogleDataLossPreventionDiscoveryConfig#patterns}
    */
    readonly patterns?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterCollectionIncludeRegexesPatterns[] | cdktf.IResolvable;
}
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterCollectionIncludeRegexesToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterCollectionIncludeRegexesOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterCollectionIncludeRegexes): any;
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterCollectionIncludeRegexesToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterCollectionIncludeRegexesOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterCollectionIncludeRegexes): any;
export declare class GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterCollectionIncludeRegexesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterCollectionIncludeRegexes | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterCollectionIncludeRegexes | undefined);
    private _patterns;
    get patterns(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterCollectionIncludeRegexesPatternsList;
    putPatterns(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterCollectionIncludeRegexesPatterns[] | cdktf.IResolvable): void;
    resetPatterns(): void;
    get patternsInput(): cdktf.IResolvable | GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterCollectionIncludeRegexesPatterns[] | undefined;
}
export interface GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterCollection {
    /**
    * include_regexes block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#include_regexes GoogleDataLossPreventionDiscoveryConfig#include_regexes}
    */
    readonly includeRegexes?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterCollectionIncludeRegexes;
}
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterCollectionToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterCollectionOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterCollection): any;
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterCollectionToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterCollectionOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterCollection): any;
export declare class GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterCollectionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterCollection | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterCollection | undefined);
    private _includeRegexes;
    get includeRegexes(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterCollectionIncludeRegexesOutputReference;
    putIncludeRegexes(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterCollectionIncludeRegexes): void;
    resetIncludeRegexes(): void;
    get includeRegexesInput(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterCollectionIncludeRegexes | undefined;
}
export interface GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterDatabaseResourceReference {
    /**
    * Required. Name of a database within the instance.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#database GoogleDataLossPreventionDiscoveryConfig#database}
    */
    readonly database: string;
    /**
    * Required. Name of a database resource, for example, a table within the database.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#database_resource GoogleDataLossPreventionDiscoveryConfig#database_resource}
    */
    readonly databaseResource: string;
    /**
    * Required. The instance where this resource is located. For example: Cloud SQL instance ID.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#instance GoogleDataLossPreventionDiscoveryConfig#instance}
    */
    readonly instance: string;
    /**
    * Required. If within a project-level config, then this must match the config's project ID.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#project_id GoogleDataLossPreventionDiscoveryConfig#project_id}
    */
    readonly projectId: string;
}
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterDatabaseResourceReferenceToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterDatabaseResourceReferenceOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterDatabaseResourceReference): any;
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterDatabaseResourceReferenceToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterDatabaseResourceReferenceOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterDatabaseResourceReference): any;
export declare class GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterDatabaseResourceReferenceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterDatabaseResourceReference | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterDatabaseResourceReference | undefined);
    private _database?;
    get database(): string;
    set database(value: string);
    get databaseInput(): string | undefined;
    private _databaseResource?;
    get databaseResource(): string;
    set databaseResource(value: string);
    get databaseResourceInput(): string | undefined;
    private _instance?;
    get instance(): string;
    set instance(value: string);
    get instanceInput(): string | undefined;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    get projectIdInput(): string | undefined;
}
export interface GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterOthers {
}
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterOthersToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterOthersOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterOthers): any;
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterOthersToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterOthersOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterOthers): any;
export declare class GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterOthersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterOthers | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterOthers | undefined);
}
export interface GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilter {
    /**
    * collection block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#collection GoogleDataLossPreventionDiscoveryConfig#collection}
    */
    readonly collection?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterCollection;
    /**
    * database_resource_reference block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#database_resource_reference GoogleDataLossPreventionDiscoveryConfig#database_resource_reference}
    */
    readonly databaseResourceReference?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterDatabaseResourceReference;
    /**
    * others block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#others GoogleDataLossPreventionDiscoveryConfig#others}
    */
    readonly others?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterOthers;
}
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilter): any;
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilter): any;
export declare class GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilter | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilter | undefined);
    private _collection;
    get collection(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterCollectionOutputReference;
    putCollection(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterCollection): void;
    resetCollection(): void;
    get collectionInput(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterCollection | undefined;
    private _databaseResourceReference;
    get databaseResourceReference(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterDatabaseResourceReferenceOutputReference;
    putDatabaseResourceReference(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterDatabaseResourceReference): void;
    resetDatabaseResourceReference(): void;
    get databaseResourceReferenceInput(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterDatabaseResourceReference | undefined;
    private _others;
    get others(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterOthersOutputReference;
    putOthers(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterOthers): void;
    resetOthers(): void;
    get othersInput(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterOthers | undefined;
}
export interface GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetGenerationCadenceInspectTemplateModifiedCadence {
    /**
    * How frequently data profiles can be updated when the template is modified. Defaults to never. Possible values: ["UPDATE_FREQUENCY_NEVER", "UPDATE_FREQUENCY_DAILY", "UPDATE_FREQUENCY_MONTHLY"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#frequency GoogleDataLossPreventionDiscoveryConfig#frequency}
    */
    readonly frequency: string;
}
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetGenerationCadenceInspectTemplateModifiedCadenceToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetGenerationCadenceInspectTemplateModifiedCadenceOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetGenerationCadenceInspectTemplateModifiedCadence): any;
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetGenerationCadenceInspectTemplateModifiedCadenceToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetGenerationCadenceInspectTemplateModifiedCadenceOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetGenerationCadenceInspectTemplateModifiedCadence): any;
export declare class GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetGenerationCadenceInspectTemplateModifiedCadenceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetGenerationCadenceInspectTemplateModifiedCadence | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetGenerationCadenceInspectTemplateModifiedCadence | undefined);
    private _frequency?;
    get frequency(): string;
    set frequency(value: string);
    get frequencyInput(): string | undefined;
}
export interface GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetGenerationCadenceSchemaModifiedCadence {
    /**
    * Frequency to regenerate data profiles when the schema is modified. Defaults to monthly. Possible values: ["UPDATE_FREQUENCY_NEVER", "UPDATE_FREQUENCY_DAILY", "UPDATE_FREQUENCY_MONTHLY"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#frequency GoogleDataLossPreventionDiscoveryConfig#frequency}
    */
    readonly frequency?: string;
    /**
    * The types of schema modifications to consider. Defaults to NEW_COLUMNS. Possible values: ["NEW_COLUMNS", "REMOVED_COLUMNS"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#types GoogleDataLossPreventionDiscoveryConfig#types}
    */
    readonly types?: string[];
}
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetGenerationCadenceSchemaModifiedCadenceToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetGenerationCadenceSchemaModifiedCadenceOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetGenerationCadenceSchemaModifiedCadence): any;
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetGenerationCadenceSchemaModifiedCadenceToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetGenerationCadenceSchemaModifiedCadenceOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetGenerationCadenceSchemaModifiedCadence): any;
export declare class GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetGenerationCadenceSchemaModifiedCadenceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetGenerationCadenceSchemaModifiedCadence | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetGenerationCadenceSchemaModifiedCadence | undefined);
    private _frequency?;
    get frequency(): string;
    set frequency(value: string);
    resetFrequency(): void;
    get frequencyInput(): string | undefined;
    private _types?;
    get types(): string[];
    set types(value: string[]);
    resetTypes(): void;
    get typesInput(): string[] | undefined;
}
export interface GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetGenerationCadence {
    /**
    * Data changes (non-schema changes) in Cloud SQL tables can't trigger reprofiling. If you set this field, profiles are refreshed at this frequency regardless of whether the underlying tables have changes. Defaults to never. Possible values: ["UPDATE_FREQUENCY_NEVER", "UPDATE_FREQUENCY_DAILY", "UPDATE_FREQUENCY_MONTHLY"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#refresh_frequency GoogleDataLossPreventionDiscoveryConfig#refresh_frequency}
    */
    readonly refreshFrequency?: string;
    /**
    * inspect_template_modified_cadence block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#inspect_template_modified_cadence GoogleDataLossPreventionDiscoveryConfig#inspect_template_modified_cadence}
    */
    readonly inspectTemplateModifiedCadence?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetGenerationCadenceInspectTemplateModifiedCadence;
    /**
    * schema_modified_cadence block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#schema_modified_cadence GoogleDataLossPreventionDiscoveryConfig#schema_modified_cadence}
    */
    readonly schemaModifiedCadence?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetGenerationCadenceSchemaModifiedCadence;
}
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetGenerationCadenceToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetGenerationCadenceOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetGenerationCadence): any;
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetGenerationCadenceToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetGenerationCadenceOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetGenerationCadence): any;
export declare class GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetGenerationCadenceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetGenerationCadence | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetGenerationCadence | undefined);
    private _refreshFrequency?;
    get refreshFrequency(): string;
    set refreshFrequency(value: string);
    resetRefreshFrequency(): void;
    get refreshFrequencyInput(): string | undefined;
    private _inspectTemplateModifiedCadence;
    get inspectTemplateModifiedCadence(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetGenerationCadenceInspectTemplateModifiedCadenceOutputReference;
    putInspectTemplateModifiedCadence(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetGenerationCadenceInspectTemplateModifiedCadence): void;
    resetInspectTemplateModifiedCadence(): void;
    get inspectTemplateModifiedCadenceInput(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetGenerationCadenceInspectTemplateModifiedCadence | undefined;
    private _schemaModifiedCadence;
    get schemaModifiedCadence(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetGenerationCadenceSchemaModifiedCadenceOutputReference;
    putSchemaModifiedCadence(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetGenerationCadenceSchemaModifiedCadence): void;
    resetSchemaModifiedCadence(): void;
    get schemaModifiedCadenceInput(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetGenerationCadenceSchemaModifiedCadence | undefined;
}
export interface GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTarget {
    /**
    * conditions block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#conditions GoogleDataLossPreventionDiscoveryConfig#conditions}
    */
    readonly conditions?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetConditions;
    /**
    * disabled block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#disabled GoogleDataLossPreventionDiscoveryConfig#disabled}
    */
    readonly disabled?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetDisabled;
    /**
    * filter block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#filter GoogleDataLossPreventionDiscoveryConfig#filter}
    */
    readonly filter: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilter;
    /**
    * generation_cadence block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#generation_cadence GoogleDataLossPreventionDiscoveryConfig#generation_cadence}
    */
    readonly generationCadence?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetGenerationCadence;
}
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTarget): any;
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTarget): any;
export declare class GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTarget | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTarget | undefined);
    private _conditions;
    get conditions(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetConditionsOutputReference;
    putConditions(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetConditions): void;
    resetConditions(): void;
    get conditionsInput(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetConditions | undefined;
    private _disabled;
    get disabled(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetDisabledOutputReference;
    putDisabled(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetDisabled): void;
    resetDisabled(): void;
    get disabledInput(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetDisabled | undefined;
    private _filter;
    get filter(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilterOutputReference;
    putFilter(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilter): void;
    get filterInput(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetFilter | undefined;
    private _generationCadence;
    get generationCadence(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetGenerationCadenceOutputReference;
    putGenerationCadence(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetGenerationCadence): void;
    resetGenerationCadence(): void;
    get generationCadenceInput(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetGenerationCadence | undefined;
}
export interface GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetConditionsCloudStorageConditions {
    /**
    * Only objects with the specified attributes will be scanned. Defaults to [ALL_SUPPORTED_BUCKETS] if unset. Possible values: ["ALL_SUPPORTED_BUCKETS", "AUTOCLASS_DISABLED", "AUTOCLASS_ENABLED"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#included_bucket_attributes GoogleDataLossPreventionDiscoveryConfig#included_bucket_attributes}
    */
    readonly includedBucketAttributes?: string[];
    /**
    * Only objects with the specified attributes will be scanned. If an object has one of the specified attributes but is inside an excluded bucket, it will not be scanned. Defaults to [ALL_SUPPORTED_OBJECTS]. A profile will be created even if no objects match the included_object_attributes. Possible values: ["ALL_SUPPORTED_OBJECTS", "STANDARD", "NEARLINE", "COLDLINE", "ARCHIVE", "REGIONAL", "MULTI_REGIONAL", "DURABLE_REDUCED_AVAILABILITY"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#included_object_attributes GoogleDataLossPreventionDiscoveryConfig#included_object_attributes}
    */
    readonly includedObjectAttributes?: string[];
}
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetConditionsCloudStorageConditionsToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetConditionsCloudStorageConditionsOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetConditionsCloudStorageConditions): any;
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetConditionsCloudStorageConditionsToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetConditionsCloudStorageConditionsOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetConditionsCloudStorageConditions): any;
export declare class GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetConditionsCloudStorageConditionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetConditionsCloudStorageConditions | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetConditionsCloudStorageConditions | undefined);
    private _includedBucketAttributes?;
    get includedBucketAttributes(): string[];
    set includedBucketAttributes(value: string[]);
    resetIncludedBucketAttributes(): void;
    get includedBucketAttributesInput(): string[] | undefined;
    private _includedObjectAttributes?;
    get includedObjectAttributes(): string[];
    set includedObjectAttributes(value: string[]);
    resetIncludedObjectAttributes(): void;
    get includedObjectAttributesInput(): string[] | undefined;
}
export interface GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetConditions {
    /**
    * File store must have been created after this date. Used to avoid backfilling. A timestamp in RFC3339 UTC "Zulu" format with nanosecond resolution and upto nine fractional digits.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#created_after GoogleDataLossPreventionDiscoveryConfig#created_after}
    */
    readonly createdAfter?: string;
    /**
    * Duration format. Minimum age a file store must have. If set, the value must be 1 hour or greater.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#min_age GoogleDataLossPreventionDiscoveryConfig#min_age}
    */
    readonly minAge?: string;
    /**
    * cloud_storage_conditions block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#cloud_storage_conditions GoogleDataLossPreventionDiscoveryConfig#cloud_storage_conditions}
    */
    readonly cloudStorageConditions?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetConditionsCloudStorageConditions;
}
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetConditionsToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetConditionsOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetConditions): any;
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetConditionsToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetConditionsOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetConditions): any;
export declare class GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetConditionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetConditions | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetConditions | undefined);
    private _createdAfter?;
    get createdAfter(): string;
    set createdAfter(value: string);
    resetCreatedAfter(): void;
    get createdAfterInput(): string | undefined;
    private _minAge?;
    get minAge(): string;
    set minAge(value: string);
    resetMinAge(): void;
    get minAgeInput(): string | undefined;
    private _cloudStorageConditions;
    get cloudStorageConditions(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetConditionsCloudStorageConditionsOutputReference;
    putCloudStorageConditions(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetConditionsCloudStorageConditions): void;
    resetCloudStorageConditions(): void;
    get cloudStorageConditionsInput(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetConditionsCloudStorageConditions | undefined;
}
export interface GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetDisabled {
}
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetDisabledToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetDisabledOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetDisabled): any;
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetDisabledToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetDisabledOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetDisabled): any;
export declare class GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetDisabledOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetDisabled | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetDisabled | undefined);
}
export interface GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCloudStorageResourceReference {
    /**
    * The bucket to scan.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#bucket_name GoogleDataLossPreventionDiscoveryConfig#bucket_name}
    */
    readonly bucketName?: string;
    /**
    * If within a project-level config, then this must match the config's project id.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#project_id GoogleDataLossPreventionDiscoveryConfig#project_id}
    */
    readonly projectId?: string;
}
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCloudStorageResourceReferenceToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCloudStorageResourceReferenceOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCloudStorageResourceReference): any;
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCloudStorageResourceReferenceToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCloudStorageResourceReferenceOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCloudStorageResourceReference): any;
export declare class GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCloudStorageResourceReferenceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCloudStorageResourceReference | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCloudStorageResourceReference | undefined);
    private _bucketName?;
    get bucketName(): string;
    set bucketName(value: string);
    resetBucketName(): void;
    get bucketNameInput(): string | undefined;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    resetProjectId(): void;
    get projectIdInput(): string | undefined;
}
export interface GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionIncludeRegexesPatternsCloudStorageRegex {
    /**
    * Regex to test the bucket name against. If empty, all buckets match. Example: "marketing2021" or "(marketing)\d{4}" will both match the bucket gs://marketing2021
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#bucket_name_regex GoogleDataLossPreventionDiscoveryConfig#bucket_name_regex}
    */
    readonly bucketNameRegex?: string;
    /**
    * For organizations, if unset, will match all projects.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#project_id_regex GoogleDataLossPreventionDiscoveryConfig#project_id_regex}
    */
    readonly projectIdRegex?: string;
}
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionIncludeRegexesPatternsCloudStorageRegexToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionIncludeRegexesPatternsCloudStorageRegexOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionIncludeRegexesPatternsCloudStorageRegex): any;
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionIncludeRegexesPatternsCloudStorageRegexToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionIncludeRegexesPatternsCloudStorageRegexOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionIncludeRegexesPatternsCloudStorageRegex): any;
export declare class GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionIncludeRegexesPatternsCloudStorageRegexOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionIncludeRegexesPatternsCloudStorageRegex | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionIncludeRegexesPatternsCloudStorageRegex | undefined);
    private _bucketNameRegex?;
    get bucketNameRegex(): string;
    set bucketNameRegex(value: string);
    resetBucketNameRegex(): void;
    get bucketNameRegexInput(): string | undefined;
    private _projectIdRegex?;
    get projectIdRegex(): string;
    set projectIdRegex(value: string);
    resetProjectIdRegex(): void;
    get projectIdRegexInput(): string | undefined;
}
export interface GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionIncludeRegexesPatterns {
    /**
    * cloud_storage_regex block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#cloud_storage_regex GoogleDataLossPreventionDiscoveryConfig#cloud_storage_regex}
    */
    readonly cloudStorageRegex?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionIncludeRegexesPatternsCloudStorageRegex;
}
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionIncludeRegexesPatternsToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionIncludeRegexesPatterns | cdktf.IResolvable): any;
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionIncludeRegexesPatternsToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionIncludeRegexesPatterns | cdktf.IResolvable): any;
export declare class GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionIncludeRegexesPatternsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionIncludeRegexesPatterns | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionIncludeRegexesPatterns | cdktf.IResolvable | undefined);
    private _cloudStorageRegex;
    get cloudStorageRegex(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionIncludeRegexesPatternsCloudStorageRegexOutputReference;
    putCloudStorageRegex(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionIncludeRegexesPatternsCloudStorageRegex): void;
    resetCloudStorageRegex(): void;
    get cloudStorageRegexInput(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionIncludeRegexesPatternsCloudStorageRegex | undefined;
}
export declare class GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionIncludeRegexesPatternsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionIncludeRegexesPatterns[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionIncludeRegexesPatternsOutputReference;
}
export interface GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionIncludeRegexes {
    /**
    * patterns block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#patterns GoogleDataLossPreventionDiscoveryConfig#patterns}
    */
    readonly patterns?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionIncludeRegexesPatterns[] | cdktf.IResolvable;
}
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionIncludeRegexesToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionIncludeRegexesOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionIncludeRegexes): any;
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionIncludeRegexesToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionIncludeRegexesOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionIncludeRegexes): any;
export declare class GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionIncludeRegexesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionIncludeRegexes | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionIncludeRegexes | undefined);
    private _patterns;
    get patterns(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionIncludeRegexesPatternsList;
    putPatterns(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionIncludeRegexesPatterns[] | cdktf.IResolvable): void;
    resetPatterns(): void;
    get patternsInput(): cdktf.IResolvable | GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionIncludeRegexesPatterns[] | undefined;
}
export interface GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollection {
    /**
    * include_regexes block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#include_regexes GoogleDataLossPreventionDiscoveryConfig#include_regexes}
    */
    readonly includeRegexes?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionIncludeRegexes;
}
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollection): any;
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollection): any;
export declare class GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollection | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollection | undefined);
    private _includeRegexes;
    get includeRegexes(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionIncludeRegexesOutputReference;
    putIncludeRegexes(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionIncludeRegexes): void;
    resetIncludeRegexes(): void;
    get includeRegexesInput(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionIncludeRegexes | undefined;
}
export interface GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterOthers {
}
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterOthersToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterOthersOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterOthers): any;
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterOthersToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterOthersOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterOthers): any;
export declare class GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterOthersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterOthers | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterOthers | undefined);
}
export interface GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilter {
    /**
    * cloud_storage_resource_reference block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#cloud_storage_resource_reference GoogleDataLossPreventionDiscoveryConfig#cloud_storage_resource_reference}
    */
    readonly cloudStorageResourceReference?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCloudStorageResourceReference;
    /**
    * collection block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#collection GoogleDataLossPreventionDiscoveryConfig#collection}
    */
    readonly collection?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollection;
    /**
    * others block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#others GoogleDataLossPreventionDiscoveryConfig#others}
    */
    readonly others?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterOthers;
}
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilter): any;
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilter): any;
export declare class GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilter | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilter | undefined);
    private _cloudStorageResourceReference;
    get cloudStorageResourceReference(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCloudStorageResourceReferenceOutputReference;
    putCloudStorageResourceReference(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCloudStorageResourceReference): void;
    resetCloudStorageResourceReference(): void;
    get cloudStorageResourceReferenceInput(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCloudStorageResourceReference | undefined;
    private _collection;
    get collection(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollectionOutputReference;
    putCollection(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollection): void;
    resetCollection(): void;
    get collectionInput(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterCollection | undefined;
    private _others;
    get others(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterOthersOutputReference;
    putOthers(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterOthers): void;
    resetOthers(): void;
    get othersInput(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterOthers | undefined;
}
export interface GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetGenerationCadenceInspectTemplateModifiedCadence {
    /**
    * How frequently data profiles can be updated when the template is modified. Defaults to never. Possible values: ["UPDATE_FREQUENCY_NEVER", "UPDATE_FREQUENCY_DAILY", "UPDATE_FREQUENCY_MONTHLY"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#frequency GoogleDataLossPreventionDiscoveryConfig#frequency}
    */
    readonly frequency?: string;
}
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetGenerationCadenceInspectTemplateModifiedCadenceToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetGenerationCadenceInspectTemplateModifiedCadenceOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetGenerationCadenceInspectTemplateModifiedCadence): any;
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetGenerationCadenceInspectTemplateModifiedCadenceToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetGenerationCadenceInspectTemplateModifiedCadenceOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetGenerationCadenceInspectTemplateModifiedCadence): any;
export declare class GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetGenerationCadenceInspectTemplateModifiedCadenceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetGenerationCadenceInspectTemplateModifiedCadence | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetGenerationCadenceInspectTemplateModifiedCadence | undefined);
    private _frequency?;
    get frequency(): string;
    set frequency(value: string);
    resetFrequency(): void;
    get frequencyInput(): string | undefined;
}
export interface GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetGenerationCadence {
    /**
    * Data changes in Cloud Storage can't trigger reprofiling. If you set this field, profiles are refreshed at this frequency regardless of whether the underlying buckets have changes. Defaults to never. Possible values: ["UPDATE_FREQUENCY_NEVER", "UPDATE_FREQUENCY_DAILY", "UPDATE_FREQUENCY_MONTHLY"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#refresh_frequency GoogleDataLossPreventionDiscoveryConfig#refresh_frequency}
    */
    readonly refreshFrequency?: string;
    /**
    * inspect_template_modified_cadence block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#inspect_template_modified_cadence GoogleDataLossPreventionDiscoveryConfig#inspect_template_modified_cadence}
    */
    readonly inspectTemplateModifiedCadence?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetGenerationCadenceInspectTemplateModifiedCadence;
}
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetGenerationCadenceToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetGenerationCadenceOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetGenerationCadence): any;
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetGenerationCadenceToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetGenerationCadenceOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetGenerationCadence): any;
export declare class GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetGenerationCadenceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetGenerationCadence | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetGenerationCadence | undefined);
    private _refreshFrequency?;
    get refreshFrequency(): string;
    set refreshFrequency(value: string);
    resetRefreshFrequency(): void;
    get refreshFrequencyInput(): string | undefined;
    private _inspectTemplateModifiedCadence;
    get inspectTemplateModifiedCadence(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetGenerationCadenceInspectTemplateModifiedCadenceOutputReference;
    putInspectTemplateModifiedCadence(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetGenerationCadenceInspectTemplateModifiedCadence): void;
    resetInspectTemplateModifiedCadence(): void;
    get inspectTemplateModifiedCadenceInput(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetGenerationCadenceInspectTemplateModifiedCadence | undefined;
}
export interface GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTarget {
    /**
    * conditions block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#conditions GoogleDataLossPreventionDiscoveryConfig#conditions}
    */
    readonly conditions?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetConditions;
    /**
    * disabled block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#disabled GoogleDataLossPreventionDiscoveryConfig#disabled}
    */
    readonly disabled?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetDisabled;
    /**
    * filter block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#filter GoogleDataLossPreventionDiscoveryConfig#filter}
    */
    readonly filter: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilter;
    /**
    * generation_cadence block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#generation_cadence GoogleDataLossPreventionDiscoveryConfig#generation_cadence}
    */
    readonly generationCadence?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetGenerationCadence;
}
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTarget): any;
export declare function googleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTarget): any;
export declare class GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTarget | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTarget | undefined);
    private _conditions;
    get conditions(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetConditionsOutputReference;
    putConditions(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetConditions): void;
    resetConditions(): void;
    get conditionsInput(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetConditions | undefined;
    private _disabled;
    get disabled(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetDisabledOutputReference;
    putDisabled(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetDisabled): void;
    resetDisabled(): void;
    get disabledInput(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetDisabled | undefined;
    private _filter;
    get filter(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilterOutputReference;
    putFilter(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilter): void;
    get filterInput(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetFilter | undefined;
    private _generationCadence;
    get generationCadence(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetGenerationCadenceOutputReference;
    putGenerationCadence(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetGenerationCadence): void;
    resetGenerationCadence(): void;
    get generationCadenceInput(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetGenerationCadence | undefined;
}
export interface GoogleDataLossPreventionDiscoveryConfigTargetsSecretsTarget {
}
export declare function googleDataLossPreventionDiscoveryConfigTargetsSecretsTargetToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsSecretsTargetOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsSecretsTarget): any;
export declare function googleDataLossPreventionDiscoveryConfigTargetsSecretsTargetToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargetsSecretsTargetOutputReference | GoogleDataLossPreventionDiscoveryConfigTargetsSecretsTarget): any;
export declare class GoogleDataLossPreventionDiscoveryConfigTargetsSecretsTargetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigTargetsSecretsTarget | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigTargetsSecretsTarget | undefined);
}
export interface GoogleDataLossPreventionDiscoveryConfigTargets {
    /**
    * big_query_target block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#big_query_target GoogleDataLossPreventionDiscoveryConfig#big_query_target}
    */
    readonly bigQueryTarget?: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTarget;
    /**
    * cloud_sql_target block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#cloud_sql_target GoogleDataLossPreventionDiscoveryConfig#cloud_sql_target}
    */
    readonly cloudSqlTarget?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTarget;
    /**
    * cloud_storage_target block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#cloud_storage_target GoogleDataLossPreventionDiscoveryConfig#cloud_storage_target}
    */
    readonly cloudStorageTarget?: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTarget;
    /**
    * secrets_target block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#secrets_target GoogleDataLossPreventionDiscoveryConfig#secrets_target}
    */
    readonly secretsTarget?: GoogleDataLossPreventionDiscoveryConfigTargetsSecretsTarget;
}
export declare function googleDataLossPreventionDiscoveryConfigTargetsToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargets | cdktf.IResolvable): any;
export declare function googleDataLossPreventionDiscoveryConfigTargetsToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTargets | cdktf.IResolvable): any;
export declare class GoogleDataLossPreventionDiscoveryConfigTargetsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigTargets | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigTargets | cdktf.IResolvable | undefined);
    private _bigQueryTarget;
    get bigQueryTarget(): GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTargetOutputReference;
    putBigQueryTarget(value: GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTarget): void;
    resetBigQueryTarget(): void;
    get bigQueryTargetInput(): GoogleDataLossPreventionDiscoveryConfigTargetsBigQueryTarget | undefined;
    private _cloudSqlTarget;
    get cloudSqlTarget(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTargetOutputReference;
    putCloudSqlTarget(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTarget): void;
    resetCloudSqlTarget(): void;
    get cloudSqlTargetInput(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudSqlTarget | undefined;
    private _cloudStorageTarget;
    get cloudStorageTarget(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTargetOutputReference;
    putCloudStorageTarget(value: GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTarget): void;
    resetCloudStorageTarget(): void;
    get cloudStorageTargetInput(): GoogleDataLossPreventionDiscoveryConfigTargetsCloudStorageTarget | undefined;
    private _secretsTarget;
    get secretsTarget(): GoogleDataLossPreventionDiscoveryConfigTargetsSecretsTargetOutputReference;
    putSecretsTarget(value: GoogleDataLossPreventionDiscoveryConfigTargetsSecretsTarget): void;
    resetSecretsTarget(): void;
    get secretsTargetInput(): GoogleDataLossPreventionDiscoveryConfigTargetsSecretsTarget | undefined;
}
export declare class GoogleDataLossPreventionDiscoveryConfigTargetsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleDataLossPreventionDiscoveryConfigTargets[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDataLossPreventionDiscoveryConfigTargetsOutputReference;
}
export interface GoogleDataLossPreventionDiscoveryConfigTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#create GoogleDataLossPreventionDiscoveryConfig#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#delete GoogleDataLossPreventionDiscoveryConfig#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#update GoogleDataLossPreventionDiscoveryConfig#update}
    */
    readonly update?: string;
}
export declare function googleDataLossPreventionDiscoveryConfigTimeoutsToTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTimeouts | cdktf.IResolvable): any;
export declare function googleDataLossPreventionDiscoveryConfigTimeoutsToHclTerraform(struct?: GoogleDataLossPreventionDiscoveryConfigTimeouts | cdktf.IResolvable): any;
export declare class GoogleDataLossPreventionDiscoveryConfigTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataLossPreventionDiscoveryConfigTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleDataLossPreventionDiscoveryConfigTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config google_data_loss_prevention_discovery_config}
*/
export declare class GoogleDataLossPreventionDiscoveryConfig extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_data_loss_prevention_discovery_config";
    /**
    * Generates CDKTF code for importing a GoogleDataLossPreventionDiscoveryConfig resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleDataLossPreventionDiscoveryConfig to import
    * @param importFromId The id of the existing GoogleDataLossPreventionDiscoveryConfig that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleDataLossPreventionDiscoveryConfig to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_data_loss_prevention_discovery_config google_data_loss_prevention_discovery_config} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleDataLossPreventionDiscoveryConfigConfig
    */
    constructor(scope: Construct, id: string, config: GoogleDataLossPreventionDiscoveryConfigConfig);
    get createTime(): string;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    resetDisplayName(): void;
    get displayNameInput(): string | undefined;
    private _errors;
    get errors(): GoogleDataLossPreventionDiscoveryConfigErrorsList;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _inspectTemplates?;
    get inspectTemplates(): string[];
    set inspectTemplates(value: string[]);
    resetInspectTemplates(): void;
    get inspectTemplatesInput(): string[] | undefined;
    get lastRunTime(): string;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    get name(): string;
    private _parent?;
    get parent(): string;
    set parent(value: string);
    get parentInput(): string | undefined;
    private _status?;
    get status(): string;
    set status(value: string);
    resetStatus(): void;
    get statusInput(): string | undefined;
    get updateTime(): string;
    private _actions;
    get actions(): GoogleDataLossPreventionDiscoveryConfigActionsList;
    putActions(value: GoogleDataLossPreventionDiscoveryConfigActions[] | cdktf.IResolvable): void;
    resetActions(): void;
    get actionsInput(): cdktf.IResolvable | GoogleDataLossPreventionDiscoveryConfigActions[] | undefined;
    private _orgConfig;
    get orgConfig(): GoogleDataLossPreventionDiscoveryConfigOrgConfigOutputReference;
    putOrgConfig(value: GoogleDataLossPreventionDiscoveryConfigOrgConfig): void;
    resetOrgConfig(): void;
    get orgConfigInput(): GoogleDataLossPreventionDiscoveryConfigOrgConfig | undefined;
    private _targets;
    get targets(): GoogleDataLossPreventionDiscoveryConfigTargetsList;
    putTargets(value: GoogleDataLossPreventionDiscoveryConfigTargets[] | cdktf.IResolvable): void;
    resetTargets(): void;
    get targetsInput(): cdktf.IResolvable | GoogleDataLossPreventionDiscoveryConfigTargets[] | undefined;
    private _timeouts;
    get timeouts(): GoogleDataLossPreventionDiscoveryConfigTimeoutsOutputReference;
    putTimeouts(value: GoogleDataLossPreventionDiscoveryConfigTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleDataLossPreventionDiscoveryConfigTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
