/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleDatabaseMigrationServiceMigrationJobConfig extends cdktf.TerraformMetaArguments {
    /**
    * The name of the destination connection profile resource in the form of projects/{project}/locations/{location}/connectionProfiles/{destinationConnectionProfile}.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_database_migration_service_migration_job#destination GoogleDatabaseMigrationServiceMigrationJob#destination}
    */
    readonly destination: string;
    /**
    * The migration job display name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_database_migration_service_migration_job#display_name GoogleDatabaseMigrationServiceMigrationJob#display_name}
    */
    readonly displayName?: string;
    /**
    * The path to the dump file in Google Cloud Storage,
    * in the format: (gs://[BUCKET_NAME]/[OBJECT_NAME]).
    * This field and the "dump_flags" field are mutually exclusive.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_database_migration_service_migration_job#dump_path GoogleDatabaseMigrationServiceMigrationJob#dump_path}
    */
    readonly dumpPath?: string;
    /**
    * The type of the data dump. Supported for MySQL to CloudSQL for MySQL
    * migrations only. Possible values: ["LOGICAL", "PHYSICAL"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_database_migration_service_migration_job#dump_type GoogleDatabaseMigrationServiceMigrationJob#dump_type}
    */
    readonly dumpType?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_database_migration_service_migration_job#id GoogleDatabaseMigrationServiceMigrationJob#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The resource labels for migration job to use to annotate any related underlying resources such as Compute Engine VMs.
    *
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_database_migration_service_migration_job#labels GoogleDatabaseMigrationServiceMigrationJob#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * The location where the migration job should reside.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_database_migration_service_migration_job#location GoogleDatabaseMigrationServiceMigrationJob#location}
    */
    readonly location?: string;
    /**
    * The ID of the migration job.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_database_migration_service_migration_job#migration_job_id GoogleDatabaseMigrationServiceMigrationJob#migration_job_id}
    */
    readonly migrationJobId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_database_migration_service_migration_job#project GoogleDatabaseMigrationServiceMigrationJob#project}
    */
    readonly project?: string;
    /**
    * The name of the source connection profile resource in the form of projects/{project}/locations/{location}/connectionProfiles/{sourceConnectionProfile}.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_database_migration_service_migration_job#source GoogleDatabaseMigrationServiceMigrationJob#source}
    */
    readonly source: string;
    /**
    * The type of the migration job. Possible values: ["ONE_TIME", "CONTINUOUS"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_database_migration_service_migration_job#type GoogleDatabaseMigrationServiceMigrationJob#type}
    */
    readonly type: string;
    /**
    * dump_flags block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_database_migration_service_migration_job#dump_flags GoogleDatabaseMigrationServiceMigrationJob#dump_flags}
    */
    readonly dumpFlags?: GoogleDatabaseMigrationServiceMigrationJobDumpFlags;
    /**
    * performance_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_database_migration_service_migration_job#performance_config GoogleDatabaseMigrationServiceMigrationJob#performance_config}
    */
    readonly performanceConfig?: GoogleDatabaseMigrationServiceMigrationJobPerformanceConfig;
    /**
    * reverse_ssh_connectivity block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_database_migration_service_migration_job#reverse_ssh_connectivity GoogleDatabaseMigrationServiceMigrationJob#reverse_ssh_connectivity}
    */
    readonly reverseSshConnectivity?: GoogleDatabaseMigrationServiceMigrationJobReverseSshConnectivity;
    /**
    * static_ip_connectivity block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_database_migration_service_migration_job#static_ip_connectivity GoogleDatabaseMigrationServiceMigrationJob#static_ip_connectivity}
    */
    readonly staticIpConnectivity?: GoogleDatabaseMigrationServiceMigrationJobStaticIpConnectivity;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_database_migration_service_migration_job#timeouts GoogleDatabaseMigrationServiceMigrationJob#timeouts}
    */
    readonly timeouts?: GoogleDatabaseMigrationServiceMigrationJobTimeouts;
    /**
    * vpc_peering_connectivity block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_database_migration_service_migration_job#vpc_peering_connectivity GoogleDatabaseMigrationServiceMigrationJob#vpc_peering_connectivity}
    */
    readonly vpcPeeringConnectivity?: GoogleDatabaseMigrationServiceMigrationJobVpcPeeringConnectivity;
}
export interface GoogleDatabaseMigrationServiceMigrationJobError {
}
export declare function googleDatabaseMigrationServiceMigrationJobErrorToTerraform(struct?: GoogleDatabaseMigrationServiceMigrationJobError): any;
export declare function googleDatabaseMigrationServiceMigrationJobErrorToHclTerraform(struct?: GoogleDatabaseMigrationServiceMigrationJobError): any;
export declare class GoogleDatabaseMigrationServiceMigrationJobErrorOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDatabaseMigrationServiceMigrationJobError | undefined;
    set internalValue(value: GoogleDatabaseMigrationServiceMigrationJobError | undefined);
    get code(): number;
    private _details;
    get details(): cdktf.StringMapList;
    get message(): string;
}
export declare class GoogleDatabaseMigrationServiceMigrationJobErrorList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDatabaseMigrationServiceMigrationJobErrorOutputReference;
}
export interface GoogleDatabaseMigrationServiceMigrationJobDumpFlagsDumpFlags {
    /**
    * The name of the flag
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_database_migration_service_migration_job#name GoogleDatabaseMigrationServiceMigrationJob#name}
    */
    readonly name?: string;
    /**
    * The vale of the flag
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_database_migration_service_migration_job#value GoogleDatabaseMigrationServiceMigrationJob#value}
    */
    readonly value?: string;
}
export declare function googleDatabaseMigrationServiceMigrationJobDumpFlagsDumpFlagsToTerraform(struct?: GoogleDatabaseMigrationServiceMigrationJobDumpFlagsDumpFlags | cdktf.IResolvable): any;
export declare function googleDatabaseMigrationServiceMigrationJobDumpFlagsDumpFlagsToHclTerraform(struct?: GoogleDatabaseMigrationServiceMigrationJobDumpFlagsDumpFlags | cdktf.IResolvable): any;
export declare class GoogleDatabaseMigrationServiceMigrationJobDumpFlagsDumpFlagsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDatabaseMigrationServiceMigrationJobDumpFlagsDumpFlags | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleDatabaseMigrationServiceMigrationJobDumpFlagsDumpFlags | cdktf.IResolvable | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    resetValue(): void;
    get valueInput(): string | undefined;
}
export declare class GoogleDatabaseMigrationServiceMigrationJobDumpFlagsDumpFlagsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleDatabaseMigrationServiceMigrationJobDumpFlagsDumpFlags[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDatabaseMigrationServiceMigrationJobDumpFlagsDumpFlagsOutputReference;
}
export interface GoogleDatabaseMigrationServiceMigrationJobDumpFlags {
    /**
    * dump_flags block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_database_migration_service_migration_job#dump_flags GoogleDatabaseMigrationServiceMigrationJob#dump_flags}
    */
    readonly dumpFlags?: GoogleDatabaseMigrationServiceMigrationJobDumpFlagsDumpFlags[] | cdktf.IResolvable;
}
export declare function googleDatabaseMigrationServiceMigrationJobDumpFlagsToTerraform(struct?: GoogleDatabaseMigrationServiceMigrationJobDumpFlagsOutputReference | GoogleDatabaseMigrationServiceMigrationJobDumpFlags): any;
export declare function googleDatabaseMigrationServiceMigrationJobDumpFlagsToHclTerraform(struct?: GoogleDatabaseMigrationServiceMigrationJobDumpFlagsOutputReference | GoogleDatabaseMigrationServiceMigrationJobDumpFlags): any;
export declare class GoogleDatabaseMigrationServiceMigrationJobDumpFlagsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDatabaseMigrationServiceMigrationJobDumpFlags | undefined;
    set internalValue(value: GoogleDatabaseMigrationServiceMigrationJobDumpFlags | undefined);
    private _dumpFlags;
    get dumpFlags(): GoogleDatabaseMigrationServiceMigrationJobDumpFlagsDumpFlagsList;
    putDumpFlags(value: GoogleDatabaseMigrationServiceMigrationJobDumpFlagsDumpFlags[] | cdktf.IResolvable): void;
    resetDumpFlags(): void;
    get dumpFlagsInput(): cdktf.IResolvable | GoogleDatabaseMigrationServiceMigrationJobDumpFlagsDumpFlags[] | undefined;
}
export interface GoogleDatabaseMigrationServiceMigrationJobPerformanceConfig {
    /**
    * Initial dump parallelism level. Possible values: ["MIN", "OPTIMAL", "MAX"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_database_migration_service_migration_job#dump_parallel_level GoogleDatabaseMigrationServiceMigrationJob#dump_parallel_level}
    */
    readonly dumpParallelLevel?: string;
}
export declare function googleDatabaseMigrationServiceMigrationJobPerformanceConfigToTerraform(struct?: GoogleDatabaseMigrationServiceMigrationJobPerformanceConfigOutputReference | GoogleDatabaseMigrationServiceMigrationJobPerformanceConfig): any;
export declare function googleDatabaseMigrationServiceMigrationJobPerformanceConfigToHclTerraform(struct?: GoogleDatabaseMigrationServiceMigrationJobPerformanceConfigOutputReference | GoogleDatabaseMigrationServiceMigrationJobPerformanceConfig): any;
export declare class GoogleDatabaseMigrationServiceMigrationJobPerformanceConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDatabaseMigrationServiceMigrationJobPerformanceConfig | undefined;
    set internalValue(value: GoogleDatabaseMigrationServiceMigrationJobPerformanceConfig | undefined);
    private _dumpParallelLevel?;
    get dumpParallelLevel(): string;
    set dumpParallelLevel(value: string);
    resetDumpParallelLevel(): void;
    get dumpParallelLevelInput(): string | undefined;
}
export interface GoogleDatabaseMigrationServiceMigrationJobReverseSshConnectivity {
    /**
    * The name of the virtual machine (Compute Engine) used as the bastion server
    * for the SSH tunnel.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_database_migration_service_migration_job#vm GoogleDatabaseMigrationServiceMigrationJob#vm}
    */
    readonly vm?: string;
    /**
    * The IP of the virtual machine (Compute Engine) used as the bastion server
    * for the SSH tunnel.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_database_migration_service_migration_job#vm_ip GoogleDatabaseMigrationServiceMigrationJob#vm_ip}
    */
    readonly vmIp?: string;
    /**
    * The forwarding port of the virtual machine (Compute Engine) used as the
    * bastion server for the SSH tunnel.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_database_migration_service_migration_job#vm_port GoogleDatabaseMigrationServiceMigrationJob#vm_port}
    */
    readonly vmPort?: number;
    /**
    * The name of the VPC to peer with the Cloud SQL private network.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_database_migration_service_migration_job#vpc GoogleDatabaseMigrationServiceMigrationJob#vpc}
    */
    readonly vpc?: string;
}
export declare function googleDatabaseMigrationServiceMigrationJobReverseSshConnectivityToTerraform(struct?: GoogleDatabaseMigrationServiceMigrationJobReverseSshConnectivityOutputReference | GoogleDatabaseMigrationServiceMigrationJobReverseSshConnectivity): any;
export declare function googleDatabaseMigrationServiceMigrationJobReverseSshConnectivityToHclTerraform(struct?: GoogleDatabaseMigrationServiceMigrationJobReverseSshConnectivityOutputReference | GoogleDatabaseMigrationServiceMigrationJobReverseSshConnectivity): any;
export declare class GoogleDatabaseMigrationServiceMigrationJobReverseSshConnectivityOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDatabaseMigrationServiceMigrationJobReverseSshConnectivity | undefined;
    set internalValue(value: GoogleDatabaseMigrationServiceMigrationJobReverseSshConnectivity | undefined);
    private _vm?;
    get vm(): string;
    set vm(value: string);
    resetVm(): void;
    get vmInput(): string | undefined;
    private _vmIp?;
    get vmIp(): string;
    set vmIp(value: string);
    resetVmIp(): void;
    get vmIpInput(): string | undefined;
    private _vmPort?;
    get vmPort(): number;
    set vmPort(value: number);
    resetVmPort(): void;
    get vmPortInput(): number | undefined;
    private _vpc?;
    get vpc(): string;
    set vpc(value: string);
    resetVpc(): void;
    get vpcInput(): string | undefined;
}
export interface GoogleDatabaseMigrationServiceMigrationJobStaticIpConnectivity {
}
export declare function googleDatabaseMigrationServiceMigrationJobStaticIpConnectivityToTerraform(struct?: GoogleDatabaseMigrationServiceMigrationJobStaticIpConnectivityOutputReference | GoogleDatabaseMigrationServiceMigrationJobStaticIpConnectivity): any;
export declare function googleDatabaseMigrationServiceMigrationJobStaticIpConnectivityToHclTerraform(struct?: GoogleDatabaseMigrationServiceMigrationJobStaticIpConnectivityOutputReference | GoogleDatabaseMigrationServiceMigrationJobStaticIpConnectivity): any;
export declare class GoogleDatabaseMigrationServiceMigrationJobStaticIpConnectivityOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDatabaseMigrationServiceMigrationJobStaticIpConnectivity | undefined;
    set internalValue(value: GoogleDatabaseMigrationServiceMigrationJobStaticIpConnectivity | undefined);
}
export interface GoogleDatabaseMigrationServiceMigrationJobTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_database_migration_service_migration_job#create GoogleDatabaseMigrationServiceMigrationJob#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_database_migration_service_migration_job#delete GoogleDatabaseMigrationServiceMigrationJob#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_database_migration_service_migration_job#update GoogleDatabaseMigrationServiceMigrationJob#update}
    */
    readonly update?: string;
}
export declare function googleDatabaseMigrationServiceMigrationJobTimeoutsToTerraform(struct?: GoogleDatabaseMigrationServiceMigrationJobTimeouts | cdktf.IResolvable): any;
export declare function googleDatabaseMigrationServiceMigrationJobTimeoutsToHclTerraform(struct?: GoogleDatabaseMigrationServiceMigrationJobTimeouts | cdktf.IResolvable): any;
export declare class GoogleDatabaseMigrationServiceMigrationJobTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDatabaseMigrationServiceMigrationJobTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleDatabaseMigrationServiceMigrationJobTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
export interface GoogleDatabaseMigrationServiceMigrationJobVpcPeeringConnectivity {
    /**
    * The name of the VPC network to peer with the Cloud SQL private network.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_database_migration_service_migration_job#vpc GoogleDatabaseMigrationServiceMigrationJob#vpc}
    */
    readonly vpc?: string;
}
export declare function googleDatabaseMigrationServiceMigrationJobVpcPeeringConnectivityToTerraform(struct?: GoogleDatabaseMigrationServiceMigrationJobVpcPeeringConnectivityOutputReference | GoogleDatabaseMigrationServiceMigrationJobVpcPeeringConnectivity): any;
export declare function googleDatabaseMigrationServiceMigrationJobVpcPeeringConnectivityToHclTerraform(struct?: GoogleDatabaseMigrationServiceMigrationJobVpcPeeringConnectivityOutputReference | GoogleDatabaseMigrationServiceMigrationJobVpcPeeringConnectivity): any;
export declare class GoogleDatabaseMigrationServiceMigrationJobVpcPeeringConnectivityOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDatabaseMigrationServiceMigrationJobVpcPeeringConnectivity | undefined;
    set internalValue(value: GoogleDatabaseMigrationServiceMigrationJobVpcPeeringConnectivity | undefined);
    private _vpc?;
    get vpc(): string;
    set vpc(value: string);
    resetVpc(): void;
    get vpcInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_database_migration_service_migration_job google_database_migration_service_migration_job}
*/
export declare class GoogleDatabaseMigrationServiceMigrationJob extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_database_migration_service_migration_job";
    /**
    * Generates CDKTF code for importing a GoogleDatabaseMigrationServiceMigrationJob resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleDatabaseMigrationServiceMigrationJob to import
    * @param importFromId The id of the existing GoogleDatabaseMigrationServiceMigrationJob that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_database_migration_service_migration_job#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleDatabaseMigrationServiceMigrationJob to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_database_migration_service_migration_job google_database_migration_service_migration_job} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleDatabaseMigrationServiceMigrationJobConfig
    */
    constructor(scope: Construct, id: string, config: GoogleDatabaseMigrationServiceMigrationJobConfig);
    get createTime(): string;
    private _destination?;
    get destination(): string;
    set destination(value: string);
    get destinationInput(): string | undefined;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    resetDisplayName(): void;
    get displayNameInput(): string | undefined;
    private _dumpPath?;
    get dumpPath(): string;
    set dumpPath(value: string);
    resetDumpPath(): void;
    get dumpPathInput(): string | undefined;
    private _dumpType?;
    get dumpType(): string;
    set dumpType(value: string);
    resetDumpType(): void;
    get dumpTypeInput(): string | undefined;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    private _error;
    get error(): GoogleDatabaseMigrationServiceMigrationJobErrorList;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    resetLocation(): void;
    get locationInput(): string | undefined;
    private _migrationJobId?;
    get migrationJobId(): string;
    set migrationJobId(value: string);
    get migrationJobIdInput(): string | undefined;
    get name(): string;
    get phase(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _source?;
    get source(): string;
    set source(value: string);
    get sourceInput(): string | undefined;
    get state(): string;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
    private _dumpFlags;
    get dumpFlags(): GoogleDatabaseMigrationServiceMigrationJobDumpFlagsOutputReference;
    putDumpFlags(value: GoogleDatabaseMigrationServiceMigrationJobDumpFlags): void;
    resetDumpFlags(): void;
    get dumpFlagsInput(): GoogleDatabaseMigrationServiceMigrationJobDumpFlags | undefined;
    private _performanceConfig;
    get performanceConfig(): GoogleDatabaseMigrationServiceMigrationJobPerformanceConfigOutputReference;
    putPerformanceConfig(value: GoogleDatabaseMigrationServiceMigrationJobPerformanceConfig): void;
    resetPerformanceConfig(): void;
    get performanceConfigInput(): GoogleDatabaseMigrationServiceMigrationJobPerformanceConfig | undefined;
    private _reverseSshConnectivity;
    get reverseSshConnectivity(): GoogleDatabaseMigrationServiceMigrationJobReverseSshConnectivityOutputReference;
    putReverseSshConnectivity(value: GoogleDatabaseMigrationServiceMigrationJobReverseSshConnectivity): void;
    resetReverseSshConnectivity(): void;
    get reverseSshConnectivityInput(): GoogleDatabaseMigrationServiceMigrationJobReverseSshConnectivity | undefined;
    private _staticIpConnectivity;
    get staticIpConnectivity(): GoogleDatabaseMigrationServiceMigrationJobStaticIpConnectivityOutputReference;
    putStaticIpConnectivity(value: GoogleDatabaseMigrationServiceMigrationJobStaticIpConnectivity): void;
    resetStaticIpConnectivity(): void;
    get staticIpConnectivityInput(): GoogleDatabaseMigrationServiceMigrationJobStaticIpConnectivity | undefined;
    private _timeouts;
    get timeouts(): GoogleDatabaseMigrationServiceMigrationJobTimeoutsOutputReference;
    putTimeouts(value: GoogleDatabaseMigrationServiceMigrationJobTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleDatabaseMigrationServiceMigrationJobTimeouts | undefined;
    private _vpcPeeringConnectivity;
    get vpcPeeringConnectivity(): GoogleDatabaseMigrationServiceMigrationJobVpcPeeringConnectivityOutputReference;
    putVpcPeeringConnectivity(value: GoogleDatabaseMigrationServiceMigrationJobVpcPeeringConnectivity): void;
    resetVpcPeeringConnectivity(): void;
    get vpcPeeringConnectivityInput(): GoogleDatabaseMigrationServiceMigrationJobVpcPeeringConnectivity | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
