/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleDataprocBatchConfig extends cdktf.TerraformMetaArguments {
    /**
    * The ID to use for the batch, which will become the final component of the batch's resource name.
    * This value must be 4-63 characters. Valid characters are /[a-z][0-9]-/.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#batch_id GoogleDataprocBatch#batch_id}
    */
    readonly batchId?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#id GoogleDataprocBatch#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The labels to associate with this batch.
    *
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#labels GoogleDataprocBatch#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * The location in which the batch will be created in.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#location GoogleDataprocBatch#location}
    */
    readonly location?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#project GoogleDataprocBatch#project}
    */
    readonly project?: string;
    /**
    * environment_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#environment_config GoogleDataprocBatch#environment_config}
    */
    readonly environmentConfig?: GoogleDataprocBatchEnvironmentConfig;
    /**
    * pyspark_batch block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#pyspark_batch GoogleDataprocBatch#pyspark_batch}
    */
    readonly pysparkBatch?: GoogleDataprocBatchPysparkBatch;
    /**
    * runtime_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#runtime_config GoogleDataprocBatch#runtime_config}
    */
    readonly runtimeConfig?: GoogleDataprocBatchRuntimeConfig;
    /**
    * spark_batch block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#spark_batch GoogleDataprocBatch#spark_batch}
    */
    readonly sparkBatch?: GoogleDataprocBatchSparkBatch;
    /**
    * spark_r_batch block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#spark_r_batch GoogleDataprocBatch#spark_r_batch}
    */
    readonly sparkRBatch?: GoogleDataprocBatchSparkRBatch;
    /**
    * spark_sql_batch block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#spark_sql_batch GoogleDataprocBatch#spark_sql_batch}
    */
    readonly sparkSqlBatch?: GoogleDataprocBatchSparkSqlBatch;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#timeouts GoogleDataprocBatch#timeouts}
    */
    readonly timeouts?: GoogleDataprocBatchTimeouts;
}
export interface GoogleDataprocBatchRuntimeInfoApproximateUsage {
}
export declare function googleDataprocBatchRuntimeInfoApproximateUsageToTerraform(struct?: GoogleDataprocBatchRuntimeInfoApproximateUsage): any;
export declare function googleDataprocBatchRuntimeInfoApproximateUsageToHclTerraform(struct?: GoogleDataprocBatchRuntimeInfoApproximateUsage): any;
export declare class GoogleDataprocBatchRuntimeInfoApproximateUsageOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDataprocBatchRuntimeInfoApproximateUsage | undefined;
    set internalValue(value: GoogleDataprocBatchRuntimeInfoApproximateUsage | undefined);
    get acceleratorType(): string;
    get milliAcceleratorSeconds(): string;
    get milliDcuSeconds(): string;
    get shuffleStorageGbSeconds(): string;
}
export declare class GoogleDataprocBatchRuntimeInfoApproximateUsageList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDataprocBatchRuntimeInfoApproximateUsageOutputReference;
}
export interface GoogleDataprocBatchRuntimeInfoCurrentUsage {
}
export declare function googleDataprocBatchRuntimeInfoCurrentUsageToTerraform(struct?: GoogleDataprocBatchRuntimeInfoCurrentUsage): any;
export declare function googleDataprocBatchRuntimeInfoCurrentUsageToHclTerraform(struct?: GoogleDataprocBatchRuntimeInfoCurrentUsage): any;
export declare class GoogleDataprocBatchRuntimeInfoCurrentUsageOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDataprocBatchRuntimeInfoCurrentUsage | undefined;
    set internalValue(value: GoogleDataprocBatchRuntimeInfoCurrentUsage | undefined);
    get acceleratorType(): string;
    get milliAccelerator(): string;
    get milliDcu(): string;
    get milliDcuPremium(): string;
    get shuffleStorageGb(): string;
    get shuffleStorageGbPremium(): string;
    get snapshotTime(): string;
}
export declare class GoogleDataprocBatchRuntimeInfoCurrentUsageList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDataprocBatchRuntimeInfoCurrentUsageOutputReference;
}
export interface GoogleDataprocBatchRuntimeInfo {
}
export declare function googleDataprocBatchRuntimeInfoToTerraform(struct?: GoogleDataprocBatchRuntimeInfo): any;
export declare function googleDataprocBatchRuntimeInfoToHclTerraform(struct?: GoogleDataprocBatchRuntimeInfo): any;
export declare class GoogleDataprocBatchRuntimeInfoOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDataprocBatchRuntimeInfo | undefined;
    set internalValue(value: GoogleDataprocBatchRuntimeInfo | undefined);
    private _approximateUsage;
    get approximateUsage(): GoogleDataprocBatchRuntimeInfoApproximateUsageList;
    private _currentUsage;
    get currentUsage(): GoogleDataprocBatchRuntimeInfoCurrentUsageList;
    get diagnosticOutputUri(): string;
    private _endpoints;
    get endpoints(): cdktf.StringMap;
    get outputUri(): string;
}
export declare class GoogleDataprocBatchRuntimeInfoList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDataprocBatchRuntimeInfoOutputReference;
}
export interface GoogleDataprocBatchStateHistory {
}
export declare function googleDataprocBatchStateHistoryToTerraform(struct?: GoogleDataprocBatchStateHistory): any;
export declare function googleDataprocBatchStateHistoryToHclTerraform(struct?: GoogleDataprocBatchStateHistory): any;
export declare class GoogleDataprocBatchStateHistoryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDataprocBatchStateHistory | undefined;
    set internalValue(value: GoogleDataprocBatchStateHistory | undefined);
    get state(): string;
    get stateMessage(): string;
    get stateStartTime(): string;
}
export declare class GoogleDataprocBatchStateHistoryList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDataprocBatchStateHistoryOutputReference;
}
export interface GoogleDataprocBatchEnvironmentConfigExecutionConfig {
    /**
    * The Cloud KMS key to use for encryption.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#kms_key GoogleDataprocBatch#kms_key}
    */
    readonly kmsKey?: string;
    /**
    * Tags used for network traffic control.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#network_tags GoogleDataprocBatch#network_tags}
    */
    readonly networkTags?: string[];
    /**
    * Network configuration for workload execution.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#network_uri GoogleDataprocBatch#network_uri}
    */
    readonly networkUri?: string;
    /**
    * Service account that used to execute workload.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#service_account GoogleDataprocBatch#service_account}
    */
    readonly serviceAccount?: string;
    /**
    * A Cloud Storage bucket used to stage workload dependencies, config files, and store
    * workload output and other ephemeral data, such as Spark history files. If you do not specify a staging bucket,
    * Cloud Dataproc will determine a Cloud Storage location according to the region where your workload is running,
    * and then create and manage project-level, per-location staging and temporary buckets.
    * This field requires a Cloud Storage bucket name, not a gs://... URI to a Cloud Storage bucket.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#staging_bucket GoogleDataprocBatch#staging_bucket}
    */
    readonly stagingBucket?: string;
    /**
    * Subnetwork configuration for workload execution.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#subnetwork_uri GoogleDataprocBatch#subnetwork_uri}
    */
    readonly subnetworkUri?: string;
    /**
    * The duration after which the workload will be terminated.
    * When the workload exceeds this duration, it will be unconditionally terminated without waiting for ongoing
    * work to finish. If ttl is not specified for a batch workload, the workload will be allowed to run until it
    * exits naturally (or run forever without exiting). If ttl is not specified for an interactive session,
    * it defaults to 24 hours. If ttl is not specified for a batch that uses 2.1+ runtime version, it defaults to 4 hours.
    * Minimum value is 10 minutes; maximum value is 14 days. If both ttl and idleTtl are specified (for an interactive session),
    * the conditions are treated as OR conditions: the workload will be terminated when it has been idle for idleTtl or
    * when ttl has been exceeded, whichever occurs first.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#ttl GoogleDataprocBatch#ttl}
    */
    readonly ttl?: string;
}
export declare function googleDataprocBatchEnvironmentConfigExecutionConfigToTerraform(struct?: GoogleDataprocBatchEnvironmentConfigExecutionConfigOutputReference | GoogleDataprocBatchEnvironmentConfigExecutionConfig): any;
export declare function googleDataprocBatchEnvironmentConfigExecutionConfigToHclTerraform(struct?: GoogleDataprocBatchEnvironmentConfigExecutionConfigOutputReference | GoogleDataprocBatchEnvironmentConfigExecutionConfig): any;
export declare class GoogleDataprocBatchEnvironmentConfigExecutionConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataprocBatchEnvironmentConfigExecutionConfig | undefined;
    set internalValue(value: GoogleDataprocBatchEnvironmentConfigExecutionConfig | undefined);
    private _kmsKey?;
    get kmsKey(): string;
    set kmsKey(value: string);
    resetKmsKey(): void;
    get kmsKeyInput(): string | undefined;
    private _networkTags?;
    get networkTags(): string[];
    set networkTags(value: string[]);
    resetNetworkTags(): void;
    get networkTagsInput(): string[] | undefined;
    private _networkUri?;
    get networkUri(): string;
    set networkUri(value: string);
    resetNetworkUri(): void;
    get networkUriInput(): string | undefined;
    private _serviceAccount?;
    get serviceAccount(): string;
    set serviceAccount(value: string);
    resetServiceAccount(): void;
    get serviceAccountInput(): string | undefined;
    private _stagingBucket?;
    get stagingBucket(): string;
    set stagingBucket(value: string);
    resetStagingBucket(): void;
    get stagingBucketInput(): string | undefined;
    private _subnetworkUri?;
    get subnetworkUri(): string;
    set subnetworkUri(value: string);
    resetSubnetworkUri(): void;
    get subnetworkUriInput(): string | undefined;
    private _ttl?;
    get ttl(): string;
    set ttl(value: string);
    resetTtl(): void;
    get ttlInput(): string | undefined;
}
export interface GoogleDataprocBatchEnvironmentConfigPeripheralsConfigSparkHistoryServerConfig {
    /**
    * Resource name of an existing Dataproc Cluster to act as a Spark History Server for the workload.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#dataproc_cluster GoogleDataprocBatch#dataproc_cluster}
    */
    readonly dataprocCluster?: string;
}
export declare function googleDataprocBatchEnvironmentConfigPeripheralsConfigSparkHistoryServerConfigToTerraform(struct?: GoogleDataprocBatchEnvironmentConfigPeripheralsConfigSparkHistoryServerConfigOutputReference | GoogleDataprocBatchEnvironmentConfigPeripheralsConfigSparkHistoryServerConfig): any;
export declare function googleDataprocBatchEnvironmentConfigPeripheralsConfigSparkHistoryServerConfigToHclTerraform(struct?: GoogleDataprocBatchEnvironmentConfigPeripheralsConfigSparkHistoryServerConfigOutputReference | GoogleDataprocBatchEnvironmentConfigPeripheralsConfigSparkHistoryServerConfig): any;
export declare class GoogleDataprocBatchEnvironmentConfigPeripheralsConfigSparkHistoryServerConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataprocBatchEnvironmentConfigPeripheralsConfigSparkHistoryServerConfig | undefined;
    set internalValue(value: GoogleDataprocBatchEnvironmentConfigPeripheralsConfigSparkHistoryServerConfig | undefined);
    private _dataprocCluster?;
    get dataprocCluster(): string;
    set dataprocCluster(value: string);
    resetDataprocCluster(): void;
    get dataprocClusterInput(): string | undefined;
}
export interface GoogleDataprocBatchEnvironmentConfigPeripheralsConfig {
    /**
    * Resource name of an existing Dataproc Metastore service.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#metastore_service GoogleDataprocBatch#metastore_service}
    */
    readonly metastoreService?: string;
    /**
    * spark_history_server_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#spark_history_server_config GoogleDataprocBatch#spark_history_server_config}
    */
    readonly sparkHistoryServerConfig?: GoogleDataprocBatchEnvironmentConfigPeripheralsConfigSparkHistoryServerConfig;
}
export declare function googleDataprocBatchEnvironmentConfigPeripheralsConfigToTerraform(struct?: GoogleDataprocBatchEnvironmentConfigPeripheralsConfigOutputReference | GoogleDataprocBatchEnvironmentConfigPeripheralsConfig): any;
export declare function googleDataprocBatchEnvironmentConfigPeripheralsConfigToHclTerraform(struct?: GoogleDataprocBatchEnvironmentConfigPeripheralsConfigOutputReference | GoogleDataprocBatchEnvironmentConfigPeripheralsConfig): any;
export declare class GoogleDataprocBatchEnvironmentConfigPeripheralsConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataprocBatchEnvironmentConfigPeripheralsConfig | undefined;
    set internalValue(value: GoogleDataprocBatchEnvironmentConfigPeripheralsConfig | undefined);
    private _metastoreService?;
    get metastoreService(): string;
    set metastoreService(value: string);
    resetMetastoreService(): void;
    get metastoreServiceInput(): string | undefined;
    private _sparkHistoryServerConfig;
    get sparkHistoryServerConfig(): GoogleDataprocBatchEnvironmentConfigPeripheralsConfigSparkHistoryServerConfigOutputReference;
    putSparkHistoryServerConfig(value: GoogleDataprocBatchEnvironmentConfigPeripheralsConfigSparkHistoryServerConfig): void;
    resetSparkHistoryServerConfig(): void;
    get sparkHistoryServerConfigInput(): GoogleDataprocBatchEnvironmentConfigPeripheralsConfigSparkHistoryServerConfig | undefined;
}
export interface GoogleDataprocBatchEnvironmentConfig {
    /**
    * execution_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#execution_config GoogleDataprocBatch#execution_config}
    */
    readonly executionConfig?: GoogleDataprocBatchEnvironmentConfigExecutionConfig;
    /**
    * peripherals_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#peripherals_config GoogleDataprocBatch#peripherals_config}
    */
    readonly peripheralsConfig?: GoogleDataprocBatchEnvironmentConfigPeripheralsConfig;
}
export declare function googleDataprocBatchEnvironmentConfigToTerraform(struct?: GoogleDataprocBatchEnvironmentConfigOutputReference | GoogleDataprocBatchEnvironmentConfig): any;
export declare function googleDataprocBatchEnvironmentConfigToHclTerraform(struct?: GoogleDataprocBatchEnvironmentConfigOutputReference | GoogleDataprocBatchEnvironmentConfig): any;
export declare class GoogleDataprocBatchEnvironmentConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataprocBatchEnvironmentConfig | undefined;
    set internalValue(value: GoogleDataprocBatchEnvironmentConfig | undefined);
    private _executionConfig;
    get executionConfig(): GoogleDataprocBatchEnvironmentConfigExecutionConfigOutputReference;
    putExecutionConfig(value: GoogleDataprocBatchEnvironmentConfigExecutionConfig): void;
    resetExecutionConfig(): void;
    get executionConfigInput(): GoogleDataprocBatchEnvironmentConfigExecutionConfig | undefined;
    private _peripheralsConfig;
    get peripheralsConfig(): GoogleDataprocBatchEnvironmentConfigPeripheralsConfigOutputReference;
    putPeripheralsConfig(value: GoogleDataprocBatchEnvironmentConfigPeripheralsConfig): void;
    resetPeripheralsConfig(): void;
    get peripheralsConfigInput(): GoogleDataprocBatchEnvironmentConfigPeripheralsConfig | undefined;
}
export interface GoogleDataprocBatchPysparkBatch {
    /**
    * HCFS URIs of archives to be extracted into the working directory of each executor.
    * Supported file types: .jar, .tar, .tar.gz, .tgz, and .zip.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#archive_uris GoogleDataprocBatch#archive_uris}
    */
    readonly archiveUris?: string[];
    /**
    * The arguments to pass to the driver. Do not include arguments that can be set as batch
    * properties, such as --conf, since a collision can occur that causes an incorrect batch submission.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#args GoogleDataprocBatch#args}
    */
    readonly args?: string[];
    /**
    * HCFS URIs of files to be placed in the working directory of each executor.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#file_uris GoogleDataprocBatch#file_uris}
    */
    readonly fileUris?: string[];
    /**
    * HCFS URIs of jar files to add to the classpath of the Spark driver and tasks.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#jar_file_uris GoogleDataprocBatch#jar_file_uris}
    */
    readonly jarFileUris?: string[];
    /**
    * The HCFS URI of the main Python file to use as the Spark driver. Must be a .py file.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#main_python_file_uri GoogleDataprocBatch#main_python_file_uri}
    */
    readonly mainPythonFileUri?: string;
    /**
    * HCFS file URIs of Python files to pass to the PySpark framework.
    * Supported file types: .py, .egg, and .zip.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#python_file_uris GoogleDataprocBatch#python_file_uris}
    */
    readonly pythonFileUris?: string[];
}
export declare function googleDataprocBatchPysparkBatchToTerraform(struct?: GoogleDataprocBatchPysparkBatchOutputReference | GoogleDataprocBatchPysparkBatch): any;
export declare function googleDataprocBatchPysparkBatchToHclTerraform(struct?: GoogleDataprocBatchPysparkBatchOutputReference | GoogleDataprocBatchPysparkBatch): any;
export declare class GoogleDataprocBatchPysparkBatchOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataprocBatchPysparkBatch | undefined;
    set internalValue(value: GoogleDataprocBatchPysparkBatch | undefined);
    private _archiveUris?;
    get archiveUris(): string[];
    set archiveUris(value: string[]);
    resetArchiveUris(): void;
    get archiveUrisInput(): string[] | undefined;
    private _args?;
    get args(): string[];
    set args(value: string[]);
    resetArgs(): void;
    get argsInput(): string[] | undefined;
    private _fileUris?;
    get fileUris(): string[];
    set fileUris(value: string[]);
    resetFileUris(): void;
    get fileUrisInput(): string[] | undefined;
    private _jarFileUris?;
    get jarFileUris(): string[];
    set jarFileUris(value: string[]);
    resetJarFileUris(): void;
    get jarFileUrisInput(): string[] | undefined;
    private _mainPythonFileUri?;
    get mainPythonFileUri(): string;
    set mainPythonFileUri(value: string);
    resetMainPythonFileUri(): void;
    get mainPythonFileUriInput(): string | undefined;
    private _pythonFileUris?;
    get pythonFileUris(): string[];
    set pythonFileUris(value: string[]);
    resetPythonFileUris(): void;
    get pythonFileUrisInput(): string[] | undefined;
}
export interface GoogleDataprocBatchRuntimeConfig {
    /**
    * Optional custom container image for the job runtime environment. If not specified, a default container image will be used.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#container_image GoogleDataprocBatch#container_image}
    */
    readonly containerImage?: string;
    /**
    * A mapping of property names to values, which are used to configure workload execution.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#properties GoogleDataprocBatch#properties}
    */
    readonly properties?: {
        [key: string]: string;
    };
    /**
    * Version of the batch runtime.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#version GoogleDataprocBatch#version}
    */
    readonly version?: string;
}
export declare function googleDataprocBatchRuntimeConfigToTerraform(struct?: GoogleDataprocBatchRuntimeConfigOutputReference | GoogleDataprocBatchRuntimeConfig): any;
export declare function googleDataprocBatchRuntimeConfigToHclTerraform(struct?: GoogleDataprocBatchRuntimeConfigOutputReference | GoogleDataprocBatchRuntimeConfig): any;
export declare class GoogleDataprocBatchRuntimeConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataprocBatchRuntimeConfig | undefined;
    set internalValue(value: GoogleDataprocBatchRuntimeConfig | undefined);
    private _containerImage?;
    get containerImage(): string;
    set containerImage(value: string);
    resetContainerImage(): void;
    get containerImageInput(): string | undefined;
    private _effectiveProperties;
    get effectiveProperties(): cdktf.StringMap;
    private _properties?;
    get properties(): {
        [key: string]: string;
    };
    set properties(value: {
        [key: string]: string;
    });
    resetProperties(): void;
    get propertiesInput(): {
        [key: string]: string;
    } | undefined;
    private _version?;
    get version(): string;
    set version(value: string);
    resetVersion(): void;
    get versionInput(): string | undefined;
}
export interface GoogleDataprocBatchSparkBatch {
    /**
    * HCFS URIs of archives to be extracted into the working directory of each executor.
    * Supported file types: .jar, .tar, .tar.gz, .tgz, and .zip.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#archive_uris GoogleDataprocBatch#archive_uris}
    */
    readonly archiveUris?: string[];
    /**
    * The arguments to pass to the driver. Do not include arguments that can be set as batch
    * properties, such as --conf, since a collision can occur that causes an incorrect batch submission.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#args GoogleDataprocBatch#args}
    */
    readonly args?: string[];
    /**
    * HCFS URIs of files to be placed in the working directory of each executor.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#file_uris GoogleDataprocBatch#file_uris}
    */
    readonly fileUris?: string[];
    /**
    * HCFS URIs of jar files to add to the classpath of the Spark driver and tasks.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#jar_file_uris GoogleDataprocBatch#jar_file_uris}
    */
    readonly jarFileUris?: string[];
    /**
    * The name of the driver main class. The jar file that contains the class must be in the
    * classpath or specified in jarFileUris.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#main_class GoogleDataprocBatch#main_class}
    */
    readonly mainClass?: string;
    /**
    * The HCFS URI of the jar file that contains the main class.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#main_jar_file_uri GoogleDataprocBatch#main_jar_file_uri}
    */
    readonly mainJarFileUri?: string;
}
export declare function googleDataprocBatchSparkBatchToTerraform(struct?: GoogleDataprocBatchSparkBatchOutputReference | GoogleDataprocBatchSparkBatch): any;
export declare function googleDataprocBatchSparkBatchToHclTerraform(struct?: GoogleDataprocBatchSparkBatchOutputReference | GoogleDataprocBatchSparkBatch): any;
export declare class GoogleDataprocBatchSparkBatchOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataprocBatchSparkBatch | undefined;
    set internalValue(value: GoogleDataprocBatchSparkBatch | undefined);
    private _archiveUris?;
    get archiveUris(): string[];
    set archiveUris(value: string[]);
    resetArchiveUris(): void;
    get archiveUrisInput(): string[] | undefined;
    private _args?;
    get args(): string[];
    set args(value: string[]);
    resetArgs(): void;
    get argsInput(): string[] | undefined;
    private _fileUris?;
    get fileUris(): string[];
    set fileUris(value: string[]);
    resetFileUris(): void;
    get fileUrisInput(): string[] | undefined;
    private _jarFileUris?;
    get jarFileUris(): string[];
    set jarFileUris(value: string[]);
    resetJarFileUris(): void;
    get jarFileUrisInput(): string[] | undefined;
    private _mainClass?;
    get mainClass(): string;
    set mainClass(value: string);
    resetMainClass(): void;
    get mainClassInput(): string | undefined;
    private _mainJarFileUri?;
    get mainJarFileUri(): string;
    set mainJarFileUri(value: string);
    resetMainJarFileUri(): void;
    get mainJarFileUriInput(): string | undefined;
}
export interface GoogleDataprocBatchSparkRBatch {
    /**
    * HCFS URIs of archives to be extracted into the working directory of each executor.
    * Supported file types: .jar, .tar, .tar.gz, .tgz, and .zip.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#archive_uris GoogleDataprocBatch#archive_uris}
    */
    readonly archiveUris?: string[];
    /**
    * The arguments to pass to the driver. Do not include arguments that can be set as batch
    * properties, such as --conf, since a collision can occur that causes an incorrect batch submission.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#args GoogleDataprocBatch#args}
    */
    readonly args?: string[];
    /**
    * HCFS URIs of files to be placed in the working directory of each executor.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#file_uris GoogleDataprocBatch#file_uris}
    */
    readonly fileUris?: string[];
    /**
    * The HCFS URI of the main R file to use as the driver. Must be a .R or .r file.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#main_r_file_uri GoogleDataprocBatch#main_r_file_uri}
    */
    readonly mainRFileUri?: string;
}
export declare function googleDataprocBatchSparkRBatchToTerraform(struct?: GoogleDataprocBatchSparkRBatchOutputReference | GoogleDataprocBatchSparkRBatch): any;
export declare function googleDataprocBatchSparkRBatchToHclTerraform(struct?: GoogleDataprocBatchSparkRBatchOutputReference | GoogleDataprocBatchSparkRBatch): any;
export declare class GoogleDataprocBatchSparkRBatchOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataprocBatchSparkRBatch | undefined;
    set internalValue(value: GoogleDataprocBatchSparkRBatch | undefined);
    private _archiveUris?;
    get archiveUris(): string[];
    set archiveUris(value: string[]);
    resetArchiveUris(): void;
    get archiveUrisInput(): string[] | undefined;
    private _args?;
    get args(): string[];
    set args(value: string[]);
    resetArgs(): void;
    get argsInput(): string[] | undefined;
    private _fileUris?;
    get fileUris(): string[];
    set fileUris(value: string[]);
    resetFileUris(): void;
    get fileUrisInput(): string[] | undefined;
    private _mainRFileUri?;
    get mainRFileUri(): string;
    set mainRFileUri(value: string);
    resetMainRFileUri(): void;
    get mainRFileUriInput(): string | undefined;
}
export interface GoogleDataprocBatchSparkSqlBatch {
    /**
    * HCFS URIs of jar files to be added to the Spark CLASSPATH.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#jar_file_uris GoogleDataprocBatch#jar_file_uris}
    */
    readonly jarFileUris?: string[];
    /**
    * The HCFS URI of the script that contains Spark SQL queries to execute.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#query_file_uri GoogleDataprocBatch#query_file_uri}
    */
    readonly queryFileUri?: string;
    /**
    * Mapping of query variable names to values (equivalent to the Spark SQL command: SET name="value";).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#query_variables GoogleDataprocBatch#query_variables}
    */
    readonly queryVariables?: {
        [key: string]: string;
    };
}
export declare function googleDataprocBatchSparkSqlBatchToTerraform(struct?: GoogleDataprocBatchSparkSqlBatchOutputReference | GoogleDataprocBatchSparkSqlBatch): any;
export declare function googleDataprocBatchSparkSqlBatchToHclTerraform(struct?: GoogleDataprocBatchSparkSqlBatchOutputReference | GoogleDataprocBatchSparkSqlBatch): any;
export declare class GoogleDataprocBatchSparkSqlBatchOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataprocBatchSparkSqlBatch | undefined;
    set internalValue(value: GoogleDataprocBatchSparkSqlBatch | undefined);
    private _jarFileUris?;
    get jarFileUris(): string[];
    set jarFileUris(value: string[]);
    resetJarFileUris(): void;
    get jarFileUrisInput(): string[] | undefined;
    private _queryFileUri?;
    get queryFileUri(): string;
    set queryFileUri(value: string);
    resetQueryFileUri(): void;
    get queryFileUriInput(): string | undefined;
    private _queryVariables?;
    get queryVariables(): {
        [key: string]: string;
    };
    set queryVariables(value: {
        [key: string]: string;
    });
    resetQueryVariables(): void;
    get queryVariablesInput(): {
        [key: string]: string;
    } | undefined;
}
export interface GoogleDataprocBatchTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#create GoogleDataprocBatch#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#delete GoogleDataprocBatch#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#update GoogleDataprocBatch#update}
    */
    readonly update?: string;
}
export declare function googleDataprocBatchTimeoutsToTerraform(struct?: GoogleDataprocBatchTimeouts | cdktf.IResolvable): any;
export declare function googleDataprocBatchTimeoutsToHclTerraform(struct?: GoogleDataprocBatchTimeouts | cdktf.IResolvable): any;
export declare class GoogleDataprocBatchTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataprocBatchTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleDataprocBatchTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch google_dataproc_batch}
*/
export declare class GoogleDataprocBatch extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_dataproc_batch";
    /**
    * Generates CDKTF code for importing a GoogleDataprocBatch resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleDataprocBatch to import
    * @param importFromId The id of the existing GoogleDataprocBatch that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleDataprocBatch to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_batch google_dataproc_batch} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleDataprocBatchConfig = {}
    */
    constructor(scope: Construct, id: string, config?: GoogleDataprocBatchConfig);
    private _batchId?;
    get batchId(): string;
    set batchId(value: string);
    resetBatchId(): void;
    get batchIdInput(): string | undefined;
    get createTime(): string;
    get creator(): string;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    resetLocation(): void;
    get locationInput(): string | undefined;
    get name(): string;
    get operation(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _runtimeInfo;
    get runtimeInfo(): GoogleDataprocBatchRuntimeInfoList;
    get state(): string;
    private _stateHistory;
    get stateHistory(): GoogleDataprocBatchStateHistoryList;
    get stateMessage(): string;
    get stateTime(): string;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    get uuid(): string;
    private _environmentConfig;
    get environmentConfig(): GoogleDataprocBatchEnvironmentConfigOutputReference;
    putEnvironmentConfig(value: GoogleDataprocBatchEnvironmentConfig): void;
    resetEnvironmentConfig(): void;
    get environmentConfigInput(): GoogleDataprocBatchEnvironmentConfig | undefined;
    private _pysparkBatch;
    get pysparkBatch(): GoogleDataprocBatchPysparkBatchOutputReference;
    putPysparkBatch(value: GoogleDataprocBatchPysparkBatch): void;
    resetPysparkBatch(): void;
    get pysparkBatchInput(): GoogleDataprocBatchPysparkBatch | undefined;
    private _runtimeConfig;
    get runtimeConfig(): GoogleDataprocBatchRuntimeConfigOutputReference;
    putRuntimeConfig(value: GoogleDataprocBatchRuntimeConfig): void;
    resetRuntimeConfig(): void;
    get runtimeConfigInput(): GoogleDataprocBatchRuntimeConfig | undefined;
    private _sparkBatch;
    get sparkBatch(): GoogleDataprocBatchSparkBatchOutputReference;
    putSparkBatch(value: GoogleDataprocBatchSparkBatch): void;
    resetSparkBatch(): void;
    get sparkBatchInput(): GoogleDataprocBatchSparkBatch | undefined;
    private _sparkRBatch;
    get sparkRBatch(): GoogleDataprocBatchSparkRBatchOutputReference;
    putSparkRBatch(value: GoogleDataprocBatchSparkRBatch): void;
    resetSparkRBatch(): void;
    get sparkRBatchInput(): GoogleDataprocBatchSparkRBatch | undefined;
    private _sparkSqlBatch;
    get sparkSqlBatch(): GoogleDataprocBatchSparkSqlBatchOutputReference;
    putSparkSqlBatch(value: GoogleDataprocBatchSparkSqlBatch): void;
    resetSparkSqlBatch(): void;
    get sparkSqlBatchInput(): GoogleDataprocBatchSparkSqlBatch | undefined;
    private _timeouts;
    get timeouts(): GoogleDataprocBatchTimeoutsOutputReference;
    putTimeouts(value: GoogleDataprocBatchTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleDataprocBatchTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
