/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleDataprocMetastoreServiceConfig extends cdktf.TerraformMetaArguments {
    /**
    * The database type that the Metastore service stores its data. Default value: "MYSQL" Possible values: ["MYSQL", "SPANNER"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#database_type GoogleDataprocMetastoreService#database_type}
    */
    readonly databaseType?: string;
    /**
    * Indicates if the dataproc metastore should be protected against accidental deletions.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#deletion_protection GoogleDataprocMetastoreService#deletion_protection}
    */
    readonly deletionProtection?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#id GoogleDataprocMetastoreService#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * User-defined labels for the metastore service.
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#labels GoogleDataprocMetastoreService#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * The location where the metastore service should reside.
    * The default value is 'global'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#location GoogleDataprocMetastoreService#location}
    */
    readonly location?: string;
    /**
    * The relative resource name of the VPC network on which the instance can be accessed. It is specified in the following form:
    *
    * "projects/{projectNumber}/global/networks/{network_id}".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#network GoogleDataprocMetastoreService#network}
    */
    readonly network?: string;
    /**
    * The TCP port at which the metastore service is reached. Default: 9083.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#port GoogleDataprocMetastoreService#port}
    */
    readonly port?: number;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#project GoogleDataprocMetastoreService#project}
    */
    readonly project?: string;
    /**
    * The release channel of the service. If unspecified, defaults to 'STABLE'. Default value: "STABLE" Possible values: ["CANARY", "STABLE"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#release_channel GoogleDataprocMetastoreService#release_channel}
    */
    readonly releaseChannel?: string;
    /**
    * The ID of the metastore service. The id must contain only letters (a-z, A-Z), numbers (0-9), underscores (_),
    * and hyphens (-). Cannot begin or end with underscore or hyphen. Must consist of between
    * 3 and 63 characters.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#service_id GoogleDataprocMetastoreService#service_id}
    */
    readonly serviceId: string;
    /**
    * The tier of the service. Possible values: ["DEVELOPER", "ENTERPRISE"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#tier GoogleDataprocMetastoreService#tier}
    */
    readonly tier?: string;
    /**
    * encryption_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#encryption_config GoogleDataprocMetastoreService#encryption_config}
    */
    readonly encryptionConfig?: GoogleDataprocMetastoreServiceEncryptionConfig;
    /**
    * hive_metastore_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#hive_metastore_config GoogleDataprocMetastoreService#hive_metastore_config}
    */
    readonly hiveMetastoreConfig?: GoogleDataprocMetastoreServiceHiveMetastoreConfig;
    /**
    * maintenance_window block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#maintenance_window GoogleDataprocMetastoreService#maintenance_window}
    */
    readonly maintenanceWindow?: GoogleDataprocMetastoreServiceMaintenanceWindow;
    /**
    * metadata_integration block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#metadata_integration GoogleDataprocMetastoreService#metadata_integration}
    */
    readonly metadataIntegration?: GoogleDataprocMetastoreServiceMetadataIntegration;
    /**
    * network_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#network_config GoogleDataprocMetastoreService#network_config}
    */
    readonly networkConfig?: GoogleDataprocMetastoreServiceNetworkConfig;
    /**
    * scaling_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#scaling_config GoogleDataprocMetastoreService#scaling_config}
    */
    readonly scalingConfig?: GoogleDataprocMetastoreServiceScalingConfig;
    /**
    * scheduled_backup block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#scheduled_backup GoogleDataprocMetastoreService#scheduled_backup}
    */
    readonly scheduledBackup?: GoogleDataprocMetastoreServiceScheduledBackup;
    /**
    * telemetry_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#telemetry_config GoogleDataprocMetastoreService#telemetry_config}
    */
    readonly telemetryConfig?: GoogleDataprocMetastoreServiceTelemetryConfig;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#timeouts GoogleDataprocMetastoreService#timeouts}
    */
    readonly timeouts?: GoogleDataprocMetastoreServiceTimeouts;
}
export interface GoogleDataprocMetastoreServiceEncryptionConfig {
    /**
    * The fully qualified customer provided Cloud KMS key name to use for customer data encryption.
    * Use the following format: 'projects/([^/]+)/locations/([^/]+)/keyRings/([^/]+)/cryptoKeys/([^/]+)'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#kms_key GoogleDataprocMetastoreService#kms_key}
    */
    readonly kmsKey: string;
}
export declare function googleDataprocMetastoreServiceEncryptionConfigToTerraform(struct?: GoogleDataprocMetastoreServiceEncryptionConfigOutputReference | GoogleDataprocMetastoreServiceEncryptionConfig): any;
export declare function googleDataprocMetastoreServiceEncryptionConfigToHclTerraform(struct?: GoogleDataprocMetastoreServiceEncryptionConfigOutputReference | GoogleDataprocMetastoreServiceEncryptionConfig): any;
export declare class GoogleDataprocMetastoreServiceEncryptionConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataprocMetastoreServiceEncryptionConfig | undefined;
    set internalValue(value: GoogleDataprocMetastoreServiceEncryptionConfig | undefined);
    private _kmsKey?;
    get kmsKey(): string;
    set kmsKey(value: string);
    get kmsKeyInput(): string | undefined;
}
export interface GoogleDataprocMetastoreServiceHiveMetastoreConfigAuxiliaryVersions {
    /**
    * A mapping of Hive metastore configuration key-value pairs to apply to the auxiliary Hive metastore (configured in hive-site.xml) in addition to the primary version's overrides.
    * If keys are present in both the auxiliary version's overrides and the primary version's overrides, the value from the auxiliary version's overrides takes precedence.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#config_overrides GoogleDataprocMetastoreService#config_overrides}
    */
    readonly configOverrides?: {
        [key: string]: string;
    };
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#key GoogleDataprocMetastoreService#key}
    */
    readonly key: string;
    /**
    * The Hive metastore version of the auxiliary service. It must be less than the primary Hive metastore service's version.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#version GoogleDataprocMetastoreService#version}
    */
    readonly version: string;
}
export declare function googleDataprocMetastoreServiceHiveMetastoreConfigAuxiliaryVersionsToTerraform(struct?: GoogleDataprocMetastoreServiceHiveMetastoreConfigAuxiliaryVersions | cdktf.IResolvable): any;
export declare function googleDataprocMetastoreServiceHiveMetastoreConfigAuxiliaryVersionsToHclTerraform(struct?: GoogleDataprocMetastoreServiceHiveMetastoreConfigAuxiliaryVersions | cdktf.IResolvable): any;
export declare class GoogleDataprocMetastoreServiceHiveMetastoreConfigAuxiliaryVersionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDataprocMetastoreServiceHiveMetastoreConfigAuxiliaryVersions | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleDataprocMetastoreServiceHiveMetastoreConfigAuxiliaryVersions | cdktf.IResolvable | undefined);
    private _configOverrides?;
    get configOverrides(): {
        [key: string]: string;
    };
    set configOverrides(value: {
        [key: string]: string;
    });
    resetConfigOverrides(): void;
    get configOverridesInput(): {
        [key: string]: string;
    } | undefined;
    private _key?;
    get key(): string;
    set key(value: string);
    get keyInput(): string | undefined;
    private _version?;
    get version(): string;
    set version(value: string);
    get versionInput(): string | undefined;
}
export declare class GoogleDataprocMetastoreServiceHiveMetastoreConfigAuxiliaryVersionsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleDataprocMetastoreServiceHiveMetastoreConfigAuxiliaryVersions[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDataprocMetastoreServiceHiveMetastoreConfigAuxiliaryVersionsOutputReference;
}
export interface GoogleDataprocMetastoreServiceHiveMetastoreConfigKerberosConfigKeytab {
    /**
    * The relative resource name of a Secret Manager secret version, in the following form:
    *
    * "projects/{projectNumber}/secrets/{secret_id}/versions/{version_id}".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#cloud_secret GoogleDataprocMetastoreService#cloud_secret}
    */
    readonly cloudSecret: string;
}
export declare function googleDataprocMetastoreServiceHiveMetastoreConfigKerberosConfigKeytabToTerraform(struct?: GoogleDataprocMetastoreServiceHiveMetastoreConfigKerberosConfigKeytabOutputReference | GoogleDataprocMetastoreServiceHiveMetastoreConfigKerberosConfigKeytab): any;
export declare function googleDataprocMetastoreServiceHiveMetastoreConfigKerberosConfigKeytabToHclTerraform(struct?: GoogleDataprocMetastoreServiceHiveMetastoreConfigKerberosConfigKeytabOutputReference | GoogleDataprocMetastoreServiceHiveMetastoreConfigKerberosConfigKeytab): any;
export declare class GoogleDataprocMetastoreServiceHiveMetastoreConfigKerberosConfigKeytabOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataprocMetastoreServiceHiveMetastoreConfigKerberosConfigKeytab | undefined;
    set internalValue(value: GoogleDataprocMetastoreServiceHiveMetastoreConfigKerberosConfigKeytab | undefined);
    private _cloudSecret?;
    get cloudSecret(): string;
    set cloudSecret(value: string);
    get cloudSecretInput(): string | undefined;
}
export interface GoogleDataprocMetastoreServiceHiveMetastoreConfigKerberosConfig {
    /**
    * A Cloud Storage URI that specifies the path to a krb5.conf file. It is of the form gs://{bucket_name}/path/to/krb5.conf, although the file does not need to be named krb5.conf explicitly.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#krb5_config_gcs_uri GoogleDataprocMetastoreService#krb5_config_gcs_uri}
    */
    readonly krb5ConfigGcsUri: string;
    /**
    * A Kerberos principal that exists in the both the keytab the KDC to authenticate as. A typical principal is of the form "primary/instance@REALM", but there is no exact format.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#principal GoogleDataprocMetastoreService#principal}
    */
    readonly principal: string;
    /**
    * keytab block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#keytab GoogleDataprocMetastoreService#keytab}
    */
    readonly keytab: GoogleDataprocMetastoreServiceHiveMetastoreConfigKerberosConfigKeytab;
}
export declare function googleDataprocMetastoreServiceHiveMetastoreConfigKerberosConfigToTerraform(struct?: GoogleDataprocMetastoreServiceHiveMetastoreConfigKerberosConfigOutputReference | GoogleDataprocMetastoreServiceHiveMetastoreConfigKerberosConfig): any;
export declare function googleDataprocMetastoreServiceHiveMetastoreConfigKerberosConfigToHclTerraform(struct?: GoogleDataprocMetastoreServiceHiveMetastoreConfigKerberosConfigOutputReference | GoogleDataprocMetastoreServiceHiveMetastoreConfigKerberosConfig): any;
export declare class GoogleDataprocMetastoreServiceHiveMetastoreConfigKerberosConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataprocMetastoreServiceHiveMetastoreConfigKerberosConfig | undefined;
    set internalValue(value: GoogleDataprocMetastoreServiceHiveMetastoreConfigKerberosConfig | undefined);
    private _krb5ConfigGcsUri?;
    get krb5ConfigGcsUri(): string;
    set krb5ConfigGcsUri(value: string);
    get krb5ConfigGcsUriInput(): string | undefined;
    private _principal?;
    get principal(): string;
    set principal(value: string);
    get principalInput(): string | undefined;
    private _keytab;
    get keytab(): GoogleDataprocMetastoreServiceHiveMetastoreConfigKerberosConfigKeytabOutputReference;
    putKeytab(value: GoogleDataprocMetastoreServiceHiveMetastoreConfigKerberosConfigKeytab): void;
    get keytabInput(): GoogleDataprocMetastoreServiceHiveMetastoreConfigKerberosConfigKeytab | undefined;
}
export interface GoogleDataprocMetastoreServiceHiveMetastoreConfig {
    /**
    * A mapping of Hive metastore configuration key-value pairs to apply to the Hive metastore (configured in hive-site.xml).
    * The mappings override system defaults (some keys cannot be overridden)
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#config_overrides GoogleDataprocMetastoreService#config_overrides}
    */
    readonly configOverrides?: {
        [key: string]: string;
    };
    /**
    * The protocol to use for the metastore service endpoint. If unspecified, defaults to 'THRIFT'. Default value: "THRIFT" Possible values: ["THRIFT", "GRPC"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#endpoint_protocol GoogleDataprocMetastoreService#endpoint_protocol}
    */
    readonly endpointProtocol?: string;
    /**
    * The Hive metastore schema version.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#version GoogleDataprocMetastoreService#version}
    */
    readonly version: string;
    /**
    * auxiliary_versions block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#auxiliary_versions GoogleDataprocMetastoreService#auxiliary_versions}
    */
    readonly auxiliaryVersions?: GoogleDataprocMetastoreServiceHiveMetastoreConfigAuxiliaryVersions[] | cdktf.IResolvable;
    /**
    * kerberos_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#kerberos_config GoogleDataprocMetastoreService#kerberos_config}
    */
    readonly kerberosConfig?: GoogleDataprocMetastoreServiceHiveMetastoreConfigKerberosConfig;
}
export declare function googleDataprocMetastoreServiceHiveMetastoreConfigToTerraform(struct?: GoogleDataprocMetastoreServiceHiveMetastoreConfigOutputReference | GoogleDataprocMetastoreServiceHiveMetastoreConfig): any;
export declare function googleDataprocMetastoreServiceHiveMetastoreConfigToHclTerraform(struct?: GoogleDataprocMetastoreServiceHiveMetastoreConfigOutputReference | GoogleDataprocMetastoreServiceHiveMetastoreConfig): any;
export declare class GoogleDataprocMetastoreServiceHiveMetastoreConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataprocMetastoreServiceHiveMetastoreConfig | undefined;
    set internalValue(value: GoogleDataprocMetastoreServiceHiveMetastoreConfig | undefined);
    private _configOverrides?;
    get configOverrides(): {
        [key: string]: string;
    };
    set configOverrides(value: {
        [key: string]: string;
    });
    resetConfigOverrides(): void;
    get configOverridesInput(): {
        [key: string]: string;
    } | undefined;
    private _endpointProtocol?;
    get endpointProtocol(): string;
    set endpointProtocol(value: string);
    resetEndpointProtocol(): void;
    get endpointProtocolInput(): string | undefined;
    private _version?;
    get version(): string;
    set version(value: string);
    get versionInput(): string | undefined;
    private _auxiliaryVersions;
    get auxiliaryVersions(): GoogleDataprocMetastoreServiceHiveMetastoreConfigAuxiliaryVersionsList;
    putAuxiliaryVersions(value: GoogleDataprocMetastoreServiceHiveMetastoreConfigAuxiliaryVersions[] | cdktf.IResolvable): void;
    resetAuxiliaryVersions(): void;
    get auxiliaryVersionsInput(): cdktf.IResolvable | GoogleDataprocMetastoreServiceHiveMetastoreConfigAuxiliaryVersions[] | undefined;
    private _kerberosConfig;
    get kerberosConfig(): GoogleDataprocMetastoreServiceHiveMetastoreConfigKerberosConfigOutputReference;
    putKerberosConfig(value: GoogleDataprocMetastoreServiceHiveMetastoreConfigKerberosConfig): void;
    resetKerberosConfig(): void;
    get kerberosConfigInput(): GoogleDataprocMetastoreServiceHiveMetastoreConfigKerberosConfig | undefined;
}
export interface GoogleDataprocMetastoreServiceMaintenanceWindow {
    /**
    * The day of week, when the window starts. Possible values: ["MONDAY", "TUESDAY", "WEDNESDAY", "THURSDAY", "FRIDAY", "SATURDAY", "SUNDAY"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#day_of_week GoogleDataprocMetastoreService#day_of_week}
    */
    readonly dayOfWeek: string;
    /**
    * The hour of day (0-23) when the window starts.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#hour_of_day GoogleDataprocMetastoreService#hour_of_day}
    */
    readonly hourOfDay: number;
}
export declare function googleDataprocMetastoreServiceMaintenanceWindowToTerraform(struct?: GoogleDataprocMetastoreServiceMaintenanceWindowOutputReference | GoogleDataprocMetastoreServiceMaintenanceWindow): any;
export declare function googleDataprocMetastoreServiceMaintenanceWindowToHclTerraform(struct?: GoogleDataprocMetastoreServiceMaintenanceWindowOutputReference | GoogleDataprocMetastoreServiceMaintenanceWindow): any;
export declare class GoogleDataprocMetastoreServiceMaintenanceWindowOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataprocMetastoreServiceMaintenanceWindow | undefined;
    set internalValue(value: GoogleDataprocMetastoreServiceMaintenanceWindow | undefined);
    private _dayOfWeek?;
    get dayOfWeek(): string;
    set dayOfWeek(value: string);
    get dayOfWeekInput(): string | undefined;
    private _hourOfDay?;
    get hourOfDay(): number;
    set hourOfDay(value: number);
    get hourOfDayInput(): number | undefined;
}
export interface GoogleDataprocMetastoreServiceMetadataIntegrationDataCatalogConfig {
    /**
    * Defines whether the metastore metadata should be synced to Data Catalog. The default value is to disable syncing metastore metadata to Data Catalog.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#enabled GoogleDataprocMetastoreService#enabled}
    */
    readonly enabled: boolean | cdktf.IResolvable;
}
export declare function googleDataprocMetastoreServiceMetadataIntegrationDataCatalogConfigToTerraform(struct?: GoogleDataprocMetastoreServiceMetadataIntegrationDataCatalogConfigOutputReference | GoogleDataprocMetastoreServiceMetadataIntegrationDataCatalogConfig): any;
export declare function googleDataprocMetastoreServiceMetadataIntegrationDataCatalogConfigToHclTerraform(struct?: GoogleDataprocMetastoreServiceMetadataIntegrationDataCatalogConfigOutputReference | GoogleDataprocMetastoreServiceMetadataIntegrationDataCatalogConfig): any;
export declare class GoogleDataprocMetastoreServiceMetadataIntegrationDataCatalogConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataprocMetastoreServiceMetadataIntegrationDataCatalogConfig | undefined;
    set internalValue(value: GoogleDataprocMetastoreServiceMetadataIntegrationDataCatalogConfig | undefined);
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
}
export interface GoogleDataprocMetastoreServiceMetadataIntegration {
    /**
    * data_catalog_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#data_catalog_config GoogleDataprocMetastoreService#data_catalog_config}
    */
    readonly dataCatalogConfig: GoogleDataprocMetastoreServiceMetadataIntegrationDataCatalogConfig;
}
export declare function googleDataprocMetastoreServiceMetadataIntegrationToTerraform(struct?: GoogleDataprocMetastoreServiceMetadataIntegrationOutputReference | GoogleDataprocMetastoreServiceMetadataIntegration): any;
export declare function googleDataprocMetastoreServiceMetadataIntegrationToHclTerraform(struct?: GoogleDataprocMetastoreServiceMetadataIntegrationOutputReference | GoogleDataprocMetastoreServiceMetadataIntegration): any;
export declare class GoogleDataprocMetastoreServiceMetadataIntegrationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataprocMetastoreServiceMetadataIntegration | undefined;
    set internalValue(value: GoogleDataprocMetastoreServiceMetadataIntegration | undefined);
    private _dataCatalogConfig;
    get dataCatalogConfig(): GoogleDataprocMetastoreServiceMetadataIntegrationDataCatalogConfigOutputReference;
    putDataCatalogConfig(value: GoogleDataprocMetastoreServiceMetadataIntegrationDataCatalogConfig): void;
    get dataCatalogConfigInput(): GoogleDataprocMetastoreServiceMetadataIntegrationDataCatalogConfig | undefined;
}
export interface GoogleDataprocMetastoreServiceNetworkConfigConsumers {
    /**
    * The subnetwork of the customer project from which an IP address is reserved and used as the Dataproc Metastore service's endpoint.
    * It is accessible to hosts in the subnet and to all hosts in a subnet in the same region and same network.
    * There must be at least one IP address available in the subnet's primary range. The subnet is specified in the following form:
    * 'projects/{projectNumber}/regions/{region_id}/subnetworks/{subnetwork_id}
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#subnetwork GoogleDataprocMetastoreService#subnetwork}
    */
    readonly subnetwork: string;
}
export declare function googleDataprocMetastoreServiceNetworkConfigConsumersToTerraform(struct?: GoogleDataprocMetastoreServiceNetworkConfigConsumers | cdktf.IResolvable): any;
export declare function googleDataprocMetastoreServiceNetworkConfigConsumersToHclTerraform(struct?: GoogleDataprocMetastoreServiceNetworkConfigConsumers | cdktf.IResolvable): any;
export declare class GoogleDataprocMetastoreServiceNetworkConfigConsumersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDataprocMetastoreServiceNetworkConfigConsumers | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleDataprocMetastoreServiceNetworkConfigConsumers | cdktf.IResolvable | undefined);
    get endpointUri(): string;
    private _subnetwork?;
    get subnetwork(): string;
    set subnetwork(value: string);
    get subnetworkInput(): string | undefined;
}
export declare class GoogleDataprocMetastoreServiceNetworkConfigConsumersList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleDataprocMetastoreServiceNetworkConfigConsumers[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDataprocMetastoreServiceNetworkConfigConsumersOutputReference;
}
export interface GoogleDataprocMetastoreServiceNetworkConfig {
    /**
    * Enables custom routes to be imported and exported for the Dataproc Metastore service's peered VPC network.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#custom_routes_enabled GoogleDataprocMetastoreService#custom_routes_enabled}
    */
    readonly customRoutesEnabled?: boolean | cdktf.IResolvable;
    /**
    * consumers block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#consumers GoogleDataprocMetastoreService#consumers}
    */
    readonly consumers: GoogleDataprocMetastoreServiceNetworkConfigConsumers[] | cdktf.IResolvable;
}
export declare function googleDataprocMetastoreServiceNetworkConfigToTerraform(struct?: GoogleDataprocMetastoreServiceNetworkConfigOutputReference | GoogleDataprocMetastoreServiceNetworkConfig): any;
export declare function googleDataprocMetastoreServiceNetworkConfigToHclTerraform(struct?: GoogleDataprocMetastoreServiceNetworkConfigOutputReference | GoogleDataprocMetastoreServiceNetworkConfig): any;
export declare class GoogleDataprocMetastoreServiceNetworkConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataprocMetastoreServiceNetworkConfig | undefined;
    set internalValue(value: GoogleDataprocMetastoreServiceNetworkConfig | undefined);
    private _customRoutesEnabled?;
    get customRoutesEnabled(): boolean | cdktf.IResolvable;
    set customRoutesEnabled(value: boolean | cdktf.IResolvable);
    resetCustomRoutesEnabled(): void;
    get customRoutesEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _consumers;
    get consumers(): GoogleDataprocMetastoreServiceNetworkConfigConsumersList;
    putConsumers(value: GoogleDataprocMetastoreServiceNetworkConfigConsumers[] | cdktf.IResolvable): void;
    get consumersInput(): cdktf.IResolvable | GoogleDataprocMetastoreServiceNetworkConfigConsumers[] | undefined;
}
export interface GoogleDataprocMetastoreServiceScalingConfigAutoscalingConfigLimitConfig {
    /**
    * The maximum scaling factor that the service will autoscale to. The default value is 6.0.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#max_scaling_factor GoogleDataprocMetastoreService#max_scaling_factor}
    */
    readonly maxScalingFactor?: number;
    /**
    * The minimum scaling factor that the service will autoscale to. The default value is 0.1.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#min_scaling_factor GoogleDataprocMetastoreService#min_scaling_factor}
    */
    readonly minScalingFactor?: number;
}
export declare function googleDataprocMetastoreServiceScalingConfigAutoscalingConfigLimitConfigToTerraform(struct?: GoogleDataprocMetastoreServiceScalingConfigAutoscalingConfigLimitConfigOutputReference | GoogleDataprocMetastoreServiceScalingConfigAutoscalingConfigLimitConfig): any;
export declare function googleDataprocMetastoreServiceScalingConfigAutoscalingConfigLimitConfigToHclTerraform(struct?: GoogleDataprocMetastoreServiceScalingConfigAutoscalingConfigLimitConfigOutputReference | GoogleDataprocMetastoreServiceScalingConfigAutoscalingConfigLimitConfig): any;
export declare class GoogleDataprocMetastoreServiceScalingConfigAutoscalingConfigLimitConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataprocMetastoreServiceScalingConfigAutoscalingConfigLimitConfig | undefined;
    set internalValue(value: GoogleDataprocMetastoreServiceScalingConfigAutoscalingConfigLimitConfig | undefined);
    private _maxScalingFactor?;
    get maxScalingFactor(): number;
    set maxScalingFactor(value: number);
    resetMaxScalingFactor(): void;
    get maxScalingFactorInput(): number | undefined;
    private _minScalingFactor?;
    get minScalingFactor(): number;
    set minScalingFactor(value: number);
    resetMinScalingFactor(): void;
    get minScalingFactorInput(): number | undefined;
}
export interface GoogleDataprocMetastoreServiceScalingConfigAutoscalingConfig {
    /**
    * Defines whether autoscaling is enabled. The default value is false.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#autoscaling_enabled GoogleDataprocMetastoreService#autoscaling_enabled}
    */
    readonly autoscalingEnabled?: boolean | cdktf.IResolvable;
    /**
    * limit_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#limit_config GoogleDataprocMetastoreService#limit_config}
    */
    readonly limitConfig?: GoogleDataprocMetastoreServiceScalingConfigAutoscalingConfigLimitConfig;
}
export declare function googleDataprocMetastoreServiceScalingConfigAutoscalingConfigToTerraform(struct?: GoogleDataprocMetastoreServiceScalingConfigAutoscalingConfigOutputReference | GoogleDataprocMetastoreServiceScalingConfigAutoscalingConfig): any;
export declare function googleDataprocMetastoreServiceScalingConfigAutoscalingConfigToHclTerraform(struct?: GoogleDataprocMetastoreServiceScalingConfigAutoscalingConfigOutputReference | GoogleDataprocMetastoreServiceScalingConfigAutoscalingConfig): any;
export declare class GoogleDataprocMetastoreServiceScalingConfigAutoscalingConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataprocMetastoreServiceScalingConfigAutoscalingConfig | undefined;
    set internalValue(value: GoogleDataprocMetastoreServiceScalingConfigAutoscalingConfig | undefined);
    private _autoscalingEnabled?;
    get autoscalingEnabled(): boolean | cdktf.IResolvable;
    set autoscalingEnabled(value: boolean | cdktf.IResolvable);
    resetAutoscalingEnabled(): void;
    get autoscalingEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _limitConfig;
    get limitConfig(): GoogleDataprocMetastoreServiceScalingConfigAutoscalingConfigLimitConfigOutputReference;
    putLimitConfig(value: GoogleDataprocMetastoreServiceScalingConfigAutoscalingConfigLimitConfig): void;
    resetLimitConfig(): void;
    get limitConfigInput(): GoogleDataprocMetastoreServiceScalingConfigAutoscalingConfigLimitConfig | undefined;
}
export interface GoogleDataprocMetastoreServiceScalingConfig {
    /**
    * Metastore instance sizes. Possible values: ["EXTRA_SMALL", "SMALL", "MEDIUM", "LARGE", "EXTRA_LARGE"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#instance_size GoogleDataprocMetastoreService#instance_size}
    */
    readonly instanceSize?: string;
    /**
    * Scaling factor, in increments of 0.1 for values less than 1.0, and increments of 1.0 for values greater than 1.0.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#scaling_factor GoogleDataprocMetastoreService#scaling_factor}
    */
    readonly scalingFactor?: number;
    /**
    * autoscaling_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#autoscaling_config GoogleDataprocMetastoreService#autoscaling_config}
    */
    readonly autoscalingConfig?: GoogleDataprocMetastoreServiceScalingConfigAutoscalingConfig;
}
export declare function googleDataprocMetastoreServiceScalingConfigToTerraform(struct?: GoogleDataprocMetastoreServiceScalingConfigOutputReference | GoogleDataprocMetastoreServiceScalingConfig): any;
export declare function googleDataprocMetastoreServiceScalingConfigToHclTerraform(struct?: GoogleDataprocMetastoreServiceScalingConfigOutputReference | GoogleDataprocMetastoreServiceScalingConfig): any;
export declare class GoogleDataprocMetastoreServiceScalingConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataprocMetastoreServiceScalingConfig | undefined;
    set internalValue(value: GoogleDataprocMetastoreServiceScalingConfig | undefined);
    private _instanceSize?;
    get instanceSize(): string;
    set instanceSize(value: string);
    resetInstanceSize(): void;
    get instanceSizeInput(): string | undefined;
    private _scalingFactor?;
    get scalingFactor(): number;
    set scalingFactor(value: number);
    resetScalingFactor(): void;
    get scalingFactorInput(): number | undefined;
    private _autoscalingConfig;
    get autoscalingConfig(): GoogleDataprocMetastoreServiceScalingConfigAutoscalingConfigOutputReference;
    putAutoscalingConfig(value: GoogleDataprocMetastoreServiceScalingConfigAutoscalingConfig): void;
    resetAutoscalingConfig(): void;
    get autoscalingConfigInput(): GoogleDataprocMetastoreServiceScalingConfigAutoscalingConfig | undefined;
}
export interface GoogleDataprocMetastoreServiceScheduledBackup {
    /**
    * A Cloud Storage URI of a folder, in the format gs://<bucket_name>/<path_inside_bucket>. A sub-folder <backup_folder> containing backup files will be stored below it.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#backup_location GoogleDataprocMetastoreService#backup_location}
    */
    readonly backupLocation: string;
    /**
    * The scheduled interval in Cron format, see https://en.wikipedia.org/wiki/Cron The default is empty: scheduled backup is not enabled. Must be specified to enable scheduled backups.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#cron_schedule GoogleDataprocMetastoreService#cron_schedule}
    */
    readonly cronSchedule?: string;
    /**
    * Defines whether the scheduled backup is enabled. The default value is false.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#enabled GoogleDataprocMetastoreService#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * Specifies the time zone to be used when interpreting cronSchedule. Must be a time zone name from the time zone database (https://en.wikipedia.org/wiki/List_of_tz_database_time_zones), e.g. America/Los_Angeles or Africa/Abidjan. If left unspecified, the default is UTC.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#time_zone GoogleDataprocMetastoreService#time_zone}
    */
    readonly timeZone?: string;
}
export declare function googleDataprocMetastoreServiceScheduledBackupToTerraform(struct?: GoogleDataprocMetastoreServiceScheduledBackupOutputReference | GoogleDataprocMetastoreServiceScheduledBackup): any;
export declare function googleDataprocMetastoreServiceScheduledBackupToHclTerraform(struct?: GoogleDataprocMetastoreServiceScheduledBackupOutputReference | GoogleDataprocMetastoreServiceScheduledBackup): any;
export declare class GoogleDataprocMetastoreServiceScheduledBackupOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataprocMetastoreServiceScheduledBackup | undefined;
    set internalValue(value: GoogleDataprocMetastoreServiceScheduledBackup | undefined);
    private _backupLocation?;
    get backupLocation(): string;
    set backupLocation(value: string);
    get backupLocationInput(): string | undefined;
    private _cronSchedule?;
    get cronSchedule(): string;
    set cronSchedule(value: string);
    resetCronSchedule(): void;
    get cronScheduleInput(): string | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _timeZone?;
    get timeZone(): string;
    set timeZone(value: string);
    resetTimeZone(): void;
    get timeZoneInput(): string | undefined;
}
export interface GoogleDataprocMetastoreServiceTelemetryConfig {
    /**
    * The output format of the Dataproc Metastore service's logs. Default value: "JSON" Possible values: ["LEGACY", "JSON"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#log_format GoogleDataprocMetastoreService#log_format}
    */
    readonly logFormat?: string;
}
export declare function googleDataprocMetastoreServiceTelemetryConfigToTerraform(struct?: GoogleDataprocMetastoreServiceTelemetryConfigOutputReference | GoogleDataprocMetastoreServiceTelemetryConfig): any;
export declare function googleDataprocMetastoreServiceTelemetryConfigToHclTerraform(struct?: GoogleDataprocMetastoreServiceTelemetryConfigOutputReference | GoogleDataprocMetastoreServiceTelemetryConfig): any;
export declare class GoogleDataprocMetastoreServiceTelemetryConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataprocMetastoreServiceTelemetryConfig | undefined;
    set internalValue(value: GoogleDataprocMetastoreServiceTelemetryConfig | undefined);
    private _logFormat?;
    get logFormat(): string;
    set logFormat(value: string);
    resetLogFormat(): void;
    get logFormatInput(): string | undefined;
}
export interface GoogleDataprocMetastoreServiceTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#create GoogleDataprocMetastoreService#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#delete GoogleDataprocMetastoreService#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#update GoogleDataprocMetastoreService#update}
    */
    readonly update?: string;
}
export declare function googleDataprocMetastoreServiceTimeoutsToTerraform(struct?: GoogleDataprocMetastoreServiceTimeouts | cdktf.IResolvable): any;
export declare function googleDataprocMetastoreServiceTimeoutsToHclTerraform(struct?: GoogleDataprocMetastoreServiceTimeouts | cdktf.IResolvable): any;
export declare class GoogleDataprocMetastoreServiceTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDataprocMetastoreServiceTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleDataprocMetastoreServiceTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service google_dataproc_metastore_service}
*/
export declare class GoogleDataprocMetastoreService extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_dataproc_metastore_service";
    /**
    * Generates CDKTF code for importing a GoogleDataprocMetastoreService resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleDataprocMetastoreService to import
    * @param importFromId The id of the existing GoogleDataprocMetastoreService that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleDataprocMetastoreService to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_dataproc_metastore_service google_dataproc_metastore_service} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleDataprocMetastoreServiceConfig
    */
    constructor(scope: Construct, id: string, config: GoogleDataprocMetastoreServiceConfig);
    get artifactGcsUri(): string;
    private _databaseType?;
    get databaseType(): string;
    set databaseType(value: string);
    resetDatabaseType(): void;
    get databaseTypeInput(): string | undefined;
    private _deletionProtection?;
    get deletionProtection(): boolean | cdktf.IResolvable;
    set deletionProtection(value: boolean | cdktf.IResolvable);
    resetDeletionProtection(): void;
    get deletionProtectionInput(): boolean | cdktf.IResolvable | undefined;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    get endpointUri(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    resetLocation(): void;
    get locationInput(): string | undefined;
    get name(): string;
    private _network?;
    get network(): string;
    set network(value: string);
    resetNetwork(): void;
    get networkInput(): string | undefined;
    private _port?;
    get port(): number;
    set port(value: number);
    resetPort(): void;
    get portInput(): number | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _releaseChannel?;
    get releaseChannel(): string;
    set releaseChannel(value: string);
    resetReleaseChannel(): void;
    get releaseChannelInput(): string | undefined;
    private _serviceId?;
    get serviceId(): string;
    set serviceId(value: string);
    get serviceIdInput(): string | undefined;
    get state(): string;
    get stateMessage(): string;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    private _tier?;
    get tier(): string;
    set tier(value: string);
    resetTier(): void;
    get tierInput(): string | undefined;
    get uid(): string;
    private _encryptionConfig;
    get encryptionConfig(): GoogleDataprocMetastoreServiceEncryptionConfigOutputReference;
    putEncryptionConfig(value: GoogleDataprocMetastoreServiceEncryptionConfig): void;
    resetEncryptionConfig(): void;
    get encryptionConfigInput(): GoogleDataprocMetastoreServiceEncryptionConfig | undefined;
    private _hiveMetastoreConfig;
    get hiveMetastoreConfig(): GoogleDataprocMetastoreServiceHiveMetastoreConfigOutputReference;
    putHiveMetastoreConfig(value: GoogleDataprocMetastoreServiceHiveMetastoreConfig): void;
    resetHiveMetastoreConfig(): void;
    get hiveMetastoreConfigInput(): GoogleDataprocMetastoreServiceHiveMetastoreConfig | undefined;
    private _maintenanceWindow;
    get maintenanceWindow(): GoogleDataprocMetastoreServiceMaintenanceWindowOutputReference;
    putMaintenanceWindow(value: GoogleDataprocMetastoreServiceMaintenanceWindow): void;
    resetMaintenanceWindow(): void;
    get maintenanceWindowInput(): GoogleDataprocMetastoreServiceMaintenanceWindow | undefined;
    private _metadataIntegration;
    get metadataIntegration(): GoogleDataprocMetastoreServiceMetadataIntegrationOutputReference;
    putMetadataIntegration(value: GoogleDataprocMetastoreServiceMetadataIntegration): void;
    resetMetadataIntegration(): void;
    get metadataIntegrationInput(): GoogleDataprocMetastoreServiceMetadataIntegration | undefined;
    private _networkConfig;
    get networkConfig(): GoogleDataprocMetastoreServiceNetworkConfigOutputReference;
    putNetworkConfig(value: GoogleDataprocMetastoreServiceNetworkConfig): void;
    resetNetworkConfig(): void;
    get networkConfigInput(): GoogleDataprocMetastoreServiceNetworkConfig | undefined;
    private _scalingConfig;
    get scalingConfig(): GoogleDataprocMetastoreServiceScalingConfigOutputReference;
    putScalingConfig(value: GoogleDataprocMetastoreServiceScalingConfig): void;
    resetScalingConfig(): void;
    get scalingConfigInput(): GoogleDataprocMetastoreServiceScalingConfig | undefined;
    private _scheduledBackup;
    get scheduledBackup(): GoogleDataprocMetastoreServiceScheduledBackupOutputReference;
    putScheduledBackup(value: GoogleDataprocMetastoreServiceScheduledBackup): void;
    resetScheduledBackup(): void;
    get scheduledBackupInput(): GoogleDataprocMetastoreServiceScheduledBackup | undefined;
    private _telemetryConfig;
    get telemetryConfig(): GoogleDataprocMetastoreServiceTelemetryConfigOutputReference;
    putTelemetryConfig(value: GoogleDataprocMetastoreServiceTelemetryConfig): void;
    resetTelemetryConfig(): void;
    get telemetryConfigInput(): GoogleDataprocMetastoreServiceTelemetryConfig | undefined;
    private _timeouts;
    get timeouts(): GoogleDataprocMetastoreServiceTimeoutsOutputReference;
    putTimeouts(value: GoogleDataprocMetastoreServiceTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleDataprocMetastoreServiceTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
