/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleDeveloperConnectConnectionConfig extends cdktf.TerraformMetaArguments {
    /**
    * Optional. Allows clients to store small amounts of arbitrary data.
    *
    *
    * **Note**: This field is non-authoritative, and will only manage the annotations present in your configuration.
    * Please refer to the field 'effective_annotations' for all of the annotations present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_developer_connect_connection#annotations GoogleDeveloperConnectConnection#annotations}
    */
    readonly annotations?: {
        [key: string]: string;
    };
    /**
    * Required. Id of the requesting object. If auto-generating Id server-side,
    * remove this field and connection_id from the method_signature of Create RPC.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_developer_connect_connection#connection_id GoogleDeveloperConnectConnection#connection_id}
    */
    readonly connectionId: string;
    /**
    * Optional. If disabled is set to true, functionality is disabled for this connection. Repository based API methods and webhooks processing for repositories in this connection will be disabled.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_developer_connect_connection#disabled GoogleDeveloperConnectConnection#disabled}
    */
    readonly disabled?: boolean | cdktf.IResolvable;
    /**
    * Optional. This checksum is computed by the server based on the value
    * of other fields, and may be sent on update and delete requests to ensure the
    * client has an up-to-date value before proceeding.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_developer_connect_connection#etag GoogleDeveloperConnectConnection#etag}
    */
    readonly etag?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_developer_connect_connection#id GoogleDeveloperConnectConnection#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Optional. Labels as key value pairs
    *
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_developer_connect_connection#labels GoogleDeveloperConnectConnection#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * Resource ID segment making up resource 'name'. It identifies the resource
    * within its parent collection as described in https://google.aip.dev/122. See documentation
    * for resource type 'developerconnect.googleapis.com/GitRepositoryLink'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_developer_connect_connection#location GoogleDeveloperConnectConnection#location}
    */
    readonly location: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_developer_connect_connection#project GoogleDeveloperConnectConnection#project}
    */
    readonly project?: string;
    /**
    * github_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_developer_connect_connection#github_config GoogleDeveloperConnectConnection#github_config}
    */
    readonly githubConfig?: GoogleDeveloperConnectConnectionGithubConfig;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_developer_connect_connection#timeouts GoogleDeveloperConnectConnection#timeouts}
    */
    readonly timeouts?: GoogleDeveloperConnectConnectionTimeouts;
}
export interface GoogleDeveloperConnectConnectionInstallationState {
}
export declare function googleDeveloperConnectConnectionInstallationStateToTerraform(struct?: GoogleDeveloperConnectConnectionInstallationState): any;
export declare function googleDeveloperConnectConnectionInstallationStateToHclTerraform(struct?: GoogleDeveloperConnectConnectionInstallationState): any;
export declare class GoogleDeveloperConnectConnectionInstallationStateOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDeveloperConnectConnectionInstallationState | undefined;
    set internalValue(value: GoogleDeveloperConnectConnectionInstallationState | undefined);
    get actionUri(): string;
    get message(): string;
    get stage(): string;
}
export declare class GoogleDeveloperConnectConnectionInstallationStateList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDeveloperConnectConnectionInstallationStateOutputReference;
}
export interface GoogleDeveloperConnectConnectionGithubConfigAuthorizerCredential {
    /**
    * Required. A SecretManager resource containing the OAuth token
    * that authorizes the connection.
    * Format: 'projects/* /secrets/* /versions/*'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_developer_connect_connection#oauth_token_secret_version GoogleDeveloperConnectConnection#oauth_token_secret_version}
     *
    * Note: The above comment contained a comment block ending sequence (* followed by /). We have introduced a space between to prevent syntax errors. Please ignore the space.
    */
    readonly oauthTokenSecretVersion: string;
}
export declare function googleDeveloperConnectConnectionGithubConfigAuthorizerCredentialToTerraform(struct?: GoogleDeveloperConnectConnectionGithubConfigAuthorizerCredentialOutputReference | GoogleDeveloperConnectConnectionGithubConfigAuthorizerCredential): any;
export declare function googleDeveloperConnectConnectionGithubConfigAuthorizerCredentialToHclTerraform(struct?: GoogleDeveloperConnectConnectionGithubConfigAuthorizerCredentialOutputReference | GoogleDeveloperConnectConnectionGithubConfigAuthorizerCredential): any;
export declare class GoogleDeveloperConnectConnectionGithubConfigAuthorizerCredentialOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDeveloperConnectConnectionGithubConfigAuthorizerCredential | undefined;
    set internalValue(value: GoogleDeveloperConnectConnectionGithubConfigAuthorizerCredential | undefined);
    private _oauthTokenSecretVersion?;
    get oauthTokenSecretVersion(): string;
    set oauthTokenSecretVersion(value: string);
    get oauthTokenSecretVersionInput(): string | undefined;
    get username(): string;
}
export interface GoogleDeveloperConnectConnectionGithubConfig {
    /**
    * Optional. GitHub App installation id.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_developer_connect_connection#app_installation_id GoogleDeveloperConnectConnection#app_installation_id}
    */
    readonly appInstallationId?: string;
    /**
    * Required. Immutable. The GitHub Application that was installed to
    * the GitHub user or organization.
    * Possible values:
    *   GIT_HUB_APP_UNSPECIFIED
    *   DEVELOPER_CONNECT
    *   FIREBASE"
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_developer_connect_connection#github_app GoogleDeveloperConnectConnection#github_app}
    */
    readonly githubApp: string;
    /**
    * authorizer_credential block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_developer_connect_connection#authorizer_credential GoogleDeveloperConnectConnection#authorizer_credential}
    */
    readonly authorizerCredential?: GoogleDeveloperConnectConnectionGithubConfigAuthorizerCredential;
}
export declare function googleDeveloperConnectConnectionGithubConfigToTerraform(struct?: GoogleDeveloperConnectConnectionGithubConfigOutputReference | GoogleDeveloperConnectConnectionGithubConfig): any;
export declare function googleDeveloperConnectConnectionGithubConfigToHclTerraform(struct?: GoogleDeveloperConnectConnectionGithubConfigOutputReference | GoogleDeveloperConnectConnectionGithubConfig): any;
export declare class GoogleDeveloperConnectConnectionGithubConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDeveloperConnectConnectionGithubConfig | undefined;
    set internalValue(value: GoogleDeveloperConnectConnectionGithubConfig | undefined);
    private _appInstallationId?;
    get appInstallationId(): string;
    set appInstallationId(value: string);
    resetAppInstallationId(): void;
    get appInstallationIdInput(): string | undefined;
    private _githubApp?;
    get githubApp(): string;
    set githubApp(value: string);
    get githubAppInput(): string | undefined;
    get installationUri(): string;
    private _authorizerCredential;
    get authorizerCredential(): GoogleDeveloperConnectConnectionGithubConfigAuthorizerCredentialOutputReference;
    putAuthorizerCredential(value: GoogleDeveloperConnectConnectionGithubConfigAuthorizerCredential): void;
    resetAuthorizerCredential(): void;
    get authorizerCredentialInput(): GoogleDeveloperConnectConnectionGithubConfigAuthorizerCredential | undefined;
}
export interface GoogleDeveloperConnectConnectionTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_developer_connect_connection#create GoogleDeveloperConnectConnection#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_developer_connect_connection#delete GoogleDeveloperConnectConnection#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_developer_connect_connection#update GoogleDeveloperConnectConnection#update}
    */
    readonly update?: string;
}
export declare function googleDeveloperConnectConnectionTimeoutsToTerraform(struct?: GoogleDeveloperConnectConnectionTimeouts | cdktf.IResolvable): any;
export declare function googleDeveloperConnectConnectionTimeoutsToHclTerraform(struct?: GoogleDeveloperConnectConnectionTimeouts | cdktf.IResolvable): any;
export declare class GoogleDeveloperConnectConnectionTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDeveloperConnectConnectionTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleDeveloperConnectConnectionTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_developer_connect_connection google_developer_connect_connection}
*/
export declare class GoogleDeveloperConnectConnection extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_developer_connect_connection";
    /**
    * Generates CDKTF code for importing a GoogleDeveloperConnectConnection resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleDeveloperConnectConnection to import
    * @param importFromId The id of the existing GoogleDeveloperConnectConnection that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_developer_connect_connection#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleDeveloperConnectConnection to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_developer_connect_connection google_developer_connect_connection} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleDeveloperConnectConnectionConfig
    */
    constructor(scope: Construct, id: string, config: GoogleDeveloperConnectConnectionConfig);
    private _annotations?;
    get annotations(): {
        [key: string]: string;
    };
    set annotations(value: {
        [key: string]: string;
    });
    resetAnnotations(): void;
    get annotationsInput(): {
        [key: string]: string;
    } | undefined;
    private _connectionId?;
    get connectionId(): string;
    set connectionId(value: string);
    get connectionIdInput(): string | undefined;
    get createTime(): string;
    get deleteTime(): string;
    private _disabled?;
    get disabled(): boolean | cdktf.IResolvable;
    set disabled(value: boolean | cdktf.IResolvable);
    resetDisabled(): void;
    get disabledInput(): boolean | cdktf.IResolvable | undefined;
    private _effectiveAnnotations;
    get effectiveAnnotations(): cdktf.StringMap;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    private _etag?;
    get etag(): string;
    set etag(value: string);
    resetEtag(): void;
    get etagInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _installationState;
    get installationState(): GoogleDeveloperConnectConnectionInstallationStateList;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    get reconciling(): cdktf.IResolvable;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    get uid(): string;
    get updateTime(): string;
    private _githubConfig;
    get githubConfig(): GoogleDeveloperConnectConnectionGithubConfigOutputReference;
    putGithubConfig(value: GoogleDeveloperConnectConnectionGithubConfig): void;
    resetGithubConfig(): void;
    get githubConfigInput(): GoogleDeveloperConnectConnectionGithubConfig | undefined;
    private _timeouts;
    get timeouts(): GoogleDeveloperConnectConnectionTimeoutsOutputReference;
    putTimeouts(value: GoogleDeveloperConnectConnectionTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleDeveloperConnectConnectionTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
