/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleDiscoveryEngineTargetSiteConfig extends cdktf.TerraformMetaArguments {
    /**
    * The unique id of the data store.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_discovery_engine_target_site#data_store_id GoogleDiscoveryEngineTargetSite#data_store_id}
    */
    readonly dataStoreId: string;
    /**
    * If set to false, a uri_pattern is generated to include all pages whose
    * address contains the provided_uri_pattern. If set to true, an uri_pattern
    * is generated to try to be an exact match of the provided_uri_pattern or
    * just the specific page if the provided_uri_pattern is a specific one.
    * provided_uri_pattern is always normalized to generate the URI pattern to
    * be used by the search engine.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_discovery_engine_target_site#exact_match GoogleDiscoveryEngineTargetSite#exact_match}
    */
    readonly exactMatch?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_discovery_engine_target_site#id GoogleDiscoveryEngineTargetSite#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The geographic location where the data store should reside. The value can
    * only be one of "global", "us" and "eu".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_discovery_engine_target_site#location GoogleDiscoveryEngineTargetSite#location}
    */
    readonly location: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_discovery_engine_target_site#project GoogleDiscoveryEngineTargetSite#project}
    */
    readonly project?: string;
    /**
    * The user provided URI pattern from which the 'generated_uri_pattern' is
    * generated.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_discovery_engine_target_site#provided_uri_pattern GoogleDiscoveryEngineTargetSite#provided_uri_pattern}
    */
    readonly providedUriPattern: string;
    /**
    * The possible target site types. Possible values: ["INCLUDE", "EXCLUDE"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_discovery_engine_target_site#type GoogleDiscoveryEngineTargetSite#type}
    */
    readonly type?: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_discovery_engine_target_site#timeouts GoogleDiscoveryEngineTargetSite#timeouts}
    */
    readonly timeouts?: GoogleDiscoveryEngineTargetSiteTimeouts;
}
export interface GoogleDiscoveryEngineTargetSiteFailureReasonQuotaFailure {
}
export declare function googleDiscoveryEngineTargetSiteFailureReasonQuotaFailureToTerraform(struct?: GoogleDiscoveryEngineTargetSiteFailureReasonQuotaFailure): any;
export declare function googleDiscoveryEngineTargetSiteFailureReasonQuotaFailureToHclTerraform(struct?: GoogleDiscoveryEngineTargetSiteFailureReasonQuotaFailure): any;
export declare class GoogleDiscoveryEngineTargetSiteFailureReasonQuotaFailureOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDiscoveryEngineTargetSiteFailureReasonQuotaFailure | undefined;
    set internalValue(value: GoogleDiscoveryEngineTargetSiteFailureReasonQuotaFailure | undefined);
    get totalRequiredQuota(): number;
}
export declare class GoogleDiscoveryEngineTargetSiteFailureReasonQuotaFailureList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDiscoveryEngineTargetSiteFailureReasonQuotaFailureOutputReference;
}
export interface GoogleDiscoveryEngineTargetSiteFailureReason {
}
export declare function googleDiscoveryEngineTargetSiteFailureReasonToTerraform(struct?: GoogleDiscoveryEngineTargetSiteFailureReason): any;
export declare function googleDiscoveryEngineTargetSiteFailureReasonToHclTerraform(struct?: GoogleDiscoveryEngineTargetSiteFailureReason): any;
export declare class GoogleDiscoveryEngineTargetSiteFailureReasonOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDiscoveryEngineTargetSiteFailureReason | undefined;
    set internalValue(value: GoogleDiscoveryEngineTargetSiteFailureReason | undefined);
    private _quotaFailure;
    get quotaFailure(): GoogleDiscoveryEngineTargetSiteFailureReasonQuotaFailureList;
}
export declare class GoogleDiscoveryEngineTargetSiteFailureReasonList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDiscoveryEngineTargetSiteFailureReasonOutputReference;
}
export interface GoogleDiscoveryEngineTargetSiteSiteVerificationInfo {
}
export declare function googleDiscoveryEngineTargetSiteSiteVerificationInfoToTerraform(struct?: GoogleDiscoveryEngineTargetSiteSiteVerificationInfo): any;
export declare function googleDiscoveryEngineTargetSiteSiteVerificationInfoToHclTerraform(struct?: GoogleDiscoveryEngineTargetSiteSiteVerificationInfo): any;
export declare class GoogleDiscoveryEngineTargetSiteSiteVerificationInfoOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleDiscoveryEngineTargetSiteSiteVerificationInfo | undefined;
    set internalValue(value: GoogleDiscoveryEngineTargetSiteSiteVerificationInfo | undefined);
    get siteVerificationState(): string;
    get verifyTime(): string;
}
export declare class GoogleDiscoveryEngineTargetSiteSiteVerificationInfoList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleDiscoveryEngineTargetSiteSiteVerificationInfoOutputReference;
}
export interface GoogleDiscoveryEngineTargetSiteTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_discovery_engine_target_site#create GoogleDiscoveryEngineTargetSite#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_discovery_engine_target_site#delete GoogleDiscoveryEngineTargetSite#delete}
    */
    readonly delete?: string;
}
export declare function googleDiscoveryEngineTargetSiteTimeoutsToTerraform(struct?: GoogleDiscoveryEngineTargetSiteTimeouts | cdktf.IResolvable): any;
export declare function googleDiscoveryEngineTargetSiteTimeoutsToHclTerraform(struct?: GoogleDiscoveryEngineTargetSiteTimeouts | cdktf.IResolvable): any;
export declare class GoogleDiscoveryEngineTargetSiteTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDiscoveryEngineTargetSiteTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleDiscoveryEngineTargetSiteTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_discovery_engine_target_site google_discovery_engine_target_site}
*/
export declare class GoogleDiscoveryEngineTargetSite extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_discovery_engine_target_site";
    /**
    * Generates CDKTF code for importing a GoogleDiscoveryEngineTargetSite resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleDiscoveryEngineTargetSite to import
    * @param importFromId The id of the existing GoogleDiscoveryEngineTargetSite that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_discovery_engine_target_site#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleDiscoveryEngineTargetSite to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_discovery_engine_target_site google_discovery_engine_target_site} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleDiscoveryEngineTargetSiteConfig
    */
    constructor(scope: Construct, id: string, config: GoogleDiscoveryEngineTargetSiteConfig);
    private _dataStoreId?;
    get dataStoreId(): string;
    set dataStoreId(value: string);
    get dataStoreIdInput(): string | undefined;
    private _exactMatch?;
    get exactMatch(): boolean | cdktf.IResolvable;
    set exactMatch(value: boolean | cdktf.IResolvable);
    resetExactMatch(): void;
    get exactMatchInput(): boolean | cdktf.IResolvable | undefined;
    private _failureReason;
    get failureReason(): GoogleDiscoveryEngineTargetSiteFailureReasonList;
    get generatedUriPattern(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get indexingStatus(): string;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _providedUriPattern?;
    get providedUriPattern(): string;
    set providedUriPattern(value: string);
    get providedUriPatternInput(): string | undefined;
    get rootDomainUri(): string;
    private _siteVerificationInfo;
    get siteVerificationInfo(): GoogleDiscoveryEngineTargetSiteSiteVerificationInfoList;
    get targetSiteId(): string;
    private _type?;
    get type(): string;
    set type(value: string);
    resetType(): void;
    get typeInput(): string | undefined;
    get updateTime(): string;
    private _timeouts;
    get timeouts(): GoogleDiscoveryEngineTargetSiteTimeoutsOutputReference;
    putTimeouts(value: GoogleDiscoveryEngineTargetSiteTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleDiscoveryEngineTargetSiteTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
