/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleFirebaseAndroidAppConfig extends cdktf.TerraformMetaArguments {
    /**
    * The globally unique, Google-assigned identifier (UID) for the Firebase API key associated with the AndroidApp.
    * If apiKeyId is not set during creation, then Firebase automatically associates an apiKeyId with the AndroidApp.
    * This auto-associated key may be an existing valid key or, if no valid key exists, a new one will be provisioned.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_firebase_android_app#api_key_id GoogleFirebaseAndroidApp#api_key_id}
    */
    readonly apiKeyId?: string;
    /**
    * (Optional) Set to 'ABANDON' to allow the AndroidApp to be untracked from terraform state
    * rather than deleted upon 'terraform destroy'. This is useful because the AndroidApp may be
    * serving traffic. Set to 'DELETE' to delete the AndroidApp. Defaults to 'DELETE'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_firebase_android_app#deletion_policy GoogleFirebaseAndroidApp#deletion_policy}
    */
    readonly deletionPolicy?: string;
    /**
    * The user-assigned display name of the AndroidApp.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_firebase_android_app#display_name GoogleFirebaseAndroidApp#display_name}
    */
    readonly displayName: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_firebase_android_app#id GoogleFirebaseAndroidApp#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The canonical package name of the Android app as would appear in the Google Play
    * Developer Console.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_firebase_android_app#package_name GoogleFirebaseAndroidApp#package_name}
    */
    readonly packageName: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_firebase_android_app#project GoogleFirebaseAndroidApp#project}
    */
    readonly project?: string;
    /**
    * The SHA1 certificate hashes for the AndroidApp.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_firebase_android_app#sha1_hashes GoogleFirebaseAndroidApp#sha1_hashes}
    */
    readonly sha1Hashes?: string[];
    /**
    * The SHA256 certificate hashes for the AndroidApp.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_firebase_android_app#sha256_hashes GoogleFirebaseAndroidApp#sha256_hashes}
    */
    readonly sha256Hashes?: string[];
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_firebase_android_app#timeouts GoogleFirebaseAndroidApp#timeouts}
    */
    readonly timeouts?: GoogleFirebaseAndroidAppTimeouts;
}
export interface GoogleFirebaseAndroidAppTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_firebase_android_app#create GoogleFirebaseAndroidApp#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_firebase_android_app#delete GoogleFirebaseAndroidApp#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_firebase_android_app#update GoogleFirebaseAndroidApp#update}
    */
    readonly update?: string;
}
export declare function googleFirebaseAndroidAppTimeoutsToTerraform(struct?: GoogleFirebaseAndroidAppTimeouts | cdktf.IResolvable): any;
export declare function googleFirebaseAndroidAppTimeoutsToHclTerraform(struct?: GoogleFirebaseAndroidAppTimeouts | cdktf.IResolvable): any;
export declare class GoogleFirebaseAndroidAppTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleFirebaseAndroidAppTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleFirebaseAndroidAppTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_firebase_android_app google_firebase_android_app}
*/
export declare class GoogleFirebaseAndroidApp extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_firebase_android_app";
    /**
    * Generates CDKTF code for importing a GoogleFirebaseAndroidApp resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleFirebaseAndroidApp to import
    * @param importFromId The id of the existing GoogleFirebaseAndroidApp that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_firebase_android_app#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleFirebaseAndroidApp to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_firebase_android_app google_firebase_android_app} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleFirebaseAndroidAppConfig
    */
    constructor(scope: Construct, id: string, config: GoogleFirebaseAndroidAppConfig);
    private _apiKeyId?;
    get apiKeyId(): string;
    set apiKeyId(value: string);
    resetApiKeyId(): void;
    get apiKeyIdInput(): string | undefined;
    get appId(): string;
    private _deletionPolicy?;
    get deletionPolicy(): string;
    set deletionPolicy(value: string);
    resetDeletionPolicy(): void;
    get deletionPolicyInput(): string | undefined;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    get displayNameInput(): string | undefined;
    get etag(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get name(): string;
    private _packageName?;
    get packageName(): string;
    set packageName(value: string);
    get packageNameInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _sha1Hashes?;
    get sha1Hashes(): string[];
    set sha1Hashes(value: string[]);
    resetSha1Hashes(): void;
    get sha1HashesInput(): string[] | undefined;
    private _sha256Hashes?;
    get sha256Hashes(): string[];
    set sha256Hashes(value: string[]);
    resetSha256Hashes(): void;
    get sha256HashesInput(): string[] | undefined;
    private _timeouts;
    get timeouts(): GoogleFirebaseAndroidAppTimeoutsOutputReference;
    putTimeouts(value: GoogleFirebaseAndroidAppTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleFirebaseAndroidAppTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
