/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleGkeHubNamespaceConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_gke_hub_namespace#id GoogleGkeHubNamespace#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Labels for this Namespace.
    *
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_gke_hub_namespace#labels GoogleGkeHubNamespace#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * Namespace-level cluster namespace labels. These labels are applied
    * to the related namespace of the member clusters bound to the parent
    * Scope. Scope-level labels ('namespace_labels' in the Fleet Scope
    * resource) take precedence over Namespace-level labels if they share
    * a key. Keys and values must be Kubernetes-conformant.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_gke_hub_namespace#namespace_labels GoogleGkeHubNamespace#namespace_labels}
    */
    readonly namespaceLabels?: {
        [key: string]: string;
    };
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_gke_hub_namespace#project GoogleGkeHubNamespace#project}
    */
    readonly project?: string;
    /**
    * The name of the Scope instance.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_gke_hub_namespace#scope GoogleGkeHubNamespace#scope}
    */
    readonly scope: string;
    /**
    * Id of the scope
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_gke_hub_namespace#scope_id GoogleGkeHubNamespace#scope_id}
    */
    readonly scopeId: string;
    /**
    * The client-provided identifier of the namespace.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_gke_hub_namespace#scope_namespace_id GoogleGkeHubNamespace#scope_namespace_id}
    */
    readonly scopeNamespaceId: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_gke_hub_namespace#timeouts GoogleGkeHubNamespace#timeouts}
    */
    readonly timeouts?: GoogleGkeHubNamespaceTimeouts;
}
export interface GoogleGkeHubNamespaceState {
}
export declare function googleGkeHubNamespaceStateToTerraform(struct?: GoogleGkeHubNamespaceState): any;
export declare function googleGkeHubNamespaceStateToHclTerraform(struct?: GoogleGkeHubNamespaceState): any;
export declare class GoogleGkeHubNamespaceStateOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleGkeHubNamespaceState | undefined;
    set internalValue(value: GoogleGkeHubNamespaceState | undefined);
    get code(): string;
}
export declare class GoogleGkeHubNamespaceStateList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleGkeHubNamespaceStateOutputReference;
}
export interface GoogleGkeHubNamespaceTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_gke_hub_namespace#create GoogleGkeHubNamespace#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_gke_hub_namespace#delete GoogleGkeHubNamespace#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_gke_hub_namespace#update GoogleGkeHubNamespace#update}
    */
    readonly update?: string;
}
export declare function googleGkeHubNamespaceTimeoutsToTerraform(struct?: GoogleGkeHubNamespaceTimeouts | cdktf.IResolvable): any;
export declare function googleGkeHubNamespaceTimeoutsToHclTerraform(struct?: GoogleGkeHubNamespaceTimeouts | cdktf.IResolvable): any;
export declare class GoogleGkeHubNamespaceTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleGkeHubNamespaceTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleGkeHubNamespaceTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_gke_hub_namespace google_gke_hub_namespace}
*/
export declare class GoogleGkeHubNamespace extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_gke_hub_namespace";
    /**
    * Generates CDKTF code for importing a GoogleGkeHubNamespace resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleGkeHubNamespace to import
    * @param importFromId The id of the existing GoogleGkeHubNamespace that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_gke_hub_namespace#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleGkeHubNamespace to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_gke_hub_namespace google_gke_hub_namespace} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleGkeHubNamespaceConfig
    */
    constructor(scope: Construct, id: string, config: GoogleGkeHubNamespaceConfig);
    get createTime(): string;
    get deleteTime(): string;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    get name(): string;
    private _namespaceLabels?;
    get namespaceLabels(): {
        [key: string]: string;
    };
    set namespaceLabels(value: {
        [key: string]: string;
    });
    resetNamespaceLabels(): void;
    get namespaceLabelsInput(): {
        [key: string]: string;
    } | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _scope?;
    get scope(): string;
    set scope(value: string);
    get scopeInput(): string | undefined;
    private _scopeId?;
    get scopeId(): string;
    set scopeId(value: string);
    get scopeIdInput(): string | undefined;
    private _scopeNamespaceId?;
    get scopeNamespaceId(): string;
    set scopeNamespaceId(value: string);
    get scopeNamespaceIdInput(): string | undefined;
    private _state;
    get state(): GoogleGkeHubNamespaceStateList;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    get uid(): string;
    get updateTime(): string;
    private _timeouts;
    get timeouts(): GoogleGkeHubNamespaceTimeoutsOutputReference;
    putTimeouts(value: GoogleGkeHubNamespaceTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleGkeHubNamespaceTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
