/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleHealthcarePipelineJobConfig extends cdktf.TerraformMetaArguments {
    /**
    * Healthcare Dataset under which the Pipeline Job is to run
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_healthcare_pipeline_job#dataset GoogleHealthcarePipelineJob#dataset}
    */
    readonly dataset: string;
    /**
    * If true, disables writing lineage for the pipeline.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_healthcare_pipeline_job#disable_lineage GoogleHealthcarePipelineJob#disable_lineage}
    */
    readonly disableLineage?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_healthcare_pipeline_job#id GoogleHealthcarePipelineJob#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * User-supplied key-value pairs used to organize Pipeline Jobs.
    * Label keys must be between 1 and 63 characters long, have a UTF-8 encoding of
    * maximum 128 bytes, and must conform to the following PCRE regular expression:
    * [\p{Ll}\p{Lo}][\p{Ll}\p{Lo}\p{N}_-]{0,62}
    * Label values are optional, must be between 1 and 63 characters long, have a
    * UTF-8 encoding of maximum 128 bytes, and must conform to the following PCRE
    * regular expression: [\p{Ll}\p{Lo}\p{N}_-]{0,63}
    * No more than 64 labels can be associated with a given pipeline.
    * An object containing a list of "key": value pairs.
    * Example: { "name": "wrench", "mass": "1.3kg", "count": "3" }.
    *
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_healthcare_pipeline_job#labels GoogleHealthcarePipelineJob#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * Location where the Pipeline Job is to run
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_healthcare_pipeline_job#location GoogleHealthcarePipelineJob#location}
    */
    readonly location: string;
    /**
    * Specifies the name of the pipeline job. This field is user-assigned.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_healthcare_pipeline_job#name GoogleHealthcarePipelineJob#name}
    */
    readonly name: string;
    /**
    * backfill_pipeline_job block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_healthcare_pipeline_job#backfill_pipeline_job GoogleHealthcarePipelineJob#backfill_pipeline_job}
    */
    readonly backfillPipelineJob?: GoogleHealthcarePipelineJobBackfillPipelineJob;
    /**
    * mapping_pipeline_job block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_healthcare_pipeline_job#mapping_pipeline_job GoogleHealthcarePipelineJob#mapping_pipeline_job}
    */
    readonly mappingPipelineJob?: GoogleHealthcarePipelineJobMappingPipelineJob;
    /**
    * reconciliation_pipeline_job block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_healthcare_pipeline_job#reconciliation_pipeline_job GoogleHealthcarePipelineJob#reconciliation_pipeline_job}
    */
    readonly reconciliationPipelineJob?: GoogleHealthcarePipelineJobReconciliationPipelineJob;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_healthcare_pipeline_job#timeouts GoogleHealthcarePipelineJob#timeouts}
    */
    readonly timeouts?: GoogleHealthcarePipelineJobTimeouts;
}
export interface GoogleHealthcarePipelineJobBackfillPipelineJob {
    /**
    * Specifies the mapping pipeline job to backfill, the name format
    * should follow: projects/{projectId}/locations/{locationId}/datasets/{datasetId}/pipelineJobs/{pipelineJobId}.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_healthcare_pipeline_job#mapping_pipeline_job GoogleHealthcarePipelineJob#mapping_pipeline_job}
    */
    readonly mappingPipelineJob?: string;
}
export declare function googleHealthcarePipelineJobBackfillPipelineJobToTerraform(struct?: GoogleHealthcarePipelineJobBackfillPipelineJobOutputReference | GoogleHealthcarePipelineJobBackfillPipelineJob): any;
export declare function googleHealthcarePipelineJobBackfillPipelineJobToHclTerraform(struct?: GoogleHealthcarePipelineJobBackfillPipelineJobOutputReference | GoogleHealthcarePipelineJobBackfillPipelineJob): any;
export declare class GoogleHealthcarePipelineJobBackfillPipelineJobOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleHealthcarePipelineJobBackfillPipelineJob | undefined;
    set internalValue(value: GoogleHealthcarePipelineJobBackfillPipelineJob | undefined);
    private _mappingPipelineJob?;
    get mappingPipelineJob(): string;
    set mappingPipelineJob(value: string);
    resetMappingPipelineJob(): void;
    get mappingPipelineJobInput(): string | undefined;
}
export interface GoogleHealthcarePipelineJobMappingPipelineJobFhirStreamingSource {
    /**
    * Describes the streaming FHIR data source.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_healthcare_pipeline_job#description GoogleHealthcarePipelineJob#description}
    */
    readonly description?: string;
    /**
    * The path to the FHIR store in the format projects/{projectId}/locations/{locationId}/datasets/{datasetId}/fhirStores/{fhirStoreId}.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_healthcare_pipeline_job#fhir_store GoogleHealthcarePipelineJob#fhir_store}
    */
    readonly fhirStore: string;
}
export declare function googleHealthcarePipelineJobMappingPipelineJobFhirStreamingSourceToTerraform(struct?: GoogleHealthcarePipelineJobMappingPipelineJobFhirStreamingSourceOutputReference | GoogleHealthcarePipelineJobMappingPipelineJobFhirStreamingSource): any;
export declare function googleHealthcarePipelineJobMappingPipelineJobFhirStreamingSourceToHclTerraform(struct?: GoogleHealthcarePipelineJobMappingPipelineJobFhirStreamingSourceOutputReference | GoogleHealthcarePipelineJobMappingPipelineJobFhirStreamingSource): any;
export declare class GoogleHealthcarePipelineJobMappingPipelineJobFhirStreamingSourceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleHealthcarePipelineJobMappingPipelineJobFhirStreamingSource | undefined;
    set internalValue(value: GoogleHealthcarePipelineJobMappingPipelineJobFhirStreamingSource | undefined);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _fhirStore?;
    get fhirStore(): string;
    set fhirStore(value: string);
    get fhirStoreInput(): string | undefined;
}
export interface GoogleHealthcarePipelineJobMappingPipelineJobMappingConfigWhistleConfigSource {
    /**
    * Directory path where all the Whistle files are located.
    * Example: gs://{bucket-id}/{path/to/import-root/dir}
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_healthcare_pipeline_job#import_uri_prefix GoogleHealthcarePipelineJob#import_uri_prefix}
    */
    readonly importUriPrefix: string;
    /**
    * Main configuration file which has the entrypoint or the root function.
    * Example: gs://{bucket-id}/{path/to/import-root/dir}/entrypoint-file-name.wstl.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_healthcare_pipeline_job#uri GoogleHealthcarePipelineJob#uri}
    */
    readonly uri: string;
}
export declare function googleHealthcarePipelineJobMappingPipelineJobMappingConfigWhistleConfigSourceToTerraform(struct?: GoogleHealthcarePipelineJobMappingPipelineJobMappingConfigWhistleConfigSourceOutputReference | GoogleHealthcarePipelineJobMappingPipelineJobMappingConfigWhistleConfigSource): any;
export declare function googleHealthcarePipelineJobMappingPipelineJobMappingConfigWhistleConfigSourceToHclTerraform(struct?: GoogleHealthcarePipelineJobMappingPipelineJobMappingConfigWhistleConfigSourceOutputReference | GoogleHealthcarePipelineJobMappingPipelineJobMappingConfigWhistleConfigSource): any;
export declare class GoogleHealthcarePipelineJobMappingPipelineJobMappingConfigWhistleConfigSourceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleHealthcarePipelineJobMappingPipelineJobMappingConfigWhistleConfigSource | undefined;
    set internalValue(value: GoogleHealthcarePipelineJobMappingPipelineJobMappingConfigWhistleConfigSource | undefined);
    private _importUriPrefix?;
    get importUriPrefix(): string;
    set importUriPrefix(value: string);
    get importUriPrefixInput(): string | undefined;
    private _uri?;
    get uri(): string;
    set uri(value: string);
    get uriInput(): string | undefined;
}
export interface GoogleHealthcarePipelineJobMappingPipelineJobMappingConfig {
    /**
    * Describes the mapping configuration.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_healthcare_pipeline_job#description GoogleHealthcarePipelineJob#description}
    */
    readonly description?: string;
    /**
    * whistle_config_source block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_healthcare_pipeline_job#whistle_config_source GoogleHealthcarePipelineJob#whistle_config_source}
    */
    readonly whistleConfigSource?: GoogleHealthcarePipelineJobMappingPipelineJobMappingConfigWhistleConfigSource;
}
export declare function googleHealthcarePipelineJobMappingPipelineJobMappingConfigToTerraform(struct?: GoogleHealthcarePipelineJobMappingPipelineJobMappingConfigOutputReference | GoogleHealthcarePipelineJobMappingPipelineJobMappingConfig): any;
export declare function googleHealthcarePipelineJobMappingPipelineJobMappingConfigToHclTerraform(struct?: GoogleHealthcarePipelineJobMappingPipelineJobMappingConfigOutputReference | GoogleHealthcarePipelineJobMappingPipelineJobMappingConfig): any;
export declare class GoogleHealthcarePipelineJobMappingPipelineJobMappingConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleHealthcarePipelineJobMappingPipelineJobMappingConfig | undefined;
    set internalValue(value: GoogleHealthcarePipelineJobMappingPipelineJobMappingConfig | undefined);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _whistleConfigSource;
    get whistleConfigSource(): GoogleHealthcarePipelineJobMappingPipelineJobMappingConfigWhistleConfigSourceOutputReference;
    putWhistleConfigSource(value: GoogleHealthcarePipelineJobMappingPipelineJobMappingConfigWhistleConfigSource): void;
    resetWhistleConfigSource(): void;
    get whistleConfigSourceInput(): GoogleHealthcarePipelineJobMappingPipelineJobMappingConfigWhistleConfigSource | undefined;
}
export interface GoogleHealthcarePipelineJobMappingPipelineJob {
    /**
    * If set, the mapping pipeline will write snapshots to this
    * FHIR store without assigning stable IDs. You must
    * grant your pipeline project's Cloud Healthcare Service
    * Agent serviceaccount healthcare.fhirResources.executeBundle
    * and healthcare.fhirResources.create permissions on the
    * destination store. The destination store must set
    * [disableReferentialIntegrity][FhirStore.disable_referential_integrity]
    * to true. The destination store must use FHIR version R4.
    * Format: project/{projectID}/locations/{locationID}/datasets/{datasetName}/fhirStores/{fhirStoreID}.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_healthcare_pipeline_job#fhir_store_destination GoogleHealthcarePipelineJob#fhir_store_destination}
    */
    readonly fhirStoreDestination?: string;
    /**
    * If set to true, a mapping pipeline will send output snapshots
    * to the reconciliation pipeline in its dataset. A reconciliation
    * pipeline must exist in this dataset before a mapping pipeline
    * with a reconciliation destination can be created.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_healthcare_pipeline_job#reconciliation_destination GoogleHealthcarePipelineJob#reconciliation_destination}
    */
    readonly reconciliationDestination?: boolean | cdktf.IResolvable;
    /**
    * fhir_streaming_source block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_healthcare_pipeline_job#fhir_streaming_source GoogleHealthcarePipelineJob#fhir_streaming_source}
    */
    readonly fhirStreamingSource?: GoogleHealthcarePipelineJobMappingPipelineJobFhirStreamingSource;
    /**
    * mapping_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_healthcare_pipeline_job#mapping_config GoogleHealthcarePipelineJob#mapping_config}
    */
    readonly mappingConfig: GoogleHealthcarePipelineJobMappingPipelineJobMappingConfig;
}
export declare function googleHealthcarePipelineJobMappingPipelineJobToTerraform(struct?: GoogleHealthcarePipelineJobMappingPipelineJobOutputReference | GoogleHealthcarePipelineJobMappingPipelineJob): any;
export declare function googleHealthcarePipelineJobMappingPipelineJobToHclTerraform(struct?: GoogleHealthcarePipelineJobMappingPipelineJobOutputReference | GoogleHealthcarePipelineJobMappingPipelineJob): any;
export declare class GoogleHealthcarePipelineJobMappingPipelineJobOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleHealthcarePipelineJobMappingPipelineJob | undefined;
    set internalValue(value: GoogleHealthcarePipelineJobMappingPipelineJob | undefined);
    private _fhirStoreDestination?;
    get fhirStoreDestination(): string;
    set fhirStoreDestination(value: string);
    resetFhirStoreDestination(): void;
    get fhirStoreDestinationInput(): string | undefined;
    private _reconciliationDestination?;
    get reconciliationDestination(): boolean | cdktf.IResolvable;
    set reconciliationDestination(value: boolean | cdktf.IResolvable);
    resetReconciliationDestination(): void;
    get reconciliationDestinationInput(): boolean | cdktf.IResolvable | undefined;
    private _fhirStreamingSource;
    get fhirStreamingSource(): GoogleHealthcarePipelineJobMappingPipelineJobFhirStreamingSourceOutputReference;
    putFhirStreamingSource(value: GoogleHealthcarePipelineJobMappingPipelineJobFhirStreamingSource): void;
    resetFhirStreamingSource(): void;
    get fhirStreamingSourceInput(): GoogleHealthcarePipelineJobMappingPipelineJobFhirStreamingSource | undefined;
    private _mappingConfig;
    get mappingConfig(): GoogleHealthcarePipelineJobMappingPipelineJobMappingConfigOutputReference;
    putMappingConfig(value: GoogleHealthcarePipelineJobMappingPipelineJobMappingConfig): void;
    get mappingConfigInput(): GoogleHealthcarePipelineJobMappingPipelineJobMappingConfig | undefined;
}
export interface GoogleHealthcarePipelineJobReconciliationPipelineJobMergeConfigWhistleConfigSource {
    /**
    * Directory path where all the Whistle files are located.
    * Example: gs://{bucket-id}/{path/to/import-root/dir}
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_healthcare_pipeline_job#import_uri_prefix GoogleHealthcarePipelineJob#import_uri_prefix}
    */
    readonly importUriPrefix: string;
    /**
    * Main configuration file which has the entrypoint or the root function.
    * Example: gs://{bucket-id}/{path/to/import-root/dir}/entrypoint-file-name.wstl.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_healthcare_pipeline_job#uri GoogleHealthcarePipelineJob#uri}
    */
    readonly uri: string;
}
export declare function googleHealthcarePipelineJobReconciliationPipelineJobMergeConfigWhistleConfigSourceToTerraform(struct?: GoogleHealthcarePipelineJobReconciliationPipelineJobMergeConfigWhistleConfigSourceOutputReference | GoogleHealthcarePipelineJobReconciliationPipelineJobMergeConfigWhistleConfigSource): any;
export declare function googleHealthcarePipelineJobReconciliationPipelineJobMergeConfigWhistleConfigSourceToHclTerraform(struct?: GoogleHealthcarePipelineJobReconciliationPipelineJobMergeConfigWhistleConfigSourceOutputReference | GoogleHealthcarePipelineJobReconciliationPipelineJobMergeConfigWhistleConfigSource): any;
export declare class GoogleHealthcarePipelineJobReconciliationPipelineJobMergeConfigWhistleConfigSourceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleHealthcarePipelineJobReconciliationPipelineJobMergeConfigWhistleConfigSource | undefined;
    set internalValue(value: GoogleHealthcarePipelineJobReconciliationPipelineJobMergeConfigWhistleConfigSource | undefined);
    private _importUriPrefix?;
    get importUriPrefix(): string;
    set importUriPrefix(value: string);
    get importUriPrefixInput(): string | undefined;
    private _uri?;
    get uri(): string;
    set uri(value: string);
    get uriInput(): string | undefined;
}
export interface GoogleHealthcarePipelineJobReconciliationPipelineJobMergeConfig {
    /**
    * Describes the mapping configuration.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_healthcare_pipeline_job#description GoogleHealthcarePipelineJob#description}
    */
    readonly description?: string;
    /**
    * whistle_config_source block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_healthcare_pipeline_job#whistle_config_source GoogleHealthcarePipelineJob#whistle_config_source}
    */
    readonly whistleConfigSource: GoogleHealthcarePipelineJobReconciliationPipelineJobMergeConfigWhistleConfigSource;
}
export declare function googleHealthcarePipelineJobReconciliationPipelineJobMergeConfigToTerraform(struct?: GoogleHealthcarePipelineJobReconciliationPipelineJobMergeConfigOutputReference | GoogleHealthcarePipelineJobReconciliationPipelineJobMergeConfig): any;
export declare function googleHealthcarePipelineJobReconciliationPipelineJobMergeConfigToHclTerraform(struct?: GoogleHealthcarePipelineJobReconciliationPipelineJobMergeConfigOutputReference | GoogleHealthcarePipelineJobReconciliationPipelineJobMergeConfig): any;
export declare class GoogleHealthcarePipelineJobReconciliationPipelineJobMergeConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleHealthcarePipelineJobReconciliationPipelineJobMergeConfig | undefined;
    set internalValue(value: GoogleHealthcarePipelineJobReconciliationPipelineJobMergeConfig | undefined);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _whistleConfigSource;
    get whistleConfigSource(): GoogleHealthcarePipelineJobReconciliationPipelineJobMergeConfigWhistleConfigSourceOutputReference;
    putWhistleConfigSource(value: GoogleHealthcarePipelineJobReconciliationPipelineJobMergeConfigWhistleConfigSource): void;
    get whistleConfigSourceInput(): GoogleHealthcarePipelineJobReconciliationPipelineJobMergeConfigWhistleConfigSource | undefined;
}
export interface GoogleHealthcarePipelineJobReconciliationPipelineJob {
    /**
    * The harmonized FHIR store to write harmonized FHIR resources to,
    * in the format of: project/{projectID}/locations/{locationID}/datasets/{datasetName}/fhirStores/{id}
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_healthcare_pipeline_job#fhir_store_destination GoogleHealthcarePipelineJob#fhir_store_destination}
    */
    readonly fhirStoreDestination?: string;
    /**
    * Specifies the top level directory of the matching configs used
    * in all mapping pipelines, which extract properties for resources
    * to be matched on.
    * Example: gs://{bucket-id}/{path/to/matching/configs}
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_healthcare_pipeline_job#matching_uri_prefix GoogleHealthcarePipelineJob#matching_uri_prefix}
    */
    readonly matchingUriPrefix: string;
    /**
    * merge_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_healthcare_pipeline_job#merge_config GoogleHealthcarePipelineJob#merge_config}
    */
    readonly mergeConfig: GoogleHealthcarePipelineJobReconciliationPipelineJobMergeConfig;
}
export declare function googleHealthcarePipelineJobReconciliationPipelineJobToTerraform(struct?: GoogleHealthcarePipelineJobReconciliationPipelineJobOutputReference | GoogleHealthcarePipelineJobReconciliationPipelineJob): any;
export declare function googleHealthcarePipelineJobReconciliationPipelineJobToHclTerraform(struct?: GoogleHealthcarePipelineJobReconciliationPipelineJobOutputReference | GoogleHealthcarePipelineJobReconciliationPipelineJob): any;
export declare class GoogleHealthcarePipelineJobReconciliationPipelineJobOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleHealthcarePipelineJobReconciliationPipelineJob | undefined;
    set internalValue(value: GoogleHealthcarePipelineJobReconciliationPipelineJob | undefined);
    private _fhirStoreDestination?;
    get fhirStoreDestination(): string;
    set fhirStoreDestination(value: string);
    resetFhirStoreDestination(): void;
    get fhirStoreDestinationInput(): string | undefined;
    private _matchingUriPrefix?;
    get matchingUriPrefix(): string;
    set matchingUriPrefix(value: string);
    get matchingUriPrefixInput(): string | undefined;
    private _mergeConfig;
    get mergeConfig(): GoogleHealthcarePipelineJobReconciliationPipelineJobMergeConfigOutputReference;
    putMergeConfig(value: GoogleHealthcarePipelineJobReconciliationPipelineJobMergeConfig): void;
    get mergeConfigInput(): GoogleHealthcarePipelineJobReconciliationPipelineJobMergeConfig | undefined;
}
export interface GoogleHealthcarePipelineJobTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_healthcare_pipeline_job#create GoogleHealthcarePipelineJob#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_healthcare_pipeline_job#delete GoogleHealthcarePipelineJob#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_healthcare_pipeline_job#update GoogleHealthcarePipelineJob#update}
    */
    readonly update?: string;
}
export declare function googleHealthcarePipelineJobTimeoutsToTerraform(struct?: GoogleHealthcarePipelineJobTimeouts | cdktf.IResolvable): any;
export declare function googleHealthcarePipelineJobTimeoutsToHclTerraform(struct?: GoogleHealthcarePipelineJobTimeouts | cdktf.IResolvable): any;
export declare class GoogleHealthcarePipelineJobTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleHealthcarePipelineJobTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleHealthcarePipelineJobTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_healthcare_pipeline_job google_healthcare_pipeline_job}
*/
export declare class GoogleHealthcarePipelineJob extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_healthcare_pipeline_job";
    /**
    * Generates CDKTF code for importing a GoogleHealthcarePipelineJob resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleHealthcarePipelineJob to import
    * @param importFromId The id of the existing GoogleHealthcarePipelineJob that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_healthcare_pipeline_job#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleHealthcarePipelineJob to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_healthcare_pipeline_job google_healthcare_pipeline_job} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleHealthcarePipelineJobConfig
    */
    constructor(scope: Construct, id: string, config: GoogleHealthcarePipelineJobConfig);
    private _dataset?;
    get dataset(): string;
    set dataset(value: string);
    get datasetInput(): string | undefined;
    private _disableLineage?;
    get disableLineage(): boolean | cdktf.IResolvable;
    set disableLineage(value: boolean | cdktf.IResolvable);
    resetDisableLineage(): void;
    get disableLineageInput(): boolean | cdktf.IResolvable | undefined;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    get selfLink(): string;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    private _backfillPipelineJob;
    get backfillPipelineJob(): GoogleHealthcarePipelineJobBackfillPipelineJobOutputReference;
    putBackfillPipelineJob(value: GoogleHealthcarePipelineJobBackfillPipelineJob): void;
    resetBackfillPipelineJob(): void;
    get backfillPipelineJobInput(): GoogleHealthcarePipelineJobBackfillPipelineJob | undefined;
    private _mappingPipelineJob;
    get mappingPipelineJob(): GoogleHealthcarePipelineJobMappingPipelineJobOutputReference;
    putMappingPipelineJob(value: GoogleHealthcarePipelineJobMappingPipelineJob): void;
    resetMappingPipelineJob(): void;
    get mappingPipelineJobInput(): GoogleHealthcarePipelineJobMappingPipelineJob | undefined;
    private _reconciliationPipelineJob;
    get reconciliationPipelineJob(): GoogleHealthcarePipelineJobReconciliationPipelineJobOutputReference;
    putReconciliationPipelineJob(value: GoogleHealthcarePipelineJobReconciliationPipelineJob): void;
    resetReconciliationPipelineJob(): void;
    get reconciliationPipelineJobInput(): GoogleHealthcarePipelineJobReconciliationPipelineJob | undefined;
    private _timeouts;
    get timeouts(): GoogleHealthcarePipelineJobTimeoutsOutputReference;
    putTimeouts(value: GoogleHealthcarePipelineJobTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleHealthcarePipelineJobTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
