/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleIapSettingsConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_iap_settings#id GoogleIapSettings#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The resource name of the IAP protected resource. Name can have below resources:
    * * organizations/{organization_id}
    * * folders/{folder_id}
    * * projects/{projects_id}
    * * projects/{projects_id}/iap_web
    * * projects/{projects_id}/iap_web/compute
    * * projects/{projects_id}/iap_web/compute-{region}
    * * projects/{projects_id}/iap_web/compute/service/{service_id}
    * * projects/{projects_id}/iap_web/compute-{region}/service/{service_id}
    * * projects/{projects_id}/iap_web/appengine-{app_id}
    * * projects/{projects_id}/iap_web/appengine-{app_id}/service/{service_id}
    * * projects/{projects_id}/iap_web/appengine-{app_id}/service/{service_id}/version/{version_id}
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_iap_settings#name GoogleIapSettings#name}
    */
    readonly name: string;
    /**
    * access_settings block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_iap_settings#access_settings GoogleIapSettings#access_settings}
    */
    readonly accessSettings?: GoogleIapSettingsAccessSettings;
    /**
    * application_settings block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_iap_settings#application_settings GoogleIapSettings#application_settings}
    */
    readonly applicationSettings?: GoogleIapSettingsApplicationSettings;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_iap_settings#timeouts GoogleIapSettings#timeouts}
    */
    readonly timeouts?: GoogleIapSettingsTimeouts;
}
export interface GoogleIapSettingsAccessSettingsAllowedDomainsSettings {
    /**
    * List of trusted domains.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_iap_settings#domains GoogleIapSettings#domains}
    */
    readonly domains?: string[];
    /**
    * Configuration for customers to opt in for the feature.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_iap_settings#enable GoogleIapSettings#enable}
    */
    readonly enable?: boolean | cdktf.IResolvable;
}
export declare function googleIapSettingsAccessSettingsAllowedDomainsSettingsToTerraform(struct?: GoogleIapSettingsAccessSettingsAllowedDomainsSettingsOutputReference | GoogleIapSettingsAccessSettingsAllowedDomainsSettings): any;
export declare function googleIapSettingsAccessSettingsAllowedDomainsSettingsToHclTerraform(struct?: GoogleIapSettingsAccessSettingsAllowedDomainsSettingsOutputReference | GoogleIapSettingsAccessSettingsAllowedDomainsSettings): any;
export declare class GoogleIapSettingsAccessSettingsAllowedDomainsSettingsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleIapSettingsAccessSettingsAllowedDomainsSettings | undefined;
    set internalValue(value: GoogleIapSettingsAccessSettingsAllowedDomainsSettings | undefined);
    private _domains?;
    get domains(): string[];
    set domains(value: string[]);
    resetDomains(): void;
    get domainsInput(): string[] | undefined;
    private _enable?;
    get enable(): boolean | cdktf.IResolvable;
    set enable(value: boolean | cdktf.IResolvable);
    resetEnable(): void;
    get enableInput(): boolean | cdktf.IResolvable | undefined;
}
export interface GoogleIapSettingsAccessSettingsCorsSettings {
    /**
    * Configuration to allow HTTP OPTIONS calls to skip authorization.
    * If undefined, IAP will not apply any special logic to OPTIONS requests.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_iap_settings#allow_http_options GoogleIapSettings#allow_http_options}
    */
    readonly allowHttpOptions?: boolean | cdktf.IResolvable;
}
export declare function googleIapSettingsAccessSettingsCorsSettingsToTerraform(struct?: GoogleIapSettingsAccessSettingsCorsSettingsOutputReference | GoogleIapSettingsAccessSettingsCorsSettings): any;
export declare function googleIapSettingsAccessSettingsCorsSettingsToHclTerraform(struct?: GoogleIapSettingsAccessSettingsCorsSettingsOutputReference | GoogleIapSettingsAccessSettingsCorsSettings): any;
export declare class GoogleIapSettingsAccessSettingsCorsSettingsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleIapSettingsAccessSettingsCorsSettings | undefined;
    set internalValue(value: GoogleIapSettingsAccessSettingsCorsSettings | undefined);
    private _allowHttpOptions?;
    get allowHttpOptions(): boolean | cdktf.IResolvable;
    set allowHttpOptions(value: boolean | cdktf.IResolvable);
    resetAllowHttpOptions(): void;
    get allowHttpOptionsInput(): boolean | cdktf.IResolvable | undefined;
}
export interface GoogleIapSettingsAccessSettingsGcipSettings {
    /**
    * Login page URI associated with the GCIP tenants. Typically, all resources within
    * the same project share the same login page, though it could be overridden at the
    * sub resource level.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_iap_settings#login_page_uri GoogleIapSettings#login_page_uri}
    */
    readonly loginPageUri?: string;
    /**
    * GCIP tenant ids that are linked to the IAP resource. tenantIds could be a string
    * beginning with a number character to indicate authenticating with GCIP tenant flow,
    * or in the format of _ to indicate authenticating with GCIP agent flow. If agent flow
    * is used, tenantIds should only contain one single element, while for tenant flow,
    * tenantIds can contain multiple elements.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_iap_settings#tenant_ids GoogleIapSettings#tenant_ids}
    */
    readonly tenantIds?: string[];
}
export declare function googleIapSettingsAccessSettingsGcipSettingsToTerraform(struct?: GoogleIapSettingsAccessSettingsGcipSettingsOutputReference | GoogleIapSettingsAccessSettingsGcipSettings): any;
export declare function googleIapSettingsAccessSettingsGcipSettingsToHclTerraform(struct?: GoogleIapSettingsAccessSettingsGcipSettingsOutputReference | GoogleIapSettingsAccessSettingsGcipSettings): any;
export declare class GoogleIapSettingsAccessSettingsGcipSettingsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleIapSettingsAccessSettingsGcipSettings | undefined;
    set internalValue(value: GoogleIapSettingsAccessSettingsGcipSettings | undefined);
    private _loginPageUri?;
    get loginPageUri(): string;
    set loginPageUri(value: string);
    resetLoginPageUri(): void;
    get loginPageUriInput(): string | undefined;
    private _tenantIds?;
    get tenantIds(): string[];
    set tenantIds(value: string[]);
    resetTenantIds(): void;
    get tenantIdsInput(): string[] | undefined;
}
export interface GoogleIapSettingsAccessSettingsOauthSettings {
    /**
    * Domain hint to send as hd=? parameter in OAuth request flow.
    * Enables redirect to primary IDP by skipping Google's login screen.
    * (https://developers.google.com/identity/protocols/OpenIDConnect#hd-param)
    * Note: IAP does not verify that the id token's hd claim matches this value
    * since access behavior is managed by IAM policies.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_iap_settings#login_hint GoogleIapSettings#login_hint}
    */
    readonly loginHint?: string;
    /**
    * List of client ids allowed to use IAP programmatically.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_iap_settings#programmatic_clients GoogleIapSettings#programmatic_clients}
    */
    readonly programmaticClients?: string[];
}
export declare function googleIapSettingsAccessSettingsOauthSettingsToTerraform(struct?: GoogleIapSettingsAccessSettingsOauthSettingsOutputReference | GoogleIapSettingsAccessSettingsOauthSettings): any;
export declare function googleIapSettingsAccessSettingsOauthSettingsToHclTerraform(struct?: GoogleIapSettingsAccessSettingsOauthSettingsOutputReference | GoogleIapSettingsAccessSettingsOauthSettings): any;
export declare class GoogleIapSettingsAccessSettingsOauthSettingsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleIapSettingsAccessSettingsOauthSettings | undefined;
    set internalValue(value: GoogleIapSettingsAccessSettingsOauthSettings | undefined);
    private _loginHint?;
    get loginHint(): string;
    set loginHint(value: string);
    resetLoginHint(): void;
    get loginHintInput(): string | undefined;
    private _programmaticClients?;
    get programmaticClients(): string[];
    set programmaticClients(value: string[]);
    resetProgrammaticClients(): void;
    get programmaticClientsInput(): string[] | undefined;
}
export interface GoogleIapSettingsAccessSettingsReauthSettings {
    /**
    * Reauth session lifetime, how long before a user has to reauthenticate again.
    * A duration in seconds with up to nine fractional digits, ending with 's'.
    * Example: "3.5s".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_iap_settings#max_age GoogleIapSettings#max_age}
    */
    readonly maxAge: string;
    /**
    * Reauth method requested. The possible values are:
    *
    * * 'LOGIN': Prompts the user to log in again.
    * * 'SECURE_KEY': User must use their secure key 2nd factor device.
    * * 'ENROLLED_SECOND_FACTORS': User can use any enabled 2nd factor. Possible values: ["LOGIN", "SECURE_KEY", "ENROLLED_SECOND_FACTORS"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_iap_settings#method GoogleIapSettings#method}
    */
    readonly method: string;
    /**
    * How IAP determines the effective policy in cases of hierarchical policies.
    * Policies are merged from higher in the hierarchy to lower in the hierarchy.
    * The possible values are:
    *
    * * 'MINIMUM': This policy acts as a minimum to other policies, lower in the hierarchy.
    * 		   Effective policy may only be the same or stricter.
    * * 'DEFAULT': This policy acts as a default if no other reauth policy is set. Possible values: ["MINIMUM", "DEFAULT"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_iap_settings#policy_type GoogleIapSettings#policy_type}
    */
    readonly policyType: string;
}
export declare function googleIapSettingsAccessSettingsReauthSettingsToTerraform(struct?: GoogleIapSettingsAccessSettingsReauthSettingsOutputReference | GoogleIapSettingsAccessSettingsReauthSettings): any;
export declare function googleIapSettingsAccessSettingsReauthSettingsToHclTerraform(struct?: GoogleIapSettingsAccessSettingsReauthSettingsOutputReference | GoogleIapSettingsAccessSettingsReauthSettings): any;
export declare class GoogleIapSettingsAccessSettingsReauthSettingsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleIapSettingsAccessSettingsReauthSettings | undefined;
    set internalValue(value: GoogleIapSettingsAccessSettingsReauthSettings | undefined);
    private _maxAge?;
    get maxAge(): string;
    set maxAge(value: string);
    get maxAgeInput(): string | undefined;
    private _method?;
    get method(): string;
    set method(value: string);
    get methodInput(): string | undefined;
    private _policyType?;
    get policyType(): string;
    set policyType(value: string);
    get policyTypeInput(): string | undefined;
}
export interface GoogleIapSettingsAccessSettingsWorkforceIdentitySettingsOauth2 {
    /**
    * The OAuth 2.0 client ID registered in the workforce identity
    * federation OAuth 2.0 Server.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_iap_settings#client_id GoogleIapSettings#client_id}
    */
    readonly clientId?: string;
    /**
    * Input only. The OAuth 2.0 client secret created while registering
    * the client ID.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_iap_settings#client_secret GoogleIapSettings#client_secret}
    */
    readonly clientSecret?: string;
}
export declare function googleIapSettingsAccessSettingsWorkforceIdentitySettingsOauth2ToTerraform(struct?: GoogleIapSettingsAccessSettingsWorkforceIdentitySettingsOauth2OutputReference | GoogleIapSettingsAccessSettingsWorkforceIdentitySettingsOauth2): any;
export declare function googleIapSettingsAccessSettingsWorkforceIdentitySettingsOauth2ToHclTerraform(struct?: GoogleIapSettingsAccessSettingsWorkforceIdentitySettingsOauth2OutputReference | GoogleIapSettingsAccessSettingsWorkforceIdentitySettingsOauth2): any;
export declare class GoogleIapSettingsAccessSettingsWorkforceIdentitySettingsOauth2OutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleIapSettingsAccessSettingsWorkforceIdentitySettingsOauth2 | undefined;
    set internalValue(value: GoogleIapSettingsAccessSettingsWorkforceIdentitySettingsOauth2 | undefined);
    private _clientId?;
    get clientId(): string;
    set clientId(value: string);
    resetClientId(): void;
    get clientIdInput(): string | undefined;
    private _clientSecret?;
    get clientSecret(): string;
    set clientSecret(value: string);
    resetClientSecret(): void;
    get clientSecretInput(): string | undefined;
    get clientSecretSha256(): string;
}
export interface GoogleIapSettingsAccessSettingsWorkforceIdentitySettings {
    /**
    * The workforce pool resources. Only one workforce pool is accepted.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_iap_settings#workforce_pools GoogleIapSettings#workforce_pools}
    */
    readonly workforcePools?: string[];
    /**
    * oauth2 block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_iap_settings#oauth2 GoogleIapSettings#oauth2}
    */
    readonly oauth2?: GoogleIapSettingsAccessSettingsWorkforceIdentitySettingsOauth2;
}
export declare function googleIapSettingsAccessSettingsWorkforceIdentitySettingsToTerraform(struct?: GoogleIapSettingsAccessSettingsWorkforceIdentitySettingsOutputReference | GoogleIapSettingsAccessSettingsWorkforceIdentitySettings): any;
export declare function googleIapSettingsAccessSettingsWorkforceIdentitySettingsToHclTerraform(struct?: GoogleIapSettingsAccessSettingsWorkforceIdentitySettingsOutputReference | GoogleIapSettingsAccessSettingsWorkforceIdentitySettings): any;
export declare class GoogleIapSettingsAccessSettingsWorkforceIdentitySettingsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleIapSettingsAccessSettingsWorkforceIdentitySettings | undefined;
    set internalValue(value: GoogleIapSettingsAccessSettingsWorkforceIdentitySettings | undefined);
    private _workforcePools?;
    get workforcePools(): string[];
    set workforcePools(value: string[]);
    resetWorkforcePools(): void;
    get workforcePoolsInput(): string[] | undefined;
    private _oauth2;
    get oauth2(): GoogleIapSettingsAccessSettingsWorkforceIdentitySettingsOauth2OutputReference;
    putOauth2(value: GoogleIapSettingsAccessSettingsWorkforceIdentitySettingsOauth2): void;
    resetOauth2(): void;
    get oauth2Input(): GoogleIapSettingsAccessSettingsWorkforceIdentitySettingsOauth2 | undefined;
}
export interface GoogleIapSettingsAccessSettings {
    /**
    * Identity sources that IAP can use to authenticate the end user. Only one identity source
    * can be configured. The possible values are:
    *
    * * 'WORKFORCE_IDENTITY_FEDERATION': Use external identities set up on Google Cloud Workforce
    *   				     Identity Federation. Possible values: ["WORKFORCE_IDENTITY_FEDERATION"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_iap_settings#identity_sources GoogleIapSettings#identity_sources}
    */
    readonly identitySources?: string[];
    /**
    * allowed_domains_settings block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_iap_settings#allowed_domains_settings GoogleIapSettings#allowed_domains_settings}
    */
    readonly allowedDomainsSettings?: GoogleIapSettingsAccessSettingsAllowedDomainsSettings;
    /**
    * cors_settings block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_iap_settings#cors_settings GoogleIapSettings#cors_settings}
    */
    readonly corsSettings?: GoogleIapSettingsAccessSettingsCorsSettings;
    /**
    * gcip_settings block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_iap_settings#gcip_settings GoogleIapSettings#gcip_settings}
    */
    readonly gcipSettings?: GoogleIapSettingsAccessSettingsGcipSettings;
    /**
    * oauth_settings block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_iap_settings#oauth_settings GoogleIapSettings#oauth_settings}
    */
    readonly oauthSettings?: GoogleIapSettingsAccessSettingsOauthSettings;
    /**
    * reauth_settings block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_iap_settings#reauth_settings GoogleIapSettings#reauth_settings}
    */
    readonly reauthSettings?: GoogleIapSettingsAccessSettingsReauthSettings;
    /**
    * workforce_identity_settings block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_iap_settings#workforce_identity_settings GoogleIapSettings#workforce_identity_settings}
    */
    readonly workforceIdentitySettings?: GoogleIapSettingsAccessSettingsWorkforceIdentitySettings;
}
export declare function googleIapSettingsAccessSettingsToTerraform(struct?: GoogleIapSettingsAccessSettingsOutputReference | GoogleIapSettingsAccessSettings): any;
export declare function googleIapSettingsAccessSettingsToHclTerraform(struct?: GoogleIapSettingsAccessSettingsOutputReference | GoogleIapSettingsAccessSettings): any;
export declare class GoogleIapSettingsAccessSettingsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleIapSettingsAccessSettings | undefined;
    set internalValue(value: GoogleIapSettingsAccessSettings | undefined);
    private _identitySources?;
    get identitySources(): string[];
    set identitySources(value: string[]);
    resetIdentitySources(): void;
    get identitySourcesInput(): string[] | undefined;
    private _allowedDomainsSettings;
    get allowedDomainsSettings(): GoogleIapSettingsAccessSettingsAllowedDomainsSettingsOutputReference;
    putAllowedDomainsSettings(value: GoogleIapSettingsAccessSettingsAllowedDomainsSettings): void;
    resetAllowedDomainsSettings(): void;
    get allowedDomainsSettingsInput(): GoogleIapSettingsAccessSettingsAllowedDomainsSettings | undefined;
    private _corsSettings;
    get corsSettings(): GoogleIapSettingsAccessSettingsCorsSettingsOutputReference;
    putCorsSettings(value: GoogleIapSettingsAccessSettingsCorsSettings): void;
    resetCorsSettings(): void;
    get corsSettingsInput(): GoogleIapSettingsAccessSettingsCorsSettings | undefined;
    private _gcipSettings;
    get gcipSettings(): GoogleIapSettingsAccessSettingsGcipSettingsOutputReference;
    putGcipSettings(value: GoogleIapSettingsAccessSettingsGcipSettings): void;
    resetGcipSettings(): void;
    get gcipSettingsInput(): GoogleIapSettingsAccessSettingsGcipSettings | undefined;
    private _oauthSettings;
    get oauthSettings(): GoogleIapSettingsAccessSettingsOauthSettingsOutputReference;
    putOauthSettings(value: GoogleIapSettingsAccessSettingsOauthSettings): void;
    resetOauthSettings(): void;
    get oauthSettingsInput(): GoogleIapSettingsAccessSettingsOauthSettings | undefined;
    private _reauthSettings;
    get reauthSettings(): GoogleIapSettingsAccessSettingsReauthSettingsOutputReference;
    putReauthSettings(value: GoogleIapSettingsAccessSettingsReauthSettings): void;
    resetReauthSettings(): void;
    get reauthSettingsInput(): GoogleIapSettingsAccessSettingsReauthSettings | undefined;
    private _workforceIdentitySettings;
    get workforceIdentitySettings(): GoogleIapSettingsAccessSettingsWorkforceIdentitySettingsOutputReference;
    putWorkforceIdentitySettings(value: GoogleIapSettingsAccessSettingsWorkforceIdentitySettings): void;
    resetWorkforceIdentitySettings(): void;
    get workforceIdentitySettingsInput(): GoogleIapSettingsAccessSettingsWorkforceIdentitySettings | undefined;
}
export interface GoogleIapSettingsApplicationSettingsAccessDeniedPageSettings {
    /**
    * The URI to be redirected to when access is denied.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_iap_settings#access_denied_page_uri GoogleIapSettings#access_denied_page_uri}
    */
    readonly accessDeniedPageUri?: string;
    /**
    * Whether to generate a troubleshooting URL on access denied events to this application.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_iap_settings#generate_troubleshooting_uri GoogleIapSettings#generate_troubleshooting_uri}
    */
    readonly generateTroubleshootingUri?: boolean | cdktf.IResolvable;
    /**
    * Whether to generate remediation token on access denied events to this application.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_iap_settings#remediation_token_generation_enabled GoogleIapSettings#remediation_token_generation_enabled}
    */
    readonly remediationTokenGenerationEnabled?: boolean | cdktf.IResolvable;
}
export declare function googleIapSettingsApplicationSettingsAccessDeniedPageSettingsToTerraform(struct?: GoogleIapSettingsApplicationSettingsAccessDeniedPageSettingsOutputReference | GoogleIapSettingsApplicationSettingsAccessDeniedPageSettings): any;
export declare function googleIapSettingsApplicationSettingsAccessDeniedPageSettingsToHclTerraform(struct?: GoogleIapSettingsApplicationSettingsAccessDeniedPageSettingsOutputReference | GoogleIapSettingsApplicationSettingsAccessDeniedPageSettings): any;
export declare class GoogleIapSettingsApplicationSettingsAccessDeniedPageSettingsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleIapSettingsApplicationSettingsAccessDeniedPageSettings | undefined;
    set internalValue(value: GoogleIapSettingsApplicationSettingsAccessDeniedPageSettings | undefined);
    private _accessDeniedPageUri?;
    get accessDeniedPageUri(): string;
    set accessDeniedPageUri(value: string);
    resetAccessDeniedPageUri(): void;
    get accessDeniedPageUriInput(): string | undefined;
    private _generateTroubleshootingUri?;
    get generateTroubleshootingUri(): boolean | cdktf.IResolvable;
    set generateTroubleshootingUri(value: boolean | cdktf.IResolvable);
    resetGenerateTroubleshootingUri(): void;
    get generateTroubleshootingUriInput(): boolean | cdktf.IResolvable | undefined;
    private _remediationTokenGenerationEnabled?;
    get remediationTokenGenerationEnabled(): boolean | cdktf.IResolvable;
    set remediationTokenGenerationEnabled(value: boolean | cdktf.IResolvable);
    resetRemediationTokenGenerationEnabled(): void;
    get remediationTokenGenerationEnabledInput(): boolean | cdktf.IResolvable | undefined;
}
export interface GoogleIapSettingsApplicationSettingsAttributePropagationSettings {
    /**
    * Whether the provided attribute propagation settings should be evaluated on user requests.
    * If set to true, attributes returned from the expression will be propagated in the set output credentials.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_iap_settings#enable GoogleIapSettings#enable}
    */
    readonly enable?: boolean | cdktf.IResolvable;
    /**
    * Raw string CEL expression. Must return a list of attributes. A maximum of 45 attributes can
    * be selected. Expressions can select different attribute types from attributes:
    * attributes.saml_attributes, attributes.iap_attributes.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_iap_settings#expression GoogleIapSettings#expression}
    */
    readonly expression?: string;
    /**
    * Which output credentials attributes selected by the CEL expression should be propagated in.
    * All attributes will be fully duplicated in each selected output credential.
    * Possible values are:
    *
    * * 'HEADER': Propagate attributes in the headers with "x-goog-iap-attr-" prefix.
    * * 'JWT': Propagate attributes in the JWT of the form:
    *          "additional_claims": { "my_attribute": ["value1", "value2"] }
    * * 'RCTOKEN': Propagate attributes in the RCToken of the form: "
    *              additional_claims": { "my_attribute": ["value1", "value2"] } Possible values: ["HEADER", "JWT", "RCTOKEN"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_iap_settings#output_credentials GoogleIapSettings#output_credentials}
    */
    readonly outputCredentials?: string[];
}
export declare function googleIapSettingsApplicationSettingsAttributePropagationSettingsToTerraform(struct?: GoogleIapSettingsApplicationSettingsAttributePropagationSettingsOutputReference | GoogleIapSettingsApplicationSettingsAttributePropagationSettings): any;
export declare function googleIapSettingsApplicationSettingsAttributePropagationSettingsToHclTerraform(struct?: GoogleIapSettingsApplicationSettingsAttributePropagationSettingsOutputReference | GoogleIapSettingsApplicationSettingsAttributePropagationSettings): any;
export declare class GoogleIapSettingsApplicationSettingsAttributePropagationSettingsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleIapSettingsApplicationSettingsAttributePropagationSettings | undefined;
    set internalValue(value: GoogleIapSettingsApplicationSettingsAttributePropagationSettings | undefined);
    private _enable?;
    get enable(): boolean | cdktf.IResolvable;
    set enable(value: boolean | cdktf.IResolvable);
    resetEnable(): void;
    get enableInput(): boolean | cdktf.IResolvable | undefined;
    private _expression?;
    get expression(): string;
    set expression(value: string);
    resetExpression(): void;
    get expressionInput(): string | undefined;
    private _outputCredentials?;
    get outputCredentials(): string[];
    set outputCredentials(value: string[]);
    resetOutputCredentials(): void;
    get outputCredentialsInput(): string[] | undefined;
}
export interface GoogleIapSettingsApplicationSettingsCsmSettings {
    /**
    * Audience claim set in the generated RCToken. This value is not validated by IAP.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_iap_settings#rctoken_aud GoogleIapSettings#rctoken_aud}
    */
    readonly rctokenAud?: string;
}
export declare function googleIapSettingsApplicationSettingsCsmSettingsToTerraform(struct?: GoogleIapSettingsApplicationSettingsCsmSettingsOutputReference | GoogleIapSettingsApplicationSettingsCsmSettings): any;
export declare function googleIapSettingsApplicationSettingsCsmSettingsToHclTerraform(struct?: GoogleIapSettingsApplicationSettingsCsmSettingsOutputReference | GoogleIapSettingsApplicationSettingsCsmSettings): any;
export declare class GoogleIapSettingsApplicationSettingsCsmSettingsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleIapSettingsApplicationSettingsCsmSettings | undefined;
    set internalValue(value: GoogleIapSettingsApplicationSettingsCsmSettings | undefined);
    private _rctokenAud?;
    get rctokenAud(): string;
    set rctokenAud(value: string);
    resetRctokenAud(): void;
    get rctokenAudInput(): string | undefined;
}
export interface GoogleIapSettingsApplicationSettings {
    /**
    * The Domain value to set for cookies generated by IAP. This value is not validated by the API,
    * but will be ignored at runtime if invalid.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_iap_settings#cookie_domain GoogleIapSettings#cookie_domain}
    */
    readonly cookieDomain?: string;
    /**
    * access_denied_page_settings block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_iap_settings#access_denied_page_settings GoogleIapSettings#access_denied_page_settings}
    */
    readonly accessDeniedPageSettings?: GoogleIapSettingsApplicationSettingsAccessDeniedPageSettings;
    /**
    * attribute_propagation_settings block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_iap_settings#attribute_propagation_settings GoogleIapSettings#attribute_propagation_settings}
    */
    readonly attributePropagationSettings?: GoogleIapSettingsApplicationSettingsAttributePropagationSettings;
    /**
    * csm_settings block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_iap_settings#csm_settings GoogleIapSettings#csm_settings}
    */
    readonly csmSettings?: GoogleIapSettingsApplicationSettingsCsmSettings;
}
export declare function googleIapSettingsApplicationSettingsToTerraform(struct?: GoogleIapSettingsApplicationSettingsOutputReference | GoogleIapSettingsApplicationSettings): any;
export declare function googleIapSettingsApplicationSettingsToHclTerraform(struct?: GoogleIapSettingsApplicationSettingsOutputReference | GoogleIapSettingsApplicationSettings): any;
export declare class GoogleIapSettingsApplicationSettingsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleIapSettingsApplicationSettings | undefined;
    set internalValue(value: GoogleIapSettingsApplicationSettings | undefined);
    private _cookieDomain?;
    get cookieDomain(): string;
    set cookieDomain(value: string);
    resetCookieDomain(): void;
    get cookieDomainInput(): string | undefined;
    private _accessDeniedPageSettings;
    get accessDeniedPageSettings(): GoogleIapSettingsApplicationSettingsAccessDeniedPageSettingsOutputReference;
    putAccessDeniedPageSettings(value: GoogleIapSettingsApplicationSettingsAccessDeniedPageSettings): void;
    resetAccessDeniedPageSettings(): void;
    get accessDeniedPageSettingsInput(): GoogleIapSettingsApplicationSettingsAccessDeniedPageSettings | undefined;
    private _attributePropagationSettings;
    get attributePropagationSettings(): GoogleIapSettingsApplicationSettingsAttributePropagationSettingsOutputReference;
    putAttributePropagationSettings(value: GoogleIapSettingsApplicationSettingsAttributePropagationSettings): void;
    resetAttributePropagationSettings(): void;
    get attributePropagationSettingsInput(): GoogleIapSettingsApplicationSettingsAttributePropagationSettings | undefined;
    private _csmSettings;
    get csmSettings(): GoogleIapSettingsApplicationSettingsCsmSettingsOutputReference;
    putCsmSettings(value: GoogleIapSettingsApplicationSettingsCsmSettings): void;
    resetCsmSettings(): void;
    get csmSettingsInput(): GoogleIapSettingsApplicationSettingsCsmSettings | undefined;
}
export interface GoogleIapSettingsTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_iap_settings#create GoogleIapSettings#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_iap_settings#delete GoogleIapSettings#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_iap_settings#update GoogleIapSettings#update}
    */
    readonly update?: string;
}
export declare function googleIapSettingsTimeoutsToTerraform(struct?: GoogleIapSettingsTimeouts | cdktf.IResolvable): any;
export declare function googleIapSettingsTimeoutsToHclTerraform(struct?: GoogleIapSettingsTimeouts | cdktf.IResolvable): any;
export declare class GoogleIapSettingsTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleIapSettingsTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleIapSettingsTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_iap_settings google_iap_settings}
*/
export declare class GoogleIapSettings extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_iap_settings";
    /**
    * Generates CDKTF code for importing a GoogleIapSettings resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleIapSettings to import
    * @param importFromId The id of the existing GoogleIapSettings that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_iap_settings#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleIapSettings to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_iap_settings google_iap_settings} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleIapSettingsConfig
    */
    constructor(scope: Construct, id: string, config: GoogleIapSettingsConfig);
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _accessSettings;
    get accessSettings(): GoogleIapSettingsAccessSettingsOutputReference;
    putAccessSettings(value: GoogleIapSettingsAccessSettings): void;
    resetAccessSettings(): void;
    get accessSettingsInput(): GoogleIapSettingsAccessSettings | undefined;
    private _applicationSettings;
    get applicationSettings(): GoogleIapSettingsApplicationSettingsOutputReference;
    putApplicationSettings(value: GoogleIapSettingsApplicationSettings): void;
    resetApplicationSettings(): void;
    get applicationSettingsInput(): GoogleIapSettingsApplicationSettings | undefined;
    private _timeouts;
    get timeouts(): GoogleIapSettingsTimeoutsOutputReference;
    putTimeouts(value: GoogleIapSettingsTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleIapSettingsTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
