/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleIntegrationsAuthConfigConfig extends cdktf.TerraformMetaArguments {
    /**
    * A description of the auth config.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#description GoogleIntegrationsAuthConfig#description}
    */
    readonly description?: string;
    /**
    * The name of the auth config.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#display_name GoogleIntegrationsAuthConfig#display_name}
    */
    readonly displayName: string;
    /**
    * User can define the time to receive notification after which the auth config becomes invalid. Support up to 30 days. Support granularity in hours.
    *
    * A duration in seconds with up to nine fractional digits, ending with 's'. Example: "3.5s".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#expiry_notification_duration GoogleIntegrationsAuthConfig#expiry_notification_duration}
    */
    readonly expiryNotificationDuration?: string[];
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#id GoogleIntegrationsAuthConfig#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Location in which client needs to be provisioned.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#location GoogleIntegrationsAuthConfig#location}
    */
    readonly location: string;
    /**
    * User provided expiry time to override. For the example of Salesforce, username/password credentials can be valid for 6 months depending on the instance settings.
    *
    * A timestamp in RFC3339 UTC "Zulu" format, with nanosecond resolution and up to nine fractional digits. Examples: "2014-10-02T15:01:23Z" and "2014-10-02T15:01:23.045123456Z".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#override_valid_time GoogleIntegrationsAuthConfig#override_valid_time}
    */
    readonly overrideValidTime?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#project GoogleIntegrationsAuthConfig#project}
    */
    readonly project?: string;
    /**
    * The visibility of the auth config. Possible values: ["PRIVATE", "CLIENT_VISIBLE"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#visibility GoogleIntegrationsAuthConfig#visibility}
    */
    readonly visibility?: string;
    /**
    * client_certificate block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#client_certificate GoogleIntegrationsAuthConfig#client_certificate}
    */
    readonly clientCertificate?: GoogleIntegrationsAuthConfigClientCertificate;
    /**
    * decrypted_credential block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#decrypted_credential GoogleIntegrationsAuthConfig#decrypted_credential}
    */
    readonly decryptedCredential?: GoogleIntegrationsAuthConfigDecryptedCredential;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#timeouts GoogleIntegrationsAuthConfig#timeouts}
    */
    readonly timeouts?: GoogleIntegrationsAuthConfigTimeouts;
}
export interface GoogleIntegrationsAuthConfigClientCertificate {
    /**
    * The ssl certificate encoded in PEM format. This string must include the begin header and end footer lines.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#encrypted_private_key GoogleIntegrationsAuthConfig#encrypted_private_key}
    */
    readonly encryptedPrivateKey: string;
    /**
    * 'passphrase' should be left unset if private key is not encrypted.
    * Note that 'passphrase' is not the password for web server, but an extra layer of security to protected private key.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#passphrase GoogleIntegrationsAuthConfig#passphrase}
    */
    readonly passphrase?: string;
    /**
    * The ssl certificate encoded in PEM format. This string must include the begin header and end footer lines.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#ssl_certificate GoogleIntegrationsAuthConfig#ssl_certificate}
    */
    readonly sslCertificate: string;
}
export declare function googleIntegrationsAuthConfigClientCertificateToTerraform(struct?: GoogleIntegrationsAuthConfigClientCertificateOutputReference | GoogleIntegrationsAuthConfigClientCertificate): any;
export declare function googleIntegrationsAuthConfigClientCertificateToHclTerraform(struct?: GoogleIntegrationsAuthConfigClientCertificateOutputReference | GoogleIntegrationsAuthConfigClientCertificate): any;
export declare class GoogleIntegrationsAuthConfigClientCertificateOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleIntegrationsAuthConfigClientCertificate | undefined;
    set internalValue(value: GoogleIntegrationsAuthConfigClientCertificate | undefined);
    private _encryptedPrivateKey?;
    get encryptedPrivateKey(): string;
    set encryptedPrivateKey(value: string);
    get encryptedPrivateKeyInput(): string | undefined;
    private _passphrase?;
    get passphrase(): string;
    set passphrase(value: string);
    resetPassphrase(): void;
    get passphraseInput(): string | undefined;
    private _sslCertificate?;
    get sslCertificate(): string;
    set sslCertificate(value: string);
    get sslCertificateInput(): string | undefined;
}
export interface GoogleIntegrationsAuthConfigDecryptedCredentialAuthToken {
    /**
    * The token for the auth type.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#token GoogleIntegrationsAuthConfig#token}
    */
    readonly token?: string;
    /**
    * Authentication type, e.g. "Basic", "Bearer", etc.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#type GoogleIntegrationsAuthConfig#type}
    */
    readonly type?: string;
}
export declare function googleIntegrationsAuthConfigDecryptedCredentialAuthTokenToTerraform(struct?: GoogleIntegrationsAuthConfigDecryptedCredentialAuthTokenOutputReference | GoogleIntegrationsAuthConfigDecryptedCredentialAuthToken): any;
export declare function googleIntegrationsAuthConfigDecryptedCredentialAuthTokenToHclTerraform(struct?: GoogleIntegrationsAuthConfigDecryptedCredentialAuthTokenOutputReference | GoogleIntegrationsAuthConfigDecryptedCredentialAuthToken): any;
export declare class GoogleIntegrationsAuthConfigDecryptedCredentialAuthTokenOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleIntegrationsAuthConfigDecryptedCredentialAuthToken | undefined;
    set internalValue(value: GoogleIntegrationsAuthConfigDecryptedCredentialAuthToken | undefined);
    private _token?;
    get token(): string;
    set token(value: string);
    resetToken(): void;
    get tokenInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    resetType(): void;
    get typeInput(): string | undefined;
}
export interface GoogleIntegrationsAuthConfigDecryptedCredentialJwt {
    /**
    * Identifies which algorithm is used to generate the signature.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#jwt_header GoogleIntegrationsAuthConfig#jwt_header}
    */
    readonly jwtHeader?: string;
    /**
    * Contains a set of claims. The JWT specification defines seven Registered Claim Names which are the standard fields commonly included in tokens. Custom claims are usually also included, depending on the purpose of the token.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#jwt_payload GoogleIntegrationsAuthConfig#jwt_payload}
    */
    readonly jwtPayload?: string;
    /**
    * User's pre-shared secret to sign the token.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#secret GoogleIntegrationsAuthConfig#secret}
    */
    readonly secret?: string;
}
export declare function googleIntegrationsAuthConfigDecryptedCredentialJwtToTerraform(struct?: GoogleIntegrationsAuthConfigDecryptedCredentialJwtOutputReference | GoogleIntegrationsAuthConfigDecryptedCredentialJwt): any;
export declare function googleIntegrationsAuthConfigDecryptedCredentialJwtToHclTerraform(struct?: GoogleIntegrationsAuthConfigDecryptedCredentialJwtOutputReference | GoogleIntegrationsAuthConfigDecryptedCredentialJwt): any;
export declare class GoogleIntegrationsAuthConfigDecryptedCredentialJwtOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleIntegrationsAuthConfigDecryptedCredentialJwt | undefined;
    set internalValue(value: GoogleIntegrationsAuthConfigDecryptedCredentialJwt | undefined);
    get jwt(): string;
    private _jwtHeader?;
    get jwtHeader(): string;
    set jwtHeader(value: string);
    resetJwtHeader(): void;
    get jwtHeaderInput(): string | undefined;
    private _jwtPayload?;
    get jwtPayload(): string;
    set jwtPayload(value: string);
    resetJwtPayload(): void;
    get jwtPayloadInput(): string | undefined;
    private _secret?;
    get secret(): string;
    set secret(value: string);
    resetSecret(): void;
    get secretInput(): string | undefined;
}
export interface GoogleIntegrationsAuthConfigDecryptedCredentialOauth2AuthorizationCode {
    /**
    * The auth url endpoint to send the auth code request to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#auth_endpoint GoogleIntegrationsAuthConfig#auth_endpoint}
    */
    readonly authEndpoint?: string;
    /**
    * The client's id.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#client_id GoogleIntegrationsAuthConfig#client_id}
    */
    readonly clientId?: string;
    /**
    * The client's secret.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#client_secret GoogleIntegrationsAuthConfig#client_secret}
    */
    readonly clientSecret?: string;
    /**
    * A space-delimited list of requested scope permissions.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#scope GoogleIntegrationsAuthConfig#scope}
    */
    readonly scope?: string;
    /**
    * The token url endpoint to send the token request to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#token_endpoint GoogleIntegrationsAuthConfig#token_endpoint}
    */
    readonly tokenEndpoint?: string;
}
export declare function googleIntegrationsAuthConfigDecryptedCredentialOauth2AuthorizationCodeToTerraform(struct?: GoogleIntegrationsAuthConfigDecryptedCredentialOauth2AuthorizationCodeOutputReference | GoogleIntegrationsAuthConfigDecryptedCredentialOauth2AuthorizationCode): any;
export declare function googleIntegrationsAuthConfigDecryptedCredentialOauth2AuthorizationCodeToHclTerraform(struct?: GoogleIntegrationsAuthConfigDecryptedCredentialOauth2AuthorizationCodeOutputReference | GoogleIntegrationsAuthConfigDecryptedCredentialOauth2AuthorizationCode): any;
export declare class GoogleIntegrationsAuthConfigDecryptedCredentialOauth2AuthorizationCodeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleIntegrationsAuthConfigDecryptedCredentialOauth2AuthorizationCode | undefined;
    set internalValue(value: GoogleIntegrationsAuthConfigDecryptedCredentialOauth2AuthorizationCode | undefined);
    private _authEndpoint?;
    get authEndpoint(): string;
    set authEndpoint(value: string);
    resetAuthEndpoint(): void;
    get authEndpointInput(): string | undefined;
    private _clientId?;
    get clientId(): string;
    set clientId(value: string);
    resetClientId(): void;
    get clientIdInput(): string | undefined;
    private _clientSecret?;
    get clientSecret(): string;
    set clientSecret(value: string);
    resetClientSecret(): void;
    get clientSecretInput(): string | undefined;
    private _scope?;
    get scope(): string;
    set scope(value: string);
    resetScope(): void;
    get scopeInput(): string | undefined;
    private _tokenEndpoint?;
    get tokenEndpoint(): string;
    set tokenEndpoint(value: string);
    resetTokenEndpoint(): void;
    get tokenEndpointInput(): string | undefined;
}
export interface GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesKeyLiteralValue {
    /**
    * String.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#string_value GoogleIntegrationsAuthConfig#string_value}
    */
    readonly stringValue?: string;
}
export declare function googleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesKeyLiteralValueToTerraform(struct?: GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesKeyLiteralValueOutputReference | GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesKeyLiteralValue): any;
export declare function googleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesKeyLiteralValueToHclTerraform(struct?: GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesKeyLiteralValueOutputReference | GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesKeyLiteralValue): any;
export declare class GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesKeyLiteralValueOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesKeyLiteralValue | undefined;
    set internalValue(value: GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesKeyLiteralValue | undefined);
    private _stringValue?;
    get stringValue(): string;
    set stringValue(value: string);
    resetStringValue(): void;
    get stringValueInput(): string | undefined;
}
export interface GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesKey {
    /**
    * literal_value block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#literal_value GoogleIntegrationsAuthConfig#literal_value}
    */
    readonly literalValue?: GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesKeyLiteralValue;
}
export declare function googleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesKeyToTerraform(struct?: GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesKeyOutputReference | GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesKey): any;
export declare function googleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesKeyToHclTerraform(struct?: GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesKeyOutputReference | GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesKey): any;
export declare class GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesKeyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesKey | undefined;
    set internalValue(value: GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesKey | undefined);
    private _literalValue;
    get literalValue(): GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesKeyLiteralValueOutputReference;
    putLiteralValue(value: GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesKeyLiteralValue): void;
    resetLiteralValue(): void;
    get literalValueInput(): GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesKeyLiteralValue | undefined;
}
export interface GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesValueLiteralValue {
    /**
    * String.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#string_value GoogleIntegrationsAuthConfig#string_value}
    */
    readonly stringValue?: string;
}
export declare function googleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesValueLiteralValueToTerraform(struct?: GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesValueLiteralValueOutputReference | GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesValueLiteralValue): any;
export declare function googleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesValueLiteralValueToHclTerraform(struct?: GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesValueLiteralValueOutputReference | GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesValueLiteralValue): any;
export declare class GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesValueLiteralValueOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesValueLiteralValue | undefined;
    set internalValue(value: GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesValueLiteralValue | undefined);
    private _stringValue?;
    get stringValue(): string;
    set stringValue(value: string);
    resetStringValue(): void;
    get stringValueInput(): string | undefined;
}
export interface GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesValue {
    /**
    * literal_value block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#literal_value GoogleIntegrationsAuthConfig#literal_value}
    */
    readonly literalValue?: GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesValueLiteralValue;
}
export declare function googleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesValueToTerraform(struct?: GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesValueOutputReference | GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesValue): any;
export declare function googleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesValueToHclTerraform(struct?: GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesValueOutputReference | GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesValue): any;
export declare class GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesValueOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesValue | undefined;
    set internalValue(value: GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesValue | undefined);
    private _literalValue;
    get literalValue(): GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesValueLiteralValueOutputReference;
    putLiteralValue(value: GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesValueLiteralValue): void;
    resetLiteralValue(): void;
    get literalValueInput(): GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesValueLiteralValue | undefined;
}
export interface GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntries {
    /**
    * key block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#key GoogleIntegrationsAuthConfig#key}
    */
    readonly key?: GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesKey;
    /**
    * value block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#value GoogleIntegrationsAuthConfig#value}
    */
    readonly value?: GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesValue;
}
export declare function googleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesToTerraform(struct?: GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntries | cdktf.IResolvable): any;
export declare function googleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesToHclTerraform(struct?: GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntries | cdktf.IResolvable): any;
export declare class GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntries | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntries | cdktf.IResolvable | undefined);
    private _key;
    get key(): GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesKeyOutputReference;
    putKey(value: GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesKey): void;
    resetKey(): void;
    get keyInput(): GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesKey | undefined;
    private _value;
    get value(): GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesValueOutputReference;
    putValue(value: GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesValue): void;
    resetValue(): void;
    get valueInput(): GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesValue | undefined;
}
export declare class GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntries[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesOutputReference;
}
export interface GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParams {
    /**
    * entries block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#entries GoogleIntegrationsAuthConfig#entries}
    */
    readonly entries?: GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntries[] | cdktf.IResolvable;
}
export declare function googleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsToTerraform(struct?: GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsOutputReference | GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParams): any;
export declare function googleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsToHclTerraform(struct?: GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsOutputReference | GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParams): any;
export declare class GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParams | undefined;
    set internalValue(value: GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParams | undefined);
    private _entries;
    get entries(): GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntriesList;
    putEntries(value: GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntries[] | cdktf.IResolvable): void;
    resetEntries(): void;
    get entriesInput(): cdktf.IResolvable | GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsEntries[] | undefined;
}
export interface GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentials {
    /**
    * The client's ID.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#client_id GoogleIntegrationsAuthConfig#client_id}
    */
    readonly clientId?: string;
    /**
    * The client's secret.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#client_secret GoogleIntegrationsAuthConfig#client_secret}
    */
    readonly clientSecret?: string;
    /**
    * Represent how to pass parameters to fetch access token Possible values: ["REQUEST_TYPE_UNSPECIFIED", "REQUEST_BODY", "QUERY_PARAMETERS", "ENCODED_HEADER"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#request_type GoogleIntegrationsAuthConfig#request_type}
    */
    readonly requestType?: string;
    /**
    * A space-delimited list of requested scope permissions.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#scope GoogleIntegrationsAuthConfig#scope}
    */
    readonly scope?: string;
    /**
    * The token endpoint is used by the client to obtain an access token by presenting its authorization grant or refresh token.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#token_endpoint GoogleIntegrationsAuthConfig#token_endpoint}
    */
    readonly tokenEndpoint?: string;
    /**
    * token_params block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#token_params GoogleIntegrationsAuthConfig#token_params}
    */
    readonly tokenParams?: GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParams;
}
export declare function googleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsToTerraform(struct?: GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsOutputReference | GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentials): any;
export declare function googleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsToHclTerraform(struct?: GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsOutputReference | GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentials): any;
export declare class GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentials | undefined;
    set internalValue(value: GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentials | undefined);
    private _clientId?;
    get clientId(): string;
    set clientId(value: string);
    resetClientId(): void;
    get clientIdInput(): string | undefined;
    private _clientSecret?;
    get clientSecret(): string;
    set clientSecret(value: string);
    resetClientSecret(): void;
    get clientSecretInput(): string | undefined;
    private _requestType?;
    get requestType(): string;
    set requestType(value: string);
    resetRequestType(): void;
    get requestTypeInput(): string | undefined;
    private _scope?;
    get scope(): string;
    set scope(value: string);
    resetScope(): void;
    get scopeInput(): string | undefined;
    private _tokenEndpoint?;
    get tokenEndpoint(): string;
    set tokenEndpoint(value: string);
    resetTokenEndpoint(): void;
    get tokenEndpointInput(): string | undefined;
    private _tokenParams;
    get tokenParams(): GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParamsOutputReference;
    putTokenParams(value: GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParams): void;
    resetTokenParams(): void;
    get tokenParamsInput(): GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsTokenParams | undefined;
}
export interface GoogleIntegrationsAuthConfigDecryptedCredentialOidcToken {
    /**
    * Audience to be used when generating OIDC token. The audience claim identifies the recipients that the JWT is intended for.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#audience GoogleIntegrationsAuthConfig#audience}
    */
    readonly audience?: string;
    /**
    * The service account email to be used as the identity for the token.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#service_account_email GoogleIntegrationsAuthConfig#service_account_email}
    */
    readonly serviceAccountEmail?: string;
}
export declare function googleIntegrationsAuthConfigDecryptedCredentialOidcTokenToTerraform(struct?: GoogleIntegrationsAuthConfigDecryptedCredentialOidcTokenOutputReference | GoogleIntegrationsAuthConfigDecryptedCredentialOidcToken): any;
export declare function googleIntegrationsAuthConfigDecryptedCredentialOidcTokenToHclTerraform(struct?: GoogleIntegrationsAuthConfigDecryptedCredentialOidcTokenOutputReference | GoogleIntegrationsAuthConfigDecryptedCredentialOidcToken): any;
export declare class GoogleIntegrationsAuthConfigDecryptedCredentialOidcTokenOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleIntegrationsAuthConfigDecryptedCredentialOidcToken | undefined;
    set internalValue(value: GoogleIntegrationsAuthConfigDecryptedCredentialOidcToken | undefined);
    private _audience?;
    get audience(): string;
    set audience(value: string);
    resetAudience(): void;
    get audienceInput(): string | undefined;
    private _serviceAccountEmail?;
    get serviceAccountEmail(): string;
    set serviceAccountEmail(value: string);
    resetServiceAccountEmail(): void;
    get serviceAccountEmailInput(): string | undefined;
    get token(): string;
    get tokenExpireTime(): string;
}
export interface GoogleIntegrationsAuthConfigDecryptedCredentialServiceAccountCredentials {
    /**
    * A space-delimited list of requested scope permissions.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#scope GoogleIntegrationsAuthConfig#scope}
    */
    readonly scope?: string;
    /**
    * Name of the service account that has the permission to make the request.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#service_account GoogleIntegrationsAuthConfig#service_account}
    */
    readonly serviceAccount?: string;
}
export declare function googleIntegrationsAuthConfigDecryptedCredentialServiceAccountCredentialsToTerraform(struct?: GoogleIntegrationsAuthConfigDecryptedCredentialServiceAccountCredentialsOutputReference | GoogleIntegrationsAuthConfigDecryptedCredentialServiceAccountCredentials): any;
export declare function googleIntegrationsAuthConfigDecryptedCredentialServiceAccountCredentialsToHclTerraform(struct?: GoogleIntegrationsAuthConfigDecryptedCredentialServiceAccountCredentialsOutputReference | GoogleIntegrationsAuthConfigDecryptedCredentialServiceAccountCredentials): any;
export declare class GoogleIntegrationsAuthConfigDecryptedCredentialServiceAccountCredentialsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleIntegrationsAuthConfigDecryptedCredentialServiceAccountCredentials | undefined;
    set internalValue(value: GoogleIntegrationsAuthConfigDecryptedCredentialServiceAccountCredentials | undefined);
    private _scope?;
    get scope(): string;
    set scope(value: string);
    resetScope(): void;
    get scopeInput(): string | undefined;
    private _serviceAccount?;
    get serviceAccount(): string;
    set serviceAccount(value: string);
    resetServiceAccount(): void;
    get serviceAccountInput(): string | undefined;
}
export interface GoogleIntegrationsAuthConfigDecryptedCredentialUsernameAndPassword {
    /**
    * Password to be used.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#password GoogleIntegrationsAuthConfig#password}
    */
    readonly password?: string;
    /**
    * Username to be used.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#username GoogleIntegrationsAuthConfig#username}
    */
    readonly username?: string;
}
export declare function googleIntegrationsAuthConfigDecryptedCredentialUsernameAndPasswordToTerraform(struct?: GoogleIntegrationsAuthConfigDecryptedCredentialUsernameAndPasswordOutputReference | GoogleIntegrationsAuthConfigDecryptedCredentialUsernameAndPassword): any;
export declare function googleIntegrationsAuthConfigDecryptedCredentialUsernameAndPasswordToHclTerraform(struct?: GoogleIntegrationsAuthConfigDecryptedCredentialUsernameAndPasswordOutputReference | GoogleIntegrationsAuthConfigDecryptedCredentialUsernameAndPassword): any;
export declare class GoogleIntegrationsAuthConfigDecryptedCredentialUsernameAndPasswordOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleIntegrationsAuthConfigDecryptedCredentialUsernameAndPassword | undefined;
    set internalValue(value: GoogleIntegrationsAuthConfigDecryptedCredentialUsernameAndPassword | undefined);
    private _password?;
    get password(): string;
    set password(value: string);
    resetPassword(): void;
    get passwordInput(): string | undefined;
    private _username?;
    get username(): string;
    set username(value: string);
    resetUsername(): void;
    get usernameInput(): string | undefined;
}
export interface GoogleIntegrationsAuthConfigDecryptedCredential {
    /**
    * Credential type associated with auth configs.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#credential_type GoogleIntegrationsAuthConfig#credential_type}
    */
    readonly credentialType: string;
    /**
    * auth_token block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#auth_token GoogleIntegrationsAuthConfig#auth_token}
    */
    readonly authToken?: GoogleIntegrationsAuthConfigDecryptedCredentialAuthToken;
    /**
    * jwt block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#jwt GoogleIntegrationsAuthConfig#jwt}
    */
    readonly jwt?: GoogleIntegrationsAuthConfigDecryptedCredentialJwt;
    /**
    * oauth2_authorization_code block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#oauth2_authorization_code GoogleIntegrationsAuthConfig#oauth2_authorization_code}
    */
    readonly oauth2AuthorizationCode?: GoogleIntegrationsAuthConfigDecryptedCredentialOauth2AuthorizationCode;
    /**
    * oauth2_client_credentials block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#oauth2_client_credentials GoogleIntegrationsAuthConfig#oauth2_client_credentials}
    */
    readonly oauth2ClientCredentials?: GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentials;
    /**
    * oidc_token block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#oidc_token GoogleIntegrationsAuthConfig#oidc_token}
    */
    readonly oidcToken?: GoogleIntegrationsAuthConfigDecryptedCredentialOidcToken;
    /**
    * service_account_credentials block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#service_account_credentials GoogleIntegrationsAuthConfig#service_account_credentials}
    */
    readonly serviceAccountCredentials?: GoogleIntegrationsAuthConfigDecryptedCredentialServiceAccountCredentials;
    /**
    * username_and_password block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#username_and_password GoogleIntegrationsAuthConfig#username_and_password}
    */
    readonly usernameAndPassword?: GoogleIntegrationsAuthConfigDecryptedCredentialUsernameAndPassword;
}
export declare function googleIntegrationsAuthConfigDecryptedCredentialToTerraform(struct?: GoogleIntegrationsAuthConfigDecryptedCredentialOutputReference | GoogleIntegrationsAuthConfigDecryptedCredential): any;
export declare function googleIntegrationsAuthConfigDecryptedCredentialToHclTerraform(struct?: GoogleIntegrationsAuthConfigDecryptedCredentialOutputReference | GoogleIntegrationsAuthConfigDecryptedCredential): any;
export declare class GoogleIntegrationsAuthConfigDecryptedCredentialOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleIntegrationsAuthConfigDecryptedCredential | undefined;
    set internalValue(value: GoogleIntegrationsAuthConfigDecryptedCredential | undefined);
    private _credentialType?;
    get credentialType(): string;
    set credentialType(value: string);
    get credentialTypeInput(): string | undefined;
    private _authToken;
    get authToken(): GoogleIntegrationsAuthConfigDecryptedCredentialAuthTokenOutputReference;
    putAuthToken(value: GoogleIntegrationsAuthConfigDecryptedCredentialAuthToken): void;
    resetAuthToken(): void;
    get authTokenInput(): GoogleIntegrationsAuthConfigDecryptedCredentialAuthToken | undefined;
    private _jwt;
    get jwt(): GoogleIntegrationsAuthConfigDecryptedCredentialJwtOutputReference;
    putJwt(value: GoogleIntegrationsAuthConfigDecryptedCredentialJwt): void;
    resetJwt(): void;
    get jwtInput(): GoogleIntegrationsAuthConfigDecryptedCredentialJwt | undefined;
    private _oauth2AuthorizationCode;
    get oauth2AuthorizationCode(): GoogleIntegrationsAuthConfigDecryptedCredentialOauth2AuthorizationCodeOutputReference;
    putOauth2AuthorizationCode(value: GoogleIntegrationsAuthConfigDecryptedCredentialOauth2AuthorizationCode): void;
    resetOauth2AuthorizationCode(): void;
    get oauth2AuthorizationCodeInput(): GoogleIntegrationsAuthConfigDecryptedCredentialOauth2AuthorizationCode | undefined;
    private _oauth2ClientCredentials;
    get oauth2ClientCredentials(): GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentialsOutputReference;
    putOauth2ClientCredentials(value: GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentials): void;
    resetOauth2ClientCredentials(): void;
    get oauth2ClientCredentialsInput(): GoogleIntegrationsAuthConfigDecryptedCredentialOauth2ClientCredentials | undefined;
    private _oidcToken;
    get oidcToken(): GoogleIntegrationsAuthConfigDecryptedCredentialOidcTokenOutputReference;
    putOidcToken(value: GoogleIntegrationsAuthConfigDecryptedCredentialOidcToken): void;
    resetOidcToken(): void;
    get oidcTokenInput(): GoogleIntegrationsAuthConfigDecryptedCredentialOidcToken | undefined;
    private _serviceAccountCredentials;
    get serviceAccountCredentials(): GoogleIntegrationsAuthConfigDecryptedCredentialServiceAccountCredentialsOutputReference;
    putServiceAccountCredentials(value: GoogleIntegrationsAuthConfigDecryptedCredentialServiceAccountCredentials): void;
    resetServiceAccountCredentials(): void;
    get serviceAccountCredentialsInput(): GoogleIntegrationsAuthConfigDecryptedCredentialServiceAccountCredentials | undefined;
    private _usernameAndPassword;
    get usernameAndPassword(): GoogleIntegrationsAuthConfigDecryptedCredentialUsernameAndPasswordOutputReference;
    putUsernameAndPassword(value: GoogleIntegrationsAuthConfigDecryptedCredentialUsernameAndPassword): void;
    resetUsernameAndPassword(): void;
    get usernameAndPasswordInput(): GoogleIntegrationsAuthConfigDecryptedCredentialUsernameAndPassword | undefined;
}
export interface GoogleIntegrationsAuthConfigTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#create GoogleIntegrationsAuthConfig#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#delete GoogleIntegrationsAuthConfig#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#update GoogleIntegrationsAuthConfig#update}
    */
    readonly update?: string;
}
export declare function googleIntegrationsAuthConfigTimeoutsToTerraform(struct?: GoogleIntegrationsAuthConfigTimeouts | cdktf.IResolvable): any;
export declare function googleIntegrationsAuthConfigTimeoutsToHclTerraform(struct?: GoogleIntegrationsAuthConfigTimeouts | cdktf.IResolvable): any;
export declare class GoogleIntegrationsAuthConfigTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleIntegrationsAuthConfigTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleIntegrationsAuthConfigTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config google_integrations_auth_config}
*/
export declare class GoogleIntegrationsAuthConfig extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_integrations_auth_config";
    /**
    * Generates CDKTF code for importing a GoogleIntegrationsAuthConfig resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleIntegrationsAuthConfig to import
    * @param importFromId The id of the existing GoogleIntegrationsAuthConfig that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleIntegrationsAuthConfig to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_integrations_auth_config google_integrations_auth_config} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleIntegrationsAuthConfigConfig
    */
    constructor(scope: Construct, id: string, config: GoogleIntegrationsAuthConfigConfig);
    get certificateId(): string;
    get createTime(): string;
    get creatorEmail(): string;
    get credentialType(): string;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    get displayNameInput(): string | undefined;
    get encryptedCredential(): string;
    private _expiryNotificationDuration?;
    get expiryNotificationDuration(): string[];
    set expiryNotificationDuration(value: string[]);
    resetExpiryNotificationDuration(): void;
    get expiryNotificationDurationInput(): string[] | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get lastModifierEmail(): string;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    get name(): string;
    private _overrideValidTime?;
    get overrideValidTime(): string;
    set overrideValidTime(value: string);
    resetOverrideValidTime(): void;
    get overrideValidTimeInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    get reason(): string;
    get state(): string;
    get updateTime(): string;
    get validTime(): string;
    private _visibility?;
    get visibility(): string;
    set visibility(value: string);
    resetVisibility(): void;
    get visibilityInput(): string | undefined;
    private _clientCertificate;
    get clientCertificate(): GoogleIntegrationsAuthConfigClientCertificateOutputReference;
    putClientCertificate(value: GoogleIntegrationsAuthConfigClientCertificate): void;
    resetClientCertificate(): void;
    get clientCertificateInput(): GoogleIntegrationsAuthConfigClientCertificate | undefined;
    private _decryptedCredential;
    get decryptedCredential(): GoogleIntegrationsAuthConfigDecryptedCredentialOutputReference;
    putDecryptedCredential(value: GoogleIntegrationsAuthConfigDecryptedCredential): void;
    resetDecryptedCredential(): void;
    get decryptedCredentialInput(): GoogleIntegrationsAuthConfigDecryptedCredential | undefined;
    private _timeouts;
    get timeouts(): GoogleIntegrationsAuthConfigTimeoutsOutputReference;
    putTimeouts(value: GoogleIntegrationsAuthConfigTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleIntegrationsAuthConfigTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
