/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleKmsAutokeyConfigConfig extends cdktf.TerraformMetaArguments {
    /**
    * The folder for which to retrieve config.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_kms_autokey_config#folder GoogleKmsAutokeyConfig#folder}
    */
    readonly folder: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_kms_autokey_config#id GoogleKmsAutokeyConfig#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The target key project for a given folder where KMS Autokey will provision a
    * CryptoKey for any new KeyHandle the Developer creates. Should have the form
    * 'projects/<project_id_or_number>'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_kms_autokey_config#key_project GoogleKmsAutokeyConfig#key_project}
    */
    readonly keyProject?: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_kms_autokey_config#timeouts GoogleKmsAutokeyConfig#timeouts}
    */
    readonly timeouts?: GoogleKmsAutokeyConfigTimeouts;
}
export interface GoogleKmsAutokeyConfigTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_kms_autokey_config#create GoogleKmsAutokeyConfig#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_kms_autokey_config#delete GoogleKmsAutokeyConfig#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_kms_autokey_config#update GoogleKmsAutokeyConfig#update}
    */
    readonly update?: string;
}
export declare function googleKmsAutokeyConfigTimeoutsToTerraform(struct?: GoogleKmsAutokeyConfigTimeouts | cdktf.IResolvable): any;
export declare function googleKmsAutokeyConfigTimeoutsToHclTerraform(struct?: GoogleKmsAutokeyConfigTimeouts | cdktf.IResolvable): any;
export declare class GoogleKmsAutokeyConfigTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleKmsAutokeyConfigTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleKmsAutokeyConfigTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_kms_autokey_config google_kms_autokey_config}
*/
export declare class GoogleKmsAutokeyConfig extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_kms_autokey_config";
    /**
    * Generates CDKTF code for importing a GoogleKmsAutokeyConfig resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleKmsAutokeyConfig to import
    * @param importFromId The id of the existing GoogleKmsAutokeyConfig that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_kms_autokey_config#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleKmsAutokeyConfig to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_kms_autokey_config google_kms_autokey_config} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleKmsAutokeyConfigConfig
    */
    constructor(scope: Construct, id: string, config: GoogleKmsAutokeyConfigConfig);
    private _folder?;
    get folder(): string;
    set folder(value: string);
    get folderInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _keyProject?;
    get keyProject(): string;
    set keyProject(value: string);
    resetKeyProject(): void;
    get keyProjectInput(): string | undefined;
    private _timeouts;
    get timeouts(): GoogleKmsAutokeyConfigTimeoutsOutputReference;
    putTimeouts(value: GoogleKmsAutokeyConfigTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleKmsAutokeyConfigTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
