/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleKmsKeyHandleConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_kms_key_handle#id GoogleKmsKeyHandle#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The location for the KeyHandle.
    * A full list of valid locations can be found by running 'gcloud kms locations list'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_kms_key_handle#location GoogleKmsKeyHandle#location}
    */
    readonly location: string;
    /**
    * The resource name for the KeyHandle.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_kms_key_handle#name GoogleKmsKeyHandle#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_kms_key_handle#project GoogleKmsKeyHandle#project}
    */
    readonly project?: string;
    /**
    * Selector of the resource type where we want to protect resources.
    * For example, 'storage.googleapis.com/Bucket'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_kms_key_handle#resource_type_selector GoogleKmsKeyHandle#resource_type_selector}
    */
    readonly resourceTypeSelector: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_kms_key_handle#timeouts GoogleKmsKeyHandle#timeouts}
    */
    readonly timeouts?: GoogleKmsKeyHandleTimeouts;
}
export interface GoogleKmsKeyHandleTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_kms_key_handle#create GoogleKmsKeyHandle#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_kms_key_handle#delete GoogleKmsKeyHandle#delete}
    */
    readonly delete?: string;
}
export declare function googleKmsKeyHandleTimeoutsToTerraform(struct?: GoogleKmsKeyHandleTimeouts | cdktf.IResolvable): any;
export declare function googleKmsKeyHandleTimeoutsToHclTerraform(struct?: GoogleKmsKeyHandleTimeouts | cdktf.IResolvable): any;
export declare class GoogleKmsKeyHandleTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleKmsKeyHandleTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleKmsKeyHandleTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_kms_key_handle google_kms_key_handle}
*/
export declare class GoogleKmsKeyHandle extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_kms_key_handle";
    /**
    * Generates CDKTF code for importing a GoogleKmsKeyHandle resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleKmsKeyHandle to import
    * @param importFromId The id of the existing GoogleKmsKeyHandle that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_kms_key_handle#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleKmsKeyHandle to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_kms_key_handle google_kms_key_handle} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleKmsKeyHandleConfig
    */
    constructor(scope: Construct, id: string, config: GoogleKmsKeyHandleConfig);
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get kmsKey(): string;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _resourceTypeSelector?;
    get resourceTypeSelector(): string;
    set resourceTypeSelector(value: string);
    get resourceTypeSelectorInput(): string | undefined;
    private _timeouts;
    get timeouts(): GoogleKmsKeyHandleTimeoutsOutputReference;
    putTimeouts(value: GoogleKmsKeyHandleTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleKmsKeyHandleTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
