/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleManagedKafkaClusterConfig extends cdktf.TerraformMetaArguments {
    /**
    * The ID to use for the cluster, which will become the final component of the cluster's name. The ID must be 1-63 characters long, and match the regular expression '[a-z]([-a-z0-9]*[a-z0-9])?' to comply with RFC 1035. This value is structured like: 'my-cluster-id'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_managed_kafka_cluster#cluster_id GoogleManagedKafkaCluster#cluster_id}
    */
    readonly clusterId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_managed_kafka_cluster#id GoogleManagedKafkaCluster#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * List of label KEY=VALUE pairs to add. Keys must start with a lowercase character and contain only hyphens (-), underscores ( ), lowercase characters, and numbers. Values must contain only hyphens (-), underscores ( ), lowercase characters, and numbers.
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_managed_kafka_cluster#labels GoogleManagedKafkaCluster#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * ID of the location of the Kafka resource. See https://cloud.google.com/managed-kafka/docs/locations for a list of supported locations.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_managed_kafka_cluster#location GoogleManagedKafkaCluster#location}
    */
    readonly location: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_managed_kafka_cluster#project GoogleManagedKafkaCluster#project}
    */
    readonly project?: string;
    /**
    * capacity_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_managed_kafka_cluster#capacity_config GoogleManagedKafkaCluster#capacity_config}
    */
    readonly capacityConfig: GoogleManagedKafkaClusterCapacityConfig;
    /**
    * gcp_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_managed_kafka_cluster#gcp_config GoogleManagedKafkaCluster#gcp_config}
    */
    readonly gcpConfig: GoogleManagedKafkaClusterGcpConfig;
    /**
    * rebalance_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_managed_kafka_cluster#rebalance_config GoogleManagedKafkaCluster#rebalance_config}
    */
    readonly rebalanceConfig?: GoogleManagedKafkaClusterRebalanceConfig;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_managed_kafka_cluster#timeouts GoogleManagedKafkaCluster#timeouts}
    */
    readonly timeouts?: GoogleManagedKafkaClusterTimeouts;
}
export interface GoogleManagedKafkaClusterCapacityConfig {
    /**
    * The memory to provision for the cluster in bytes. The value must be between 1 GiB and 8 GiB per vCPU. Ex. 1024Mi, 4Gi.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_managed_kafka_cluster#memory_bytes GoogleManagedKafkaCluster#memory_bytes}
    */
    readonly memoryBytes: string;
    /**
    * The number of vCPUs to provision for the cluster. The minimum is 3.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_managed_kafka_cluster#vcpu_count GoogleManagedKafkaCluster#vcpu_count}
    */
    readonly vcpuCount: string;
}
export declare function googleManagedKafkaClusterCapacityConfigToTerraform(struct?: GoogleManagedKafkaClusterCapacityConfigOutputReference | GoogleManagedKafkaClusterCapacityConfig): any;
export declare function googleManagedKafkaClusterCapacityConfigToHclTerraform(struct?: GoogleManagedKafkaClusterCapacityConfigOutputReference | GoogleManagedKafkaClusterCapacityConfig): any;
export declare class GoogleManagedKafkaClusterCapacityConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleManagedKafkaClusterCapacityConfig | undefined;
    set internalValue(value: GoogleManagedKafkaClusterCapacityConfig | undefined);
    private _memoryBytes?;
    get memoryBytes(): string;
    set memoryBytes(value: string);
    get memoryBytesInput(): string | undefined;
    private _vcpuCount?;
    get vcpuCount(): string;
    set vcpuCount(value: string);
    get vcpuCountInput(): string | undefined;
}
export interface GoogleManagedKafkaClusterGcpConfigAccessConfigNetworkConfigs {
    /**
    * Name of the VPC subnet from which the cluster is accessible. Both broker and bootstrap server IP addresses and DNS entries are automatically created in the subnet. The subnet must be located in the same region as the cluster. The project may differ. The name of the subnet must be in the format 'projects/PROJECT_ID/regions/REGION/subnetworks/SUBNET'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_managed_kafka_cluster#subnet GoogleManagedKafkaCluster#subnet}
    */
    readonly subnet: string;
}
export declare function googleManagedKafkaClusterGcpConfigAccessConfigNetworkConfigsToTerraform(struct?: GoogleManagedKafkaClusterGcpConfigAccessConfigNetworkConfigs | cdktf.IResolvable): any;
export declare function googleManagedKafkaClusterGcpConfigAccessConfigNetworkConfigsToHclTerraform(struct?: GoogleManagedKafkaClusterGcpConfigAccessConfigNetworkConfigs | cdktf.IResolvable): any;
export declare class GoogleManagedKafkaClusterGcpConfigAccessConfigNetworkConfigsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleManagedKafkaClusterGcpConfigAccessConfigNetworkConfigs | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleManagedKafkaClusterGcpConfigAccessConfigNetworkConfigs | cdktf.IResolvable | undefined);
    private _subnet?;
    get subnet(): string;
    set subnet(value: string);
    get subnetInput(): string | undefined;
}
export declare class GoogleManagedKafkaClusterGcpConfigAccessConfigNetworkConfigsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleManagedKafkaClusterGcpConfigAccessConfigNetworkConfigs[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleManagedKafkaClusterGcpConfigAccessConfigNetworkConfigsOutputReference;
}
export interface GoogleManagedKafkaClusterGcpConfigAccessConfig {
    /**
    * network_configs block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_managed_kafka_cluster#network_configs GoogleManagedKafkaCluster#network_configs}
    */
    readonly networkConfigs: GoogleManagedKafkaClusterGcpConfigAccessConfigNetworkConfigs[] | cdktf.IResolvable;
}
export declare function googleManagedKafkaClusterGcpConfigAccessConfigToTerraform(struct?: GoogleManagedKafkaClusterGcpConfigAccessConfigOutputReference | GoogleManagedKafkaClusterGcpConfigAccessConfig): any;
export declare function googleManagedKafkaClusterGcpConfigAccessConfigToHclTerraform(struct?: GoogleManagedKafkaClusterGcpConfigAccessConfigOutputReference | GoogleManagedKafkaClusterGcpConfigAccessConfig): any;
export declare class GoogleManagedKafkaClusterGcpConfigAccessConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleManagedKafkaClusterGcpConfigAccessConfig | undefined;
    set internalValue(value: GoogleManagedKafkaClusterGcpConfigAccessConfig | undefined);
    private _networkConfigs;
    get networkConfigs(): GoogleManagedKafkaClusterGcpConfigAccessConfigNetworkConfigsList;
    putNetworkConfigs(value: GoogleManagedKafkaClusterGcpConfigAccessConfigNetworkConfigs[] | cdktf.IResolvable): void;
    get networkConfigsInput(): cdktf.IResolvable | GoogleManagedKafkaClusterGcpConfigAccessConfigNetworkConfigs[] | undefined;
}
export interface GoogleManagedKafkaClusterGcpConfig {
    /**
    * The Cloud KMS Key name to use for encryption. The key must be located in the same region as the cluster and cannot be changed. Must be in the format 'projects/PROJECT_ID/locations/LOCATION/keyRings/KEY_RING/cryptoKeys/KEY'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_managed_kafka_cluster#kms_key GoogleManagedKafkaCluster#kms_key}
    */
    readonly kmsKey?: string;
    /**
    * access_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_managed_kafka_cluster#access_config GoogleManagedKafkaCluster#access_config}
    */
    readonly accessConfig: GoogleManagedKafkaClusterGcpConfigAccessConfig;
}
export declare function googleManagedKafkaClusterGcpConfigToTerraform(struct?: GoogleManagedKafkaClusterGcpConfigOutputReference | GoogleManagedKafkaClusterGcpConfig): any;
export declare function googleManagedKafkaClusterGcpConfigToHclTerraform(struct?: GoogleManagedKafkaClusterGcpConfigOutputReference | GoogleManagedKafkaClusterGcpConfig): any;
export declare class GoogleManagedKafkaClusterGcpConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleManagedKafkaClusterGcpConfig | undefined;
    set internalValue(value: GoogleManagedKafkaClusterGcpConfig | undefined);
    private _kmsKey?;
    get kmsKey(): string;
    set kmsKey(value: string);
    resetKmsKey(): void;
    get kmsKeyInput(): string | undefined;
    private _accessConfig;
    get accessConfig(): GoogleManagedKafkaClusterGcpConfigAccessConfigOutputReference;
    putAccessConfig(value: GoogleManagedKafkaClusterGcpConfigAccessConfig): void;
    get accessConfigInput(): GoogleManagedKafkaClusterGcpConfigAccessConfig | undefined;
}
export interface GoogleManagedKafkaClusterRebalanceConfig {
    /**
    * The rebalance behavior for the cluster. When not specified, defaults to 'NO_REBALANCE'. Possible values: 'MODE_UNSPECIFIED', 'NO_REBALANCE', 'AUTO_REBALANCE_ON_SCALE_UP'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_managed_kafka_cluster#mode GoogleManagedKafkaCluster#mode}
    */
    readonly mode?: string;
}
export declare function googleManagedKafkaClusterRebalanceConfigToTerraform(struct?: GoogleManagedKafkaClusterRebalanceConfigOutputReference | GoogleManagedKafkaClusterRebalanceConfig): any;
export declare function googleManagedKafkaClusterRebalanceConfigToHclTerraform(struct?: GoogleManagedKafkaClusterRebalanceConfigOutputReference | GoogleManagedKafkaClusterRebalanceConfig): any;
export declare class GoogleManagedKafkaClusterRebalanceConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleManagedKafkaClusterRebalanceConfig | undefined;
    set internalValue(value: GoogleManagedKafkaClusterRebalanceConfig | undefined);
    private _mode?;
    get mode(): string;
    set mode(value: string);
    resetMode(): void;
    get modeInput(): string | undefined;
}
export interface GoogleManagedKafkaClusterTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_managed_kafka_cluster#create GoogleManagedKafkaCluster#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_managed_kafka_cluster#delete GoogleManagedKafkaCluster#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_managed_kafka_cluster#update GoogleManagedKafkaCluster#update}
    */
    readonly update?: string;
}
export declare function googleManagedKafkaClusterTimeoutsToTerraform(struct?: GoogleManagedKafkaClusterTimeouts | cdktf.IResolvable): any;
export declare function googleManagedKafkaClusterTimeoutsToHclTerraform(struct?: GoogleManagedKafkaClusterTimeouts | cdktf.IResolvable): any;
export declare class GoogleManagedKafkaClusterTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleManagedKafkaClusterTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleManagedKafkaClusterTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_managed_kafka_cluster google_managed_kafka_cluster}
*/
export declare class GoogleManagedKafkaCluster extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_managed_kafka_cluster";
    /**
    * Generates CDKTF code for importing a GoogleManagedKafkaCluster resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleManagedKafkaCluster to import
    * @param importFromId The id of the existing GoogleManagedKafkaCluster that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_managed_kafka_cluster#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleManagedKafkaCluster to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_managed_kafka_cluster google_managed_kafka_cluster} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleManagedKafkaClusterConfig
    */
    constructor(scope: Construct, id: string, config: GoogleManagedKafkaClusterConfig);
    private _clusterId?;
    get clusterId(): string;
    set clusterId(value: string);
    get clusterIdInput(): string | undefined;
    get createTime(): string;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    get state(): string;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    get updateTime(): string;
    private _capacityConfig;
    get capacityConfig(): GoogleManagedKafkaClusterCapacityConfigOutputReference;
    putCapacityConfig(value: GoogleManagedKafkaClusterCapacityConfig): void;
    get capacityConfigInput(): GoogleManagedKafkaClusterCapacityConfig | undefined;
    private _gcpConfig;
    get gcpConfig(): GoogleManagedKafkaClusterGcpConfigOutputReference;
    putGcpConfig(value: GoogleManagedKafkaClusterGcpConfig): void;
    get gcpConfigInput(): GoogleManagedKafkaClusterGcpConfig | undefined;
    private _rebalanceConfig;
    get rebalanceConfig(): GoogleManagedKafkaClusterRebalanceConfigOutputReference;
    putRebalanceConfig(value: GoogleManagedKafkaClusterRebalanceConfig): void;
    resetRebalanceConfig(): void;
    get rebalanceConfigInput(): GoogleManagedKafkaClusterRebalanceConfig | undefined;
    private _timeouts;
    get timeouts(): GoogleManagedKafkaClusterTimeoutsOutputReference;
    putTimeouts(value: GoogleManagedKafkaClusterTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleManagedKafkaClusterTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
