/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleNetworkConnectivitySpokeConfig extends cdktf.TerraformMetaArguments {
    /**
    * An optional description of the spoke.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_connectivity_spoke#description GoogleNetworkConnectivitySpoke#description}
    */
    readonly description?: string;
    /**
    * Immutable. The URI of the hub that this spoke is attached to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_connectivity_spoke#hub GoogleNetworkConnectivitySpoke#hub}
    */
    readonly hub: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_connectivity_spoke#id GoogleNetworkConnectivitySpoke#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Optional labels in key:value format. For more information about labels, see [Requirements for labels](https://cloud.google.com/resource-manager/docs/creating-managing-labels#requirements).
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_connectivity_spoke#labels GoogleNetworkConnectivitySpoke#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * The location for the resource
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_connectivity_spoke#location GoogleNetworkConnectivitySpoke#location}
    */
    readonly location: string;
    /**
    * Immutable. The name of the spoke. Spoke names must be unique.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_connectivity_spoke#name GoogleNetworkConnectivitySpoke#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_connectivity_spoke#project GoogleNetworkConnectivitySpoke#project}
    */
    readonly project?: string;
    /**
    * linked_interconnect_attachments block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_connectivity_spoke#linked_interconnect_attachments GoogleNetworkConnectivitySpoke#linked_interconnect_attachments}
    */
    readonly linkedInterconnectAttachments?: GoogleNetworkConnectivitySpokeLinkedInterconnectAttachments;
    /**
    * linked_producer_vpc_network block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_connectivity_spoke#linked_producer_vpc_network GoogleNetworkConnectivitySpoke#linked_producer_vpc_network}
    */
    readonly linkedProducerVpcNetwork?: GoogleNetworkConnectivitySpokeLinkedProducerVpcNetwork;
    /**
    * linked_router_appliance_instances block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_connectivity_spoke#linked_router_appliance_instances GoogleNetworkConnectivitySpoke#linked_router_appliance_instances}
    */
    readonly linkedRouterApplianceInstances?: GoogleNetworkConnectivitySpokeLinkedRouterApplianceInstances;
    /**
    * linked_vpc_network block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_connectivity_spoke#linked_vpc_network GoogleNetworkConnectivitySpoke#linked_vpc_network}
    */
    readonly linkedVpcNetwork?: GoogleNetworkConnectivitySpokeLinkedVpcNetwork;
    /**
    * linked_vpn_tunnels block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_connectivity_spoke#linked_vpn_tunnels GoogleNetworkConnectivitySpoke#linked_vpn_tunnels}
    */
    readonly linkedVpnTunnels?: GoogleNetworkConnectivitySpokeLinkedVpnTunnels;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_connectivity_spoke#timeouts GoogleNetworkConnectivitySpoke#timeouts}
    */
    readonly timeouts?: GoogleNetworkConnectivitySpokeTimeouts;
}
export interface GoogleNetworkConnectivitySpokeLinkedInterconnectAttachments {
    /**
    * IP ranges allowed to be included during import from hub (does not control transit connectivity).
    * The only allowed value for now is "ALL_IPV4_RANGES".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_connectivity_spoke#include_import_ranges GoogleNetworkConnectivitySpoke#include_import_ranges}
    */
    readonly includeImportRanges?: string[];
    /**
    * A value that controls whether site-to-site data transfer is enabled for these resources. Note that data transfer is available only in supported locations.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_connectivity_spoke#site_to_site_data_transfer GoogleNetworkConnectivitySpoke#site_to_site_data_transfer}
    */
    readonly siteToSiteDataTransfer: boolean | cdktf.IResolvable;
    /**
    * The URIs of linked interconnect attachment resources
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_connectivity_spoke#uris GoogleNetworkConnectivitySpoke#uris}
    */
    readonly uris: string[];
}
export declare function googleNetworkConnectivitySpokeLinkedInterconnectAttachmentsToTerraform(struct?: GoogleNetworkConnectivitySpokeLinkedInterconnectAttachmentsOutputReference | GoogleNetworkConnectivitySpokeLinkedInterconnectAttachments): any;
export declare function googleNetworkConnectivitySpokeLinkedInterconnectAttachmentsToHclTerraform(struct?: GoogleNetworkConnectivitySpokeLinkedInterconnectAttachmentsOutputReference | GoogleNetworkConnectivitySpokeLinkedInterconnectAttachments): any;
export declare class GoogleNetworkConnectivitySpokeLinkedInterconnectAttachmentsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleNetworkConnectivitySpokeLinkedInterconnectAttachments | undefined;
    set internalValue(value: GoogleNetworkConnectivitySpokeLinkedInterconnectAttachments | undefined);
    private _includeImportRanges?;
    get includeImportRanges(): string[];
    set includeImportRanges(value: string[]);
    resetIncludeImportRanges(): void;
    get includeImportRangesInput(): string[] | undefined;
    private _siteToSiteDataTransfer?;
    get siteToSiteDataTransfer(): boolean | cdktf.IResolvable;
    set siteToSiteDataTransfer(value: boolean | cdktf.IResolvable);
    get siteToSiteDataTransferInput(): boolean | cdktf.IResolvable | undefined;
    private _uris?;
    get uris(): string[];
    set uris(value: string[]);
    get urisInput(): string[] | undefined;
}
export interface GoogleNetworkConnectivitySpokeLinkedProducerVpcNetwork {
    /**
    * IP ranges encompassing the subnets to be excluded from peering.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_connectivity_spoke#exclude_export_ranges GoogleNetworkConnectivitySpoke#exclude_export_ranges}
    */
    readonly excludeExportRanges?: string[];
    /**
    * IP ranges allowed to be included from peering.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_connectivity_spoke#include_export_ranges GoogleNetworkConnectivitySpoke#include_export_ranges}
    */
    readonly includeExportRanges?: string[];
    /**
    * The URI of the Service Consumer VPC that the Producer VPC is peered with.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_connectivity_spoke#network GoogleNetworkConnectivitySpoke#network}
    */
    readonly network: string;
    /**
    * The name of the VPC peering between the Service Consumer VPC and the Producer VPC (defined in the Tenant project) which is added to the NCC hub. This peering must be in ACTIVE state.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_connectivity_spoke#peering GoogleNetworkConnectivitySpoke#peering}
    */
    readonly peering: string;
}
export declare function googleNetworkConnectivitySpokeLinkedProducerVpcNetworkToTerraform(struct?: GoogleNetworkConnectivitySpokeLinkedProducerVpcNetworkOutputReference | GoogleNetworkConnectivitySpokeLinkedProducerVpcNetwork): any;
export declare function googleNetworkConnectivitySpokeLinkedProducerVpcNetworkToHclTerraform(struct?: GoogleNetworkConnectivitySpokeLinkedProducerVpcNetworkOutputReference | GoogleNetworkConnectivitySpokeLinkedProducerVpcNetwork): any;
export declare class GoogleNetworkConnectivitySpokeLinkedProducerVpcNetworkOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleNetworkConnectivitySpokeLinkedProducerVpcNetwork | undefined;
    set internalValue(value: GoogleNetworkConnectivitySpokeLinkedProducerVpcNetwork | undefined);
    private _excludeExportRanges?;
    get excludeExportRanges(): string[];
    set excludeExportRanges(value: string[]);
    resetExcludeExportRanges(): void;
    get excludeExportRangesInput(): string[] | undefined;
    private _includeExportRanges?;
    get includeExportRanges(): string[];
    set includeExportRanges(value: string[]);
    resetIncludeExportRanges(): void;
    get includeExportRangesInput(): string[] | undefined;
    private _network?;
    get network(): string;
    set network(value: string);
    get networkInput(): string | undefined;
    private _peering?;
    get peering(): string;
    set peering(value: string);
    get peeringInput(): string | undefined;
    get producerNetwork(): string;
}
export interface GoogleNetworkConnectivitySpokeLinkedRouterApplianceInstancesInstances {
    /**
    * The IP address on the VM to use for peering.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_connectivity_spoke#ip_address GoogleNetworkConnectivitySpoke#ip_address}
    */
    readonly ipAddress?: string;
    /**
    * The URI of the virtual machine resource
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_connectivity_spoke#virtual_machine GoogleNetworkConnectivitySpoke#virtual_machine}
    */
    readonly virtualMachine?: string;
}
export declare function googleNetworkConnectivitySpokeLinkedRouterApplianceInstancesInstancesToTerraform(struct?: GoogleNetworkConnectivitySpokeLinkedRouterApplianceInstancesInstances | cdktf.IResolvable): any;
export declare function googleNetworkConnectivitySpokeLinkedRouterApplianceInstancesInstancesToHclTerraform(struct?: GoogleNetworkConnectivitySpokeLinkedRouterApplianceInstancesInstances | cdktf.IResolvable): any;
export declare class GoogleNetworkConnectivitySpokeLinkedRouterApplianceInstancesInstancesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleNetworkConnectivitySpokeLinkedRouterApplianceInstancesInstances | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleNetworkConnectivitySpokeLinkedRouterApplianceInstancesInstances | cdktf.IResolvable | undefined);
    private _ipAddress?;
    get ipAddress(): string;
    set ipAddress(value: string);
    resetIpAddress(): void;
    get ipAddressInput(): string | undefined;
    private _virtualMachine?;
    get virtualMachine(): string;
    set virtualMachine(value: string);
    resetVirtualMachine(): void;
    get virtualMachineInput(): string | undefined;
}
export declare class GoogleNetworkConnectivitySpokeLinkedRouterApplianceInstancesInstancesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleNetworkConnectivitySpokeLinkedRouterApplianceInstancesInstances[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleNetworkConnectivitySpokeLinkedRouterApplianceInstancesInstancesOutputReference;
}
export interface GoogleNetworkConnectivitySpokeLinkedRouterApplianceInstances {
    /**
    * IP ranges allowed to be included during import from hub (does not control transit connectivity).
    * The only allowed value for now is "ALL_IPV4_RANGES".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_connectivity_spoke#include_import_ranges GoogleNetworkConnectivitySpoke#include_import_ranges}
    */
    readonly includeImportRanges?: string[];
    /**
    * A value that controls whether site-to-site data transfer is enabled for these resources. Note that data transfer is available only in supported locations.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_connectivity_spoke#site_to_site_data_transfer GoogleNetworkConnectivitySpoke#site_to_site_data_transfer}
    */
    readonly siteToSiteDataTransfer: boolean | cdktf.IResolvable;
    /**
    * instances block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_connectivity_spoke#instances GoogleNetworkConnectivitySpoke#instances}
    */
    readonly instances: GoogleNetworkConnectivitySpokeLinkedRouterApplianceInstancesInstances[] | cdktf.IResolvable;
}
export declare function googleNetworkConnectivitySpokeLinkedRouterApplianceInstancesToTerraform(struct?: GoogleNetworkConnectivitySpokeLinkedRouterApplianceInstancesOutputReference | GoogleNetworkConnectivitySpokeLinkedRouterApplianceInstances): any;
export declare function googleNetworkConnectivitySpokeLinkedRouterApplianceInstancesToHclTerraform(struct?: GoogleNetworkConnectivitySpokeLinkedRouterApplianceInstancesOutputReference | GoogleNetworkConnectivitySpokeLinkedRouterApplianceInstances): any;
export declare class GoogleNetworkConnectivitySpokeLinkedRouterApplianceInstancesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleNetworkConnectivitySpokeLinkedRouterApplianceInstances | undefined;
    set internalValue(value: GoogleNetworkConnectivitySpokeLinkedRouterApplianceInstances | undefined);
    private _includeImportRanges?;
    get includeImportRanges(): string[];
    set includeImportRanges(value: string[]);
    resetIncludeImportRanges(): void;
    get includeImportRangesInput(): string[] | undefined;
    private _siteToSiteDataTransfer?;
    get siteToSiteDataTransfer(): boolean | cdktf.IResolvable;
    set siteToSiteDataTransfer(value: boolean | cdktf.IResolvable);
    get siteToSiteDataTransferInput(): boolean | cdktf.IResolvable | undefined;
    private _instances;
    get instances(): GoogleNetworkConnectivitySpokeLinkedRouterApplianceInstancesInstancesList;
    putInstances(value: GoogleNetworkConnectivitySpokeLinkedRouterApplianceInstancesInstances[] | cdktf.IResolvable): void;
    get instancesInput(): cdktf.IResolvable | GoogleNetworkConnectivitySpokeLinkedRouterApplianceInstancesInstances[] | undefined;
}
export interface GoogleNetworkConnectivitySpokeLinkedVpcNetwork {
    /**
    * IP ranges encompassing the subnets to be excluded from peering.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_connectivity_spoke#exclude_export_ranges GoogleNetworkConnectivitySpoke#exclude_export_ranges}
    */
    readonly excludeExportRanges?: string[];
    /**
    * IP ranges allowed to be included from peering.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_connectivity_spoke#include_export_ranges GoogleNetworkConnectivitySpoke#include_export_ranges}
    */
    readonly includeExportRanges?: string[];
    /**
    * The URI of the VPC network resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_connectivity_spoke#uri GoogleNetworkConnectivitySpoke#uri}
    */
    readonly uri: string;
}
export declare function googleNetworkConnectivitySpokeLinkedVpcNetworkToTerraform(struct?: GoogleNetworkConnectivitySpokeLinkedVpcNetworkOutputReference | GoogleNetworkConnectivitySpokeLinkedVpcNetwork): any;
export declare function googleNetworkConnectivitySpokeLinkedVpcNetworkToHclTerraform(struct?: GoogleNetworkConnectivitySpokeLinkedVpcNetworkOutputReference | GoogleNetworkConnectivitySpokeLinkedVpcNetwork): any;
export declare class GoogleNetworkConnectivitySpokeLinkedVpcNetworkOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleNetworkConnectivitySpokeLinkedVpcNetwork | undefined;
    set internalValue(value: GoogleNetworkConnectivitySpokeLinkedVpcNetwork | undefined);
    private _excludeExportRanges?;
    get excludeExportRanges(): string[];
    set excludeExportRanges(value: string[]);
    resetExcludeExportRanges(): void;
    get excludeExportRangesInput(): string[] | undefined;
    private _includeExportRanges?;
    get includeExportRanges(): string[];
    set includeExportRanges(value: string[]);
    resetIncludeExportRanges(): void;
    get includeExportRangesInput(): string[] | undefined;
    private _uri?;
    get uri(): string;
    set uri(value: string);
    get uriInput(): string | undefined;
}
export interface GoogleNetworkConnectivitySpokeLinkedVpnTunnels {
    /**
    * IP ranges allowed to be included during import from hub (does not control transit connectivity).
    * The only allowed value for now is "ALL_IPV4_RANGES".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_connectivity_spoke#include_import_ranges GoogleNetworkConnectivitySpoke#include_import_ranges}
    */
    readonly includeImportRanges?: string[];
    /**
    * A value that controls whether site-to-site data transfer is enabled for these resources. Note that data transfer is available only in supported locations.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_connectivity_spoke#site_to_site_data_transfer GoogleNetworkConnectivitySpoke#site_to_site_data_transfer}
    */
    readonly siteToSiteDataTransfer: boolean | cdktf.IResolvable;
    /**
    * The URIs of linked VPN tunnel resources.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_connectivity_spoke#uris GoogleNetworkConnectivitySpoke#uris}
    */
    readonly uris: string[];
}
export declare function googleNetworkConnectivitySpokeLinkedVpnTunnelsToTerraform(struct?: GoogleNetworkConnectivitySpokeLinkedVpnTunnelsOutputReference | GoogleNetworkConnectivitySpokeLinkedVpnTunnels): any;
export declare function googleNetworkConnectivitySpokeLinkedVpnTunnelsToHclTerraform(struct?: GoogleNetworkConnectivitySpokeLinkedVpnTunnelsOutputReference | GoogleNetworkConnectivitySpokeLinkedVpnTunnels): any;
export declare class GoogleNetworkConnectivitySpokeLinkedVpnTunnelsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleNetworkConnectivitySpokeLinkedVpnTunnels | undefined;
    set internalValue(value: GoogleNetworkConnectivitySpokeLinkedVpnTunnels | undefined);
    private _includeImportRanges?;
    get includeImportRanges(): string[];
    set includeImportRanges(value: string[]);
    resetIncludeImportRanges(): void;
    get includeImportRangesInput(): string[] | undefined;
    private _siteToSiteDataTransfer?;
    get siteToSiteDataTransfer(): boolean | cdktf.IResolvable;
    set siteToSiteDataTransfer(value: boolean | cdktf.IResolvable);
    get siteToSiteDataTransferInput(): boolean | cdktf.IResolvable | undefined;
    private _uris?;
    get uris(): string[];
    set uris(value: string[]);
    get urisInput(): string[] | undefined;
}
export interface GoogleNetworkConnectivitySpokeTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_connectivity_spoke#create GoogleNetworkConnectivitySpoke#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_connectivity_spoke#delete GoogleNetworkConnectivitySpoke#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_connectivity_spoke#update GoogleNetworkConnectivitySpoke#update}
    */
    readonly update?: string;
}
export declare function googleNetworkConnectivitySpokeTimeoutsToTerraform(struct?: GoogleNetworkConnectivitySpokeTimeouts | cdktf.IResolvable): any;
export declare function googleNetworkConnectivitySpokeTimeoutsToHclTerraform(struct?: GoogleNetworkConnectivitySpokeTimeouts | cdktf.IResolvable): any;
export declare class GoogleNetworkConnectivitySpokeTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleNetworkConnectivitySpokeTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleNetworkConnectivitySpokeTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_connectivity_spoke google_network_connectivity_spoke}
*/
export declare class GoogleNetworkConnectivitySpoke extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_network_connectivity_spoke";
    /**
    * Generates CDKTF code for importing a GoogleNetworkConnectivitySpoke resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleNetworkConnectivitySpoke to import
    * @param importFromId The id of the existing GoogleNetworkConnectivitySpoke that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_connectivity_spoke#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleNetworkConnectivitySpoke to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_connectivity_spoke google_network_connectivity_spoke} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleNetworkConnectivitySpokeConfig
    */
    constructor(scope: Construct, id: string, config: GoogleNetworkConnectivitySpokeConfig);
    get createTime(): string;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    private _hub?;
    get hub(): string;
    set hub(value: string);
    get hubInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    get state(): string;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    get uniqueId(): string;
    get updateTime(): string;
    private _linkedInterconnectAttachments;
    get linkedInterconnectAttachments(): GoogleNetworkConnectivitySpokeLinkedInterconnectAttachmentsOutputReference;
    putLinkedInterconnectAttachments(value: GoogleNetworkConnectivitySpokeLinkedInterconnectAttachments): void;
    resetLinkedInterconnectAttachments(): void;
    get linkedInterconnectAttachmentsInput(): GoogleNetworkConnectivitySpokeLinkedInterconnectAttachments | undefined;
    private _linkedProducerVpcNetwork;
    get linkedProducerVpcNetwork(): GoogleNetworkConnectivitySpokeLinkedProducerVpcNetworkOutputReference;
    putLinkedProducerVpcNetwork(value: GoogleNetworkConnectivitySpokeLinkedProducerVpcNetwork): void;
    resetLinkedProducerVpcNetwork(): void;
    get linkedProducerVpcNetworkInput(): GoogleNetworkConnectivitySpokeLinkedProducerVpcNetwork | undefined;
    private _linkedRouterApplianceInstances;
    get linkedRouterApplianceInstances(): GoogleNetworkConnectivitySpokeLinkedRouterApplianceInstancesOutputReference;
    putLinkedRouterApplianceInstances(value: GoogleNetworkConnectivitySpokeLinkedRouterApplianceInstances): void;
    resetLinkedRouterApplianceInstances(): void;
    get linkedRouterApplianceInstancesInput(): GoogleNetworkConnectivitySpokeLinkedRouterApplianceInstances | undefined;
    private _linkedVpcNetwork;
    get linkedVpcNetwork(): GoogleNetworkConnectivitySpokeLinkedVpcNetworkOutputReference;
    putLinkedVpcNetwork(value: GoogleNetworkConnectivitySpokeLinkedVpcNetwork): void;
    resetLinkedVpcNetwork(): void;
    get linkedVpcNetworkInput(): GoogleNetworkConnectivitySpokeLinkedVpcNetwork | undefined;
    private _linkedVpnTunnels;
    get linkedVpnTunnels(): GoogleNetworkConnectivitySpokeLinkedVpnTunnelsOutputReference;
    putLinkedVpnTunnels(value: GoogleNetworkConnectivitySpokeLinkedVpnTunnels): void;
    resetLinkedVpnTunnels(): void;
    get linkedVpnTunnelsInput(): GoogleNetworkConnectivitySpokeLinkedVpnTunnels | undefined;
    private _timeouts;
    get timeouts(): GoogleNetworkConnectivitySpokeTimeoutsOutputReference;
    putTimeouts(value: GoogleNetworkConnectivitySpokeTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleNetworkConnectivitySpokeTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
