/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleNetworkServicesServiceLbPoliciesConfig extends cdktf.TerraformMetaArguments {
    /**
    * A free-text description of the resource. Max length 1024 characters.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_services_service_lb_policies#description GoogleNetworkServicesServiceLbPolicies#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_services_service_lb_policies#id GoogleNetworkServicesServiceLbPolicies#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Set of label tags associated with the ServiceLbPolicy resource.
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_services_service_lb_policies#labels GoogleNetworkServicesServiceLbPolicies#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * The type of load balancing algorithm to be used. The default behavior is WATERFALL_BY_REGION. Possible values: ["SPRAY_TO_REGION", "SPRAY_TO_WORLD", "WATERFALL_BY_REGION", "WATERFALL_BY_ZONE"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_services_service_lb_policies#load_balancing_algorithm GoogleNetworkServicesServiceLbPolicies#load_balancing_algorithm}
    */
    readonly loadBalancingAlgorithm?: string;
    /**
    * The location of the service lb policy.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_services_service_lb_policies#location GoogleNetworkServicesServiceLbPolicies#location}
    */
    readonly location: string;
    /**
    * Name of the ServiceLbPolicy resource. It matches pattern 'projects/{project}/locations/{location}/serviceLbPolicies/{service_lb_policy_name}'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_services_service_lb_policies#name GoogleNetworkServicesServiceLbPolicies#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_services_service_lb_policies#project GoogleNetworkServicesServiceLbPolicies#project}
    */
    readonly project?: string;
    /**
    * auto_capacity_drain block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_services_service_lb_policies#auto_capacity_drain GoogleNetworkServicesServiceLbPolicies#auto_capacity_drain}
    */
    readonly autoCapacityDrain?: GoogleNetworkServicesServiceLbPoliciesAutoCapacityDrain;
    /**
    * failover_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_services_service_lb_policies#failover_config GoogleNetworkServicesServiceLbPolicies#failover_config}
    */
    readonly failoverConfig?: GoogleNetworkServicesServiceLbPoliciesFailoverConfig;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_services_service_lb_policies#timeouts GoogleNetworkServicesServiceLbPolicies#timeouts}
    */
    readonly timeouts?: GoogleNetworkServicesServiceLbPoliciesTimeouts;
}
export interface GoogleNetworkServicesServiceLbPoliciesAutoCapacityDrain {
    /**
    * Optional. If set to 'True', an unhealthy MIG/NEG will be set as drained. - An MIG/NEG is considered unhealthy if less than 25% of the instances/endpoints in the MIG/NEG are healthy. - This option will never result in draining more than 50% of the configured IGs/NEGs for the Backend Service.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_services_service_lb_policies#enable GoogleNetworkServicesServiceLbPolicies#enable}
    */
    readonly enable?: boolean | cdktf.IResolvable;
}
export declare function googleNetworkServicesServiceLbPoliciesAutoCapacityDrainToTerraform(struct?: GoogleNetworkServicesServiceLbPoliciesAutoCapacityDrainOutputReference | GoogleNetworkServicesServiceLbPoliciesAutoCapacityDrain): any;
export declare function googleNetworkServicesServiceLbPoliciesAutoCapacityDrainToHclTerraform(struct?: GoogleNetworkServicesServiceLbPoliciesAutoCapacityDrainOutputReference | GoogleNetworkServicesServiceLbPoliciesAutoCapacityDrain): any;
export declare class GoogleNetworkServicesServiceLbPoliciesAutoCapacityDrainOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleNetworkServicesServiceLbPoliciesAutoCapacityDrain | undefined;
    set internalValue(value: GoogleNetworkServicesServiceLbPoliciesAutoCapacityDrain | undefined);
    private _enable?;
    get enable(): boolean | cdktf.IResolvable;
    set enable(value: boolean | cdktf.IResolvable);
    resetEnable(): void;
    get enableInput(): boolean | cdktf.IResolvable | undefined;
}
export interface GoogleNetworkServicesServiceLbPoliciesFailoverConfig {
    /**
    * Optional. The percentage threshold that a load balancer will begin to send traffic to failover backends. If the percentage of endpoints in a MIG/NEG is smaller than this value, traffic would be sent to failover backends if possible. This field should be set to a value between 1 and 99. The default value is 50 for Global external HTTP(S) load balancer (classic) and Proxyless service mesh, and 70 for others.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_services_service_lb_policies#failover_health_threshold GoogleNetworkServicesServiceLbPolicies#failover_health_threshold}
    */
    readonly failoverHealthThreshold: number;
}
export declare function googleNetworkServicesServiceLbPoliciesFailoverConfigToTerraform(struct?: GoogleNetworkServicesServiceLbPoliciesFailoverConfigOutputReference | GoogleNetworkServicesServiceLbPoliciesFailoverConfig): any;
export declare function googleNetworkServicesServiceLbPoliciesFailoverConfigToHclTerraform(struct?: GoogleNetworkServicesServiceLbPoliciesFailoverConfigOutputReference | GoogleNetworkServicesServiceLbPoliciesFailoverConfig): any;
export declare class GoogleNetworkServicesServiceLbPoliciesFailoverConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleNetworkServicesServiceLbPoliciesFailoverConfig | undefined;
    set internalValue(value: GoogleNetworkServicesServiceLbPoliciesFailoverConfig | undefined);
    private _failoverHealthThreshold?;
    get failoverHealthThreshold(): number;
    set failoverHealthThreshold(value: number);
    get failoverHealthThresholdInput(): number | undefined;
}
export interface GoogleNetworkServicesServiceLbPoliciesTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_services_service_lb_policies#create GoogleNetworkServicesServiceLbPolicies#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_services_service_lb_policies#delete GoogleNetworkServicesServiceLbPolicies#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_services_service_lb_policies#update GoogleNetworkServicesServiceLbPolicies#update}
    */
    readonly update?: string;
}
export declare function googleNetworkServicesServiceLbPoliciesTimeoutsToTerraform(struct?: GoogleNetworkServicesServiceLbPoliciesTimeouts | cdktf.IResolvable): any;
export declare function googleNetworkServicesServiceLbPoliciesTimeoutsToHclTerraform(struct?: GoogleNetworkServicesServiceLbPoliciesTimeouts | cdktf.IResolvable): any;
export declare class GoogleNetworkServicesServiceLbPoliciesTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleNetworkServicesServiceLbPoliciesTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleNetworkServicesServiceLbPoliciesTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_services_service_lb_policies google_network_services_service_lb_policies}
*/
export declare class GoogleNetworkServicesServiceLbPolicies extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_network_services_service_lb_policies";
    /**
    * Generates CDKTF code for importing a GoogleNetworkServicesServiceLbPolicies resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleNetworkServicesServiceLbPolicies to import
    * @param importFromId The id of the existing GoogleNetworkServicesServiceLbPolicies that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_services_service_lb_policies#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleNetworkServicesServiceLbPolicies to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_network_services_service_lb_policies google_network_services_service_lb_policies} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleNetworkServicesServiceLbPoliciesConfig
    */
    constructor(scope: Construct, id: string, config: GoogleNetworkServicesServiceLbPoliciesConfig);
    get createTime(): string;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _loadBalancingAlgorithm?;
    get loadBalancingAlgorithm(): string;
    set loadBalancingAlgorithm(value: string);
    resetLoadBalancingAlgorithm(): void;
    get loadBalancingAlgorithmInput(): string | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    get updateTime(): string;
    private _autoCapacityDrain;
    get autoCapacityDrain(): GoogleNetworkServicesServiceLbPoliciesAutoCapacityDrainOutputReference;
    putAutoCapacityDrain(value: GoogleNetworkServicesServiceLbPoliciesAutoCapacityDrain): void;
    resetAutoCapacityDrain(): void;
    get autoCapacityDrainInput(): GoogleNetworkServicesServiceLbPoliciesAutoCapacityDrain | undefined;
    private _failoverConfig;
    get failoverConfig(): GoogleNetworkServicesServiceLbPoliciesFailoverConfigOutputReference;
    putFailoverConfig(value: GoogleNetworkServicesServiceLbPoliciesFailoverConfig): void;
    resetFailoverConfig(): void;
    get failoverConfigInput(): GoogleNetworkServicesServiceLbPoliciesFailoverConfig | undefined;
    private _timeouts;
    get timeouts(): GoogleNetworkServicesServiceLbPoliciesTimeoutsOutputReference;
    putTimeouts(value: GoogleNetworkServicesServiceLbPoliciesTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleNetworkServicesServiceLbPoliciesTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
