/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleOracleDatabaseAutonomousDatabaseConfig extends cdktf.TerraformMetaArguments {
    /**
    * The password for the default ADMIN user.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_oracle_database_autonomous_database#admin_password GoogleOracleDatabaseAutonomousDatabase#admin_password}
    */
    readonly adminPassword?: string;
    /**
    * The ID of the Autonomous Database to create. This value is restricted
    * to (^[a-z]([a-z0-9-]{0,61}[a-z0-9])?$) and must be a maximum of 63
    * characters in length. The value must start with a letter and end with
    * a letter or a number.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_oracle_database_autonomous_database#autonomous_database_id GoogleOracleDatabaseAutonomousDatabase#autonomous_database_id}
    */
    readonly autonomousDatabaseId: string;
    /**
    * The subnet CIDR range for the Autonmous Database.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_oracle_database_autonomous_database#cidr GoogleOracleDatabaseAutonomousDatabase#cidr}
    */
    readonly cidr: string;
    /**
    * The name of the Autonomous Database. The database name must be unique in
    * the project. The name must begin with a letter and can
    * contain a maximum of 30 alphanumeric characters.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_oracle_database_autonomous_database#database GoogleOracleDatabaseAutonomousDatabase#database}
    */
    readonly database: string;
    /**
    * The display name for the Autonomous Database. The name does not have to
    * be unique within your project.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_oracle_database_autonomous_database#display_name GoogleOracleDatabaseAutonomousDatabase#display_name}
    */
    readonly displayName?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_oracle_database_autonomous_database#id GoogleOracleDatabaseAutonomousDatabase#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The labels or tags associated with the Autonomous Database.
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_oracle_database_autonomous_database#labels GoogleOracleDatabaseAutonomousDatabase#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * Resource ID segment making up resource 'name'. See documentation for resource type 'oracledatabase.googleapis.com/AutonomousDatabaseBackup'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_oracle_database_autonomous_database#location GoogleOracleDatabaseAutonomousDatabase#location}
    */
    readonly location: string;
    /**
    * The name of the VPC network used by the Autonomous Database.
    * Format: projects/{project}/global/networks/{network}
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_oracle_database_autonomous_database#network GoogleOracleDatabaseAutonomousDatabase#network}
    */
    readonly network: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_oracle_database_autonomous_database#project GoogleOracleDatabaseAutonomousDatabase#project}
    */
    readonly project?: string;
    /**
    * properties block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_oracle_database_autonomous_database#properties GoogleOracleDatabaseAutonomousDatabase#properties}
    */
    readonly properties: GoogleOracleDatabaseAutonomousDatabaseProperties;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_oracle_database_autonomous_database#timeouts GoogleOracleDatabaseAutonomousDatabase#timeouts}
    */
    readonly timeouts?: GoogleOracleDatabaseAutonomousDatabaseTimeouts;
}
export interface GoogleOracleDatabaseAutonomousDatabasePropertiesApexDetails {
}
export declare function googleOracleDatabaseAutonomousDatabasePropertiesApexDetailsToTerraform(struct?: GoogleOracleDatabaseAutonomousDatabasePropertiesApexDetails): any;
export declare function googleOracleDatabaseAutonomousDatabasePropertiesApexDetailsToHclTerraform(struct?: GoogleOracleDatabaseAutonomousDatabasePropertiesApexDetails): any;
export declare class GoogleOracleDatabaseAutonomousDatabasePropertiesApexDetailsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleOracleDatabaseAutonomousDatabasePropertiesApexDetails | undefined;
    set internalValue(value: GoogleOracleDatabaseAutonomousDatabasePropertiesApexDetails | undefined);
    get apexVersion(): string;
    get ordsVersion(): string;
}
export declare class GoogleOracleDatabaseAutonomousDatabasePropertiesApexDetailsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleOracleDatabaseAutonomousDatabasePropertiesApexDetailsOutputReference;
}
export interface GoogleOracleDatabaseAutonomousDatabasePropertiesConnectionStringsAllConnectionStrings {
}
export declare function googleOracleDatabaseAutonomousDatabasePropertiesConnectionStringsAllConnectionStringsToTerraform(struct?: GoogleOracleDatabaseAutonomousDatabasePropertiesConnectionStringsAllConnectionStrings): any;
export declare function googleOracleDatabaseAutonomousDatabasePropertiesConnectionStringsAllConnectionStringsToHclTerraform(struct?: GoogleOracleDatabaseAutonomousDatabasePropertiesConnectionStringsAllConnectionStrings): any;
export declare class GoogleOracleDatabaseAutonomousDatabasePropertiesConnectionStringsAllConnectionStringsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleOracleDatabaseAutonomousDatabasePropertiesConnectionStringsAllConnectionStrings | undefined;
    set internalValue(value: GoogleOracleDatabaseAutonomousDatabasePropertiesConnectionStringsAllConnectionStrings | undefined);
    get high(): string;
    get low(): string;
    get medium(): string;
}
export declare class GoogleOracleDatabaseAutonomousDatabasePropertiesConnectionStringsAllConnectionStringsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleOracleDatabaseAutonomousDatabasePropertiesConnectionStringsAllConnectionStringsOutputReference;
}
export interface GoogleOracleDatabaseAutonomousDatabasePropertiesConnectionStringsProfiles {
}
export declare function googleOracleDatabaseAutonomousDatabasePropertiesConnectionStringsProfilesToTerraform(struct?: GoogleOracleDatabaseAutonomousDatabasePropertiesConnectionStringsProfiles): any;
export declare function googleOracleDatabaseAutonomousDatabasePropertiesConnectionStringsProfilesToHclTerraform(struct?: GoogleOracleDatabaseAutonomousDatabasePropertiesConnectionStringsProfiles): any;
export declare class GoogleOracleDatabaseAutonomousDatabasePropertiesConnectionStringsProfilesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleOracleDatabaseAutonomousDatabasePropertiesConnectionStringsProfiles | undefined;
    set internalValue(value: GoogleOracleDatabaseAutonomousDatabasePropertiesConnectionStringsProfiles | undefined);
    get consumerGroup(): string;
    get displayName(): string;
    get hostFormat(): string;
    get isRegional(): cdktf.IResolvable;
    get protocol(): string;
    get sessionMode(): string;
    get syntaxFormat(): string;
    get tlsAuthentication(): string;
    get value(): string;
}
export declare class GoogleOracleDatabaseAutonomousDatabasePropertiesConnectionStringsProfilesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleOracleDatabaseAutonomousDatabasePropertiesConnectionStringsProfilesOutputReference;
}
export interface GoogleOracleDatabaseAutonomousDatabasePropertiesConnectionStrings {
}
export declare function googleOracleDatabaseAutonomousDatabasePropertiesConnectionStringsToTerraform(struct?: GoogleOracleDatabaseAutonomousDatabasePropertiesConnectionStrings): any;
export declare function googleOracleDatabaseAutonomousDatabasePropertiesConnectionStringsToHclTerraform(struct?: GoogleOracleDatabaseAutonomousDatabasePropertiesConnectionStrings): any;
export declare class GoogleOracleDatabaseAutonomousDatabasePropertiesConnectionStringsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleOracleDatabaseAutonomousDatabasePropertiesConnectionStrings | undefined;
    set internalValue(value: GoogleOracleDatabaseAutonomousDatabasePropertiesConnectionStrings | undefined);
    private _allConnectionStrings;
    get allConnectionStrings(): GoogleOracleDatabaseAutonomousDatabasePropertiesConnectionStringsAllConnectionStringsList;
    get dedicated(): string;
    get high(): string;
    get low(): string;
    get medium(): string;
    private _profiles;
    get profiles(): GoogleOracleDatabaseAutonomousDatabasePropertiesConnectionStringsProfilesList;
}
export declare class GoogleOracleDatabaseAutonomousDatabasePropertiesConnectionStringsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleOracleDatabaseAutonomousDatabasePropertiesConnectionStringsOutputReference;
}
export interface GoogleOracleDatabaseAutonomousDatabasePropertiesConnectionUrls {
}
export declare function googleOracleDatabaseAutonomousDatabasePropertiesConnectionUrlsToTerraform(struct?: GoogleOracleDatabaseAutonomousDatabasePropertiesConnectionUrls): any;
export declare function googleOracleDatabaseAutonomousDatabasePropertiesConnectionUrlsToHclTerraform(struct?: GoogleOracleDatabaseAutonomousDatabasePropertiesConnectionUrls): any;
export declare class GoogleOracleDatabaseAutonomousDatabasePropertiesConnectionUrlsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleOracleDatabaseAutonomousDatabasePropertiesConnectionUrls | undefined;
    set internalValue(value: GoogleOracleDatabaseAutonomousDatabasePropertiesConnectionUrls | undefined);
    get apexUri(): string;
    get databaseTransformsUri(): string;
    get graphStudioUri(): string;
    get machineLearningNotebookUri(): string;
    get machineLearningUserManagementUri(): string;
    get mongoDbUri(): string;
    get ordsUri(): string;
    get sqlDevWebUri(): string;
}
export declare class GoogleOracleDatabaseAutonomousDatabasePropertiesConnectionUrlsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleOracleDatabaseAutonomousDatabasePropertiesConnectionUrlsOutputReference;
}
export interface GoogleOracleDatabaseAutonomousDatabasePropertiesLocalStandbyDb {
}
export declare function googleOracleDatabaseAutonomousDatabasePropertiesLocalStandbyDbToTerraform(struct?: GoogleOracleDatabaseAutonomousDatabasePropertiesLocalStandbyDb): any;
export declare function googleOracleDatabaseAutonomousDatabasePropertiesLocalStandbyDbToHclTerraform(struct?: GoogleOracleDatabaseAutonomousDatabasePropertiesLocalStandbyDb): any;
export declare class GoogleOracleDatabaseAutonomousDatabasePropertiesLocalStandbyDbOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleOracleDatabaseAutonomousDatabasePropertiesLocalStandbyDb | undefined;
    set internalValue(value: GoogleOracleDatabaseAutonomousDatabasePropertiesLocalStandbyDb | undefined);
    get dataGuardRoleChangedTime(): string;
    get disasterRecoveryRoleChangedTime(): string;
    get lagTimeDuration(): string;
    get lifecycleDetails(): string;
    get state(): string;
}
export declare class GoogleOracleDatabaseAutonomousDatabasePropertiesLocalStandbyDbList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleOracleDatabaseAutonomousDatabasePropertiesLocalStandbyDbOutputReference;
}
export interface GoogleOracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsStartTime {
}
export declare function googleOracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsStartTimeToTerraform(struct?: GoogleOracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsStartTime): any;
export declare function googleOracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsStartTimeToHclTerraform(struct?: GoogleOracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsStartTime): any;
export declare class GoogleOracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsStartTimeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleOracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsStartTime | undefined;
    set internalValue(value: GoogleOracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsStartTime | undefined);
    get hours(): number;
    get minutes(): number;
    get nanos(): number;
    get seconds(): number;
}
export declare class GoogleOracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsStartTimeList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleOracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsStartTimeOutputReference;
}
export interface GoogleOracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsStopTime {
}
export declare function googleOracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsStopTimeToTerraform(struct?: GoogleOracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsStopTime): any;
export declare function googleOracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsStopTimeToHclTerraform(struct?: GoogleOracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsStopTime): any;
export declare class GoogleOracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsStopTimeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleOracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsStopTime | undefined;
    set internalValue(value: GoogleOracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsStopTime | undefined);
    get hours(): number;
    get minutes(): number;
    get nanos(): number;
    get seconds(): number;
}
export declare class GoogleOracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsStopTimeList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleOracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsStopTimeOutputReference;
}
export interface GoogleOracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetails {
}
export declare function googleOracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsToTerraform(struct?: GoogleOracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetails): any;
export declare function googleOracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsToHclTerraform(struct?: GoogleOracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetails): any;
export declare class GoogleOracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleOracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetails | undefined;
    set internalValue(value: GoogleOracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetails | undefined);
    get dayOfWeek(): string;
    private _startTime;
    get startTime(): GoogleOracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsStartTimeList;
    private _stopTime;
    get stopTime(): GoogleOracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsStopTimeList;
}
export declare class GoogleOracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleOracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsOutputReference;
}
export interface GoogleOracleDatabaseAutonomousDatabasePropertiesCustomerContacts {
    /**
    * The email address used by Oracle to send notifications regarding databases
    * and infrastructure.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_oracle_database_autonomous_database#email GoogleOracleDatabaseAutonomousDatabase#email}
    */
    readonly email: string;
}
export declare function googleOracleDatabaseAutonomousDatabasePropertiesCustomerContactsToTerraform(struct?: GoogleOracleDatabaseAutonomousDatabasePropertiesCustomerContacts | cdktf.IResolvable): any;
export declare function googleOracleDatabaseAutonomousDatabasePropertiesCustomerContactsToHclTerraform(struct?: GoogleOracleDatabaseAutonomousDatabasePropertiesCustomerContacts | cdktf.IResolvable): any;
export declare class GoogleOracleDatabaseAutonomousDatabasePropertiesCustomerContactsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleOracleDatabaseAutonomousDatabasePropertiesCustomerContacts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleOracleDatabaseAutonomousDatabasePropertiesCustomerContacts | cdktf.IResolvable | undefined);
    private _email?;
    get email(): string;
    set email(value: string);
    get emailInput(): string | undefined;
}
export declare class GoogleOracleDatabaseAutonomousDatabasePropertiesCustomerContactsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleOracleDatabaseAutonomousDatabasePropertiesCustomerContacts[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleOracleDatabaseAutonomousDatabasePropertiesCustomerContactsOutputReference;
}
export interface GoogleOracleDatabaseAutonomousDatabaseProperties {
    /**
    * The retention period for the Autonomous Database. This field is specified
    * in days, can range from 1 day to 60 days, and has a default value of
    * 60 days.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_oracle_database_autonomous_database#backup_retention_period_days GoogleOracleDatabaseAutonomousDatabase#backup_retention_period_days}
    */
    readonly backupRetentionPeriodDays?: number;
    /**
    * The character set for the Autonomous Database. The default is AL32UTF8.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_oracle_database_autonomous_database#character_set GoogleOracleDatabaseAutonomousDatabase#character_set}
    */
    readonly characterSet?: string;
    /**
    * The number of compute servers for the Autonomous Database.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_oracle_database_autonomous_database#compute_count GoogleOracleDatabaseAutonomousDatabase#compute_count}
    */
    readonly computeCount?: number;
    /**
    * The size of the data stored in the database, in gigabytes.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_oracle_database_autonomous_database#data_storage_size_gb GoogleOracleDatabaseAutonomousDatabase#data_storage_size_gb}
    */
    readonly dataStorageSizeGb?: number;
    /**
    * The size of the data stored in the database, in terabytes.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_oracle_database_autonomous_database#data_storage_size_tb GoogleOracleDatabaseAutonomousDatabase#data_storage_size_tb}
    */
    readonly dataStorageSizeTb?: number;
    /**
    * The edition of the Autonomous Databases.
    *  Possible values:
    *  DATABASE_EDITION_UNSPECIFIED
    * STANDARD_EDITION
    * ENTERPRISE_EDITION
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_oracle_database_autonomous_database#db_edition GoogleOracleDatabaseAutonomousDatabase#db_edition}
    */
    readonly dbEdition?: string;
    /**
    * The Oracle Database version for the Autonomous Database.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_oracle_database_autonomous_database#db_version GoogleOracleDatabaseAutonomousDatabase#db_version}
    */
    readonly dbVersion?: string;
    /**
    * Possible values:
    *  DB_WORKLOAD_UNSPECIFIED
    * OLTP
    * DW
    * AJD
    * APEX
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_oracle_database_autonomous_database#db_workload GoogleOracleDatabaseAutonomousDatabase#db_workload}
    */
    readonly dbWorkload: string;
    /**
    * This field indicates if auto scaling is enabled for the Autonomous Database
    * CPU core count.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_oracle_database_autonomous_database#is_auto_scaling_enabled GoogleOracleDatabaseAutonomousDatabase#is_auto_scaling_enabled}
    */
    readonly isAutoScalingEnabled?: boolean | cdktf.IResolvable;
    /**
    * This field indicates if auto scaling is enabled for the Autonomous Database
    * storage.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_oracle_database_autonomous_database#is_storage_auto_scaling_enabled GoogleOracleDatabaseAutonomousDatabase#is_storage_auto_scaling_enabled}
    */
    readonly isStorageAutoScalingEnabled?: boolean | cdktf.IResolvable;
    /**
    * The license type used for the Autonomous Database.
    *  Possible values:
    *  LICENSE_TYPE_UNSPECIFIED
    * LICENSE_INCLUDED
    * BRING_YOUR_OWN_LICENSE
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_oracle_database_autonomous_database#license_type GoogleOracleDatabaseAutonomousDatabase#license_type}
    */
    readonly licenseType: string;
    /**
    * The maintenance schedule of the Autonomous Database.
    *  Possible values:
    *  MAINTENANCE_SCHEDULE_TYPE_UNSPECIFIED
    * EARLY
    * REGULAR
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_oracle_database_autonomous_database#maintenance_schedule_type GoogleOracleDatabaseAutonomousDatabase#maintenance_schedule_type}
    */
    readonly maintenanceScheduleType?: string;
    /**
    * This field specifies if the Autonomous Database requires mTLS connections.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_oracle_database_autonomous_database#mtls_connection_required GoogleOracleDatabaseAutonomousDatabase#mtls_connection_required}
    */
    readonly mtlsConnectionRequired?: boolean | cdktf.IResolvable;
    /**
    * The national character set for the Autonomous Database. The default is
    * AL16UTF16.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_oracle_database_autonomous_database#n_character_set GoogleOracleDatabaseAutonomousDatabase#n_character_set}
    */
    readonly nCharacterSet?: string;
    /**
    * Possible values:
    *  OPERATIONS_INSIGHTS_STATE_UNSPECIFIED
    * ENABLING
    * ENABLED
    * DISABLING
    * NOT_ENABLED
    * FAILED_ENABLING
    * FAILED_DISABLING
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_oracle_database_autonomous_database#operations_insights_state GoogleOracleDatabaseAutonomousDatabase#operations_insights_state}
    */
    readonly operationsInsightsState?: string;
    /**
    * The private endpoint IP address for the Autonomous Database.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_oracle_database_autonomous_database#private_endpoint_ip GoogleOracleDatabaseAutonomousDatabase#private_endpoint_ip}
    */
    readonly privateEndpointIp?: string;
    /**
    * The private endpoint label for the Autonomous Database.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_oracle_database_autonomous_database#private_endpoint_label GoogleOracleDatabaseAutonomousDatabase#private_endpoint_label}
    */
    readonly privateEndpointLabel?: string;
    /**
    * customer_contacts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_oracle_database_autonomous_database#customer_contacts GoogleOracleDatabaseAutonomousDatabase#customer_contacts}
    */
    readonly customerContacts?: GoogleOracleDatabaseAutonomousDatabasePropertiesCustomerContacts[] | cdktf.IResolvable;
}
export declare function googleOracleDatabaseAutonomousDatabasePropertiesToTerraform(struct?: GoogleOracleDatabaseAutonomousDatabasePropertiesOutputReference | GoogleOracleDatabaseAutonomousDatabaseProperties): any;
export declare function googleOracleDatabaseAutonomousDatabasePropertiesToHclTerraform(struct?: GoogleOracleDatabaseAutonomousDatabasePropertiesOutputReference | GoogleOracleDatabaseAutonomousDatabaseProperties): any;
export declare class GoogleOracleDatabaseAutonomousDatabasePropertiesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleOracleDatabaseAutonomousDatabaseProperties | undefined;
    set internalValue(value: GoogleOracleDatabaseAutonomousDatabaseProperties | undefined);
    get actualUsedDataStorageSizeTb(): number;
    get allocatedStorageSizeTb(): number;
    private _apexDetails;
    get apexDetails(): GoogleOracleDatabaseAutonomousDatabasePropertiesApexDetailsList;
    get arePrimaryAllowlistedIpsUsed(): cdktf.IResolvable;
    get autonomousContainerDatabaseId(): string;
    get availableUpgradeVersions(): string[];
    private _backupRetentionPeriodDays?;
    get backupRetentionPeriodDays(): number;
    set backupRetentionPeriodDays(value: number);
    resetBackupRetentionPeriodDays(): void;
    get backupRetentionPeriodDaysInput(): number | undefined;
    private _characterSet?;
    get characterSet(): string;
    set characterSet(value: string);
    resetCharacterSet(): void;
    get characterSetInput(): string | undefined;
    private _computeCount?;
    get computeCount(): number;
    set computeCount(value: number);
    resetComputeCount(): void;
    get computeCountInput(): number | undefined;
    private _connectionStrings;
    get connectionStrings(): GoogleOracleDatabaseAutonomousDatabasePropertiesConnectionStringsList;
    private _connectionUrls;
    get connectionUrls(): GoogleOracleDatabaseAutonomousDatabasePropertiesConnectionUrlsList;
    get dataSafeState(): string;
    private _dataStorageSizeGb?;
    get dataStorageSizeGb(): number;
    set dataStorageSizeGb(value: number);
    resetDataStorageSizeGb(): void;
    get dataStorageSizeGbInput(): number | undefined;
    private _dataStorageSizeTb?;
    get dataStorageSizeTb(): number;
    set dataStorageSizeTb(value: number);
    resetDataStorageSizeTb(): void;
    get dataStorageSizeTbInput(): number | undefined;
    get databaseManagementState(): string;
    private _dbEdition?;
    get dbEdition(): string;
    set dbEdition(value: string);
    resetDbEdition(): void;
    get dbEditionInput(): string | undefined;
    private _dbVersion?;
    get dbVersion(): string;
    set dbVersion(value: string);
    resetDbVersion(): void;
    get dbVersionInput(): string | undefined;
    private _dbWorkload?;
    get dbWorkload(): string;
    set dbWorkload(value: string);
    get dbWorkloadInput(): string | undefined;
    get failedDataRecoveryDuration(): string;
    private _isAutoScalingEnabled?;
    get isAutoScalingEnabled(): boolean | cdktf.IResolvable;
    set isAutoScalingEnabled(value: boolean | cdktf.IResolvable);
    resetIsAutoScalingEnabled(): void;
    get isAutoScalingEnabledInput(): boolean | cdktf.IResolvable | undefined;
    get isLocalDataGuardEnabled(): cdktf.IResolvable;
    private _isStorageAutoScalingEnabled?;
    get isStorageAutoScalingEnabled(): boolean | cdktf.IResolvable;
    set isStorageAutoScalingEnabled(value: boolean | cdktf.IResolvable);
    resetIsStorageAutoScalingEnabled(): void;
    get isStorageAutoScalingEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _licenseType?;
    get licenseType(): string;
    set licenseType(value: string);
    get licenseTypeInput(): string | undefined;
    get lifecycleDetails(): string;
    get localAdgAutoFailoverMaxDataLossLimit(): number;
    get localDisasterRecoveryType(): string;
    private _localStandbyDb;
    get localStandbyDb(): GoogleOracleDatabaseAutonomousDatabasePropertiesLocalStandbyDbList;
    get maintenanceBeginTime(): string;
    get maintenanceEndTime(): string;
    private _maintenanceScheduleType?;
    get maintenanceScheduleType(): string;
    set maintenanceScheduleType(value: string);
    resetMaintenanceScheduleType(): void;
    get maintenanceScheduleTypeInput(): string | undefined;
    get memoryPerOracleComputeUnitGbs(): number;
    get memoryTableGbs(): number;
    private _mtlsConnectionRequired?;
    get mtlsConnectionRequired(): boolean | cdktf.IResolvable;
    set mtlsConnectionRequired(value: boolean | cdktf.IResolvable);
    resetMtlsConnectionRequired(): void;
    get mtlsConnectionRequiredInput(): boolean | cdktf.IResolvable | undefined;
    private _nCharacterSet?;
    get nCharacterSet(): string;
    set nCharacterSet(value: string);
    resetNCharacterSet(): void;
    get nCharacterSetInput(): string | undefined;
    get nextLongTermBackupTime(): string;
    get ociUrl(): string;
    get ocid(): string;
    get openMode(): string;
    private _operationsInsightsState?;
    get operationsInsightsState(): string;
    set operationsInsightsState(value: string);
    resetOperationsInsightsState(): void;
    get operationsInsightsStateInput(): string | undefined;
    get peerDbIds(): string[];
    get permissionLevel(): string;
    get privateEndpoint(): string;
    private _privateEndpointIp?;
    get privateEndpointIp(): string;
    set privateEndpointIp(value: string);
    resetPrivateEndpointIp(): void;
    get privateEndpointIpInput(): string | undefined;
    private _privateEndpointLabel?;
    get privateEndpointLabel(): string;
    set privateEndpointLabel(value: string);
    resetPrivateEndpointLabel(): void;
    get privateEndpointLabelInput(): string | undefined;
    get refreshableMode(): string;
    get refreshableState(): string;
    get role(): string;
    private _scheduledOperationDetails;
    get scheduledOperationDetails(): GoogleOracleDatabaseAutonomousDatabasePropertiesScheduledOperationDetailsList;
    get sqlWebDeveloperUrl(): string;
    get state(): string;
    get supportedCloneRegions(): string[];
    get totalAutoBackupStorageSizeGbs(): number;
    get usedDataStorageSizeTbs(): number;
    private _customerContacts;
    get customerContacts(): GoogleOracleDatabaseAutonomousDatabasePropertiesCustomerContactsList;
    putCustomerContacts(value: GoogleOracleDatabaseAutonomousDatabasePropertiesCustomerContacts[] | cdktf.IResolvable): void;
    resetCustomerContacts(): void;
    get customerContactsInput(): cdktf.IResolvable | GoogleOracleDatabaseAutonomousDatabasePropertiesCustomerContacts[] | undefined;
}
export interface GoogleOracleDatabaseAutonomousDatabaseTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_oracle_database_autonomous_database#create GoogleOracleDatabaseAutonomousDatabase#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_oracle_database_autonomous_database#delete GoogleOracleDatabaseAutonomousDatabase#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_oracle_database_autonomous_database#update GoogleOracleDatabaseAutonomousDatabase#update}
    */
    readonly update?: string;
}
export declare function googleOracleDatabaseAutonomousDatabaseTimeoutsToTerraform(struct?: GoogleOracleDatabaseAutonomousDatabaseTimeouts | cdktf.IResolvable): any;
export declare function googleOracleDatabaseAutonomousDatabaseTimeoutsToHclTerraform(struct?: GoogleOracleDatabaseAutonomousDatabaseTimeouts | cdktf.IResolvable): any;
export declare class GoogleOracleDatabaseAutonomousDatabaseTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleOracleDatabaseAutonomousDatabaseTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleOracleDatabaseAutonomousDatabaseTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_oracle_database_autonomous_database google_oracle_database_autonomous_database}
*/
export declare class GoogleOracleDatabaseAutonomousDatabase extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_oracle_database_autonomous_database";
    /**
    * Generates CDKTF code for importing a GoogleOracleDatabaseAutonomousDatabase resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleOracleDatabaseAutonomousDatabase to import
    * @param importFromId The id of the existing GoogleOracleDatabaseAutonomousDatabase that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_oracle_database_autonomous_database#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleOracleDatabaseAutonomousDatabase to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_oracle_database_autonomous_database google_oracle_database_autonomous_database} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleOracleDatabaseAutonomousDatabaseConfig
    */
    constructor(scope: Construct, id: string, config: GoogleOracleDatabaseAutonomousDatabaseConfig);
    private _adminPassword?;
    get adminPassword(): string;
    set adminPassword(value: string);
    resetAdminPassword(): void;
    get adminPasswordInput(): string | undefined;
    private _autonomousDatabaseId?;
    get autonomousDatabaseId(): string;
    set autonomousDatabaseId(value: string);
    get autonomousDatabaseIdInput(): string | undefined;
    private _cidr?;
    get cidr(): string;
    set cidr(value: string);
    get cidrInput(): string | undefined;
    get createTime(): string;
    private _database?;
    get database(): string;
    set database(value: string);
    get databaseInput(): string | undefined;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    resetDisplayName(): void;
    get displayNameInput(): string | undefined;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    get entitlementId(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    get name(): string;
    private _network?;
    get network(): string;
    set network(value: string);
    get networkInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    private _properties;
    get properties(): GoogleOracleDatabaseAutonomousDatabasePropertiesOutputReference;
    putProperties(value: GoogleOracleDatabaseAutonomousDatabaseProperties): void;
    get propertiesInput(): GoogleOracleDatabaseAutonomousDatabaseProperties | undefined;
    private _timeouts;
    get timeouts(): GoogleOracleDatabaseAutonomousDatabaseTimeoutsOutputReference;
    putTimeouts(value: GoogleOracleDatabaseAutonomousDatabaseTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleOracleDatabaseAutonomousDatabaseTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
