/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GooglePrivilegedAccessManagerEntitlementConfig extends cdktf.TerraformMetaArguments {
    /**
    * The ID to use for this Entitlement. This will become the last part of the resource name.
    * This value should be 4-63 characters, and valid characters are "[a-z]", "[0-9]", and "-". The first character should be from [a-z].
    * This value should be unique among all other Entitlements under the specified 'parent'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_privileged_access_manager_entitlement#entitlement_id GooglePrivilegedAccessManagerEntitlement#entitlement_id}
    */
    readonly entitlementId: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_privileged_access_manager_entitlement#id GooglePrivilegedAccessManagerEntitlement#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The region of the Entitlement resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_privileged_access_manager_entitlement#location GooglePrivilegedAccessManagerEntitlement#location}
    */
    readonly location: string;
    /**
    * The maximum amount of time for which access would be granted for a request.
    * A requester can choose to ask for access for less than this duration but never more.
    * Format: calculate the time in seconds and concatenate it with 's' i.e. 2 hours = "7200s", 45 minutes = "2700s"
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_privileged_access_manager_entitlement#max_request_duration GooglePrivilegedAccessManagerEntitlement#max_request_duration}
    */
    readonly maxRequestDuration: string;
    /**
    * Format: projects/{project-id|project-number} or organizations/{organization-number} or folders/{folder-number}
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_privileged_access_manager_entitlement#parent GooglePrivilegedAccessManagerEntitlement#parent}
    */
    readonly parent: string;
    /**
    * additional_notification_targets block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_privileged_access_manager_entitlement#additional_notification_targets GooglePrivilegedAccessManagerEntitlement#additional_notification_targets}
    */
    readonly additionalNotificationTargets?: GooglePrivilegedAccessManagerEntitlementAdditionalNotificationTargets;
    /**
    * approval_workflow block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_privileged_access_manager_entitlement#approval_workflow GooglePrivilegedAccessManagerEntitlement#approval_workflow}
    */
    readonly approvalWorkflow?: GooglePrivilegedAccessManagerEntitlementApprovalWorkflow;
    /**
    * eligible_users block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_privileged_access_manager_entitlement#eligible_users GooglePrivilegedAccessManagerEntitlement#eligible_users}
    */
    readonly eligibleUsers: GooglePrivilegedAccessManagerEntitlementEligibleUsers[] | cdktf.IResolvable;
    /**
    * privileged_access block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_privileged_access_manager_entitlement#privileged_access GooglePrivilegedAccessManagerEntitlement#privileged_access}
    */
    readonly privilegedAccess: GooglePrivilegedAccessManagerEntitlementPrivilegedAccess;
    /**
    * requester_justification_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_privileged_access_manager_entitlement#requester_justification_config GooglePrivilegedAccessManagerEntitlement#requester_justification_config}
    */
    readonly requesterJustificationConfig: GooglePrivilegedAccessManagerEntitlementRequesterJustificationConfig;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_privileged_access_manager_entitlement#timeouts GooglePrivilegedAccessManagerEntitlement#timeouts}
    */
    readonly timeouts?: GooglePrivilegedAccessManagerEntitlementTimeouts;
}
export interface GooglePrivilegedAccessManagerEntitlementAdditionalNotificationTargets {
    /**
    * Optional. Additional email addresses to be notified when a principal(requester) is granted access.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_privileged_access_manager_entitlement#admin_email_recipients GooglePrivilegedAccessManagerEntitlement#admin_email_recipients}
    */
    readonly adminEmailRecipients?: string[];
    /**
    * Optional. Additional email address to be notified about an eligible entitlement.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_privileged_access_manager_entitlement#requester_email_recipients GooglePrivilegedAccessManagerEntitlement#requester_email_recipients}
    */
    readonly requesterEmailRecipients?: string[];
}
export declare function googlePrivilegedAccessManagerEntitlementAdditionalNotificationTargetsToTerraform(struct?: GooglePrivilegedAccessManagerEntitlementAdditionalNotificationTargetsOutputReference | GooglePrivilegedAccessManagerEntitlementAdditionalNotificationTargets): any;
export declare function googlePrivilegedAccessManagerEntitlementAdditionalNotificationTargetsToHclTerraform(struct?: GooglePrivilegedAccessManagerEntitlementAdditionalNotificationTargetsOutputReference | GooglePrivilegedAccessManagerEntitlementAdditionalNotificationTargets): any;
export declare class GooglePrivilegedAccessManagerEntitlementAdditionalNotificationTargetsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GooglePrivilegedAccessManagerEntitlementAdditionalNotificationTargets | undefined;
    set internalValue(value: GooglePrivilegedAccessManagerEntitlementAdditionalNotificationTargets | undefined);
    private _adminEmailRecipients?;
    get adminEmailRecipients(): string[];
    set adminEmailRecipients(value: string[]);
    resetAdminEmailRecipients(): void;
    get adminEmailRecipientsInput(): string[] | undefined;
    private _requesterEmailRecipients?;
    get requesterEmailRecipients(): string[];
    set requesterEmailRecipients(value: string[]);
    resetRequesterEmailRecipients(): void;
    get requesterEmailRecipientsInput(): string[] | undefined;
}
export interface GooglePrivilegedAccessManagerEntitlementApprovalWorkflowManualApprovalsStepsApprovers {
    /**
    * Users who are being allowed for the operation. Each entry should be a valid v1 IAM Principal Identifier. Format for these is documented at: https://cloud.google.com/iam/docs/principal-identifiers#v1
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_privileged_access_manager_entitlement#principals GooglePrivilegedAccessManagerEntitlement#principals}
    */
    readonly principals: string[];
}
export declare function googlePrivilegedAccessManagerEntitlementApprovalWorkflowManualApprovalsStepsApproversToTerraform(struct?: GooglePrivilegedAccessManagerEntitlementApprovalWorkflowManualApprovalsStepsApproversOutputReference | GooglePrivilegedAccessManagerEntitlementApprovalWorkflowManualApprovalsStepsApprovers): any;
export declare function googlePrivilegedAccessManagerEntitlementApprovalWorkflowManualApprovalsStepsApproversToHclTerraform(struct?: GooglePrivilegedAccessManagerEntitlementApprovalWorkflowManualApprovalsStepsApproversOutputReference | GooglePrivilegedAccessManagerEntitlementApprovalWorkflowManualApprovalsStepsApprovers): any;
export declare class GooglePrivilegedAccessManagerEntitlementApprovalWorkflowManualApprovalsStepsApproversOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GooglePrivilegedAccessManagerEntitlementApprovalWorkflowManualApprovalsStepsApprovers | undefined;
    set internalValue(value: GooglePrivilegedAccessManagerEntitlementApprovalWorkflowManualApprovalsStepsApprovers | undefined);
    private _principals?;
    get principals(): string[];
    set principals(value: string[]);
    get principalsInput(): string[] | undefined;
}
export interface GooglePrivilegedAccessManagerEntitlementApprovalWorkflowManualApprovalsSteps {
    /**
    * How many users from the above list need to approve.
    * If there are not enough distinct users in the list above then the workflow
    * will indefinitely block. Should always be greater than 0. Currently 1 is the only
    * supported value.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_privileged_access_manager_entitlement#approvals_needed GooglePrivilegedAccessManagerEntitlement#approvals_needed}
    */
    readonly approvalsNeeded?: number;
    /**
    * Optional. Additional email addresses to be notified when a grant is pending approval.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_privileged_access_manager_entitlement#approver_email_recipients GooglePrivilegedAccessManagerEntitlement#approver_email_recipients}
    */
    readonly approverEmailRecipients?: string[];
    /**
    * approvers block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_privileged_access_manager_entitlement#approvers GooglePrivilegedAccessManagerEntitlement#approvers}
    */
    readonly approvers: GooglePrivilegedAccessManagerEntitlementApprovalWorkflowManualApprovalsStepsApprovers;
}
export declare function googlePrivilegedAccessManagerEntitlementApprovalWorkflowManualApprovalsStepsToTerraform(struct?: GooglePrivilegedAccessManagerEntitlementApprovalWorkflowManualApprovalsSteps | cdktf.IResolvable): any;
export declare function googlePrivilegedAccessManagerEntitlementApprovalWorkflowManualApprovalsStepsToHclTerraform(struct?: GooglePrivilegedAccessManagerEntitlementApprovalWorkflowManualApprovalsSteps | cdktf.IResolvable): any;
export declare class GooglePrivilegedAccessManagerEntitlementApprovalWorkflowManualApprovalsStepsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GooglePrivilegedAccessManagerEntitlementApprovalWorkflowManualApprovalsSteps | cdktf.IResolvable | undefined;
    set internalValue(value: GooglePrivilegedAccessManagerEntitlementApprovalWorkflowManualApprovalsSteps | cdktf.IResolvable | undefined);
    private _approvalsNeeded?;
    get approvalsNeeded(): number;
    set approvalsNeeded(value: number);
    resetApprovalsNeeded(): void;
    get approvalsNeededInput(): number | undefined;
    private _approverEmailRecipients?;
    get approverEmailRecipients(): string[];
    set approverEmailRecipients(value: string[]);
    resetApproverEmailRecipients(): void;
    get approverEmailRecipientsInput(): string[] | undefined;
    private _approvers;
    get approvers(): GooglePrivilegedAccessManagerEntitlementApprovalWorkflowManualApprovalsStepsApproversOutputReference;
    putApprovers(value: GooglePrivilegedAccessManagerEntitlementApprovalWorkflowManualApprovalsStepsApprovers): void;
    get approversInput(): GooglePrivilegedAccessManagerEntitlementApprovalWorkflowManualApprovalsStepsApprovers | undefined;
}
export declare class GooglePrivilegedAccessManagerEntitlementApprovalWorkflowManualApprovalsStepsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GooglePrivilegedAccessManagerEntitlementApprovalWorkflowManualApprovalsSteps[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GooglePrivilegedAccessManagerEntitlementApprovalWorkflowManualApprovalsStepsOutputReference;
}
export interface GooglePrivilegedAccessManagerEntitlementApprovalWorkflowManualApprovals {
    /**
    * Optional. Do the approvers need to provide a justification for their actions?
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_privileged_access_manager_entitlement#require_approver_justification GooglePrivilegedAccessManagerEntitlement#require_approver_justification}
    */
    readonly requireApproverJustification?: boolean | cdktf.IResolvable;
    /**
    * steps block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_privileged_access_manager_entitlement#steps GooglePrivilegedAccessManagerEntitlement#steps}
    */
    readonly steps: GooglePrivilegedAccessManagerEntitlementApprovalWorkflowManualApprovalsSteps[] | cdktf.IResolvable;
}
export declare function googlePrivilegedAccessManagerEntitlementApprovalWorkflowManualApprovalsToTerraform(struct?: GooglePrivilegedAccessManagerEntitlementApprovalWorkflowManualApprovalsOutputReference | GooglePrivilegedAccessManagerEntitlementApprovalWorkflowManualApprovals): any;
export declare function googlePrivilegedAccessManagerEntitlementApprovalWorkflowManualApprovalsToHclTerraform(struct?: GooglePrivilegedAccessManagerEntitlementApprovalWorkflowManualApprovalsOutputReference | GooglePrivilegedAccessManagerEntitlementApprovalWorkflowManualApprovals): any;
export declare class GooglePrivilegedAccessManagerEntitlementApprovalWorkflowManualApprovalsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GooglePrivilegedAccessManagerEntitlementApprovalWorkflowManualApprovals | undefined;
    set internalValue(value: GooglePrivilegedAccessManagerEntitlementApprovalWorkflowManualApprovals | undefined);
    private _requireApproverJustification?;
    get requireApproverJustification(): boolean | cdktf.IResolvable;
    set requireApproverJustification(value: boolean | cdktf.IResolvable);
    resetRequireApproverJustification(): void;
    get requireApproverJustificationInput(): boolean | cdktf.IResolvable | undefined;
    private _steps;
    get steps(): GooglePrivilegedAccessManagerEntitlementApprovalWorkflowManualApprovalsStepsList;
    putSteps(value: GooglePrivilegedAccessManagerEntitlementApprovalWorkflowManualApprovalsSteps[] | cdktf.IResolvable): void;
    get stepsInput(): cdktf.IResolvable | GooglePrivilegedAccessManagerEntitlementApprovalWorkflowManualApprovalsSteps[] | undefined;
}
export interface GooglePrivilegedAccessManagerEntitlementApprovalWorkflow {
    /**
    * manual_approvals block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_privileged_access_manager_entitlement#manual_approvals GooglePrivilegedAccessManagerEntitlement#manual_approvals}
    */
    readonly manualApprovals: GooglePrivilegedAccessManagerEntitlementApprovalWorkflowManualApprovals;
}
export declare function googlePrivilegedAccessManagerEntitlementApprovalWorkflowToTerraform(struct?: GooglePrivilegedAccessManagerEntitlementApprovalWorkflowOutputReference | GooglePrivilegedAccessManagerEntitlementApprovalWorkflow): any;
export declare function googlePrivilegedAccessManagerEntitlementApprovalWorkflowToHclTerraform(struct?: GooglePrivilegedAccessManagerEntitlementApprovalWorkflowOutputReference | GooglePrivilegedAccessManagerEntitlementApprovalWorkflow): any;
export declare class GooglePrivilegedAccessManagerEntitlementApprovalWorkflowOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GooglePrivilegedAccessManagerEntitlementApprovalWorkflow | undefined;
    set internalValue(value: GooglePrivilegedAccessManagerEntitlementApprovalWorkflow | undefined);
    private _manualApprovals;
    get manualApprovals(): GooglePrivilegedAccessManagerEntitlementApprovalWorkflowManualApprovalsOutputReference;
    putManualApprovals(value: GooglePrivilegedAccessManagerEntitlementApprovalWorkflowManualApprovals): void;
    get manualApprovalsInput(): GooglePrivilegedAccessManagerEntitlementApprovalWorkflowManualApprovals | undefined;
}
export interface GooglePrivilegedAccessManagerEntitlementEligibleUsers {
    /**
    * Users who are being allowed for the operation. Each entry should be a valid v1 IAM Principal Identifier. Format for these is documented at "https://cloud.google.com/iam/docs/principal-identifiers#v1"
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_privileged_access_manager_entitlement#principals GooglePrivilegedAccessManagerEntitlement#principals}
    */
    readonly principals: string[];
}
export declare function googlePrivilegedAccessManagerEntitlementEligibleUsersToTerraform(struct?: GooglePrivilegedAccessManagerEntitlementEligibleUsers | cdktf.IResolvable): any;
export declare function googlePrivilegedAccessManagerEntitlementEligibleUsersToHclTerraform(struct?: GooglePrivilegedAccessManagerEntitlementEligibleUsers | cdktf.IResolvable): any;
export declare class GooglePrivilegedAccessManagerEntitlementEligibleUsersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GooglePrivilegedAccessManagerEntitlementEligibleUsers | cdktf.IResolvable | undefined;
    set internalValue(value: GooglePrivilegedAccessManagerEntitlementEligibleUsers | cdktf.IResolvable | undefined);
    private _principals?;
    get principals(): string[];
    set principals(value: string[]);
    get principalsInput(): string[] | undefined;
}
export declare class GooglePrivilegedAccessManagerEntitlementEligibleUsersList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GooglePrivilegedAccessManagerEntitlementEligibleUsers[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GooglePrivilegedAccessManagerEntitlementEligibleUsersOutputReference;
}
export interface GooglePrivilegedAccessManagerEntitlementPrivilegedAccessGcpIamAccessRoleBindings {
    /**
    * The expression field of the IAM condition to be associated with the role. If specified, a user with an active grant for this entitlement would be able to access the resource only if this condition evaluates to true for their request.
    * https://cloud.google.com/iam/docs/conditions-overview#attributes.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_privileged_access_manager_entitlement#condition_expression GooglePrivilegedAccessManagerEntitlement#condition_expression}
    */
    readonly conditionExpression?: string;
    /**
    * IAM role to be granted. https://cloud.google.com/iam/docs/roles-overview.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_privileged_access_manager_entitlement#role GooglePrivilegedAccessManagerEntitlement#role}
    */
    readonly role: string;
}
export declare function googlePrivilegedAccessManagerEntitlementPrivilegedAccessGcpIamAccessRoleBindingsToTerraform(struct?: GooglePrivilegedAccessManagerEntitlementPrivilegedAccessGcpIamAccessRoleBindings | cdktf.IResolvable): any;
export declare function googlePrivilegedAccessManagerEntitlementPrivilegedAccessGcpIamAccessRoleBindingsToHclTerraform(struct?: GooglePrivilegedAccessManagerEntitlementPrivilegedAccessGcpIamAccessRoleBindings | cdktf.IResolvable): any;
export declare class GooglePrivilegedAccessManagerEntitlementPrivilegedAccessGcpIamAccessRoleBindingsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GooglePrivilegedAccessManagerEntitlementPrivilegedAccessGcpIamAccessRoleBindings | cdktf.IResolvable | undefined;
    set internalValue(value: GooglePrivilegedAccessManagerEntitlementPrivilegedAccessGcpIamAccessRoleBindings | cdktf.IResolvable | undefined);
    private _conditionExpression?;
    get conditionExpression(): string;
    set conditionExpression(value: string);
    resetConditionExpression(): void;
    get conditionExpressionInput(): string | undefined;
    private _role?;
    get role(): string;
    set role(value: string);
    get roleInput(): string | undefined;
}
export declare class GooglePrivilegedAccessManagerEntitlementPrivilegedAccessGcpIamAccessRoleBindingsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GooglePrivilegedAccessManagerEntitlementPrivilegedAccessGcpIamAccessRoleBindings[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GooglePrivilegedAccessManagerEntitlementPrivilegedAccessGcpIamAccessRoleBindingsOutputReference;
}
export interface GooglePrivilegedAccessManagerEntitlementPrivilegedAccessGcpIamAccess {
    /**
    * Name of the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_privileged_access_manager_entitlement#resource GooglePrivilegedAccessManagerEntitlement#resource}
    */
    readonly resource: string;
    /**
    * The type of this resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_privileged_access_manager_entitlement#resource_type GooglePrivilegedAccessManagerEntitlement#resource_type}
    */
    readonly resourceType: string;
    /**
    * role_bindings block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_privileged_access_manager_entitlement#role_bindings GooglePrivilegedAccessManagerEntitlement#role_bindings}
    */
    readonly roleBindings: GooglePrivilegedAccessManagerEntitlementPrivilegedAccessGcpIamAccessRoleBindings[] | cdktf.IResolvable;
}
export declare function googlePrivilegedAccessManagerEntitlementPrivilegedAccessGcpIamAccessToTerraform(struct?: GooglePrivilegedAccessManagerEntitlementPrivilegedAccessGcpIamAccessOutputReference | GooglePrivilegedAccessManagerEntitlementPrivilegedAccessGcpIamAccess): any;
export declare function googlePrivilegedAccessManagerEntitlementPrivilegedAccessGcpIamAccessToHclTerraform(struct?: GooglePrivilegedAccessManagerEntitlementPrivilegedAccessGcpIamAccessOutputReference | GooglePrivilegedAccessManagerEntitlementPrivilegedAccessGcpIamAccess): any;
export declare class GooglePrivilegedAccessManagerEntitlementPrivilegedAccessGcpIamAccessOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GooglePrivilegedAccessManagerEntitlementPrivilegedAccessGcpIamAccess | undefined;
    set internalValue(value: GooglePrivilegedAccessManagerEntitlementPrivilegedAccessGcpIamAccess | undefined);
    private _resource?;
    get resource(): string;
    set resource(value: string);
    get resourceInput(): string | undefined;
    private _resourceType?;
    get resourceType(): string;
    set resourceType(value: string);
    get resourceTypeInput(): string | undefined;
    private _roleBindings;
    get roleBindings(): GooglePrivilegedAccessManagerEntitlementPrivilegedAccessGcpIamAccessRoleBindingsList;
    putRoleBindings(value: GooglePrivilegedAccessManagerEntitlementPrivilegedAccessGcpIamAccessRoleBindings[] | cdktf.IResolvable): void;
    get roleBindingsInput(): cdktf.IResolvable | GooglePrivilegedAccessManagerEntitlementPrivilegedAccessGcpIamAccessRoleBindings[] | undefined;
}
export interface GooglePrivilegedAccessManagerEntitlementPrivilegedAccess {
    /**
    * gcp_iam_access block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_privileged_access_manager_entitlement#gcp_iam_access GooglePrivilegedAccessManagerEntitlement#gcp_iam_access}
    */
    readonly gcpIamAccess: GooglePrivilegedAccessManagerEntitlementPrivilegedAccessGcpIamAccess;
}
export declare function googlePrivilegedAccessManagerEntitlementPrivilegedAccessToTerraform(struct?: GooglePrivilegedAccessManagerEntitlementPrivilegedAccessOutputReference | GooglePrivilegedAccessManagerEntitlementPrivilegedAccess): any;
export declare function googlePrivilegedAccessManagerEntitlementPrivilegedAccessToHclTerraform(struct?: GooglePrivilegedAccessManagerEntitlementPrivilegedAccessOutputReference | GooglePrivilegedAccessManagerEntitlementPrivilegedAccess): any;
export declare class GooglePrivilegedAccessManagerEntitlementPrivilegedAccessOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GooglePrivilegedAccessManagerEntitlementPrivilegedAccess | undefined;
    set internalValue(value: GooglePrivilegedAccessManagerEntitlementPrivilegedAccess | undefined);
    private _gcpIamAccess;
    get gcpIamAccess(): GooglePrivilegedAccessManagerEntitlementPrivilegedAccessGcpIamAccessOutputReference;
    putGcpIamAccess(value: GooglePrivilegedAccessManagerEntitlementPrivilegedAccessGcpIamAccess): void;
    get gcpIamAccessInput(): GooglePrivilegedAccessManagerEntitlementPrivilegedAccessGcpIamAccess | undefined;
}
export interface GooglePrivilegedAccessManagerEntitlementRequesterJustificationConfigNotMandatory {
}
export declare function googlePrivilegedAccessManagerEntitlementRequesterJustificationConfigNotMandatoryToTerraform(struct?: GooglePrivilegedAccessManagerEntitlementRequesterJustificationConfigNotMandatoryOutputReference | GooglePrivilegedAccessManagerEntitlementRequesterJustificationConfigNotMandatory): any;
export declare function googlePrivilegedAccessManagerEntitlementRequesterJustificationConfigNotMandatoryToHclTerraform(struct?: GooglePrivilegedAccessManagerEntitlementRequesterJustificationConfigNotMandatoryOutputReference | GooglePrivilegedAccessManagerEntitlementRequesterJustificationConfigNotMandatory): any;
export declare class GooglePrivilegedAccessManagerEntitlementRequesterJustificationConfigNotMandatoryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GooglePrivilegedAccessManagerEntitlementRequesterJustificationConfigNotMandatory | undefined;
    set internalValue(value: GooglePrivilegedAccessManagerEntitlementRequesterJustificationConfigNotMandatory | undefined);
}
export interface GooglePrivilegedAccessManagerEntitlementRequesterJustificationConfigUnstructured {
}
export declare function googlePrivilegedAccessManagerEntitlementRequesterJustificationConfigUnstructuredToTerraform(struct?: GooglePrivilegedAccessManagerEntitlementRequesterJustificationConfigUnstructuredOutputReference | GooglePrivilegedAccessManagerEntitlementRequesterJustificationConfigUnstructured): any;
export declare function googlePrivilegedAccessManagerEntitlementRequesterJustificationConfigUnstructuredToHclTerraform(struct?: GooglePrivilegedAccessManagerEntitlementRequesterJustificationConfigUnstructuredOutputReference | GooglePrivilegedAccessManagerEntitlementRequesterJustificationConfigUnstructured): any;
export declare class GooglePrivilegedAccessManagerEntitlementRequesterJustificationConfigUnstructuredOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GooglePrivilegedAccessManagerEntitlementRequesterJustificationConfigUnstructured | undefined;
    set internalValue(value: GooglePrivilegedAccessManagerEntitlementRequesterJustificationConfigUnstructured | undefined);
}
export interface GooglePrivilegedAccessManagerEntitlementRequesterJustificationConfig {
    /**
    * not_mandatory block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_privileged_access_manager_entitlement#not_mandatory GooglePrivilegedAccessManagerEntitlement#not_mandatory}
    */
    readonly notMandatory?: GooglePrivilegedAccessManagerEntitlementRequesterJustificationConfigNotMandatory;
    /**
    * unstructured block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_privileged_access_manager_entitlement#unstructured GooglePrivilegedAccessManagerEntitlement#unstructured}
    */
    readonly unstructured?: GooglePrivilegedAccessManagerEntitlementRequesterJustificationConfigUnstructured;
}
export declare function googlePrivilegedAccessManagerEntitlementRequesterJustificationConfigToTerraform(struct?: GooglePrivilegedAccessManagerEntitlementRequesterJustificationConfigOutputReference | GooglePrivilegedAccessManagerEntitlementRequesterJustificationConfig): any;
export declare function googlePrivilegedAccessManagerEntitlementRequesterJustificationConfigToHclTerraform(struct?: GooglePrivilegedAccessManagerEntitlementRequesterJustificationConfigOutputReference | GooglePrivilegedAccessManagerEntitlementRequesterJustificationConfig): any;
export declare class GooglePrivilegedAccessManagerEntitlementRequesterJustificationConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GooglePrivilegedAccessManagerEntitlementRequesterJustificationConfig | undefined;
    set internalValue(value: GooglePrivilegedAccessManagerEntitlementRequesterJustificationConfig | undefined);
    private _notMandatory;
    get notMandatory(): GooglePrivilegedAccessManagerEntitlementRequesterJustificationConfigNotMandatoryOutputReference;
    putNotMandatory(value: GooglePrivilegedAccessManagerEntitlementRequesterJustificationConfigNotMandatory): void;
    resetNotMandatory(): void;
    get notMandatoryInput(): GooglePrivilegedAccessManagerEntitlementRequesterJustificationConfigNotMandatory | undefined;
    private _unstructured;
    get unstructured(): GooglePrivilegedAccessManagerEntitlementRequesterJustificationConfigUnstructuredOutputReference;
    putUnstructured(value: GooglePrivilegedAccessManagerEntitlementRequesterJustificationConfigUnstructured): void;
    resetUnstructured(): void;
    get unstructuredInput(): GooglePrivilegedAccessManagerEntitlementRequesterJustificationConfigUnstructured | undefined;
}
export interface GooglePrivilegedAccessManagerEntitlementTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_privileged_access_manager_entitlement#create GooglePrivilegedAccessManagerEntitlement#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_privileged_access_manager_entitlement#delete GooglePrivilegedAccessManagerEntitlement#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_privileged_access_manager_entitlement#update GooglePrivilegedAccessManagerEntitlement#update}
    */
    readonly update?: string;
}
export declare function googlePrivilegedAccessManagerEntitlementTimeoutsToTerraform(struct?: GooglePrivilegedAccessManagerEntitlementTimeouts | cdktf.IResolvable): any;
export declare function googlePrivilegedAccessManagerEntitlementTimeoutsToHclTerraform(struct?: GooglePrivilegedAccessManagerEntitlementTimeouts | cdktf.IResolvable): any;
export declare class GooglePrivilegedAccessManagerEntitlementTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GooglePrivilegedAccessManagerEntitlementTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GooglePrivilegedAccessManagerEntitlementTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_privileged_access_manager_entitlement google_privileged_access_manager_entitlement}
*/
export declare class GooglePrivilegedAccessManagerEntitlement extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_privileged_access_manager_entitlement";
    /**
    * Generates CDKTF code for importing a GooglePrivilegedAccessManagerEntitlement resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GooglePrivilegedAccessManagerEntitlement to import
    * @param importFromId The id of the existing GooglePrivilegedAccessManagerEntitlement that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_privileged_access_manager_entitlement#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GooglePrivilegedAccessManagerEntitlement to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_privileged_access_manager_entitlement google_privileged_access_manager_entitlement} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GooglePrivilegedAccessManagerEntitlementConfig
    */
    constructor(scope: Construct, id: string, config: GooglePrivilegedAccessManagerEntitlementConfig);
    get createTime(): string;
    private _entitlementId?;
    get entitlementId(): string;
    set entitlementId(value: string);
    get entitlementIdInput(): string | undefined;
    get etag(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    private _maxRequestDuration?;
    get maxRequestDuration(): string;
    set maxRequestDuration(value: string);
    get maxRequestDurationInput(): string | undefined;
    get name(): string;
    private _parent?;
    get parent(): string;
    set parent(value: string);
    get parentInput(): string | undefined;
    get state(): string;
    get updateTime(): string;
    private _additionalNotificationTargets;
    get additionalNotificationTargets(): GooglePrivilegedAccessManagerEntitlementAdditionalNotificationTargetsOutputReference;
    putAdditionalNotificationTargets(value: GooglePrivilegedAccessManagerEntitlementAdditionalNotificationTargets): void;
    resetAdditionalNotificationTargets(): void;
    get additionalNotificationTargetsInput(): GooglePrivilegedAccessManagerEntitlementAdditionalNotificationTargets | undefined;
    private _approvalWorkflow;
    get approvalWorkflow(): GooglePrivilegedAccessManagerEntitlementApprovalWorkflowOutputReference;
    putApprovalWorkflow(value: GooglePrivilegedAccessManagerEntitlementApprovalWorkflow): void;
    resetApprovalWorkflow(): void;
    get approvalWorkflowInput(): GooglePrivilegedAccessManagerEntitlementApprovalWorkflow | undefined;
    private _eligibleUsers;
    get eligibleUsers(): GooglePrivilegedAccessManagerEntitlementEligibleUsersList;
    putEligibleUsers(value: GooglePrivilegedAccessManagerEntitlementEligibleUsers[] | cdktf.IResolvable): void;
    get eligibleUsersInput(): cdktf.IResolvable | GooglePrivilegedAccessManagerEntitlementEligibleUsers[] | undefined;
    private _privilegedAccess;
    get privilegedAccess(): GooglePrivilegedAccessManagerEntitlementPrivilegedAccessOutputReference;
    putPrivilegedAccess(value: GooglePrivilegedAccessManagerEntitlementPrivilegedAccess): void;
    get privilegedAccessInput(): GooglePrivilegedAccessManagerEntitlementPrivilegedAccess | undefined;
    private _requesterJustificationConfig;
    get requesterJustificationConfig(): GooglePrivilegedAccessManagerEntitlementRequesterJustificationConfigOutputReference;
    putRequesterJustificationConfig(value: GooglePrivilegedAccessManagerEntitlementRequesterJustificationConfig): void;
    get requesterJustificationConfigInput(): GooglePrivilegedAccessManagerEntitlementRequesterJustificationConfig | undefined;
    private _timeouts;
    get timeouts(): GooglePrivilegedAccessManagerEntitlementTimeoutsOutputReference;
    putTimeouts(value: GooglePrivilegedAccessManagerEntitlementTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GooglePrivilegedAccessManagerEntitlementTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
