/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleSccV2FolderNotificationConfigConfig extends cdktf.TerraformMetaArguments {
    /**
    * This must be unique within the organization.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_scc_v2_folder_notification_config#config_id GoogleSccV2FolderNotificationConfig#config_id}
    */
    readonly configId: string;
    /**
    * The description of the notification config (max of 1024 characters).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_scc_v2_folder_notification_config#description GoogleSccV2FolderNotificationConfig#description}
    */
    readonly description?: string;
    /**
    * Numerical ID of the parent folder.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_scc_v2_folder_notification_config#folder GoogleSccV2FolderNotificationConfig#folder}
    */
    readonly folder: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_scc_v2_folder_notification_config#id GoogleSccV2FolderNotificationConfig#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Location ID of the parent organization. If not provided, 'global' will be used as the default location.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_scc_v2_folder_notification_config#location GoogleSccV2FolderNotificationConfig#location}
    */
    readonly location?: string;
    /**
    * The Pub/Sub topic to send notifications to. Its format is
    * "projects/[project_id]/topics/[topic]".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_scc_v2_folder_notification_config#pubsub_topic GoogleSccV2FolderNotificationConfig#pubsub_topic}
    */
    readonly pubsubTopic: string;
    /**
    * streaming_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_scc_v2_folder_notification_config#streaming_config GoogleSccV2FolderNotificationConfig#streaming_config}
    */
    readonly streamingConfig: GoogleSccV2FolderNotificationConfigStreamingConfig;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_scc_v2_folder_notification_config#timeouts GoogleSccV2FolderNotificationConfig#timeouts}
    */
    readonly timeouts?: GoogleSccV2FolderNotificationConfigTimeouts;
}
export interface GoogleSccV2FolderNotificationConfigStreamingConfig {
    /**
    * Expression that defines the filter to apply across create/update
    * events of assets or findings as specified by the event type. The
    * expression is a list of zero or more restrictions combined via
    * logical operators AND and OR. Parentheses are supported, and OR
    * has higher precedence than AND.
    *
    * Restrictions have the form <field> <operator> <value> and may have
    * a - character in front of them to indicate negation. The fields
    * map to those defined in the corresponding resource.
    *
    * The supported operators are:
    *
    * * = for all value types.
    * * >, <, >=, <= for integer values.
    * * :, meaning substring matching, for strings.
    *
    * The supported value types are:
    *
    * * string literals in quotes.
    * * integer literals without quotes.
    * * boolean literals true and false without quotes.
    *
    * See
    * [Filtering notifications](https://cloud.google.com/security-command-center/docs/how-to-api-filter-notifications)
    * for information on how to write a filter.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_scc_v2_folder_notification_config#filter GoogleSccV2FolderNotificationConfig#filter}
    */
    readonly filter: string;
}
export declare function googleSccV2FolderNotificationConfigStreamingConfigToTerraform(struct?: GoogleSccV2FolderNotificationConfigStreamingConfigOutputReference | GoogleSccV2FolderNotificationConfigStreamingConfig): any;
export declare function googleSccV2FolderNotificationConfigStreamingConfigToHclTerraform(struct?: GoogleSccV2FolderNotificationConfigStreamingConfigOutputReference | GoogleSccV2FolderNotificationConfigStreamingConfig): any;
export declare class GoogleSccV2FolderNotificationConfigStreamingConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleSccV2FolderNotificationConfigStreamingConfig | undefined;
    set internalValue(value: GoogleSccV2FolderNotificationConfigStreamingConfig | undefined);
    private _filter?;
    get filter(): string;
    set filter(value: string);
    get filterInput(): string | undefined;
}
export interface GoogleSccV2FolderNotificationConfigTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_scc_v2_folder_notification_config#create GoogleSccV2FolderNotificationConfig#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_scc_v2_folder_notification_config#delete GoogleSccV2FolderNotificationConfig#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_scc_v2_folder_notification_config#update GoogleSccV2FolderNotificationConfig#update}
    */
    readonly update?: string;
}
export declare function googleSccV2FolderNotificationConfigTimeoutsToTerraform(struct?: GoogleSccV2FolderNotificationConfigTimeouts | cdktf.IResolvable): any;
export declare function googleSccV2FolderNotificationConfigTimeoutsToHclTerraform(struct?: GoogleSccV2FolderNotificationConfigTimeouts | cdktf.IResolvable): any;
export declare class GoogleSccV2FolderNotificationConfigTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleSccV2FolderNotificationConfigTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleSccV2FolderNotificationConfigTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_scc_v2_folder_notification_config google_scc_v2_folder_notification_config}
*/
export declare class GoogleSccV2FolderNotificationConfig extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_scc_v2_folder_notification_config";
    /**
    * Generates CDKTF code for importing a GoogleSccV2FolderNotificationConfig resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleSccV2FolderNotificationConfig to import
    * @param importFromId The id of the existing GoogleSccV2FolderNotificationConfig that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_scc_v2_folder_notification_config#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleSccV2FolderNotificationConfig to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_scc_v2_folder_notification_config google_scc_v2_folder_notification_config} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleSccV2FolderNotificationConfigConfig
    */
    constructor(scope: Construct, id: string, config: GoogleSccV2FolderNotificationConfigConfig);
    private _configId?;
    get configId(): string;
    set configId(value: string);
    get configIdInput(): string | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _folder?;
    get folder(): string;
    set folder(value: string);
    get folderInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    resetLocation(): void;
    get locationInput(): string | undefined;
    get name(): string;
    private _pubsubTopic?;
    get pubsubTopic(): string;
    set pubsubTopic(value: string);
    get pubsubTopicInput(): string | undefined;
    get serviceAccount(): string;
    private _streamingConfig;
    get streamingConfig(): GoogleSccV2FolderNotificationConfigStreamingConfigOutputReference;
    putStreamingConfig(value: GoogleSccV2FolderNotificationConfigStreamingConfig): void;
    get streamingConfigInput(): GoogleSccV2FolderNotificationConfigStreamingConfig | undefined;
    private _timeouts;
    get timeouts(): GoogleSccV2FolderNotificationConfigTimeoutsOutputReference;
    putTimeouts(value: GoogleSccV2FolderNotificationConfigTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleSccV2FolderNotificationConfigTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
