/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleSccV2OrganizationMuteConfigConfig extends cdktf.TerraformMetaArguments {
    /**
    * A description of the mute config.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_scc_v2_organization_mute_config#description GoogleSccV2OrganizationMuteConfig#description}
    */
    readonly description?: string;
    /**
    * An expression that defines the filter to apply across create/update
    * events of findings. While creating a filter string, be mindful of
    * the scope in which the mute configuration is being created. E.g.,
    * If a filter contains project = X but is created under the
    * project = Y scope, it might not match any findings.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_scc_v2_organization_mute_config#filter GoogleSccV2OrganizationMuteConfig#filter}
    */
    readonly filter: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_scc_v2_organization_mute_config#id GoogleSccV2OrganizationMuteConfig#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * location Id is provided by organization. If not provided, Use global as default.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_scc_v2_organization_mute_config#location GoogleSccV2OrganizationMuteConfig#location}
    */
    readonly location?: string;
    /**
    * Unique identifier provided by the client within the parent scope.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_scc_v2_organization_mute_config#mute_config_id GoogleSccV2OrganizationMuteConfig#mute_config_id}
    */
    readonly muteConfigId: string;
    /**
    * The organization whose Cloud Security Command Center the Mute
    * Config lives in.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_scc_v2_organization_mute_config#organization GoogleSccV2OrganizationMuteConfig#organization}
    */
    readonly organization: string;
    /**
    * The type of the mute config.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_scc_v2_organization_mute_config#type GoogleSccV2OrganizationMuteConfig#type}
    */
    readonly type: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_scc_v2_organization_mute_config#timeouts GoogleSccV2OrganizationMuteConfig#timeouts}
    */
    readonly timeouts?: GoogleSccV2OrganizationMuteConfigTimeouts;
}
export interface GoogleSccV2OrganizationMuteConfigTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_scc_v2_organization_mute_config#create GoogleSccV2OrganizationMuteConfig#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_scc_v2_organization_mute_config#delete GoogleSccV2OrganizationMuteConfig#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_scc_v2_organization_mute_config#update GoogleSccV2OrganizationMuteConfig#update}
    */
    readonly update?: string;
}
export declare function googleSccV2OrganizationMuteConfigTimeoutsToTerraform(struct?: GoogleSccV2OrganizationMuteConfigTimeouts | cdktf.IResolvable): any;
export declare function googleSccV2OrganizationMuteConfigTimeoutsToHclTerraform(struct?: GoogleSccV2OrganizationMuteConfigTimeouts | cdktf.IResolvable): any;
export declare class GoogleSccV2OrganizationMuteConfigTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleSccV2OrganizationMuteConfigTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleSccV2OrganizationMuteConfigTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_scc_v2_organization_mute_config google_scc_v2_organization_mute_config}
*/
export declare class GoogleSccV2OrganizationMuteConfig extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_scc_v2_organization_mute_config";
    /**
    * Generates CDKTF code for importing a GoogleSccV2OrganizationMuteConfig resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleSccV2OrganizationMuteConfig to import
    * @param importFromId The id of the existing GoogleSccV2OrganizationMuteConfig that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_scc_v2_organization_mute_config#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleSccV2OrganizationMuteConfig to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_scc_v2_organization_mute_config google_scc_v2_organization_mute_config} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleSccV2OrganizationMuteConfigConfig
    */
    constructor(scope: Construct, id: string, config: GoogleSccV2OrganizationMuteConfigConfig);
    get createTime(): string;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _filter?;
    get filter(): string;
    set filter(value: string);
    get filterInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    resetLocation(): void;
    get locationInput(): string | undefined;
    get mostRecentEditor(): string;
    private _muteConfigId?;
    get muteConfigId(): string;
    set muteConfigId(value: string);
    get muteConfigIdInput(): string | undefined;
    get name(): string;
    private _organization?;
    get organization(): string;
    set organization(value: string);
    get organizationInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
    get updateTime(): string;
    private _timeouts;
    get timeouts(): GoogleSccV2OrganizationMuteConfigTimeoutsOutputReference;
    putTimeouts(value: GoogleSccV2OrganizationMuteConfigTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleSccV2OrganizationMuteConfigTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
