/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleSccV2OrganizationSccBigQueryExportsConfig extends cdktf.TerraformMetaArguments {
    /**
    * This must be unique within the organization.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_scc_v2_organization_scc_big_query_exports#big_query_export_id GoogleSccV2OrganizationSccBigQueryExports#big_query_export_id}
    */
    readonly bigQueryExportId: string;
    /**
    * The dataset to write findings' updates to.
    * Its format is "projects/[projectId]/datasets/[bigquery_dataset_id]".
    * BigQuery Dataset unique ID must contain only letters (a-z, A-Z), numbers (0-9), or underscores (_).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_scc_v2_organization_scc_big_query_exports#dataset GoogleSccV2OrganizationSccBigQueryExports#dataset}
    */
    readonly dataset?: string;
    /**
    * The description of the notification config (max of 1024 characters).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_scc_v2_organization_scc_big_query_exports#description GoogleSccV2OrganizationSccBigQueryExports#description}
    */
    readonly description?: string;
    /**
    * Expression that defines the filter to apply across create/update
    * events of findings. The
    * expression is a list of zero or more restrictions combined via
    * logical operators AND and OR. Parentheses are supported, and OR
    * has higher precedence than AND.
    *
    * Restrictions have the form <field> <operator> <value> and may have
    * a - character in front of them to indicate negation. The fields
    * map to those defined in the corresponding resource.
    *
    * The supported operators are:
    *
    * * = for all value types.
    * * >, <, >=, <= for integer values.
    * * :, meaning substring matching, for strings.
    *
    * The supported value types are:
    *
    * * string literals in quotes.
    * * integer literals without quotes.
    * * boolean literals true and false without quotes.
    *
    * See
    * [Filtering notifications](https://cloud.google.com/security-command-center/docs/how-to-api-filter-notifications)
    * for information on how to write a filter.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_scc_v2_organization_scc_big_query_exports#filter GoogleSccV2OrganizationSccBigQueryExports#filter}
    */
    readonly filter?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_scc_v2_organization_scc_big_query_exports#id GoogleSccV2OrganizationSccBigQueryExports#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * location Id is provided by organization. If not provided, Use global as default.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_scc_v2_organization_scc_big_query_exports#location GoogleSccV2OrganizationSccBigQueryExports#location}
    */
    readonly location?: string;
    /**
    * The resource name of this export, in the format
    * 'organizations/{{organization}}/locations/{{location}}/bigQueryExports/{{big_query_export_id}}'.
    * This field is provided in responses, and is ignored when provided in create requests.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_scc_v2_organization_scc_big_query_exports#name GoogleSccV2OrganizationSccBigQueryExports#name}
    */
    readonly name?: string;
    /**
    * The organization whose Cloud Security Command Center the Big Query Export
    * Config lives in.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_scc_v2_organization_scc_big_query_exports#organization GoogleSccV2OrganizationSccBigQueryExports#organization}
    */
    readonly organization: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_scc_v2_organization_scc_big_query_exports#timeouts GoogleSccV2OrganizationSccBigQueryExports#timeouts}
    */
    readonly timeouts?: GoogleSccV2OrganizationSccBigQueryExportsTimeouts;
}
export interface GoogleSccV2OrganizationSccBigQueryExportsTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_scc_v2_organization_scc_big_query_exports#create GoogleSccV2OrganizationSccBigQueryExports#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_scc_v2_organization_scc_big_query_exports#delete GoogleSccV2OrganizationSccBigQueryExports#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_scc_v2_organization_scc_big_query_exports#update GoogleSccV2OrganizationSccBigQueryExports#update}
    */
    readonly update?: string;
}
export declare function googleSccV2OrganizationSccBigQueryExportsTimeoutsToTerraform(struct?: GoogleSccV2OrganizationSccBigQueryExportsTimeouts | cdktf.IResolvable): any;
export declare function googleSccV2OrganizationSccBigQueryExportsTimeoutsToHclTerraform(struct?: GoogleSccV2OrganizationSccBigQueryExportsTimeouts | cdktf.IResolvable): any;
export declare class GoogleSccV2OrganizationSccBigQueryExportsTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleSccV2OrganizationSccBigQueryExportsTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleSccV2OrganizationSccBigQueryExportsTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_scc_v2_organization_scc_big_query_exports google_scc_v2_organization_scc_big_query_exports}
*/
export declare class GoogleSccV2OrganizationSccBigQueryExports extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_scc_v2_organization_scc_big_query_exports";
    /**
    * Generates CDKTF code for importing a GoogleSccV2OrganizationSccBigQueryExports resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleSccV2OrganizationSccBigQueryExports to import
    * @param importFromId The id of the existing GoogleSccV2OrganizationSccBigQueryExports that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_scc_v2_organization_scc_big_query_exports#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleSccV2OrganizationSccBigQueryExports to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_scc_v2_organization_scc_big_query_exports google_scc_v2_organization_scc_big_query_exports} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleSccV2OrganizationSccBigQueryExportsConfig
    */
    constructor(scope: Construct, id: string, config: GoogleSccV2OrganizationSccBigQueryExportsConfig);
    private _bigQueryExportId?;
    get bigQueryExportId(): string;
    set bigQueryExportId(value: string);
    get bigQueryExportIdInput(): string | undefined;
    get createTime(): string;
    private _dataset?;
    get dataset(): string;
    set dataset(value: string);
    resetDataset(): void;
    get datasetInput(): string | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _filter?;
    get filter(): string;
    set filter(value: string);
    resetFilter(): void;
    get filterInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    resetLocation(): void;
    get locationInput(): string | undefined;
    get mostRecentEditor(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _organization?;
    get organization(): string;
    set organization(value: string);
    get organizationInput(): string | undefined;
    get principal(): string;
    get updateTime(): string;
    private _timeouts;
    get timeouts(): GoogleSccV2OrganizationSccBigQueryExportsTimeoutsOutputReference;
    putTimeouts(value: GoogleSccV2OrganizationSccBigQueryExportsTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleSccV2OrganizationSccBigQueryExportsTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
