/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleSecretManagerRegionalSecretVersionConfig extends cdktf.TerraformMetaArguments {
    /**
    * The deletion policy for the regional secret version. Setting 'ABANDON' allows the resource
    * to be abandoned rather than deleted. Setting 'DISABLE' allows the resource to be
    * disabled rather than deleted. Default is 'DELETE'. Possible values are:
    *   * DELETE
    *   * DISABLE
    *   * ABANDON
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_secret_manager_regional_secret_version#deletion_policy GoogleSecretManagerRegionalSecretVersion#deletion_policy}
    */
    readonly deletionPolicy?: string;
    /**
    * The current state of the regional secret version.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_secret_manager_regional_secret_version#enabled GoogleSecretManagerRegionalSecretVersion#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_secret_manager_regional_secret_version#id GoogleSecretManagerRegionalSecretVersion#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * If set to 'true', the secret data is expected to be base64-encoded string and would be sent as is.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_secret_manager_regional_secret_version#is_secret_data_base64 GoogleSecretManagerRegionalSecretVersion#is_secret_data_base64}
    */
    readonly isSecretDataBase64?: boolean | cdktf.IResolvable;
    /**
    * Secret Manager regional secret resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_secret_manager_regional_secret_version#secret GoogleSecretManagerRegionalSecretVersion#secret}
    */
    readonly secret: string;
    /**
    * The secret data. Must be no larger than 64KiB.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_secret_manager_regional_secret_version#secret_data GoogleSecretManagerRegionalSecretVersion#secret_data}
    */
    readonly secretData: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_secret_manager_regional_secret_version#timeouts GoogleSecretManagerRegionalSecretVersion#timeouts}
    */
    readonly timeouts?: GoogleSecretManagerRegionalSecretVersionTimeouts;
}
export interface GoogleSecretManagerRegionalSecretVersionCustomerManagedEncryption {
}
export declare function googleSecretManagerRegionalSecretVersionCustomerManagedEncryptionToTerraform(struct?: GoogleSecretManagerRegionalSecretVersionCustomerManagedEncryption): any;
export declare function googleSecretManagerRegionalSecretVersionCustomerManagedEncryptionToHclTerraform(struct?: GoogleSecretManagerRegionalSecretVersionCustomerManagedEncryption): any;
export declare class GoogleSecretManagerRegionalSecretVersionCustomerManagedEncryptionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleSecretManagerRegionalSecretVersionCustomerManagedEncryption | undefined;
    set internalValue(value: GoogleSecretManagerRegionalSecretVersionCustomerManagedEncryption | undefined);
    get kmsKeyVersionName(): string;
}
export declare class GoogleSecretManagerRegionalSecretVersionCustomerManagedEncryptionList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleSecretManagerRegionalSecretVersionCustomerManagedEncryptionOutputReference;
}
export interface GoogleSecretManagerRegionalSecretVersionTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_secret_manager_regional_secret_version#create GoogleSecretManagerRegionalSecretVersion#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_secret_manager_regional_secret_version#delete GoogleSecretManagerRegionalSecretVersion#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_secret_manager_regional_secret_version#update GoogleSecretManagerRegionalSecretVersion#update}
    */
    readonly update?: string;
}
export declare function googleSecretManagerRegionalSecretVersionTimeoutsToTerraform(struct?: GoogleSecretManagerRegionalSecretVersionTimeouts | cdktf.IResolvable): any;
export declare function googleSecretManagerRegionalSecretVersionTimeoutsToHclTerraform(struct?: GoogleSecretManagerRegionalSecretVersionTimeouts | cdktf.IResolvable): any;
export declare class GoogleSecretManagerRegionalSecretVersionTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleSecretManagerRegionalSecretVersionTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleSecretManagerRegionalSecretVersionTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_secret_manager_regional_secret_version google_secret_manager_regional_secret_version}
*/
export declare class GoogleSecretManagerRegionalSecretVersion extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_secret_manager_regional_secret_version";
    /**
    * Generates CDKTF code for importing a GoogleSecretManagerRegionalSecretVersion resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleSecretManagerRegionalSecretVersion to import
    * @param importFromId The id of the existing GoogleSecretManagerRegionalSecretVersion that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_secret_manager_regional_secret_version#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleSecretManagerRegionalSecretVersion to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_secret_manager_regional_secret_version google_secret_manager_regional_secret_version} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleSecretManagerRegionalSecretVersionConfig
    */
    constructor(scope: Construct, id: string, config: GoogleSecretManagerRegionalSecretVersionConfig);
    get createTime(): string;
    private _customerManagedEncryption;
    get customerManagedEncryption(): GoogleSecretManagerRegionalSecretVersionCustomerManagedEncryptionList;
    private _deletionPolicy?;
    get deletionPolicy(): string;
    set deletionPolicy(value: string);
    resetDeletionPolicy(): void;
    get deletionPolicyInput(): string | undefined;
    get destroyTime(): string;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _isSecretDataBase64?;
    get isSecretDataBase64(): boolean | cdktf.IResolvable;
    set isSecretDataBase64(value: boolean | cdktf.IResolvable);
    resetIsSecretDataBase64(): void;
    get isSecretDataBase64Input(): boolean | cdktf.IResolvable | undefined;
    get location(): string;
    get name(): string;
    private _secret?;
    get secret(): string;
    set secret(value: string);
    get secretInput(): string | undefined;
    private _secretData?;
    get secretData(): string;
    set secretData(value: string);
    get secretDataInput(): string | undefined;
    get version(): string;
    private _timeouts;
    get timeouts(): GoogleSecretManagerRegionalSecretVersionTimeoutsOutputReference;
    putTimeouts(value: GoogleSecretManagerRegionalSecretVersionTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleSecretManagerRegionalSecretVersionTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
