/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleSiteVerificationOwnerConfig extends cdktf.TerraformMetaArguments {
    /**
    * The email address of the owner.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_site_verification_owner#email GoogleSiteVerificationOwner#email}
    */
    readonly email: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_site_verification_owner#id GoogleSiteVerificationOwner#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The id of the Web Resource to add this owner to, in the form "webResource/<web-resource-id>".
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_site_verification_owner#web_resource_id GoogleSiteVerificationOwner#web_resource_id}
    */
    readonly webResourceId: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_site_verification_owner#timeouts GoogleSiteVerificationOwner#timeouts}
    */
    readonly timeouts?: GoogleSiteVerificationOwnerTimeouts;
}
export interface GoogleSiteVerificationOwnerTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_site_verification_owner#create GoogleSiteVerificationOwner#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_site_verification_owner#delete GoogleSiteVerificationOwner#delete}
    */
    readonly delete?: string;
}
export declare function googleSiteVerificationOwnerTimeoutsToTerraform(struct?: GoogleSiteVerificationOwnerTimeouts | cdktf.IResolvable): any;
export declare function googleSiteVerificationOwnerTimeoutsToHclTerraform(struct?: GoogleSiteVerificationOwnerTimeouts | cdktf.IResolvable): any;
export declare class GoogleSiteVerificationOwnerTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleSiteVerificationOwnerTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleSiteVerificationOwnerTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_site_verification_owner google_site_verification_owner}
*/
export declare class GoogleSiteVerificationOwner extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_site_verification_owner";
    /**
    * Generates CDKTF code for importing a GoogleSiteVerificationOwner resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleSiteVerificationOwner to import
    * @param importFromId The id of the existing GoogleSiteVerificationOwner that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_site_verification_owner#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleSiteVerificationOwner to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_site_verification_owner google_site_verification_owner} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleSiteVerificationOwnerConfig
    */
    constructor(scope: Construct, id: string, config: GoogleSiteVerificationOwnerConfig);
    private _email?;
    get email(): string;
    set email(value: string);
    get emailInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _webResourceId?;
    get webResourceId(): string;
    set webResourceId(value: string);
    get webResourceIdInput(): string | undefined;
    private _timeouts;
    get timeouts(): GoogleSiteVerificationOwnerTimeoutsOutputReference;
    putTimeouts(value: GoogleSiteVerificationOwnerTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleSiteVerificationOwnerTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
