/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleSiteVerificationWebResourceConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_site_verification_web_resource#id GoogleSiteVerificationWebResource#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The verification method for the Site Verification system to use to verify
    * this site or domain. Possible values: ["ANALYTICS", "DNS_CNAME", "DNS_TXT", "FILE", "META", "TAG_MANAGER"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_site_verification_web_resource#verification_method GoogleSiteVerificationWebResource#verification_method}
    */
    readonly verificationMethod: string;
    /**
    * site block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_site_verification_web_resource#site GoogleSiteVerificationWebResource#site}
    */
    readonly site: GoogleSiteVerificationWebResourceSite;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_site_verification_web_resource#timeouts GoogleSiteVerificationWebResource#timeouts}
    */
    readonly timeouts?: GoogleSiteVerificationWebResourceTimeouts;
}
export interface GoogleSiteVerificationWebResourceSite {
    /**
    * The site identifier. If the type is set to SITE, the identifier is a URL. If the type is
    * set to INET_DOMAIN, the identifier is a domain name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_site_verification_web_resource#identifier GoogleSiteVerificationWebResource#identifier}
    */
    readonly identifier: string;
    /**
    * The type of resource to be verified. Possible values: ["INET_DOMAIN", "SITE"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_site_verification_web_resource#type GoogleSiteVerificationWebResource#type}
    */
    readonly type: string;
}
export declare function googleSiteVerificationWebResourceSiteToTerraform(struct?: GoogleSiteVerificationWebResourceSiteOutputReference | GoogleSiteVerificationWebResourceSite): any;
export declare function googleSiteVerificationWebResourceSiteToHclTerraform(struct?: GoogleSiteVerificationWebResourceSiteOutputReference | GoogleSiteVerificationWebResourceSite): any;
export declare class GoogleSiteVerificationWebResourceSiteOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleSiteVerificationWebResourceSite | undefined;
    set internalValue(value: GoogleSiteVerificationWebResourceSite | undefined);
    private _identifier?;
    get identifier(): string;
    set identifier(value: string);
    get identifierInput(): string | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
}
export interface GoogleSiteVerificationWebResourceTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_site_verification_web_resource#create GoogleSiteVerificationWebResource#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_site_verification_web_resource#delete GoogleSiteVerificationWebResource#delete}
    */
    readonly delete?: string;
}
export declare function googleSiteVerificationWebResourceTimeoutsToTerraform(struct?: GoogleSiteVerificationWebResourceTimeouts | cdktf.IResolvable): any;
export declare function googleSiteVerificationWebResourceTimeoutsToHclTerraform(struct?: GoogleSiteVerificationWebResourceTimeouts | cdktf.IResolvable): any;
export declare class GoogleSiteVerificationWebResourceTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleSiteVerificationWebResourceTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleSiteVerificationWebResourceTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_site_verification_web_resource google_site_verification_web_resource}
*/
export declare class GoogleSiteVerificationWebResource extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_site_verification_web_resource";
    /**
    * Generates CDKTF code for importing a GoogleSiteVerificationWebResource resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleSiteVerificationWebResource to import
    * @param importFromId The id of the existing GoogleSiteVerificationWebResource that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_site_verification_web_resource#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleSiteVerificationWebResource to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_site_verification_web_resource google_site_verification_web_resource} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleSiteVerificationWebResourceConfig
    */
    constructor(scope: Construct, id: string, config: GoogleSiteVerificationWebResourceConfig);
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get owners(): string[];
    private _verificationMethod?;
    get verificationMethod(): string;
    set verificationMethod(value: string);
    get verificationMethodInput(): string | undefined;
    get webResourceId(): string;
    private _site;
    get site(): GoogleSiteVerificationWebResourceSiteOutputReference;
    putSite(value: GoogleSiteVerificationWebResourceSite): void;
    get siteInput(): GoogleSiteVerificationWebResourceSite | undefined;
    private _timeouts;
    get timeouts(): GoogleSiteVerificationWebResourceTimeoutsOutputReference;
    putTimeouts(value: GoogleSiteVerificationWebResourceTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleSiteVerificationWebResourceTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
