/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleSpannerBackupScheduleConfig extends cdktf.TerraformMetaArguments {
    /**
    * The database to create the backup schedule on.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_spanner_backup_schedule#database GoogleSpannerBackupSchedule#database}
    */
    readonly database: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_spanner_backup_schedule#id GoogleSpannerBackupSchedule#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The instance to create the database on.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_spanner_backup_schedule#instance GoogleSpannerBackupSchedule#instance}
    */
    readonly instance: string;
    /**
    * A unique identifier for the backup schedule, which cannot be changed after
    * the backup schedule is created. Values are of the form [a-z][-a-z0-9]*[a-z0-9].
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_spanner_backup_schedule#name GoogleSpannerBackupSchedule#name}
    */
    readonly name?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_spanner_backup_schedule#project GoogleSpannerBackupSchedule#project}
    */
    readonly project?: string;
    /**
    * At what relative time in the future, compared to its creation time, the backup should be deleted, e.g. keep backups for 7 days.
    * A duration in seconds with up to nine fractional digits, ending with 's'. Example: '3.5s'.
    * You can set this to a value up to 366 days.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_spanner_backup_schedule#retention_duration GoogleSpannerBackupSchedule#retention_duration}
    */
    readonly retentionDuration: string;
    /**
    * full_backup_spec block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_spanner_backup_schedule#full_backup_spec GoogleSpannerBackupSchedule#full_backup_spec}
    */
    readonly fullBackupSpec?: GoogleSpannerBackupScheduleFullBackupSpec;
    /**
    * incremental_backup_spec block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_spanner_backup_schedule#incremental_backup_spec GoogleSpannerBackupSchedule#incremental_backup_spec}
    */
    readonly incrementalBackupSpec?: GoogleSpannerBackupScheduleIncrementalBackupSpec;
    /**
    * spec block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_spanner_backup_schedule#spec GoogleSpannerBackupSchedule#spec}
    */
    readonly spec?: GoogleSpannerBackupScheduleSpec;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_spanner_backup_schedule#timeouts GoogleSpannerBackupSchedule#timeouts}
    */
    readonly timeouts?: GoogleSpannerBackupScheduleTimeouts;
}
export interface GoogleSpannerBackupScheduleFullBackupSpec {
}
export declare function googleSpannerBackupScheduleFullBackupSpecToTerraform(struct?: GoogleSpannerBackupScheduleFullBackupSpecOutputReference | GoogleSpannerBackupScheduleFullBackupSpec): any;
export declare function googleSpannerBackupScheduleFullBackupSpecToHclTerraform(struct?: GoogleSpannerBackupScheduleFullBackupSpecOutputReference | GoogleSpannerBackupScheduleFullBackupSpec): any;
export declare class GoogleSpannerBackupScheduleFullBackupSpecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleSpannerBackupScheduleFullBackupSpec | undefined;
    set internalValue(value: GoogleSpannerBackupScheduleFullBackupSpec | undefined);
}
export interface GoogleSpannerBackupScheduleIncrementalBackupSpec {
}
export declare function googleSpannerBackupScheduleIncrementalBackupSpecToTerraform(struct?: GoogleSpannerBackupScheduleIncrementalBackupSpecOutputReference | GoogleSpannerBackupScheduleIncrementalBackupSpec): any;
export declare function googleSpannerBackupScheduleIncrementalBackupSpecToHclTerraform(struct?: GoogleSpannerBackupScheduleIncrementalBackupSpecOutputReference | GoogleSpannerBackupScheduleIncrementalBackupSpec): any;
export declare class GoogleSpannerBackupScheduleIncrementalBackupSpecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleSpannerBackupScheduleIncrementalBackupSpec | undefined;
    set internalValue(value: GoogleSpannerBackupScheduleIncrementalBackupSpec | undefined);
}
export interface GoogleSpannerBackupScheduleSpecCronSpec {
    /**
    * Textual representation of the crontab. User can customize the
    * backup frequency and the backup version time using the cron
    * expression. The version time must be in UTC timzeone.
    * The backup will contain an externally consistent copy of the
    * database at the version time. Allowed frequencies are 12 hour, 1 day,
    * 1 week and 1 month. Examples of valid cron specifications:
    *   0 2/12 * * * : every 12 hours at (2, 14) hours past midnight in UTC.
    *   0 2,14 * * * : every 12 hours at (2,14) hours past midnight in UTC.
    *   0 2 * * *    : once a day at 2 past midnight in UTC.
    *   0 2 * * 0    : once a week every Sunday at 2 past midnight in UTC.
    *   0 2 8 * *    : once a month on 8th day at 2 past midnight in UTC.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_spanner_backup_schedule#text GoogleSpannerBackupSchedule#text}
    */
    readonly text?: string;
}
export declare function googleSpannerBackupScheduleSpecCronSpecToTerraform(struct?: GoogleSpannerBackupScheduleSpecCronSpecOutputReference | GoogleSpannerBackupScheduleSpecCronSpec): any;
export declare function googleSpannerBackupScheduleSpecCronSpecToHclTerraform(struct?: GoogleSpannerBackupScheduleSpecCronSpecOutputReference | GoogleSpannerBackupScheduleSpecCronSpec): any;
export declare class GoogleSpannerBackupScheduleSpecCronSpecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleSpannerBackupScheduleSpecCronSpec | undefined;
    set internalValue(value: GoogleSpannerBackupScheduleSpecCronSpec | undefined);
    private _text?;
    get text(): string;
    set text(value: string);
    resetText(): void;
    get textInput(): string | undefined;
}
export interface GoogleSpannerBackupScheduleSpec {
    /**
    * cron_spec block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_spanner_backup_schedule#cron_spec GoogleSpannerBackupSchedule#cron_spec}
    */
    readonly cronSpec?: GoogleSpannerBackupScheduleSpecCronSpec;
}
export declare function googleSpannerBackupScheduleSpecToTerraform(struct?: GoogleSpannerBackupScheduleSpecOutputReference | GoogleSpannerBackupScheduleSpec): any;
export declare function googleSpannerBackupScheduleSpecToHclTerraform(struct?: GoogleSpannerBackupScheduleSpecOutputReference | GoogleSpannerBackupScheduleSpec): any;
export declare class GoogleSpannerBackupScheduleSpecOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleSpannerBackupScheduleSpec | undefined;
    set internalValue(value: GoogleSpannerBackupScheduleSpec | undefined);
    private _cronSpec;
    get cronSpec(): GoogleSpannerBackupScheduleSpecCronSpecOutputReference;
    putCronSpec(value: GoogleSpannerBackupScheduleSpecCronSpec): void;
    resetCronSpec(): void;
    get cronSpecInput(): GoogleSpannerBackupScheduleSpecCronSpec | undefined;
}
export interface GoogleSpannerBackupScheduleTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_spanner_backup_schedule#create GoogleSpannerBackupSchedule#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_spanner_backup_schedule#delete GoogleSpannerBackupSchedule#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_spanner_backup_schedule#update GoogleSpannerBackupSchedule#update}
    */
    readonly update?: string;
}
export declare function googleSpannerBackupScheduleTimeoutsToTerraform(struct?: GoogleSpannerBackupScheduleTimeouts | cdktf.IResolvable): any;
export declare function googleSpannerBackupScheduleTimeoutsToHclTerraform(struct?: GoogleSpannerBackupScheduleTimeouts | cdktf.IResolvable): any;
export declare class GoogleSpannerBackupScheduleTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleSpannerBackupScheduleTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleSpannerBackupScheduleTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_spanner_backup_schedule google_spanner_backup_schedule}
*/
export declare class GoogleSpannerBackupSchedule extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_spanner_backup_schedule";
    /**
    * Generates CDKTF code for importing a GoogleSpannerBackupSchedule resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleSpannerBackupSchedule to import
    * @param importFromId The id of the existing GoogleSpannerBackupSchedule that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_spanner_backup_schedule#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleSpannerBackupSchedule to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_spanner_backup_schedule google_spanner_backup_schedule} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleSpannerBackupScheduleConfig
    */
    constructor(scope: Construct, id: string, config: GoogleSpannerBackupScheduleConfig);
    private _database?;
    get database(): string;
    set database(value: string);
    get databaseInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _instance?;
    get instance(): string;
    set instance(value: string);
    get instanceInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _retentionDuration?;
    get retentionDuration(): string;
    set retentionDuration(value: string);
    get retentionDurationInput(): string | undefined;
    private _fullBackupSpec;
    get fullBackupSpec(): GoogleSpannerBackupScheduleFullBackupSpecOutputReference;
    putFullBackupSpec(value: GoogleSpannerBackupScheduleFullBackupSpec): void;
    resetFullBackupSpec(): void;
    get fullBackupSpecInput(): GoogleSpannerBackupScheduleFullBackupSpec | undefined;
    private _incrementalBackupSpec;
    get incrementalBackupSpec(): GoogleSpannerBackupScheduleIncrementalBackupSpecOutputReference;
    putIncrementalBackupSpec(value: GoogleSpannerBackupScheduleIncrementalBackupSpec): void;
    resetIncrementalBackupSpec(): void;
    get incrementalBackupSpecInput(): GoogleSpannerBackupScheduleIncrementalBackupSpec | undefined;
    private _spec;
    get spec(): GoogleSpannerBackupScheduleSpecOutputReference;
    putSpec(value: GoogleSpannerBackupScheduleSpec): void;
    resetSpec(): void;
    get specInput(): GoogleSpannerBackupScheduleSpec | undefined;
    private _timeouts;
    get timeouts(): GoogleSpannerBackupScheduleTimeoutsOutputReference;
    putTimeouts(value: GoogleSpannerBackupScheduleTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleSpannerBackupScheduleTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
