/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleStorageDefaultObjectAccessControlConfig extends cdktf.TerraformMetaArguments {
    /**
    * The name of the bucket.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_storage_default_object_access_control#bucket GoogleStorageDefaultObjectAccessControl#bucket}
    */
    readonly bucket: string;
    /**
    * The entity holding the permission, in one of the following forms:
    *   * user-{{userId}}
    *   * user-{{email}} (such as "user-liz@example.com")
    *   * group-{{groupId}}
    *   * group-{{email}} (such as "group-example@googlegroups.com")
    *   * domain-{{domain}} (such as "domain-example.com")
    *   * project-team-{{projectId}}
    *   * allUsers
    *   * allAuthenticatedUsers
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_storage_default_object_access_control#entity GoogleStorageDefaultObjectAccessControl#entity}
    */
    readonly entity: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_storage_default_object_access_control#id GoogleStorageDefaultObjectAccessControl#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The name of the object, if applied to an object.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_storage_default_object_access_control#object GoogleStorageDefaultObjectAccessControl#object}
    */
    readonly object?: string;
    /**
    * The access permission for the entity. Possible values: ["OWNER", "READER"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_storage_default_object_access_control#role GoogleStorageDefaultObjectAccessControl#role}
    */
    readonly role: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_storage_default_object_access_control#timeouts GoogleStorageDefaultObjectAccessControl#timeouts}
    */
    readonly timeouts?: GoogleStorageDefaultObjectAccessControlTimeouts;
}
export interface GoogleStorageDefaultObjectAccessControlProjectTeam {
}
export declare function googleStorageDefaultObjectAccessControlProjectTeamToTerraform(struct?: GoogleStorageDefaultObjectAccessControlProjectTeam): any;
export declare function googleStorageDefaultObjectAccessControlProjectTeamToHclTerraform(struct?: GoogleStorageDefaultObjectAccessControlProjectTeam): any;
export declare class GoogleStorageDefaultObjectAccessControlProjectTeamOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleStorageDefaultObjectAccessControlProjectTeam | undefined;
    set internalValue(value: GoogleStorageDefaultObjectAccessControlProjectTeam | undefined);
    get projectNumber(): string;
    get team(): string;
}
export declare class GoogleStorageDefaultObjectAccessControlProjectTeamList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleStorageDefaultObjectAccessControlProjectTeamOutputReference;
}
export interface GoogleStorageDefaultObjectAccessControlTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_storage_default_object_access_control#create GoogleStorageDefaultObjectAccessControl#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_storage_default_object_access_control#delete GoogleStorageDefaultObjectAccessControl#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_storage_default_object_access_control#update GoogleStorageDefaultObjectAccessControl#update}
    */
    readonly update?: string;
}
export declare function googleStorageDefaultObjectAccessControlTimeoutsToTerraform(struct?: GoogleStorageDefaultObjectAccessControlTimeouts | cdktf.IResolvable): any;
export declare function googleStorageDefaultObjectAccessControlTimeoutsToHclTerraform(struct?: GoogleStorageDefaultObjectAccessControlTimeouts | cdktf.IResolvable): any;
export declare class GoogleStorageDefaultObjectAccessControlTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleStorageDefaultObjectAccessControlTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleStorageDefaultObjectAccessControlTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_storage_default_object_access_control google_storage_default_object_access_control}
*/
export declare class GoogleStorageDefaultObjectAccessControl extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_storage_default_object_access_control";
    /**
    * Generates CDKTF code for importing a GoogleStorageDefaultObjectAccessControl resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleStorageDefaultObjectAccessControl to import
    * @param importFromId The id of the existing GoogleStorageDefaultObjectAccessControl that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_storage_default_object_access_control#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleStorageDefaultObjectAccessControl to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_storage_default_object_access_control google_storage_default_object_access_control} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleStorageDefaultObjectAccessControlConfig
    */
    constructor(scope: Construct, id: string, config: GoogleStorageDefaultObjectAccessControlConfig);
    private _bucket?;
    get bucket(): string;
    set bucket(value: string);
    get bucketInput(): string | undefined;
    get domain(): string;
    get email(): string;
    private _entity?;
    get entity(): string;
    set entity(value: string);
    get entityInput(): string | undefined;
    get entityId(): string;
    get generation(): number;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _object?;
    get object(): string;
    set object(value: string);
    resetObject(): void;
    get objectInput(): string | undefined;
    private _projectTeam;
    get projectTeam(): GoogleStorageDefaultObjectAccessControlProjectTeamList;
    private _role?;
    get role(): string;
    set role(value: string);
    get roleInput(): string | undefined;
    private _timeouts;
    get timeouts(): GoogleStorageDefaultObjectAccessControlTimeoutsOutputReference;
    putTimeouts(value: GoogleStorageDefaultObjectAccessControlTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleStorageDefaultObjectAccessControlTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
