/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleTranscoderJobTemplateConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#id GoogleTranscoderJobTemplate#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * ID to use for the Transcoding job template.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#job_template_id GoogleTranscoderJobTemplate#job_template_id}
    */
    readonly jobTemplateId: string;
    /**
    * The labels associated with this job template. You can use these to organize and group your job templates.
    *
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#labels GoogleTranscoderJobTemplate#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * The location of the transcoding job template resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#location GoogleTranscoderJobTemplate#location}
    */
    readonly location: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#project GoogleTranscoderJobTemplate#project}
    */
    readonly project?: string;
    /**
    * config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#config GoogleTranscoderJobTemplate#config}
    */
    readonly config?: GoogleTranscoderJobTemplateConfigA;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#timeouts GoogleTranscoderJobTemplate#timeouts}
    */
    readonly timeouts?: GoogleTranscoderJobTemplateTimeouts;
}
export interface GoogleTranscoderJobTemplateConfigAdBreaks {
    /**
    * Start time in seconds for the ad break, relative to the output file timeline
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#start_time_offset GoogleTranscoderJobTemplate#start_time_offset}
    */
    readonly startTimeOffset?: string;
}
export declare function googleTranscoderJobTemplateConfigAdBreaksToTerraform(struct?: GoogleTranscoderJobTemplateConfigAdBreaks | cdktf.IResolvable): any;
export declare function googleTranscoderJobTemplateConfigAdBreaksToHclTerraform(struct?: GoogleTranscoderJobTemplateConfigAdBreaks | cdktf.IResolvable): any;
export declare class GoogleTranscoderJobTemplateConfigAdBreaksOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleTranscoderJobTemplateConfigAdBreaks | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleTranscoderJobTemplateConfigAdBreaks | cdktf.IResolvable | undefined);
    private _startTimeOffset?;
    get startTimeOffset(): string;
    set startTimeOffset(value: string);
    resetStartTimeOffset(): void;
    get startTimeOffsetInput(): string | undefined;
}
export declare class GoogleTranscoderJobTemplateConfigAdBreaksList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleTranscoderJobTemplateConfigAdBreaks[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleTranscoderJobTemplateConfigAdBreaksOutputReference;
}
export interface GoogleTranscoderJobTemplateConfigEditListStruct {
    /**
    * List of values identifying files that should be used in this atom.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#inputs GoogleTranscoderJobTemplate#inputs}
    */
    readonly inputs?: string[];
    /**
    * A unique key for this atom.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#key GoogleTranscoderJobTemplate#key}
    */
    readonly key?: string;
    /**
    * Start time in seconds for the atom, relative to the input file timeline.  The default is '0s'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#start_time_offset GoogleTranscoderJobTemplate#start_time_offset}
    */
    readonly startTimeOffset?: string;
}
export declare function googleTranscoderJobTemplateConfigEditListStructToTerraform(struct?: GoogleTranscoderJobTemplateConfigEditListStruct | cdktf.IResolvable): any;
export declare function googleTranscoderJobTemplateConfigEditListStructToHclTerraform(struct?: GoogleTranscoderJobTemplateConfigEditListStruct | cdktf.IResolvable): any;
export declare class GoogleTranscoderJobTemplateConfigEditListStructOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleTranscoderJobTemplateConfigEditListStruct | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleTranscoderJobTemplateConfigEditListStruct | cdktf.IResolvable | undefined);
    private _inputs?;
    get inputs(): string[];
    set inputs(value: string[]);
    resetInputs(): void;
    get inputsInput(): string[] | undefined;
    private _key?;
    get key(): string;
    set key(value: string);
    resetKey(): void;
    get keyInput(): string | undefined;
    private _startTimeOffset?;
    get startTimeOffset(): string;
    set startTimeOffset(value: string);
    resetStartTimeOffset(): void;
    get startTimeOffsetInput(): string | undefined;
}
export declare class GoogleTranscoderJobTemplateConfigEditListStructList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleTranscoderJobTemplateConfigEditListStruct[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleTranscoderJobTemplateConfigEditListStructOutputReference;
}
export interface GoogleTranscoderJobTemplateConfigElementaryStreamsAudioStream {
    /**
    * Audio bitrate in bits per second.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#bitrate_bps GoogleTranscoderJobTemplate#bitrate_bps}
    */
    readonly bitrateBps: number;
    /**
    * Number of audio channels. The default is '2'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#channel_count GoogleTranscoderJobTemplate#channel_count}
    */
    readonly channelCount?: number;
    /**
    * A list of channel names specifying layout of the audio channels.  The default is ["fl", "fr"].
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#channel_layout GoogleTranscoderJobTemplate#channel_layout}
    */
    readonly channelLayout?: string[];
    /**
    * The codec for this audio stream. The default is 'aac'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#codec GoogleTranscoderJobTemplate#codec}
    */
    readonly codec?: string;
    /**
    * The audio sample rate in Hertz. The default is '48000'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#sample_rate_hertz GoogleTranscoderJobTemplate#sample_rate_hertz}
    */
    readonly sampleRateHertz?: number;
}
export declare function googleTranscoderJobTemplateConfigElementaryStreamsAudioStreamToTerraform(struct?: GoogleTranscoderJobTemplateConfigElementaryStreamsAudioStreamOutputReference | GoogleTranscoderJobTemplateConfigElementaryStreamsAudioStream): any;
export declare function googleTranscoderJobTemplateConfigElementaryStreamsAudioStreamToHclTerraform(struct?: GoogleTranscoderJobTemplateConfigElementaryStreamsAudioStreamOutputReference | GoogleTranscoderJobTemplateConfigElementaryStreamsAudioStream): any;
export declare class GoogleTranscoderJobTemplateConfigElementaryStreamsAudioStreamOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTranscoderJobTemplateConfigElementaryStreamsAudioStream | undefined;
    set internalValue(value: GoogleTranscoderJobTemplateConfigElementaryStreamsAudioStream | undefined);
    private _bitrateBps?;
    get bitrateBps(): number;
    set bitrateBps(value: number);
    get bitrateBpsInput(): number | undefined;
    private _channelCount?;
    get channelCount(): number;
    set channelCount(value: number);
    resetChannelCount(): void;
    get channelCountInput(): number | undefined;
    private _channelLayout?;
    get channelLayout(): string[];
    set channelLayout(value: string[]);
    resetChannelLayout(): void;
    get channelLayoutInput(): string[] | undefined;
    private _codec?;
    get codec(): string;
    set codec(value: string);
    resetCodec(): void;
    get codecInput(): string | undefined;
    private _sampleRateHertz?;
    get sampleRateHertz(): number;
    set sampleRateHertz(value: number);
    resetSampleRateHertz(): void;
    get sampleRateHertzInput(): number | undefined;
}
export interface GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStreamH264Hlg {
}
export declare function googleTranscoderJobTemplateConfigElementaryStreamsVideoStreamH264HlgToTerraform(struct?: GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStreamH264HlgOutputReference | GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStreamH264Hlg): any;
export declare function googleTranscoderJobTemplateConfigElementaryStreamsVideoStreamH264HlgToHclTerraform(struct?: GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStreamH264HlgOutputReference | GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStreamH264Hlg): any;
export declare class GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStreamH264HlgOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStreamH264Hlg | undefined;
    set internalValue(value: GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStreamH264Hlg | undefined);
}
export interface GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStreamH264Sdr {
}
export declare function googleTranscoderJobTemplateConfigElementaryStreamsVideoStreamH264SdrToTerraform(struct?: GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStreamH264SdrOutputReference | GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStreamH264Sdr): any;
export declare function googleTranscoderJobTemplateConfigElementaryStreamsVideoStreamH264SdrToHclTerraform(struct?: GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStreamH264SdrOutputReference | GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStreamH264Sdr): any;
export declare class GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStreamH264SdrOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStreamH264Sdr | undefined;
    set internalValue(value: GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStreamH264Sdr | undefined);
}
export interface GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStreamH264 {
    /**
    * The video bitrate in bits per second.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#bitrate_bps GoogleTranscoderJobTemplate#bitrate_bps}
    */
    readonly bitrateBps: number;
    /**
    * Target CRF level. The default is '21'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#crf_level GoogleTranscoderJobTemplate#crf_level}
    */
    readonly crfLevel?: number;
    /**
    * The entropy coder to use. The default is 'cabac'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#entropy_coder GoogleTranscoderJobTemplate#entropy_coder}
    */
    readonly entropyCoder?: string;
    /**
    * The target video frame rate in frames per second (FPS).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#frame_rate GoogleTranscoderJobTemplate#frame_rate}
    */
    readonly frameRate: number;
    /**
    * Select the GOP size based on the specified duration. The default is '3s'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#gop_duration GoogleTranscoderJobTemplate#gop_duration}
    */
    readonly gopDuration?: string;
    /**
    * The height of the video in pixels.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#height_pixels GoogleTranscoderJobTemplate#height_pixels}
    */
    readonly heightPixels?: number;
    /**
    * Pixel format to use. The default is 'yuv420p'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#pixel_format GoogleTranscoderJobTemplate#pixel_format}
    */
    readonly pixelFormat?: string;
    /**
    * Enforces the specified codec preset. The default is 'veryfast'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#preset GoogleTranscoderJobTemplate#preset}
    */
    readonly preset?: string;
    /**
    * Enforces the specified codec profile.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#profile GoogleTranscoderJobTemplate#profile}
    */
    readonly profile?: string;
    /**
    * Specify the mode. The default is 'vbr'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#rate_control_mode GoogleTranscoderJobTemplate#rate_control_mode}
    */
    readonly rateControlMode?: string;
    /**
    * Initial fullness of the Video Buffering Verifier (VBV) buffer in bits.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#vbv_fullness_bits GoogleTranscoderJobTemplate#vbv_fullness_bits}
    */
    readonly vbvFullnessBits?: number;
    /**
    * Size of the Video Buffering Verifier (VBV) buffer in bits.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#vbv_size_bits GoogleTranscoderJobTemplate#vbv_size_bits}
    */
    readonly vbvSizeBits?: number;
    /**
    * The width of the video in pixels.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#width_pixels GoogleTranscoderJobTemplate#width_pixels}
    */
    readonly widthPixels?: number;
    /**
    * hlg block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#hlg GoogleTranscoderJobTemplate#hlg}
    */
    readonly hlg?: GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStreamH264Hlg;
    /**
    * sdr block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#sdr GoogleTranscoderJobTemplate#sdr}
    */
    readonly sdr?: GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStreamH264Sdr;
}
export declare function googleTranscoderJobTemplateConfigElementaryStreamsVideoStreamH264ToTerraform(struct?: GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStreamH264OutputReference | GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStreamH264): any;
export declare function googleTranscoderJobTemplateConfigElementaryStreamsVideoStreamH264ToHclTerraform(struct?: GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStreamH264OutputReference | GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStreamH264): any;
export declare class GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStreamH264OutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStreamH264 | undefined;
    set internalValue(value: GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStreamH264 | undefined);
    private _bitrateBps?;
    get bitrateBps(): number;
    set bitrateBps(value: number);
    get bitrateBpsInput(): number | undefined;
    private _crfLevel?;
    get crfLevel(): number;
    set crfLevel(value: number);
    resetCrfLevel(): void;
    get crfLevelInput(): number | undefined;
    private _entropyCoder?;
    get entropyCoder(): string;
    set entropyCoder(value: string);
    resetEntropyCoder(): void;
    get entropyCoderInput(): string | undefined;
    private _frameRate?;
    get frameRate(): number;
    set frameRate(value: number);
    get frameRateInput(): number | undefined;
    private _gopDuration?;
    get gopDuration(): string;
    set gopDuration(value: string);
    resetGopDuration(): void;
    get gopDurationInput(): string | undefined;
    private _heightPixels?;
    get heightPixels(): number;
    set heightPixels(value: number);
    resetHeightPixels(): void;
    get heightPixelsInput(): number | undefined;
    private _pixelFormat?;
    get pixelFormat(): string;
    set pixelFormat(value: string);
    resetPixelFormat(): void;
    get pixelFormatInput(): string | undefined;
    private _preset?;
    get preset(): string;
    set preset(value: string);
    resetPreset(): void;
    get presetInput(): string | undefined;
    private _profile?;
    get profile(): string;
    set profile(value: string);
    resetProfile(): void;
    get profileInput(): string | undefined;
    private _rateControlMode?;
    get rateControlMode(): string;
    set rateControlMode(value: string);
    resetRateControlMode(): void;
    get rateControlModeInput(): string | undefined;
    private _vbvFullnessBits?;
    get vbvFullnessBits(): number;
    set vbvFullnessBits(value: number);
    resetVbvFullnessBits(): void;
    get vbvFullnessBitsInput(): number | undefined;
    private _vbvSizeBits?;
    get vbvSizeBits(): number;
    set vbvSizeBits(value: number);
    resetVbvSizeBits(): void;
    get vbvSizeBitsInput(): number | undefined;
    private _widthPixels?;
    get widthPixels(): number;
    set widthPixels(value: number);
    resetWidthPixels(): void;
    get widthPixelsInput(): number | undefined;
    private _hlg;
    get hlg(): GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStreamH264HlgOutputReference;
    putHlg(value: GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStreamH264Hlg): void;
    resetHlg(): void;
    get hlgInput(): GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStreamH264Hlg | undefined;
    private _sdr;
    get sdr(): GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStreamH264SdrOutputReference;
    putSdr(value: GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStreamH264Sdr): void;
    resetSdr(): void;
    get sdrInput(): GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStreamH264Sdr | undefined;
}
export interface GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStream {
    /**
    * h264 block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#h264 GoogleTranscoderJobTemplate#h264}
    */
    readonly h264?: GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStreamH264;
}
export declare function googleTranscoderJobTemplateConfigElementaryStreamsVideoStreamToTerraform(struct?: GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStreamOutputReference | GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStream): any;
export declare function googleTranscoderJobTemplateConfigElementaryStreamsVideoStreamToHclTerraform(struct?: GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStreamOutputReference | GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStream): any;
export declare class GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStreamOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStream | undefined;
    set internalValue(value: GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStream | undefined);
    private _h264;
    get h264(): GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStreamH264OutputReference;
    putH264(value: GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStreamH264): void;
    resetH264(): void;
    get h264Input(): GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStreamH264 | undefined;
}
export interface GoogleTranscoderJobTemplateConfigElementaryStreams {
    /**
    * A unique key for this atom.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#key GoogleTranscoderJobTemplate#key}
    */
    readonly key?: string;
    /**
    * audio_stream block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#audio_stream GoogleTranscoderJobTemplate#audio_stream}
    */
    readonly audioStream?: GoogleTranscoderJobTemplateConfigElementaryStreamsAudioStream;
    /**
    * video_stream block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#video_stream GoogleTranscoderJobTemplate#video_stream}
    */
    readonly videoStream?: GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStream;
}
export declare function googleTranscoderJobTemplateConfigElementaryStreamsToTerraform(struct?: GoogleTranscoderJobTemplateConfigElementaryStreams | cdktf.IResolvable): any;
export declare function googleTranscoderJobTemplateConfigElementaryStreamsToHclTerraform(struct?: GoogleTranscoderJobTemplateConfigElementaryStreams | cdktf.IResolvable): any;
export declare class GoogleTranscoderJobTemplateConfigElementaryStreamsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleTranscoderJobTemplateConfigElementaryStreams | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleTranscoderJobTemplateConfigElementaryStreams | cdktf.IResolvable | undefined);
    private _key?;
    get key(): string;
    set key(value: string);
    resetKey(): void;
    get keyInput(): string | undefined;
    private _audioStream;
    get audioStream(): GoogleTranscoderJobTemplateConfigElementaryStreamsAudioStreamOutputReference;
    putAudioStream(value: GoogleTranscoderJobTemplateConfigElementaryStreamsAudioStream): void;
    resetAudioStream(): void;
    get audioStreamInput(): GoogleTranscoderJobTemplateConfigElementaryStreamsAudioStream | undefined;
    private _videoStream;
    get videoStream(): GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStreamOutputReference;
    putVideoStream(value: GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStream): void;
    resetVideoStream(): void;
    get videoStreamInput(): GoogleTranscoderJobTemplateConfigElementaryStreamsVideoStream | undefined;
}
export declare class GoogleTranscoderJobTemplateConfigElementaryStreamsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleTranscoderJobTemplateConfigElementaryStreams[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleTranscoderJobTemplateConfigElementaryStreamsOutputReference;
}
export interface GoogleTranscoderJobTemplateConfigEncryptionsAes128 {
}
export declare function googleTranscoderJobTemplateConfigEncryptionsAes128ToTerraform(struct?: GoogleTranscoderJobTemplateConfigEncryptionsAes128OutputReference | GoogleTranscoderJobTemplateConfigEncryptionsAes128): any;
export declare function googleTranscoderJobTemplateConfigEncryptionsAes128ToHclTerraform(struct?: GoogleTranscoderJobTemplateConfigEncryptionsAes128OutputReference | GoogleTranscoderJobTemplateConfigEncryptionsAes128): any;
export declare class GoogleTranscoderJobTemplateConfigEncryptionsAes128OutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTranscoderJobTemplateConfigEncryptionsAes128 | undefined;
    set internalValue(value: GoogleTranscoderJobTemplateConfigEncryptionsAes128 | undefined);
}
export interface GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsClearkey {
}
export declare function googleTranscoderJobTemplateConfigEncryptionsDrmSystemsClearkeyToTerraform(struct?: GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsClearkeyOutputReference | GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsClearkey): any;
export declare function googleTranscoderJobTemplateConfigEncryptionsDrmSystemsClearkeyToHclTerraform(struct?: GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsClearkeyOutputReference | GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsClearkey): any;
export declare class GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsClearkeyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsClearkey | undefined;
    set internalValue(value: GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsClearkey | undefined);
}
export interface GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsFairplay {
}
export declare function googleTranscoderJobTemplateConfigEncryptionsDrmSystemsFairplayToTerraform(struct?: GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsFairplayOutputReference | GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsFairplay): any;
export declare function googleTranscoderJobTemplateConfigEncryptionsDrmSystemsFairplayToHclTerraform(struct?: GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsFairplayOutputReference | GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsFairplay): any;
export declare class GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsFairplayOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsFairplay | undefined;
    set internalValue(value: GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsFairplay | undefined);
}
export interface GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsPlayready {
}
export declare function googleTranscoderJobTemplateConfigEncryptionsDrmSystemsPlayreadyToTerraform(struct?: GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsPlayreadyOutputReference | GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsPlayready): any;
export declare function googleTranscoderJobTemplateConfigEncryptionsDrmSystemsPlayreadyToHclTerraform(struct?: GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsPlayreadyOutputReference | GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsPlayready): any;
export declare class GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsPlayreadyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsPlayready | undefined;
    set internalValue(value: GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsPlayready | undefined);
}
export interface GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsWidevine {
}
export declare function googleTranscoderJobTemplateConfigEncryptionsDrmSystemsWidevineToTerraform(struct?: GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsWidevineOutputReference | GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsWidevine): any;
export declare function googleTranscoderJobTemplateConfigEncryptionsDrmSystemsWidevineToHclTerraform(struct?: GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsWidevineOutputReference | GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsWidevine): any;
export declare class GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsWidevineOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsWidevine | undefined;
    set internalValue(value: GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsWidevine | undefined);
}
export interface GoogleTranscoderJobTemplateConfigEncryptionsDrmSystems {
    /**
    * clearkey block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#clearkey GoogleTranscoderJobTemplate#clearkey}
    */
    readonly clearkey?: GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsClearkey;
    /**
    * fairplay block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#fairplay GoogleTranscoderJobTemplate#fairplay}
    */
    readonly fairplay?: GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsFairplay;
    /**
    * playready block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#playready GoogleTranscoderJobTemplate#playready}
    */
    readonly playready?: GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsPlayready;
    /**
    * widevine block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#widevine GoogleTranscoderJobTemplate#widevine}
    */
    readonly widevine?: GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsWidevine;
}
export declare function googleTranscoderJobTemplateConfigEncryptionsDrmSystemsToTerraform(struct?: GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsOutputReference | GoogleTranscoderJobTemplateConfigEncryptionsDrmSystems): any;
export declare function googleTranscoderJobTemplateConfigEncryptionsDrmSystemsToHclTerraform(struct?: GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsOutputReference | GoogleTranscoderJobTemplateConfigEncryptionsDrmSystems): any;
export declare class GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTranscoderJobTemplateConfigEncryptionsDrmSystems | undefined;
    set internalValue(value: GoogleTranscoderJobTemplateConfigEncryptionsDrmSystems | undefined);
    private _clearkey;
    get clearkey(): GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsClearkeyOutputReference;
    putClearkey(value: GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsClearkey): void;
    resetClearkey(): void;
    get clearkeyInput(): GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsClearkey | undefined;
    private _fairplay;
    get fairplay(): GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsFairplayOutputReference;
    putFairplay(value: GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsFairplay): void;
    resetFairplay(): void;
    get fairplayInput(): GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsFairplay | undefined;
    private _playready;
    get playready(): GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsPlayreadyOutputReference;
    putPlayready(value: GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsPlayready): void;
    resetPlayready(): void;
    get playreadyInput(): GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsPlayready | undefined;
    private _widevine;
    get widevine(): GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsWidevineOutputReference;
    putWidevine(value: GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsWidevine): void;
    resetWidevine(): void;
    get widevineInput(): GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsWidevine | undefined;
}
export interface GoogleTranscoderJobTemplateConfigEncryptionsMpegCenc {
    /**
    * Specify the encryption scheme.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#scheme GoogleTranscoderJobTemplate#scheme}
    */
    readonly scheme: string;
}
export declare function googleTranscoderJobTemplateConfigEncryptionsMpegCencToTerraform(struct?: GoogleTranscoderJobTemplateConfigEncryptionsMpegCencOutputReference | GoogleTranscoderJobTemplateConfigEncryptionsMpegCenc): any;
export declare function googleTranscoderJobTemplateConfigEncryptionsMpegCencToHclTerraform(struct?: GoogleTranscoderJobTemplateConfigEncryptionsMpegCencOutputReference | GoogleTranscoderJobTemplateConfigEncryptionsMpegCenc): any;
export declare class GoogleTranscoderJobTemplateConfigEncryptionsMpegCencOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTranscoderJobTemplateConfigEncryptionsMpegCenc | undefined;
    set internalValue(value: GoogleTranscoderJobTemplateConfigEncryptionsMpegCenc | undefined);
    private _scheme?;
    get scheme(): string;
    set scheme(value: string);
    get schemeInput(): string | undefined;
}
export interface GoogleTranscoderJobTemplateConfigEncryptionsSampleAes {
}
export declare function googleTranscoderJobTemplateConfigEncryptionsSampleAesToTerraform(struct?: GoogleTranscoderJobTemplateConfigEncryptionsSampleAesOutputReference | GoogleTranscoderJobTemplateConfigEncryptionsSampleAes): any;
export declare function googleTranscoderJobTemplateConfigEncryptionsSampleAesToHclTerraform(struct?: GoogleTranscoderJobTemplateConfigEncryptionsSampleAesOutputReference | GoogleTranscoderJobTemplateConfigEncryptionsSampleAes): any;
export declare class GoogleTranscoderJobTemplateConfigEncryptionsSampleAesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTranscoderJobTemplateConfigEncryptionsSampleAes | undefined;
    set internalValue(value: GoogleTranscoderJobTemplateConfigEncryptionsSampleAes | undefined);
}
export interface GoogleTranscoderJobTemplateConfigEncryptionsSecretManagerKeySource {
    /**
    * The name of the Secret Version containing the encryption key in the following format: projects/{project}/secrets/{secret_id}/versions/{version_number}.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#secret_version GoogleTranscoderJobTemplate#secret_version}
    */
    readonly secretVersion: string;
}
export declare function googleTranscoderJobTemplateConfigEncryptionsSecretManagerKeySourceToTerraform(struct?: GoogleTranscoderJobTemplateConfigEncryptionsSecretManagerKeySourceOutputReference | GoogleTranscoderJobTemplateConfigEncryptionsSecretManagerKeySource): any;
export declare function googleTranscoderJobTemplateConfigEncryptionsSecretManagerKeySourceToHclTerraform(struct?: GoogleTranscoderJobTemplateConfigEncryptionsSecretManagerKeySourceOutputReference | GoogleTranscoderJobTemplateConfigEncryptionsSecretManagerKeySource): any;
export declare class GoogleTranscoderJobTemplateConfigEncryptionsSecretManagerKeySourceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTranscoderJobTemplateConfigEncryptionsSecretManagerKeySource | undefined;
    set internalValue(value: GoogleTranscoderJobTemplateConfigEncryptionsSecretManagerKeySource | undefined);
    private _secretVersion?;
    get secretVersion(): string;
    set secretVersion(value: string);
    get secretVersionInput(): string | undefined;
}
export interface GoogleTranscoderJobTemplateConfigEncryptions {
    /**
    * Identifier for this set of encryption options.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#id GoogleTranscoderJobTemplate#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * aes128 block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#aes128 GoogleTranscoderJobTemplate#aes128}
    */
    readonly aes128?: GoogleTranscoderJobTemplateConfigEncryptionsAes128;
    /**
    * drm_systems block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#drm_systems GoogleTranscoderJobTemplate#drm_systems}
    */
    readonly drmSystems?: GoogleTranscoderJobTemplateConfigEncryptionsDrmSystems;
    /**
    * mpeg_cenc block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#mpeg_cenc GoogleTranscoderJobTemplate#mpeg_cenc}
    */
    readonly mpegCenc?: GoogleTranscoderJobTemplateConfigEncryptionsMpegCenc;
    /**
    * sample_aes block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#sample_aes GoogleTranscoderJobTemplate#sample_aes}
    */
    readonly sampleAes?: GoogleTranscoderJobTemplateConfigEncryptionsSampleAes;
    /**
    * secret_manager_key_source block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#secret_manager_key_source GoogleTranscoderJobTemplate#secret_manager_key_source}
    */
    readonly secretManagerKeySource?: GoogleTranscoderJobTemplateConfigEncryptionsSecretManagerKeySource;
}
export declare function googleTranscoderJobTemplateConfigEncryptionsToTerraform(struct?: GoogleTranscoderJobTemplateConfigEncryptions | cdktf.IResolvable): any;
export declare function googleTranscoderJobTemplateConfigEncryptionsToHclTerraform(struct?: GoogleTranscoderJobTemplateConfigEncryptions | cdktf.IResolvable): any;
export declare class GoogleTranscoderJobTemplateConfigEncryptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleTranscoderJobTemplateConfigEncryptions | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleTranscoderJobTemplateConfigEncryptions | cdktf.IResolvable | undefined);
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _aes128;
    get aes128(): GoogleTranscoderJobTemplateConfigEncryptionsAes128OutputReference;
    putAes128(value: GoogleTranscoderJobTemplateConfigEncryptionsAes128): void;
    resetAes128(): void;
    get aes128Input(): GoogleTranscoderJobTemplateConfigEncryptionsAes128 | undefined;
    private _drmSystems;
    get drmSystems(): GoogleTranscoderJobTemplateConfigEncryptionsDrmSystemsOutputReference;
    putDrmSystems(value: GoogleTranscoderJobTemplateConfigEncryptionsDrmSystems): void;
    resetDrmSystems(): void;
    get drmSystemsInput(): GoogleTranscoderJobTemplateConfigEncryptionsDrmSystems | undefined;
    private _mpegCenc;
    get mpegCenc(): GoogleTranscoderJobTemplateConfigEncryptionsMpegCencOutputReference;
    putMpegCenc(value: GoogleTranscoderJobTemplateConfigEncryptionsMpegCenc): void;
    resetMpegCenc(): void;
    get mpegCencInput(): GoogleTranscoderJobTemplateConfigEncryptionsMpegCenc | undefined;
    private _sampleAes;
    get sampleAes(): GoogleTranscoderJobTemplateConfigEncryptionsSampleAesOutputReference;
    putSampleAes(value: GoogleTranscoderJobTemplateConfigEncryptionsSampleAes): void;
    resetSampleAes(): void;
    get sampleAesInput(): GoogleTranscoderJobTemplateConfigEncryptionsSampleAes | undefined;
    private _secretManagerKeySource;
    get secretManagerKeySource(): GoogleTranscoderJobTemplateConfigEncryptionsSecretManagerKeySourceOutputReference;
    putSecretManagerKeySource(value: GoogleTranscoderJobTemplateConfigEncryptionsSecretManagerKeySource): void;
    resetSecretManagerKeySource(): void;
    get secretManagerKeySourceInput(): GoogleTranscoderJobTemplateConfigEncryptionsSecretManagerKeySource | undefined;
}
export declare class GoogleTranscoderJobTemplateConfigEncryptionsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleTranscoderJobTemplateConfigEncryptions[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleTranscoderJobTemplateConfigEncryptionsOutputReference;
}
export interface GoogleTranscoderJobTemplateConfigInputs {
    /**
    * A unique key for this input. Must be specified when using advanced mapping and edit lists.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#key GoogleTranscoderJobTemplate#key}
    */
    readonly key?: string;
    /**
    * URI of the media. Input files must be at least 5 seconds in duration and stored in Cloud Storage (for example, gs://bucket/inputs/file.mp4).
    * If empty, the value is populated from Job.input_uri.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#uri GoogleTranscoderJobTemplate#uri}
    */
    readonly uri?: string;
}
export declare function googleTranscoderJobTemplateConfigInputsToTerraform(struct?: GoogleTranscoderJobTemplateConfigInputs | cdktf.IResolvable): any;
export declare function googleTranscoderJobTemplateConfigInputsToHclTerraform(struct?: GoogleTranscoderJobTemplateConfigInputs | cdktf.IResolvable): any;
export declare class GoogleTranscoderJobTemplateConfigInputsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleTranscoderJobTemplateConfigInputs | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleTranscoderJobTemplateConfigInputs | cdktf.IResolvable | undefined);
    private _key?;
    get key(): string;
    set key(value: string);
    resetKey(): void;
    get keyInput(): string | undefined;
    private _uri?;
    get uri(): string;
    set uri(value: string);
    resetUri(): void;
    get uriInput(): string | undefined;
}
export declare class GoogleTranscoderJobTemplateConfigInputsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleTranscoderJobTemplateConfigInputs[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleTranscoderJobTemplateConfigInputsOutputReference;
}
export interface GoogleTranscoderJobTemplateConfigManifests {
    /**
    * The name of the generated file. The default is 'manifest'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#file_name GoogleTranscoderJobTemplate#file_name}
    */
    readonly fileName?: string;
    /**
    * List of user supplied MuxStream.key values that should appear in this manifest.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#mux_streams GoogleTranscoderJobTemplate#mux_streams}
    */
    readonly muxStreams?: string[];
    /**
    * Type of the manifest. Possible values: ["MANIFEST_TYPE_UNSPECIFIED", "HLS", "DASH"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#type GoogleTranscoderJobTemplate#type}
    */
    readonly type?: string;
}
export declare function googleTranscoderJobTemplateConfigManifestsToTerraform(struct?: GoogleTranscoderJobTemplateConfigManifests | cdktf.IResolvable): any;
export declare function googleTranscoderJobTemplateConfigManifestsToHclTerraform(struct?: GoogleTranscoderJobTemplateConfigManifests | cdktf.IResolvable): any;
export declare class GoogleTranscoderJobTemplateConfigManifestsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleTranscoderJobTemplateConfigManifests | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleTranscoderJobTemplateConfigManifests | cdktf.IResolvable | undefined);
    private _fileName?;
    get fileName(): string;
    set fileName(value: string);
    resetFileName(): void;
    get fileNameInput(): string | undefined;
    private _muxStreams?;
    get muxStreams(): string[];
    set muxStreams(value: string[]);
    resetMuxStreams(): void;
    get muxStreamsInput(): string[] | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    resetType(): void;
    get typeInput(): string | undefined;
}
export declare class GoogleTranscoderJobTemplateConfigManifestsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleTranscoderJobTemplateConfigManifests[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleTranscoderJobTemplateConfigManifestsOutputReference;
}
export interface GoogleTranscoderJobTemplateConfigMuxStreamsSegmentSettings {
    /**
    * Duration of the segments in seconds. The default is '6.0s'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#segment_duration GoogleTranscoderJobTemplate#segment_duration}
    */
    readonly segmentDuration?: string;
}
export declare function googleTranscoderJobTemplateConfigMuxStreamsSegmentSettingsToTerraform(struct?: GoogleTranscoderJobTemplateConfigMuxStreamsSegmentSettingsOutputReference | GoogleTranscoderJobTemplateConfigMuxStreamsSegmentSettings): any;
export declare function googleTranscoderJobTemplateConfigMuxStreamsSegmentSettingsToHclTerraform(struct?: GoogleTranscoderJobTemplateConfigMuxStreamsSegmentSettingsOutputReference | GoogleTranscoderJobTemplateConfigMuxStreamsSegmentSettings): any;
export declare class GoogleTranscoderJobTemplateConfigMuxStreamsSegmentSettingsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTranscoderJobTemplateConfigMuxStreamsSegmentSettings | undefined;
    set internalValue(value: GoogleTranscoderJobTemplateConfigMuxStreamsSegmentSettings | undefined);
    private _segmentDuration?;
    get segmentDuration(): string;
    set segmentDuration(value: string);
    resetSegmentDuration(): void;
    get segmentDurationInput(): string | undefined;
}
export interface GoogleTranscoderJobTemplateConfigMuxStreams {
    /**
    * The container format. The default is 'mp4'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#container GoogleTranscoderJobTemplate#container}
    */
    readonly container?: string;
    /**
    * List of ElementaryStream.key values multiplexed in this stream.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#elementary_streams GoogleTranscoderJobTemplate#elementary_streams}
    */
    readonly elementaryStreams?: string[];
    /**
    * Identifier of the encryption configuration to use.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#encryption_id GoogleTranscoderJobTemplate#encryption_id}
    */
    readonly encryptionId?: string;
    /**
    * The name of the generated file.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#file_name GoogleTranscoderJobTemplate#file_name}
    */
    readonly fileName?: string;
    /**
    * A unique key for this multiplexed stream.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#key GoogleTranscoderJobTemplate#key}
    */
    readonly key?: string;
    /**
    * segment_settings block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#segment_settings GoogleTranscoderJobTemplate#segment_settings}
    */
    readonly segmentSettings?: GoogleTranscoderJobTemplateConfigMuxStreamsSegmentSettings;
}
export declare function googleTranscoderJobTemplateConfigMuxStreamsToTerraform(struct?: GoogleTranscoderJobTemplateConfigMuxStreams | cdktf.IResolvable): any;
export declare function googleTranscoderJobTemplateConfigMuxStreamsToHclTerraform(struct?: GoogleTranscoderJobTemplateConfigMuxStreams | cdktf.IResolvable): any;
export declare class GoogleTranscoderJobTemplateConfigMuxStreamsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleTranscoderJobTemplateConfigMuxStreams | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleTranscoderJobTemplateConfigMuxStreams | cdktf.IResolvable | undefined);
    private _container?;
    get container(): string;
    set container(value: string);
    resetContainer(): void;
    get containerInput(): string | undefined;
    private _elementaryStreams?;
    get elementaryStreams(): string[];
    set elementaryStreams(value: string[]);
    resetElementaryStreams(): void;
    get elementaryStreamsInput(): string[] | undefined;
    private _encryptionId?;
    get encryptionId(): string;
    set encryptionId(value: string);
    resetEncryptionId(): void;
    get encryptionIdInput(): string | undefined;
    private _fileName?;
    get fileName(): string;
    set fileName(value: string);
    resetFileName(): void;
    get fileNameInput(): string | undefined;
    private _key?;
    get key(): string;
    set key(value: string);
    resetKey(): void;
    get keyInput(): string | undefined;
    private _segmentSettings;
    get segmentSettings(): GoogleTranscoderJobTemplateConfigMuxStreamsSegmentSettingsOutputReference;
    putSegmentSettings(value: GoogleTranscoderJobTemplateConfigMuxStreamsSegmentSettings): void;
    resetSegmentSettings(): void;
    get segmentSettingsInput(): GoogleTranscoderJobTemplateConfigMuxStreamsSegmentSettings | undefined;
}
export declare class GoogleTranscoderJobTemplateConfigMuxStreamsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleTranscoderJobTemplateConfigMuxStreams[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleTranscoderJobTemplateConfigMuxStreamsOutputReference;
}
export interface GoogleTranscoderJobTemplateConfigOutput {
    /**
    * URI for the output file(s). For example, gs://my-bucket/outputs/.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#uri GoogleTranscoderJobTemplate#uri}
    */
    readonly uri?: string;
}
export declare function googleTranscoderJobTemplateConfigOutputToTerraform(struct?: GoogleTranscoderJobTemplateConfigOutputOutputReference | GoogleTranscoderJobTemplateConfigOutput): any;
export declare function googleTranscoderJobTemplateConfigOutputToHclTerraform(struct?: GoogleTranscoderJobTemplateConfigOutputOutputReference | GoogleTranscoderJobTemplateConfigOutput): any;
export declare class GoogleTranscoderJobTemplateConfigOutputOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTranscoderJobTemplateConfigOutput | undefined;
    set internalValue(value: GoogleTranscoderJobTemplateConfigOutput | undefined);
    private _uri?;
    get uri(): string;
    set uri(value: string);
    resetUri(): void;
    get uriInput(): string | undefined;
}
export interface GoogleTranscoderJobTemplateConfigOverlaysAnimationsAnimationFadeXy {
    /**
    * Normalized x coordinate.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#x GoogleTranscoderJobTemplate#x}
    */
    readonly x?: number;
    /**
    * Normalized y coordinate.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#y GoogleTranscoderJobTemplate#y}
    */
    readonly y?: number;
}
export declare function googleTranscoderJobTemplateConfigOverlaysAnimationsAnimationFadeXyToTerraform(struct?: GoogleTranscoderJobTemplateConfigOverlaysAnimationsAnimationFadeXyOutputReference | GoogleTranscoderJobTemplateConfigOverlaysAnimationsAnimationFadeXy): any;
export declare function googleTranscoderJobTemplateConfigOverlaysAnimationsAnimationFadeXyToHclTerraform(struct?: GoogleTranscoderJobTemplateConfigOverlaysAnimationsAnimationFadeXyOutputReference | GoogleTranscoderJobTemplateConfigOverlaysAnimationsAnimationFadeXy): any;
export declare class GoogleTranscoderJobTemplateConfigOverlaysAnimationsAnimationFadeXyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTranscoderJobTemplateConfigOverlaysAnimationsAnimationFadeXy | undefined;
    set internalValue(value: GoogleTranscoderJobTemplateConfigOverlaysAnimationsAnimationFadeXy | undefined);
    private _x?;
    get x(): number;
    set x(value: number);
    resetX(): void;
    get xInput(): number | undefined;
    private _y?;
    get y(): number;
    set y(value: number);
    resetY(): void;
    get yInput(): number | undefined;
}
export interface GoogleTranscoderJobTemplateConfigOverlaysAnimationsAnimationFade {
    /**
    * The time to end the fade animation, in seconds.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#end_time_offset GoogleTranscoderJobTemplate#end_time_offset}
    */
    readonly endTimeOffset?: string;
    /**
    * Required. Type of fade animation: 'FADE_IN' or 'FADE_OUT'.
    * The possible values are:
    *
    * * 'FADE_TYPE_UNSPECIFIED': The fade type is not specified.
    *
    * * 'FADE_IN': Fade the overlay object into view.
    *
    * * 'FADE_OUT': Fade the overlay object out of view. Possible values: ["FADE_TYPE_UNSPECIFIED", "FADE_IN", "FADE_OUT"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#fade_type GoogleTranscoderJobTemplate#fade_type}
    */
    readonly fadeType: string;
    /**
    * The time to start the fade animation, in seconds.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#start_time_offset GoogleTranscoderJobTemplate#start_time_offset}
    */
    readonly startTimeOffset?: string;
    /**
    * xy block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#xy GoogleTranscoderJobTemplate#xy}
    */
    readonly xy?: GoogleTranscoderJobTemplateConfigOverlaysAnimationsAnimationFadeXy;
}
export declare function googleTranscoderJobTemplateConfigOverlaysAnimationsAnimationFadeToTerraform(struct?: GoogleTranscoderJobTemplateConfigOverlaysAnimationsAnimationFadeOutputReference | GoogleTranscoderJobTemplateConfigOverlaysAnimationsAnimationFade): any;
export declare function googleTranscoderJobTemplateConfigOverlaysAnimationsAnimationFadeToHclTerraform(struct?: GoogleTranscoderJobTemplateConfigOverlaysAnimationsAnimationFadeOutputReference | GoogleTranscoderJobTemplateConfigOverlaysAnimationsAnimationFade): any;
export declare class GoogleTranscoderJobTemplateConfigOverlaysAnimationsAnimationFadeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTranscoderJobTemplateConfigOverlaysAnimationsAnimationFade | undefined;
    set internalValue(value: GoogleTranscoderJobTemplateConfigOverlaysAnimationsAnimationFade | undefined);
    private _endTimeOffset?;
    get endTimeOffset(): string;
    set endTimeOffset(value: string);
    resetEndTimeOffset(): void;
    get endTimeOffsetInput(): string | undefined;
    private _fadeType?;
    get fadeType(): string;
    set fadeType(value: string);
    get fadeTypeInput(): string | undefined;
    private _startTimeOffset?;
    get startTimeOffset(): string;
    set startTimeOffset(value: string);
    resetStartTimeOffset(): void;
    get startTimeOffsetInput(): string | undefined;
    private _xy;
    get xy(): GoogleTranscoderJobTemplateConfigOverlaysAnimationsAnimationFadeXyOutputReference;
    putXy(value: GoogleTranscoderJobTemplateConfigOverlaysAnimationsAnimationFadeXy): void;
    resetXy(): void;
    get xyInput(): GoogleTranscoderJobTemplateConfigOverlaysAnimationsAnimationFadeXy | undefined;
}
export interface GoogleTranscoderJobTemplateConfigOverlaysAnimations {
    /**
    * animation_fade block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#animation_fade GoogleTranscoderJobTemplate#animation_fade}
    */
    readonly animationFade?: GoogleTranscoderJobTemplateConfigOverlaysAnimationsAnimationFade;
}
export declare function googleTranscoderJobTemplateConfigOverlaysAnimationsToTerraform(struct?: GoogleTranscoderJobTemplateConfigOverlaysAnimations | cdktf.IResolvable): any;
export declare function googleTranscoderJobTemplateConfigOverlaysAnimationsToHclTerraform(struct?: GoogleTranscoderJobTemplateConfigOverlaysAnimations | cdktf.IResolvable): any;
export declare class GoogleTranscoderJobTemplateConfigOverlaysAnimationsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleTranscoderJobTemplateConfigOverlaysAnimations | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleTranscoderJobTemplateConfigOverlaysAnimations | cdktf.IResolvable | undefined);
    private _animationFade;
    get animationFade(): GoogleTranscoderJobTemplateConfigOverlaysAnimationsAnimationFadeOutputReference;
    putAnimationFade(value: GoogleTranscoderJobTemplateConfigOverlaysAnimationsAnimationFade): void;
    resetAnimationFade(): void;
    get animationFadeInput(): GoogleTranscoderJobTemplateConfigOverlaysAnimationsAnimationFade | undefined;
}
export declare class GoogleTranscoderJobTemplateConfigOverlaysAnimationsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleTranscoderJobTemplateConfigOverlaysAnimations[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleTranscoderJobTemplateConfigOverlaysAnimationsOutputReference;
}
export interface GoogleTranscoderJobTemplateConfigOverlaysImage {
    /**
    * URI of the image in Cloud Storage. For example, gs://bucket/inputs/image.png.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#uri GoogleTranscoderJobTemplate#uri}
    */
    readonly uri: string;
}
export declare function googleTranscoderJobTemplateConfigOverlaysImageToTerraform(struct?: GoogleTranscoderJobTemplateConfigOverlaysImageOutputReference | GoogleTranscoderJobTemplateConfigOverlaysImage): any;
export declare function googleTranscoderJobTemplateConfigOverlaysImageToHclTerraform(struct?: GoogleTranscoderJobTemplateConfigOverlaysImageOutputReference | GoogleTranscoderJobTemplateConfigOverlaysImage): any;
export declare class GoogleTranscoderJobTemplateConfigOverlaysImageOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTranscoderJobTemplateConfigOverlaysImage | undefined;
    set internalValue(value: GoogleTranscoderJobTemplateConfigOverlaysImage | undefined);
    private _uri?;
    get uri(): string;
    set uri(value: string);
    get uriInput(): string | undefined;
}
export interface GoogleTranscoderJobTemplateConfigOverlays {
    /**
    * animations block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#animations GoogleTranscoderJobTemplate#animations}
    */
    readonly animations?: GoogleTranscoderJobTemplateConfigOverlaysAnimations[] | cdktf.IResolvable;
    /**
    * image block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#image GoogleTranscoderJobTemplate#image}
    */
    readonly image?: GoogleTranscoderJobTemplateConfigOverlaysImage;
}
export declare function googleTranscoderJobTemplateConfigOverlaysToTerraform(struct?: GoogleTranscoderJobTemplateConfigOverlays | cdktf.IResolvable): any;
export declare function googleTranscoderJobTemplateConfigOverlaysToHclTerraform(struct?: GoogleTranscoderJobTemplateConfigOverlays | cdktf.IResolvable): any;
export declare class GoogleTranscoderJobTemplateConfigOverlaysOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleTranscoderJobTemplateConfigOverlays | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleTranscoderJobTemplateConfigOverlays | cdktf.IResolvable | undefined);
    private _animations;
    get animations(): GoogleTranscoderJobTemplateConfigOverlaysAnimationsList;
    putAnimations(value: GoogleTranscoderJobTemplateConfigOverlaysAnimations[] | cdktf.IResolvable): void;
    resetAnimations(): void;
    get animationsInput(): cdktf.IResolvable | GoogleTranscoderJobTemplateConfigOverlaysAnimations[] | undefined;
    private _image;
    get image(): GoogleTranscoderJobTemplateConfigOverlaysImageOutputReference;
    putImage(value: GoogleTranscoderJobTemplateConfigOverlaysImage): void;
    resetImage(): void;
    get imageInput(): GoogleTranscoderJobTemplateConfigOverlaysImage | undefined;
}
export declare class GoogleTranscoderJobTemplateConfigOverlaysList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleTranscoderJobTemplateConfigOverlays[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleTranscoderJobTemplateConfigOverlaysOutputReference;
}
export interface GoogleTranscoderJobTemplateConfigPubsubDestination {
    /**
    * The name of the Pub/Sub topic to publish job completion notification to. For example: projects/{project}/topics/{topic}.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#topic GoogleTranscoderJobTemplate#topic}
    */
    readonly topic?: string;
}
export declare function googleTranscoderJobTemplateConfigPubsubDestinationToTerraform(struct?: GoogleTranscoderJobTemplateConfigPubsubDestinationOutputReference | GoogleTranscoderJobTemplateConfigPubsubDestination): any;
export declare function googleTranscoderJobTemplateConfigPubsubDestinationToHclTerraform(struct?: GoogleTranscoderJobTemplateConfigPubsubDestinationOutputReference | GoogleTranscoderJobTemplateConfigPubsubDestination): any;
export declare class GoogleTranscoderJobTemplateConfigPubsubDestinationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTranscoderJobTemplateConfigPubsubDestination | undefined;
    set internalValue(value: GoogleTranscoderJobTemplateConfigPubsubDestination | undefined);
    private _topic?;
    get topic(): string;
    set topic(value: string);
    resetTopic(): void;
    get topicInput(): string | undefined;
}
export interface GoogleTranscoderJobTemplateConfigA {
    /**
    * ad_breaks block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#ad_breaks GoogleTranscoderJobTemplate#ad_breaks}
    */
    readonly adBreaks?: GoogleTranscoderJobTemplateConfigAdBreaks[] | cdktf.IResolvable;
    /**
    * edit_list block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#edit_list GoogleTranscoderJobTemplate#edit_list}
    */
    readonly editList?: GoogleTranscoderJobTemplateConfigEditListStruct[] | cdktf.IResolvable;
    /**
    * elementary_streams block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#elementary_streams GoogleTranscoderJobTemplate#elementary_streams}
    */
    readonly elementaryStreams?: GoogleTranscoderJobTemplateConfigElementaryStreams[] | cdktf.IResolvable;
    /**
    * encryptions block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#encryptions GoogleTranscoderJobTemplate#encryptions}
    */
    readonly encryptions?: GoogleTranscoderJobTemplateConfigEncryptions[] | cdktf.IResolvable;
    /**
    * inputs block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#inputs GoogleTranscoderJobTemplate#inputs}
    */
    readonly inputs?: GoogleTranscoderJobTemplateConfigInputs[] | cdktf.IResolvable;
    /**
    * manifests block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#manifests GoogleTranscoderJobTemplate#manifests}
    */
    readonly manifests?: GoogleTranscoderJobTemplateConfigManifests[] | cdktf.IResolvable;
    /**
    * mux_streams block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#mux_streams GoogleTranscoderJobTemplate#mux_streams}
    */
    readonly muxStreams?: GoogleTranscoderJobTemplateConfigMuxStreams[] | cdktf.IResolvable;
    /**
    * output block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#output GoogleTranscoderJobTemplate#output}
    */
    readonly output?: GoogleTranscoderJobTemplateConfigOutput;
    /**
    * overlays block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#overlays GoogleTranscoderJobTemplate#overlays}
    */
    readonly overlays?: GoogleTranscoderJobTemplateConfigOverlays[] | cdktf.IResolvable;
    /**
    * pubsub_destination block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#pubsub_destination GoogleTranscoderJobTemplate#pubsub_destination}
    */
    readonly pubsubDestination?: GoogleTranscoderJobTemplateConfigPubsubDestination;
}
export declare function googleTranscoderJobTemplateConfigAToTerraform(struct?: GoogleTranscoderJobTemplateConfigAOutputReference | GoogleTranscoderJobTemplateConfigA): any;
export declare function googleTranscoderJobTemplateConfigAToHclTerraform(struct?: GoogleTranscoderJobTemplateConfigAOutputReference | GoogleTranscoderJobTemplateConfigA): any;
export declare class GoogleTranscoderJobTemplateConfigAOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTranscoderJobTemplateConfigA | undefined;
    set internalValue(value: GoogleTranscoderJobTemplateConfigA | undefined);
    private _adBreaks;
    get adBreaks(): GoogleTranscoderJobTemplateConfigAdBreaksList;
    putAdBreaks(value: GoogleTranscoderJobTemplateConfigAdBreaks[] | cdktf.IResolvable): void;
    resetAdBreaks(): void;
    get adBreaksInput(): cdktf.IResolvable | GoogleTranscoderJobTemplateConfigAdBreaks[] | undefined;
    private _editList;
    get editList(): GoogleTranscoderJobTemplateConfigEditListStructList;
    putEditList(value: GoogleTranscoderJobTemplateConfigEditListStruct[] | cdktf.IResolvable): void;
    resetEditList(): void;
    get editListInput(): cdktf.IResolvable | GoogleTranscoderJobTemplateConfigEditListStruct[] | undefined;
    private _elementaryStreams;
    get elementaryStreams(): GoogleTranscoderJobTemplateConfigElementaryStreamsList;
    putElementaryStreams(value: GoogleTranscoderJobTemplateConfigElementaryStreams[] | cdktf.IResolvable): void;
    resetElementaryStreams(): void;
    get elementaryStreamsInput(): cdktf.IResolvable | GoogleTranscoderJobTemplateConfigElementaryStreams[] | undefined;
    private _encryptions;
    get encryptions(): GoogleTranscoderJobTemplateConfigEncryptionsList;
    putEncryptions(value: GoogleTranscoderJobTemplateConfigEncryptions[] | cdktf.IResolvable): void;
    resetEncryptions(): void;
    get encryptionsInput(): cdktf.IResolvable | GoogleTranscoderJobTemplateConfigEncryptions[] | undefined;
    private _inputs;
    get inputs(): GoogleTranscoderJobTemplateConfigInputsList;
    putInputs(value: GoogleTranscoderJobTemplateConfigInputs[] | cdktf.IResolvable): void;
    resetInputs(): void;
    get inputsInput(): cdktf.IResolvable | GoogleTranscoderJobTemplateConfigInputs[] | undefined;
    private _manifests;
    get manifests(): GoogleTranscoderJobTemplateConfigManifestsList;
    putManifests(value: GoogleTranscoderJobTemplateConfigManifests[] | cdktf.IResolvable): void;
    resetManifests(): void;
    get manifestsInput(): cdktf.IResolvable | GoogleTranscoderJobTemplateConfigManifests[] | undefined;
    private _muxStreams;
    get muxStreams(): GoogleTranscoderJobTemplateConfigMuxStreamsList;
    putMuxStreams(value: GoogleTranscoderJobTemplateConfigMuxStreams[] | cdktf.IResolvable): void;
    resetMuxStreams(): void;
    get muxStreamsInput(): cdktf.IResolvable | GoogleTranscoderJobTemplateConfigMuxStreams[] | undefined;
    private _output;
    get output(): GoogleTranscoderJobTemplateConfigOutputOutputReference;
    putOutput(value: GoogleTranscoderJobTemplateConfigOutput): void;
    resetOutput(): void;
    get outputInput(): GoogleTranscoderJobTemplateConfigOutput | undefined;
    private _overlays;
    get overlays(): GoogleTranscoderJobTemplateConfigOverlaysList;
    putOverlays(value: GoogleTranscoderJobTemplateConfigOverlays[] | cdktf.IResolvable): void;
    resetOverlays(): void;
    get overlaysInput(): cdktf.IResolvable | GoogleTranscoderJobTemplateConfigOverlays[] | undefined;
    private _pubsubDestination;
    get pubsubDestination(): GoogleTranscoderJobTemplateConfigPubsubDestinationOutputReference;
    putPubsubDestination(value: GoogleTranscoderJobTemplateConfigPubsubDestination): void;
    resetPubsubDestination(): void;
    get pubsubDestinationInput(): GoogleTranscoderJobTemplateConfigPubsubDestination | undefined;
}
export interface GoogleTranscoderJobTemplateTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#create GoogleTranscoderJobTemplate#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#delete GoogleTranscoderJobTemplate#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#update GoogleTranscoderJobTemplate#update}
    */
    readonly update?: string;
}
export declare function googleTranscoderJobTemplateTimeoutsToTerraform(struct?: GoogleTranscoderJobTemplateTimeouts | cdktf.IResolvable): any;
export declare function googleTranscoderJobTemplateTimeoutsToHclTerraform(struct?: GoogleTranscoderJobTemplateTimeouts | cdktf.IResolvable): any;
export declare class GoogleTranscoderJobTemplateTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTranscoderJobTemplateTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleTranscoderJobTemplateTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template google_transcoder_job_template}
*/
export declare class GoogleTranscoderJobTemplate extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_transcoder_job_template";
    /**
    * Generates CDKTF code for importing a GoogleTranscoderJobTemplate resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleTranscoderJobTemplate to import
    * @param importFromId The id of the existing GoogleTranscoderJobTemplate that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleTranscoderJobTemplate to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job_template google_transcoder_job_template} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleTranscoderJobTemplateConfig
    */
    constructor(scope: Construct, id: string, config: GoogleTranscoderJobTemplateConfig);
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _jobTemplateId?;
    get jobTemplateId(): string;
    set jobTemplateId(value: string);
    get jobTemplateIdInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    private _config;
    get config(): GoogleTranscoderJobTemplateConfigAOutputReference;
    putConfig(value: GoogleTranscoderJobTemplateConfigA): void;
    resetConfig(): void;
    get configInput(): GoogleTranscoderJobTemplateConfigA | undefined;
    private _timeouts;
    get timeouts(): GoogleTranscoderJobTemplateTimeoutsOutputReference;
    putTimeouts(value: GoogleTranscoderJobTemplateTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleTranscoderJobTemplateTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
