/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleTranscoderJobConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#id GoogleTranscoderJob#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The labels associated with this job. You can use these to organize and group your jobs.
    *
    *
    * **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
    * Please refer to the field 'effective_labels' for all of the labels present on the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#labels GoogleTranscoderJob#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * The location of the transcoding job resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#location GoogleTranscoderJob#location}
    */
    readonly location: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#project GoogleTranscoderJob#project}
    */
    readonly project?: string;
    /**
    * Specify the templateId to use for populating Job.config.
    * The default is preset/web-hd, which is the only supported preset.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#template_id GoogleTranscoderJob#template_id}
    */
    readonly templateId?: string;
    /**
    * config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#config GoogleTranscoderJob#config}
    */
    readonly config?: GoogleTranscoderJobConfigA;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#timeouts GoogleTranscoderJob#timeouts}
    */
    readonly timeouts?: GoogleTranscoderJobTimeouts;
}
export interface GoogleTranscoderJobConfigAdBreaks {
    /**
    * Start time in seconds for the ad break, relative to the output file timeline
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#start_time_offset GoogleTranscoderJob#start_time_offset}
    */
    readonly startTimeOffset?: string;
}
export declare function googleTranscoderJobConfigAdBreaksToTerraform(struct?: GoogleTranscoderJobConfigAdBreaks | cdktf.IResolvable): any;
export declare function googleTranscoderJobConfigAdBreaksToHclTerraform(struct?: GoogleTranscoderJobConfigAdBreaks | cdktf.IResolvable): any;
export declare class GoogleTranscoderJobConfigAdBreaksOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleTranscoderJobConfigAdBreaks | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleTranscoderJobConfigAdBreaks | cdktf.IResolvable | undefined);
    private _startTimeOffset?;
    get startTimeOffset(): string;
    set startTimeOffset(value: string);
    resetStartTimeOffset(): void;
    get startTimeOffsetInput(): string | undefined;
}
export declare class GoogleTranscoderJobConfigAdBreaksList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleTranscoderJobConfigAdBreaks[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleTranscoderJobConfigAdBreaksOutputReference;
}
export interface GoogleTranscoderJobConfigEditListStruct {
    /**
    * List of values identifying files that should be used in this atom.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#inputs GoogleTranscoderJob#inputs}
    */
    readonly inputs?: string[];
    /**
    * A unique key for this atom.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#key GoogleTranscoderJob#key}
    */
    readonly key?: string;
    /**
    * Start time in seconds for the atom, relative to the input file timeline. The default is '0s'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#start_time_offset GoogleTranscoderJob#start_time_offset}
    */
    readonly startTimeOffset?: string;
}
export declare function googleTranscoderJobConfigEditListStructToTerraform(struct?: GoogleTranscoderJobConfigEditListStruct | cdktf.IResolvable): any;
export declare function googleTranscoderJobConfigEditListStructToHclTerraform(struct?: GoogleTranscoderJobConfigEditListStruct | cdktf.IResolvable): any;
export declare class GoogleTranscoderJobConfigEditListStructOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleTranscoderJobConfigEditListStruct | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleTranscoderJobConfigEditListStruct | cdktf.IResolvable | undefined);
    private _inputs?;
    get inputs(): string[];
    set inputs(value: string[]);
    resetInputs(): void;
    get inputsInput(): string[] | undefined;
    private _key?;
    get key(): string;
    set key(value: string);
    resetKey(): void;
    get keyInput(): string | undefined;
    private _startTimeOffset?;
    get startTimeOffset(): string;
    set startTimeOffset(value: string);
    resetStartTimeOffset(): void;
    get startTimeOffsetInput(): string | undefined;
}
export declare class GoogleTranscoderJobConfigEditListStructList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleTranscoderJobConfigEditListStruct[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleTranscoderJobConfigEditListStructOutputReference;
}
export interface GoogleTranscoderJobConfigElementaryStreamsAudioStream {
    /**
    * Audio bitrate in bits per second.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#bitrate_bps GoogleTranscoderJob#bitrate_bps}
    */
    readonly bitrateBps: number;
    /**
    * Number of audio channels. The default is '2'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#channel_count GoogleTranscoderJob#channel_count}
    */
    readonly channelCount?: number;
    /**
    * A list of channel names specifying layout of the audio channels. The default is ["fl", "fr"].
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#channel_layout GoogleTranscoderJob#channel_layout}
    */
    readonly channelLayout?: string[];
    /**
    * The codec for this audio stream. The default is 'aac'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#codec GoogleTranscoderJob#codec}
    */
    readonly codec?: string;
    /**
    * The audio sample rate in Hertz. The default is '48000'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#sample_rate_hertz GoogleTranscoderJob#sample_rate_hertz}
    */
    readonly sampleRateHertz?: number;
}
export declare function googleTranscoderJobConfigElementaryStreamsAudioStreamToTerraform(struct?: GoogleTranscoderJobConfigElementaryStreamsAudioStreamOutputReference | GoogleTranscoderJobConfigElementaryStreamsAudioStream): any;
export declare function googleTranscoderJobConfigElementaryStreamsAudioStreamToHclTerraform(struct?: GoogleTranscoderJobConfigElementaryStreamsAudioStreamOutputReference | GoogleTranscoderJobConfigElementaryStreamsAudioStream): any;
export declare class GoogleTranscoderJobConfigElementaryStreamsAudioStreamOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTranscoderJobConfigElementaryStreamsAudioStream | undefined;
    set internalValue(value: GoogleTranscoderJobConfigElementaryStreamsAudioStream | undefined);
    private _bitrateBps?;
    get bitrateBps(): number;
    set bitrateBps(value: number);
    get bitrateBpsInput(): number | undefined;
    private _channelCount?;
    get channelCount(): number;
    set channelCount(value: number);
    resetChannelCount(): void;
    get channelCountInput(): number | undefined;
    private _channelLayout?;
    get channelLayout(): string[];
    set channelLayout(value: string[]);
    resetChannelLayout(): void;
    get channelLayoutInput(): string[] | undefined;
    private _codec?;
    get codec(): string;
    set codec(value: string);
    resetCodec(): void;
    get codecInput(): string | undefined;
    private _sampleRateHertz?;
    get sampleRateHertz(): number;
    set sampleRateHertz(value: number);
    resetSampleRateHertz(): void;
    get sampleRateHertzInput(): number | undefined;
}
export interface GoogleTranscoderJobConfigElementaryStreamsVideoStreamH264Hlg {
}
export declare function googleTranscoderJobConfigElementaryStreamsVideoStreamH264HlgToTerraform(struct?: GoogleTranscoderJobConfigElementaryStreamsVideoStreamH264HlgOutputReference | GoogleTranscoderJobConfigElementaryStreamsVideoStreamH264Hlg): any;
export declare function googleTranscoderJobConfigElementaryStreamsVideoStreamH264HlgToHclTerraform(struct?: GoogleTranscoderJobConfigElementaryStreamsVideoStreamH264HlgOutputReference | GoogleTranscoderJobConfigElementaryStreamsVideoStreamH264Hlg): any;
export declare class GoogleTranscoderJobConfigElementaryStreamsVideoStreamH264HlgOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTranscoderJobConfigElementaryStreamsVideoStreamH264Hlg | undefined;
    set internalValue(value: GoogleTranscoderJobConfigElementaryStreamsVideoStreamH264Hlg | undefined);
}
export interface GoogleTranscoderJobConfigElementaryStreamsVideoStreamH264Sdr {
}
export declare function googleTranscoderJobConfigElementaryStreamsVideoStreamH264SdrToTerraform(struct?: GoogleTranscoderJobConfigElementaryStreamsVideoStreamH264SdrOutputReference | GoogleTranscoderJobConfigElementaryStreamsVideoStreamH264Sdr): any;
export declare function googleTranscoderJobConfigElementaryStreamsVideoStreamH264SdrToHclTerraform(struct?: GoogleTranscoderJobConfigElementaryStreamsVideoStreamH264SdrOutputReference | GoogleTranscoderJobConfigElementaryStreamsVideoStreamH264Sdr): any;
export declare class GoogleTranscoderJobConfigElementaryStreamsVideoStreamH264SdrOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTranscoderJobConfigElementaryStreamsVideoStreamH264Sdr | undefined;
    set internalValue(value: GoogleTranscoderJobConfigElementaryStreamsVideoStreamH264Sdr | undefined);
}
export interface GoogleTranscoderJobConfigElementaryStreamsVideoStreamH264 {
    /**
    * The video bitrate in bits per second.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#bitrate_bps GoogleTranscoderJob#bitrate_bps}
    */
    readonly bitrateBps: number;
    /**
    * Target CRF level. The default is '21'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#crf_level GoogleTranscoderJob#crf_level}
    */
    readonly crfLevel?: number;
    /**
    * The entropy coder to use. The default is 'cabac'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#entropy_coder GoogleTranscoderJob#entropy_coder}
    */
    readonly entropyCoder?: string;
    /**
    * The target video frame rate in frames per second (FPS).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#frame_rate GoogleTranscoderJob#frame_rate}
    */
    readonly frameRate: number;
    /**
    * Select the GOP size based on the specified duration. The default is '3s'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#gop_duration GoogleTranscoderJob#gop_duration}
    */
    readonly gopDuration?: string;
    /**
    * The height of the video in pixels.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#height_pixels GoogleTranscoderJob#height_pixels}
    */
    readonly heightPixels?: number;
    /**
    * Pixel format to use. The default is 'yuv420p'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#pixel_format GoogleTranscoderJob#pixel_format}
    */
    readonly pixelFormat?: string;
    /**
    * Enforces the specified codec preset. The default is 'veryfast'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#preset GoogleTranscoderJob#preset}
    */
    readonly preset?: string;
    /**
    * Enforces the specified codec profile.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#profile GoogleTranscoderJob#profile}
    */
    readonly profile?: string;
    /**
    * Specify the mode. The default is 'vbr'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#rate_control_mode GoogleTranscoderJob#rate_control_mode}
    */
    readonly rateControlMode?: string;
    /**
    * Initial fullness of the Video Buffering Verifier (VBV) buffer in bits.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#vbv_fullness_bits GoogleTranscoderJob#vbv_fullness_bits}
    */
    readonly vbvFullnessBits?: number;
    /**
    * Size of the Video Buffering Verifier (VBV) buffer in bits.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#vbv_size_bits GoogleTranscoderJob#vbv_size_bits}
    */
    readonly vbvSizeBits?: number;
    /**
    * The width of the video in pixels.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#width_pixels GoogleTranscoderJob#width_pixels}
    */
    readonly widthPixels?: number;
    /**
    * hlg block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#hlg GoogleTranscoderJob#hlg}
    */
    readonly hlg?: GoogleTranscoderJobConfigElementaryStreamsVideoStreamH264Hlg;
    /**
    * sdr block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#sdr GoogleTranscoderJob#sdr}
    */
    readonly sdr?: GoogleTranscoderJobConfigElementaryStreamsVideoStreamH264Sdr;
}
export declare function googleTranscoderJobConfigElementaryStreamsVideoStreamH264ToTerraform(struct?: GoogleTranscoderJobConfigElementaryStreamsVideoStreamH264OutputReference | GoogleTranscoderJobConfigElementaryStreamsVideoStreamH264): any;
export declare function googleTranscoderJobConfigElementaryStreamsVideoStreamH264ToHclTerraform(struct?: GoogleTranscoderJobConfigElementaryStreamsVideoStreamH264OutputReference | GoogleTranscoderJobConfigElementaryStreamsVideoStreamH264): any;
export declare class GoogleTranscoderJobConfigElementaryStreamsVideoStreamH264OutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTranscoderJobConfigElementaryStreamsVideoStreamH264 | undefined;
    set internalValue(value: GoogleTranscoderJobConfigElementaryStreamsVideoStreamH264 | undefined);
    private _bitrateBps?;
    get bitrateBps(): number;
    set bitrateBps(value: number);
    get bitrateBpsInput(): number | undefined;
    private _crfLevel?;
    get crfLevel(): number;
    set crfLevel(value: number);
    resetCrfLevel(): void;
    get crfLevelInput(): number | undefined;
    private _entropyCoder?;
    get entropyCoder(): string;
    set entropyCoder(value: string);
    resetEntropyCoder(): void;
    get entropyCoderInput(): string | undefined;
    private _frameRate?;
    get frameRate(): number;
    set frameRate(value: number);
    get frameRateInput(): number | undefined;
    private _gopDuration?;
    get gopDuration(): string;
    set gopDuration(value: string);
    resetGopDuration(): void;
    get gopDurationInput(): string | undefined;
    private _heightPixels?;
    get heightPixels(): number;
    set heightPixels(value: number);
    resetHeightPixels(): void;
    get heightPixelsInput(): number | undefined;
    private _pixelFormat?;
    get pixelFormat(): string;
    set pixelFormat(value: string);
    resetPixelFormat(): void;
    get pixelFormatInput(): string | undefined;
    private _preset?;
    get preset(): string;
    set preset(value: string);
    resetPreset(): void;
    get presetInput(): string | undefined;
    private _profile?;
    get profile(): string;
    set profile(value: string);
    resetProfile(): void;
    get profileInput(): string | undefined;
    private _rateControlMode?;
    get rateControlMode(): string;
    set rateControlMode(value: string);
    resetRateControlMode(): void;
    get rateControlModeInput(): string | undefined;
    private _vbvFullnessBits?;
    get vbvFullnessBits(): number;
    set vbvFullnessBits(value: number);
    resetVbvFullnessBits(): void;
    get vbvFullnessBitsInput(): number | undefined;
    private _vbvSizeBits?;
    get vbvSizeBits(): number;
    set vbvSizeBits(value: number);
    resetVbvSizeBits(): void;
    get vbvSizeBitsInput(): number | undefined;
    private _widthPixels?;
    get widthPixels(): number;
    set widthPixels(value: number);
    resetWidthPixels(): void;
    get widthPixelsInput(): number | undefined;
    private _hlg;
    get hlg(): GoogleTranscoderJobConfigElementaryStreamsVideoStreamH264HlgOutputReference;
    putHlg(value: GoogleTranscoderJobConfigElementaryStreamsVideoStreamH264Hlg): void;
    resetHlg(): void;
    get hlgInput(): GoogleTranscoderJobConfigElementaryStreamsVideoStreamH264Hlg | undefined;
    private _sdr;
    get sdr(): GoogleTranscoderJobConfigElementaryStreamsVideoStreamH264SdrOutputReference;
    putSdr(value: GoogleTranscoderJobConfigElementaryStreamsVideoStreamH264Sdr): void;
    resetSdr(): void;
    get sdrInput(): GoogleTranscoderJobConfigElementaryStreamsVideoStreamH264Sdr | undefined;
}
export interface GoogleTranscoderJobConfigElementaryStreamsVideoStream {
    /**
    * h264 block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#h264 GoogleTranscoderJob#h264}
    */
    readonly h264?: GoogleTranscoderJobConfigElementaryStreamsVideoStreamH264;
}
export declare function googleTranscoderJobConfigElementaryStreamsVideoStreamToTerraform(struct?: GoogleTranscoderJobConfigElementaryStreamsVideoStreamOutputReference | GoogleTranscoderJobConfigElementaryStreamsVideoStream): any;
export declare function googleTranscoderJobConfigElementaryStreamsVideoStreamToHclTerraform(struct?: GoogleTranscoderJobConfigElementaryStreamsVideoStreamOutputReference | GoogleTranscoderJobConfigElementaryStreamsVideoStream): any;
export declare class GoogleTranscoderJobConfigElementaryStreamsVideoStreamOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTranscoderJobConfigElementaryStreamsVideoStream | undefined;
    set internalValue(value: GoogleTranscoderJobConfigElementaryStreamsVideoStream | undefined);
    private _h264;
    get h264(): GoogleTranscoderJobConfigElementaryStreamsVideoStreamH264OutputReference;
    putH264(value: GoogleTranscoderJobConfigElementaryStreamsVideoStreamH264): void;
    resetH264(): void;
    get h264Input(): GoogleTranscoderJobConfigElementaryStreamsVideoStreamH264 | undefined;
}
export interface GoogleTranscoderJobConfigElementaryStreams {
    /**
    * A unique key for this atom.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#key GoogleTranscoderJob#key}
    */
    readonly key?: string;
    /**
    * audio_stream block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#audio_stream GoogleTranscoderJob#audio_stream}
    */
    readonly audioStream?: GoogleTranscoderJobConfigElementaryStreamsAudioStream;
    /**
    * video_stream block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#video_stream GoogleTranscoderJob#video_stream}
    */
    readonly videoStream?: GoogleTranscoderJobConfigElementaryStreamsVideoStream;
}
export declare function googleTranscoderJobConfigElementaryStreamsToTerraform(struct?: GoogleTranscoderJobConfigElementaryStreams | cdktf.IResolvable): any;
export declare function googleTranscoderJobConfigElementaryStreamsToHclTerraform(struct?: GoogleTranscoderJobConfigElementaryStreams | cdktf.IResolvable): any;
export declare class GoogleTranscoderJobConfigElementaryStreamsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleTranscoderJobConfigElementaryStreams | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleTranscoderJobConfigElementaryStreams | cdktf.IResolvable | undefined);
    private _key?;
    get key(): string;
    set key(value: string);
    resetKey(): void;
    get keyInput(): string | undefined;
    private _audioStream;
    get audioStream(): GoogleTranscoderJobConfigElementaryStreamsAudioStreamOutputReference;
    putAudioStream(value: GoogleTranscoderJobConfigElementaryStreamsAudioStream): void;
    resetAudioStream(): void;
    get audioStreamInput(): GoogleTranscoderJobConfigElementaryStreamsAudioStream | undefined;
    private _videoStream;
    get videoStream(): GoogleTranscoderJobConfigElementaryStreamsVideoStreamOutputReference;
    putVideoStream(value: GoogleTranscoderJobConfigElementaryStreamsVideoStream): void;
    resetVideoStream(): void;
    get videoStreamInput(): GoogleTranscoderJobConfigElementaryStreamsVideoStream | undefined;
}
export declare class GoogleTranscoderJobConfigElementaryStreamsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleTranscoderJobConfigElementaryStreams[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleTranscoderJobConfigElementaryStreamsOutputReference;
}
export interface GoogleTranscoderJobConfigEncryptionsAes128 {
}
export declare function googleTranscoderJobConfigEncryptionsAes128ToTerraform(struct?: GoogleTranscoderJobConfigEncryptionsAes128OutputReference | GoogleTranscoderJobConfigEncryptionsAes128): any;
export declare function googleTranscoderJobConfigEncryptionsAes128ToHclTerraform(struct?: GoogleTranscoderJobConfigEncryptionsAes128OutputReference | GoogleTranscoderJobConfigEncryptionsAes128): any;
export declare class GoogleTranscoderJobConfigEncryptionsAes128OutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTranscoderJobConfigEncryptionsAes128 | undefined;
    set internalValue(value: GoogleTranscoderJobConfigEncryptionsAes128 | undefined);
}
export interface GoogleTranscoderJobConfigEncryptionsDrmSystemsClearkey {
}
export declare function googleTranscoderJobConfigEncryptionsDrmSystemsClearkeyToTerraform(struct?: GoogleTranscoderJobConfigEncryptionsDrmSystemsClearkeyOutputReference | GoogleTranscoderJobConfigEncryptionsDrmSystemsClearkey): any;
export declare function googleTranscoderJobConfigEncryptionsDrmSystemsClearkeyToHclTerraform(struct?: GoogleTranscoderJobConfigEncryptionsDrmSystemsClearkeyOutputReference | GoogleTranscoderJobConfigEncryptionsDrmSystemsClearkey): any;
export declare class GoogleTranscoderJobConfigEncryptionsDrmSystemsClearkeyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTranscoderJobConfigEncryptionsDrmSystemsClearkey | undefined;
    set internalValue(value: GoogleTranscoderJobConfigEncryptionsDrmSystemsClearkey | undefined);
}
export interface GoogleTranscoderJobConfigEncryptionsDrmSystemsFairplay {
}
export declare function googleTranscoderJobConfigEncryptionsDrmSystemsFairplayToTerraform(struct?: GoogleTranscoderJobConfigEncryptionsDrmSystemsFairplayOutputReference | GoogleTranscoderJobConfigEncryptionsDrmSystemsFairplay): any;
export declare function googleTranscoderJobConfigEncryptionsDrmSystemsFairplayToHclTerraform(struct?: GoogleTranscoderJobConfigEncryptionsDrmSystemsFairplayOutputReference | GoogleTranscoderJobConfigEncryptionsDrmSystemsFairplay): any;
export declare class GoogleTranscoderJobConfigEncryptionsDrmSystemsFairplayOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTranscoderJobConfigEncryptionsDrmSystemsFairplay | undefined;
    set internalValue(value: GoogleTranscoderJobConfigEncryptionsDrmSystemsFairplay | undefined);
}
export interface GoogleTranscoderJobConfigEncryptionsDrmSystemsPlayready {
}
export declare function googleTranscoderJobConfigEncryptionsDrmSystemsPlayreadyToTerraform(struct?: GoogleTranscoderJobConfigEncryptionsDrmSystemsPlayreadyOutputReference | GoogleTranscoderJobConfigEncryptionsDrmSystemsPlayready): any;
export declare function googleTranscoderJobConfigEncryptionsDrmSystemsPlayreadyToHclTerraform(struct?: GoogleTranscoderJobConfigEncryptionsDrmSystemsPlayreadyOutputReference | GoogleTranscoderJobConfigEncryptionsDrmSystemsPlayready): any;
export declare class GoogleTranscoderJobConfigEncryptionsDrmSystemsPlayreadyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTranscoderJobConfigEncryptionsDrmSystemsPlayready | undefined;
    set internalValue(value: GoogleTranscoderJobConfigEncryptionsDrmSystemsPlayready | undefined);
}
export interface GoogleTranscoderJobConfigEncryptionsDrmSystemsWidevine {
}
export declare function googleTranscoderJobConfigEncryptionsDrmSystemsWidevineToTerraform(struct?: GoogleTranscoderJobConfigEncryptionsDrmSystemsWidevineOutputReference | GoogleTranscoderJobConfigEncryptionsDrmSystemsWidevine): any;
export declare function googleTranscoderJobConfigEncryptionsDrmSystemsWidevineToHclTerraform(struct?: GoogleTranscoderJobConfigEncryptionsDrmSystemsWidevineOutputReference | GoogleTranscoderJobConfigEncryptionsDrmSystemsWidevine): any;
export declare class GoogleTranscoderJobConfigEncryptionsDrmSystemsWidevineOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTranscoderJobConfigEncryptionsDrmSystemsWidevine | undefined;
    set internalValue(value: GoogleTranscoderJobConfigEncryptionsDrmSystemsWidevine | undefined);
}
export interface GoogleTranscoderJobConfigEncryptionsDrmSystems {
    /**
    * clearkey block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#clearkey GoogleTranscoderJob#clearkey}
    */
    readonly clearkey?: GoogleTranscoderJobConfigEncryptionsDrmSystemsClearkey;
    /**
    * fairplay block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#fairplay GoogleTranscoderJob#fairplay}
    */
    readonly fairplay?: GoogleTranscoderJobConfigEncryptionsDrmSystemsFairplay;
    /**
    * playready block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#playready GoogleTranscoderJob#playready}
    */
    readonly playready?: GoogleTranscoderJobConfigEncryptionsDrmSystemsPlayready;
    /**
    * widevine block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#widevine GoogleTranscoderJob#widevine}
    */
    readonly widevine?: GoogleTranscoderJobConfigEncryptionsDrmSystemsWidevine;
}
export declare function googleTranscoderJobConfigEncryptionsDrmSystemsToTerraform(struct?: GoogleTranscoderJobConfigEncryptionsDrmSystemsOutputReference | GoogleTranscoderJobConfigEncryptionsDrmSystems): any;
export declare function googleTranscoderJobConfigEncryptionsDrmSystemsToHclTerraform(struct?: GoogleTranscoderJobConfigEncryptionsDrmSystemsOutputReference | GoogleTranscoderJobConfigEncryptionsDrmSystems): any;
export declare class GoogleTranscoderJobConfigEncryptionsDrmSystemsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTranscoderJobConfigEncryptionsDrmSystems | undefined;
    set internalValue(value: GoogleTranscoderJobConfigEncryptionsDrmSystems | undefined);
    private _clearkey;
    get clearkey(): GoogleTranscoderJobConfigEncryptionsDrmSystemsClearkeyOutputReference;
    putClearkey(value: GoogleTranscoderJobConfigEncryptionsDrmSystemsClearkey): void;
    resetClearkey(): void;
    get clearkeyInput(): GoogleTranscoderJobConfigEncryptionsDrmSystemsClearkey | undefined;
    private _fairplay;
    get fairplay(): GoogleTranscoderJobConfigEncryptionsDrmSystemsFairplayOutputReference;
    putFairplay(value: GoogleTranscoderJobConfigEncryptionsDrmSystemsFairplay): void;
    resetFairplay(): void;
    get fairplayInput(): GoogleTranscoderJobConfigEncryptionsDrmSystemsFairplay | undefined;
    private _playready;
    get playready(): GoogleTranscoderJobConfigEncryptionsDrmSystemsPlayreadyOutputReference;
    putPlayready(value: GoogleTranscoderJobConfigEncryptionsDrmSystemsPlayready): void;
    resetPlayready(): void;
    get playreadyInput(): GoogleTranscoderJobConfigEncryptionsDrmSystemsPlayready | undefined;
    private _widevine;
    get widevine(): GoogleTranscoderJobConfigEncryptionsDrmSystemsWidevineOutputReference;
    putWidevine(value: GoogleTranscoderJobConfigEncryptionsDrmSystemsWidevine): void;
    resetWidevine(): void;
    get widevineInput(): GoogleTranscoderJobConfigEncryptionsDrmSystemsWidevine | undefined;
}
export interface GoogleTranscoderJobConfigEncryptionsMpegCenc {
    /**
    * Specify the encryption scheme.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#scheme GoogleTranscoderJob#scheme}
    */
    readonly scheme: string;
}
export declare function googleTranscoderJobConfigEncryptionsMpegCencToTerraform(struct?: GoogleTranscoderJobConfigEncryptionsMpegCencOutputReference | GoogleTranscoderJobConfigEncryptionsMpegCenc): any;
export declare function googleTranscoderJobConfigEncryptionsMpegCencToHclTerraform(struct?: GoogleTranscoderJobConfigEncryptionsMpegCencOutputReference | GoogleTranscoderJobConfigEncryptionsMpegCenc): any;
export declare class GoogleTranscoderJobConfigEncryptionsMpegCencOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTranscoderJobConfigEncryptionsMpegCenc | undefined;
    set internalValue(value: GoogleTranscoderJobConfigEncryptionsMpegCenc | undefined);
    private _scheme?;
    get scheme(): string;
    set scheme(value: string);
    get schemeInput(): string | undefined;
}
export interface GoogleTranscoderJobConfigEncryptionsSampleAes {
}
export declare function googleTranscoderJobConfigEncryptionsSampleAesToTerraform(struct?: GoogleTranscoderJobConfigEncryptionsSampleAesOutputReference | GoogleTranscoderJobConfigEncryptionsSampleAes): any;
export declare function googleTranscoderJobConfigEncryptionsSampleAesToHclTerraform(struct?: GoogleTranscoderJobConfigEncryptionsSampleAesOutputReference | GoogleTranscoderJobConfigEncryptionsSampleAes): any;
export declare class GoogleTranscoderJobConfigEncryptionsSampleAesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTranscoderJobConfigEncryptionsSampleAes | undefined;
    set internalValue(value: GoogleTranscoderJobConfigEncryptionsSampleAes | undefined);
}
export interface GoogleTranscoderJobConfigEncryptionsSecretManagerKeySource {
    /**
    * The name of the Secret Version containing the encryption key in the following format: projects/{project}/secrets/{secret_id}/versions/{version_number}.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#secret_version GoogleTranscoderJob#secret_version}
    */
    readonly secretVersion: string;
}
export declare function googleTranscoderJobConfigEncryptionsSecretManagerKeySourceToTerraform(struct?: GoogleTranscoderJobConfigEncryptionsSecretManagerKeySourceOutputReference | GoogleTranscoderJobConfigEncryptionsSecretManagerKeySource): any;
export declare function googleTranscoderJobConfigEncryptionsSecretManagerKeySourceToHclTerraform(struct?: GoogleTranscoderJobConfigEncryptionsSecretManagerKeySourceOutputReference | GoogleTranscoderJobConfigEncryptionsSecretManagerKeySource): any;
export declare class GoogleTranscoderJobConfigEncryptionsSecretManagerKeySourceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTranscoderJobConfigEncryptionsSecretManagerKeySource | undefined;
    set internalValue(value: GoogleTranscoderJobConfigEncryptionsSecretManagerKeySource | undefined);
    private _secretVersion?;
    get secretVersion(): string;
    set secretVersion(value: string);
    get secretVersionInput(): string | undefined;
}
export interface GoogleTranscoderJobConfigEncryptions {
    /**
    * Identifier for this set of encryption options.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#id GoogleTranscoderJob#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * aes128 block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#aes128 GoogleTranscoderJob#aes128}
    */
    readonly aes128?: GoogleTranscoderJobConfigEncryptionsAes128;
    /**
    * drm_systems block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#drm_systems GoogleTranscoderJob#drm_systems}
    */
    readonly drmSystems?: GoogleTranscoderJobConfigEncryptionsDrmSystems;
    /**
    * mpeg_cenc block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#mpeg_cenc GoogleTranscoderJob#mpeg_cenc}
    */
    readonly mpegCenc?: GoogleTranscoderJobConfigEncryptionsMpegCenc;
    /**
    * sample_aes block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#sample_aes GoogleTranscoderJob#sample_aes}
    */
    readonly sampleAes?: GoogleTranscoderJobConfigEncryptionsSampleAes;
    /**
    * secret_manager_key_source block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#secret_manager_key_source GoogleTranscoderJob#secret_manager_key_source}
    */
    readonly secretManagerKeySource?: GoogleTranscoderJobConfigEncryptionsSecretManagerKeySource;
}
export declare function googleTranscoderJobConfigEncryptionsToTerraform(struct?: GoogleTranscoderJobConfigEncryptions | cdktf.IResolvable): any;
export declare function googleTranscoderJobConfigEncryptionsToHclTerraform(struct?: GoogleTranscoderJobConfigEncryptions | cdktf.IResolvable): any;
export declare class GoogleTranscoderJobConfigEncryptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleTranscoderJobConfigEncryptions | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleTranscoderJobConfigEncryptions | cdktf.IResolvable | undefined);
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _aes128;
    get aes128(): GoogleTranscoderJobConfigEncryptionsAes128OutputReference;
    putAes128(value: GoogleTranscoderJobConfigEncryptionsAes128): void;
    resetAes128(): void;
    get aes128Input(): GoogleTranscoderJobConfigEncryptionsAes128 | undefined;
    private _drmSystems;
    get drmSystems(): GoogleTranscoderJobConfigEncryptionsDrmSystemsOutputReference;
    putDrmSystems(value: GoogleTranscoderJobConfigEncryptionsDrmSystems): void;
    resetDrmSystems(): void;
    get drmSystemsInput(): GoogleTranscoderJobConfigEncryptionsDrmSystems | undefined;
    private _mpegCenc;
    get mpegCenc(): GoogleTranscoderJobConfigEncryptionsMpegCencOutputReference;
    putMpegCenc(value: GoogleTranscoderJobConfigEncryptionsMpegCenc): void;
    resetMpegCenc(): void;
    get mpegCencInput(): GoogleTranscoderJobConfigEncryptionsMpegCenc | undefined;
    private _sampleAes;
    get sampleAes(): GoogleTranscoderJobConfigEncryptionsSampleAesOutputReference;
    putSampleAes(value: GoogleTranscoderJobConfigEncryptionsSampleAes): void;
    resetSampleAes(): void;
    get sampleAesInput(): GoogleTranscoderJobConfigEncryptionsSampleAes | undefined;
    private _secretManagerKeySource;
    get secretManagerKeySource(): GoogleTranscoderJobConfigEncryptionsSecretManagerKeySourceOutputReference;
    putSecretManagerKeySource(value: GoogleTranscoderJobConfigEncryptionsSecretManagerKeySource): void;
    resetSecretManagerKeySource(): void;
    get secretManagerKeySourceInput(): GoogleTranscoderJobConfigEncryptionsSecretManagerKeySource | undefined;
}
export declare class GoogleTranscoderJobConfigEncryptionsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleTranscoderJobConfigEncryptions[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleTranscoderJobConfigEncryptionsOutputReference;
}
export interface GoogleTranscoderJobConfigInputs {
    /**
    * A unique key for this input. Must be specified when using advanced mapping and edit lists.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#key GoogleTranscoderJob#key}
    */
    readonly key?: string;
    /**
    * URI of the media. Input files must be at least 5 seconds in duration and stored in Cloud Storage (for example, gs://bucket/inputs/file.mp4).
    * If empty, the value is populated from Job.input_uri.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#uri GoogleTranscoderJob#uri}
    */
    readonly uri?: string;
}
export declare function googleTranscoderJobConfigInputsToTerraform(struct?: GoogleTranscoderJobConfigInputs | cdktf.IResolvable): any;
export declare function googleTranscoderJobConfigInputsToHclTerraform(struct?: GoogleTranscoderJobConfigInputs | cdktf.IResolvable): any;
export declare class GoogleTranscoderJobConfigInputsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleTranscoderJobConfigInputs | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleTranscoderJobConfigInputs | cdktf.IResolvable | undefined);
    private _key?;
    get key(): string;
    set key(value: string);
    resetKey(): void;
    get keyInput(): string | undefined;
    private _uri?;
    get uri(): string;
    set uri(value: string);
    resetUri(): void;
    get uriInput(): string | undefined;
}
export declare class GoogleTranscoderJobConfigInputsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleTranscoderJobConfigInputs[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleTranscoderJobConfigInputsOutputReference;
}
export interface GoogleTranscoderJobConfigManifests {
    /**
    * The name of the generated file. The default is 'manifest'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#file_name GoogleTranscoderJob#file_name}
    */
    readonly fileName?: string;
    /**
    * List of user supplied MuxStream.key values that should appear in this manifest.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#mux_streams GoogleTranscoderJob#mux_streams}
    */
    readonly muxStreams?: string[];
    /**
    * Type of the manifest. Possible values: ["MANIFEST_TYPE_UNSPECIFIED", "HLS", "DASH"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#type GoogleTranscoderJob#type}
    */
    readonly type?: string;
}
export declare function googleTranscoderJobConfigManifestsToTerraform(struct?: GoogleTranscoderJobConfigManifests | cdktf.IResolvable): any;
export declare function googleTranscoderJobConfigManifestsToHclTerraform(struct?: GoogleTranscoderJobConfigManifests | cdktf.IResolvable): any;
export declare class GoogleTranscoderJobConfigManifestsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleTranscoderJobConfigManifests | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleTranscoderJobConfigManifests | cdktf.IResolvable | undefined);
    private _fileName?;
    get fileName(): string;
    set fileName(value: string);
    resetFileName(): void;
    get fileNameInput(): string | undefined;
    private _muxStreams?;
    get muxStreams(): string[];
    set muxStreams(value: string[]);
    resetMuxStreams(): void;
    get muxStreamsInput(): string[] | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    resetType(): void;
    get typeInput(): string | undefined;
}
export declare class GoogleTranscoderJobConfigManifestsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleTranscoderJobConfigManifests[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleTranscoderJobConfigManifestsOutputReference;
}
export interface GoogleTranscoderJobConfigMuxStreamsSegmentSettings {
    /**
    * Duration of the segments in seconds. The default is '6.0s'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#segment_duration GoogleTranscoderJob#segment_duration}
    */
    readonly segmentDuration?: string;
}
export declare function googleTranscoderJobConfigMuxStreamsSegmentSettingsToTerraform(struct?: GoogleTranscoderJobConfigMuxStreamsSegmentSettingsOutputReference | GoogleTranscoderJobConfigMuxStreamsSegmentSettings): any;
export declare function googleTranscoderJobConfigMuxStreamsSegmentSettingsToHclTerraform(struct?: GoogleTranscoderJobConfigMuxStreamsSegmentSettingsOutputReference | GoogleTranscoderJobConfigMuxStreamsSegmentSettings): any;
export declare class GoogleTranscoderJobConfigMuxStreamsSegmentSettingsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTranscoderJobConfigMuxStreamsSegmentSettings | undefined;
    set internalValue(value: GoogleTranscoderJobConfigMuxStreamsSegmentSettings | undefined);
    private _segmentDuration?;
    get segmentDuration(): string;
    set segmentDuration(value: string);
    resetSegmentDuration(): void;
    get segmentDurationInput(): string | undefined;
}
export interface GoogleTranscoderJobConfigMuxStreams {
    /**
    * The container format. The default is 'mp4'.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#container GoogleTranscoderJob#container}
    */
    readonly container?: string;
    /**
    * List of ElementaryStream.key values multiplexed in this stream.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#elementary_streams GoogleTranscoderJob#elementary_streams}
    */
    readonly elementaryStreams?: string[];
    /**
    * Identifier of the encryption configuration to use.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#encryption_id GoogleTranscoderJob#encryption_id}
    */
    readonly encryptionId?: string;
    /**
    * The name of the generated file.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#file_name GoogleTranscoderJob#file_name}
    */
    readonly fileName?: string;
    /**
    * A unique key for this multiplexed stream.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#key GoogleTranscoderJob#key}
    */
    readonly key?: string;
    /**
    * segment_settings block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#segment_settings GoogleTranscoderJob#segment_settings}
    */
    readonly segmentSettings?: GoogleTranscoderJobConfigMuxStreamsSegmentSettings;
}
export declare function googleTranscoderJobConfigMuxStreamsToTerraform(struct?: GoogleTranscoderJobConfigMuxStreams | cdktf.IResolvable): any;
export declare function googleTranscoderJobConfigMuxStreamsToHclTerraform(struct?: GoogleTranscoderJobConfigMuxStreams | cdktf.IResolvable): any;
export declare class GoogleTranscoderJobConfigMuxStreamsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleTranscoderJobConfigMuxStreams | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleTranscoderJobConfigMuxStreams | cdktf.IResolvable | undefined);
    private _container?;
    get container(): string;
    set container(value: string);
    resetContainer(): void;
    get containerInput(): string | undefined;
    private _elementaryStreams?;
    get elementaryStreams(): string[];
    set elementaryStreams(value: string[]);
    resetElementaryStreams(): void;
    get elementaryStreamsInput(): string[] | undefined;
    private _encryptionId?;
    get encryptionId(): string;
    set encryptionId(value: string);
    resetEncryptionId(): void;
    get encryptionIdInput(): string | undefined;
    private _fileName?;
    get fileName(): string;
    set fileName(value: string);
    resetFileName(): void;
    get fileNameInput(): string | undefined;
    private _key?;
    get key(): string;
    set key(value: string);
    resetKey(): void;
    get keyInput(): string | undefined;
    private _segmentSettings;
    get segmentSettings(): GoogleTranscoderJobConfigMuxStreamsSegmentSettingsOutputReference;
    putSegmentSettings(value: GoogleTranscoderJobConfigMuxStreamsSegmentSettings): void;
    resetSegmentSettings(): void;
    get segmentSettingsInput(): GoogleTranscoderJobConfigMuxStreamsSegmentSettings | undefined;
}
export declare class GoogleTranscoderJobConfigMuxStreamsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleTranscoderJobConfigMuxStreams[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleTranscoderJobConfigMuxStreamsOutputReference;
}
export interface GoogleTranscoderJobConfigOutput {
    /**
    * URI for the output file(s). For example, gs://my-bucket/outputs/.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#uri GoogleTranscoderJob#uri}
    */
    readonly uri?: string;
}
export declare function googleTranscoderJobConfigOutputToTerraform(struct?: GoogleTranscoderJobConfigOutputOutputReference | GoogleTranscoderJobConfigOutput): any;
export declare function googleTranscoderJobConfigOutputToHclTerraform(struct?: GoogleTranscoderJobConfigOutputOutputReference | GoogleTranscoderJobConfigOutput): any;
export declare class GoogleTranscoderJobConfigOutputOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTranscoderJobConfigOutput | undefined;
    set internalValue(value: GoogleTranscoderJobConfigOutput | undefined);
    private _uri?;
    get uri(): string;
    set uri(value: string);
    resetUri(): void;
    get uriInput(): string | undefined;
}
export interface GoogleTranscoderJobConfigOverlaysAnimationsAnimationFadeXy {
    /**
    * Normalized x coordinate.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#x GoogleTranscoderJob#x}
    */
    readonly x?: number;
    /**
    * Normalized y coordinate.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#y GoogleTranscoderJob#y}
    */
    readonly y?: number;
}
export declare function googleTranscoderJobConfigOverlaysAnimationsAnimationFadeXyToTerraform(struct?: GoogleTranscoderJobConfigOverlaysAnimationsAnimationFadeXyOutputReference | GoogleTranscoderJobConfigOverlaysAnimationsAnimationFadeXy): any;
export declare function googleTranscoderJobConfigOverlaysAnimationsAnimationFadeXyToHclTerraform(struct?: GoogleTranscoderJobConfigOverlaysAnimationsAnimationFadeXyOutputReference | GoogleTranscoderJobConfigOverlaysAnimationsAnimationFadeXy): any;
export declare class GoogleTranscoderJobConfigOverlaysAnimationsAnimationFadeXyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTranscoderJobConfigOverlaysAnimationsAnimationFadeXy | undefined;
    set internalValue(value: GoogleTranscoderJobConfigOverlaysAnimationsAnimationFadeXy | undefined);
    private _x?;
    get x(): number;
    set x(value: number);
    resetX(): void;
    get xInput(): number | undefined;
    private _y?;
    get y(): number;
    set y(value: number);
    resetY(): void;
    get yInput(): number | undefined;
}
export interface GoogleTranscoderJobConfigOverlaysAnimationsAnimationFade {
    /**
    * The time to end the fade animation, in seconds.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#end_time_offset GoogleTranscoderJob#end_time_offset}
    */
    readonly endTimeOffset?: string;
    /**
    * Required. Type of fade animation: 'FADE_IN' or 'FADE_OUT'.
    * The possible values are:
    *
    * * 'FADE_TYPE_UNSPECIFIED': The fade type is not specified.
    *
    * * 'FADE_IN': Fade the overlay object into view.
    *
    * * 'FADE_OUT': Fade the overlay object out of view. Possible values: ["FADE_TYPE_UNSPECIFIED", "FADE_IN", "FADE_OUT"]
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#fade_type GoogleTranscoderJob#fade_type}
    */
    readonly fadeType: string;
    /**
    * The time to start the fade animation, in seconds.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#start_time_offset GoogleTranscoderJob#start_time_offset}
    */
    readonly startTimeOffset?: string;
    /**
    * xy block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#xy GoogleTranscoderJob#xy}
    */
    readonly xy?: GoogleTranscoderJobConfigOverlaysAnimationsAnimationFadeXy;
}
export declare function googleTranscoderJobConfigOverlaysAnimationsAnimationFadeToTerraform(struct?: GoogleTranscoderJobConfigOverlaysAnimationsAnimationFadeOutputReference | GoogleTranscoderJobConfigOverlaysAnimationsAnimationFade): any;
export declare function googleTranscoderJobConfigOverlaysAnimationsAnimationFadeToHclTerraform(struct?: GoogleTranscoderJobConfigOverlaysAnimationsAnimationFadeOutputReference | GoogleTranscoderJobConfigOverlaysAnimationsAnimationFade): any;
export declare class GoogleTranscoderJobConfigOverlaysAnimationsAnimationFadeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTranscoderJobConfigOverlaysAnimationsAnimationFade | undefined;
    set internalValue(value: GoogleTranscoderJobConfigOverlaysAnimationsAnimationFade | undefined);
    private _endTimeOffset?;
    get endTimeOffset(): string;
    set endTimeOffset(value: string);
    resetEndTimeOffset(): void;
    get endTimeOffsetInput(): string | undefined;
    private _fadeType?;
    get fadeType(): string;
    set fadeType(value: string);
    get fadeTypeInput(): string | undefined;
    private _startTimeOffset?;
    get startTimeOffset(): string;
    set startTimeOffset(value: string);
    resetStartTimeOffset(): void;
    get startTimeOffsetInput(): string | undefined;
    private _xy;
    get xy(): GoogleTranscoderJobConfigOverlaysAnimationsAnimationFadeXyOutputReference;
    putXy(value: GoogleTranscoderJobConfigOverlaysAnimationsAnimationFadeXy): void;
    resetXy(): void;
    get xyInput(): GoogleTranscoderJobConfigOverlaysAnimationsAnimationFadeXy | undefined;
}
export interface GoogleTranscoderJobConfigOverlaysAnimations {
    /**
    * animation_fade block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#animation_fade GoogleTranscoderJob#animation_fade}
    */
    readonly animationFade?: GoogleTranscoderJobConfigOverlaysAnimationsAnimationFade;
}
export declare function googleTranscoderJobConfigOverlaysAnimationsToTerraform(struct?: GoogleTranscoderJobConfigOverlaysAnimations | cdktf.IResolvable): any;
export declare function googleTranscoderJobConfigOverlaysAnimationsToHclTerraform(struct?: GoogleTranscoderJobConfigOverlaysAnimations | cdktf.IResolvable): any;
export declare class GoogleTranscoderJobConfigOverlaysAnimationsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleTranscoderJobConfigOverlaysAnimations | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleTranscoderJobConfigOverlaysAnimations | cdktf.IResolvable | undefined);
    private _animationFade;
    get animationFade(): GoogleTranscoderJobConfigOverlaysAnimationsAnimationFadeOutputReference;
    putAnimationFade(value: GoogleTranscoderJobConfigOverlaysAnimationsAnimationFade): void;
    resetAnimationFade(): void;
    get animationFadeInput(): GoogleTranscoderJobConfigOverlaysAnimationsAnimationFade | undefined;
}
export declare class GoogleTranscoderJobConfigOverlaysAnimationsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleTranscoderJobConfigOverlaysAnimations[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleTranscoderJobConfigOverlaysAnimationsOutputReference;
}
export interface GoogleTranscoderJobConfigOverlaysImage {
    /**
    * URI of the image in Cloud Storage. For example, gs://bucket/inputs/image.png.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#uri GoogleTranscoderJob#uri}
    */
    readonly uri: string;
}
export declare function googleTranscoderJobConfigOverlaysImageToTerraform(struct?: GoogleTranscoderJobConfigOverlaysImageOutputReference | GoogleTranscoderJobConfigOverlaysImage): any;
export declare function googleTranscoderJobConfigOverlaysImageToHclTerraform(struct?: GoogleTranscoderJobConfigOverlaysImageOutputReference | GoogleTranscoderJobConfigOverlaysImage): any;
export declare class GoogleTranscoderJobConfigOverlaysImageOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTranscoderJobConfigOverlaysImage | undefined;
    set internalValue(value: GoogleTranscoderJobConfigOverlaysImage | undefined);
    private _uri?;
    get uri(): string;
    set uri(value: string);
    get uriInput(): string | undefined;
}
export interface GoogleTranscoderJobConfigOverlays {
    /**
    * animations block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#animations GoogleTranscoderJob#animations}
    */
    readonly animations?: GoogleTranscoderJobConfigOverlaysAnimations[] | cdktf.IResolvable;
    /**
    * image block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#image GoogleTranscoderJob#image}
    */
    readonly image?: GoogleTranscoderJobConfigOverlaysImage;
}
export declare function googleTranscoderJobConfigOverlaysToTerraform(struct?: GoogleTranscoderJobConfigOverlays | cdktf.IResolvable): any;
export declare function googleTranscoderJobConfigOverlaysToHclTerraform(struct?: GoogleTranscoderJobConfigOverlays | cdktf.IResolvable): any;
export declare class GoogleTranscoderJobConfigOverlaysOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleTranscoderJobConfigOverlays | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleTranscoderJobConfigOverlays | cdktf.IResolvable | undefined);
    private _animations;
    get animations(): GoogleTranscoderJobConfigOverlaysAnimationsList;
    putAnimations(value: GoogleTranscoderJobConfigOverlaysAnimations[] | cdktf.IResolvable): void;
    resetAnimations(): void;
    get animationsInput(): cdktf.IResolvable | GoogleTranscoderJobConfigOverlaysAnimations[] | undefined;
    private _image;
    get image(): GoogleTranscoderJobConfigOverlaysImageOutputReference;
    putImage(value: GoogleTranscoderJobConfigOverlaysImage): void;
    resetImage(): void;
    get imageInput(): GoogleTranscoderJobConfigOverlaysImage | undefined;
}
export declare class GoogleTranscoderJobConfigOverlaysList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleTranscoderJobConfigOverlays[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleTranscoderJobConfigOverlaysOutputReference;
}
export interface GoogleTranscoderJobConfigPubsubDestination {
    /**
    * The name of the Pub/Sub topic to publish job completion notification to. For example: projects/{project}/topics/{topic}.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#topic GoogleTranscoderJob#topic}
    */
    readonly topic?: string;
}
export declare function googleTranscoderJobConfigPubsubDestinationToTerraform(struct?: GoogleTranscoderJobConfigPubsubDestinationOutputReference | GoogleTranscoderJobConfigPubsubDestination): any;
export declare function googleTranscoderJobConfigPubsubDestinationToHclTerraform(struct?: GoogleTranscoderJobConfigPubsubDestinationOutputReference | GoogleTranscoderJobConfigPubsubDestination): any;
export declare class GoogleTranscoderJobConfigPubsubDestinationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTranscoderJobConfigPubsubDestination | undefined;
    set internalValue(value: GoogleTranscoderJobConfigPubsubDestination | undefined);
    private _topic?;
    get topic(): string;
    set topic(value: string);
    resetTopic(): void;
    get topicInput(): string | undefined;
}
export interface GoogleTranscoderJobConfigA {
    /**
    * ad_breaks block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#ad_breaks GoogleTranscoderJob#ad_breaks}
    */
    readonly adBreaks?: GoogleTranscoderJobConfigAdBreaks[] | cdktf.IResolvable;
    /**
    * edit_list block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#edit_list GoogleTranscoderJob#edit_list}
    */
    readonly editList?: GoogleTranscoderJobConfigEditListStruct[] | cdktf.IResolvable;
    /**
    * elementary_streams block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#elementary_streams GoogleTranscoderJob#elementary_streams}
    */
    readonly elementaryStreams?: GoogleTranscoderJobConfigElementaryStreams[] | cdktf.IResolvable;
    /**
    * encryptions block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#encryptions GoogleTranscoderJob#encryptions}
    */
    readonly encryptions?: GoogleTranscoderJobConfigEncryptions[] | cdktf.IResolvable;
    /**
    * inputs block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#inputs GoogleTranscoderJob#inputs}
    */
    readonly inputs?: GoogleTranscoderJobConfigInputs[] | cdktf.IResolvable;
    /**
    * manifests block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#manifests GoogleTranscoderJob#manifests}
    */
    readonly manifests?: GoogleTranscoderJobConfigManifests[] | cdktf.IResolvable;
    /**
    * mux_streams block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#mux_streams GoogleTranscoderJob#mux_streams}
    */
    readonly muxStreams?: GoogleTranscoderJobConfigMuxStreams[] | cdktf.IResolvable;
    /**
    * output block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#output GoogleTranscoderJob#output}
    */
    readonly output?: GoogleTranscoderJobConfigOutput;
    /**
    * overlays block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#overlays GoogleTranscoderJob#overlays}
    */
    readonly overlays?: GoogleTranscoderJobConfigOverlays[] | cdktf.IResolvable;
    /**
    * pubsub_destination block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#pubsub_destination GoogleTranscoderJob#pubsub_destination}
    */
    readonly pubsubDestination?: GoogleTranscoderJobConfigPubsubDestination;
}
export declare function googleTranscoderJobConfigAToTerraform(struct?: GoogleTranscoderJobConfigAOutputReference | GoogleTranscoderJobConfigA): any;
export declare function googleTranscoderJobConfigAToHclTerraform(struct?: GoogleTranscoderJobConfigAOutputReference | GoogleTranscoderJobConfigA): any;
export declare class GoogleTranscoderJobConfigAOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTranscoderJobConfigA | undefined;
    set internalValue(value: GoogleTranscoderJobConfigA | undefined);
    private _adBreaks;
    get adBreaks(): GoogleTranscoderJobConfigAdBreaksList;
    putAdBreaks(value: GoogleTranscoderJobConfigAdBreaks[] | cdktf.IResolvable): void;
    resetAdBreaks(): void;
    get adBreaksInput(): cdktf.IResolvable | GoogleTranscoderJobConfigAdBreaks[] | undefined;
    private _editList;
    get editList(): GoogleTranscoderJobConfigEditListStructList;
    putEditList(value: GoogleTranscoderJobConfigEditListStruct[] | cdktf.IResolvable): void;
    resetEditList(): void;
    get editListInput(): cdktf.IResolvable | GoogleTranscoderJobConfigEditListStruct[] | undefined;
    private _elementaryStreams;
    get elementaryStreams(): GoogleTranscoderJobConfigElementaryStreamsList;
    putElementaryStreams(value: GoogleTranscoderJobConfigElementaryStreams[] | cdktf.IResolvable): void;
    resetElementaryStreams(): void;
    get elementaryStreamsInput(): cdktf.IResolvable | GoogleTranscoderJobConfigElementaryStreams[] | undefined;
    private _encryptions;
    get encryptions(): GoogleTranscoderJobConfigEncryptionsList;
    putEncryptions(value: GoogleTranscoderJobConfigEncryptions[] | cdktf.IResolvable): void;
    resetEncryptions(): void;
    get encryptionsInput(): cdktf.IResolvable | GoogleTranscoderJobConfigEncryptions[] | undefined;
    private _inputs;
    get inputs(): GoogleTranscoderJobConfigInputsList;
    putInputs(value: GoogleTranscoderJobConfigInputs[] | cdktf.IResolvable): void;
    resetInputs(): void;
    get inputsInput(): cdktf.IResolvable | GoogleTranscoderJobConfigInputs[] | undefined;
    private _manifests;
    get manifests(): GoogleTranscoderJobConfigManifestsList;
    putManifests(value: GoogleTranscoderJobConfigManifests[] | cdktf.IResolvable): void;
    resetManifests(): void;
    get manifestsInput(): cdktf.IResolvable | GoogleTranscoderJobConfigManifests[] | undefined;
    private _muxStreams;
    get muxStreams(): GoogleTranscoderJobConfigMuxStreamsList;
    putMuxStreams(value: GoogleTranscoderJobConfigMuxStreams[] | cdktf.IResolvable): void;
    resetMuxStreams(): void;
    get muxStreamsInput(): cdktf.IResolvable | GoogleTranscoderJobConfigMuxStreams[] | undefined;
    private _output;
    get output(): GoogleTranscoderJobConfigOutputOutputReference;
    putOutput(value: GoogleTranscoderJobConfigOutput): void;
    resetOutput(): void;
    get outputInput(): GoogleTranscoderJobConfigOutput | undefined;
    private _overlays;
    get overlays(): GoogleTranscoderJobConfigOverlaysList;
    putOverlays(value: GoogleTranscoderJobConfigOverlays[] | cdktf.IResolvable): void;
    resetOverlays(): void;
    get overlaysInput(): cdktf.IResolvable | GoogleTranscoderJobConfigOverlays[] | undefined;
    private _pubsubDestination;
    get pubsubDestination(): GoogleTranscoderJobConfigPubsubDestinationOutputReference;
    putPubsubDestination(value: GoogleTranscoderJobConfigPubsubDestination): void;
    resetPubsubDestination(): void;
    get pubsubDestinationInput(): GoogleTranscoderJobConfigPubsubDestination | undefined;
}
export interface GoogleTranscoderJobTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#create GoogleTranscoderJob#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#delete GoogleTranscoderJob#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#update GoogleTranscoderJob#update}
    */
    readonly update?: string;
}
export declare function googleTranscoderJobTimeoutsToTerraform(struct?: GoogleTranscoderJobTimeouts | cdktf.IResolvable): any;
export declare function googleTranscoderJobTimeoutsToHclTerraform(struct?: GoogleTranscoderJobTimeouts | cdktf.IResolvable): any;
export declare class GoogleTranscoderJobTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleTranscoderJobTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleTranscoderJobTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job google_transcoder_job}
*/
export declare class GoogleTranscoderJob extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_transcoder_job";
    /**
    * Generates CDKTF code for importing a GoogleTranscoderJob resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleTranscoderJob to import
    * @param importFromId The id of the existing GoogleTranscoderJob that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleTranscoderJob to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_transcoder_job google_transcoder_job} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleTranscoderJobConfig
    */
    constructor(scope: Construct, id: string, config: GoogleTranscoderJobConfig);
    get createTime(): string;
    private _effectiveLabels;
    get effectiveLabels(): cdktf.StringMap;
    get endTime(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    get name(): string;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    get startTime(): string;
    get state(): string;
    private _templateId?;
    get templateId(): string;
    set templateId(value: string);
    resetTemplateId(): void;
    get templateIdInput(): string | undefined;
    private _terraformLabels;
    get terraformLabels(): cdktf.StringMap;
    private _config;
    get config(): GoogleTranscoderJobConfigAOutputReference;
    putConfig(value: GoogleTranscoderJobConfigA): void;
    resetConfig(): void;
    get configInput(): GoogleTranscoderJobConfigA | undefined;
    private _timeouts;
    get timeouts(): GoogleTranscoderJobTimeoutsOutputReference;
    putTimeouts(value: GoogleTranscoderJobTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleTranscoderJobTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
