/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleVmwareengineClusterConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_vmwareengine_cluster#id GoogleVmwareengineCluster#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The ID of the Cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_vmwareengine_cluster#name GoogleVmwareengineCluster#name}
    */
    readonly name: string;
    /**
    * The resource name of the private cloud to create a new cluster in.
    * Resource names are schemeless URIs that follow the conventions in https://cloud.google.com/apis/design/resource_names.
    * For example: projects/my-project/locations/us-west1-a/privateClouds/my-cloud
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_vmwareengine_cluster#parent GoogleVmwareengineCluster#parent}
    */
    readonly parent: string;
    /**
    * autoscaling_settings block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_vmwareengine_cluster#autoscaling_settings GoogleVmwareengineCluster#autoscaling_settings}
    */
    readonly autoscalingSettings?: GoogleVmwareengineClusterAutoscalingSettings;
    /**
    * node_type_configs block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_vmwareengine_cluster#node_type_configs GoogleVmwareengineCluster#node_type_configs}
    */
    readonly nodeTypeConfigs?: GoogleVmwareengineClusterNodeTypeConfigs[] | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_vmwareengine_cluster#timeouts GoogleVmwareengineCluster#timeouts}
    */
    readonly timeouts?: GoogleVmwareengineClusterTimeouts;
}
export interface GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesConsumedMemoryThresholds {
    /**
    * The utilization triggering the scale-in operation in percent.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_vmwareengine_cluster#scale_in GoogleVmwareengineCluster#scale_in}
    */
    readonly scaleIn: number;
    /**
    * The utilization triggering the scale-out operation in percent.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_vmwareengine_cluster#scale_out GoogleVmwareengineCluster#scale_out}
    */
    readonly scaleOut: number;
}
export declare function googleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesConsumedMemoryThresholdsToTerraform(struct?: GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesConsumedMemoryThresholdsOutputReference | GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesConsumedMemoryThresholds): any;
export declare function googleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesConsumedMemoryThresholdsToHclTerraform(struct?: GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesConsumedMemoryThresholdsOutputReference | GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesConsumedMemoryThresholds): any;
export declare class GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesConsumedMemoryThresholdsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesConsumedMemoryThresholds | undefined;
    set internalValue(value: GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesConsumedMemoryThresholds | undefined);
    private _scaleIn?;
    get scaleIn(): number;
    set scaleIn(value: number);
    get scaleInInput(): number | undefined;
    private _scaleOut?;
    get scaleOut(): number;
    set scaleOut(value: number);
    get scaleOutInput(): number | undefined;
}
export interface GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesCpuThresholds {
    /**
    * The utilization triggering the scale-in operation in percent.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_vmwareengine_cluster#scale_in GoogleVmwareengineCluster#scale_in}
    */
    readonly scaleIn: number;
    /**
    * The utilization triggering the scale-out operation in percent.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_vmwareengine_cluster#scale_out GoogleVmwareengineCluster#scale_out}
    */
    readonly scaleOut: number;
}
export declare function googleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesCpuThresholdsToTerraform(struct?: GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesCpuThresholdsOutputReference | GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesCpuThresholds): any;
export declare function googleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesCpuThresholdsToHclTerraform(struct?: GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesCpuThresholdsOutputReference | GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesCpuThresholds): any;
export declare class GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesCpuThresholdsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesCpuThresholds | undefined;
    set internalValue(value: GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesCpuThresholds | undefined);
    private _scaleIn?;
    get scaleIn(): number;
    set scaleIn(value: number);
    get scaleInInput(): number | undefined;
    private _scaleOut?;
    get scaleOut(): number;
    set scaleOut(value: number);
    get scaleOutInput(): number | undefined;
}
export interface GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesStorageThresholds {
    /**
    * The utilization triggering the scale-in operation in percent.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_vmwareengine_cluster#scale_in GoogleVmwareengineCluster#scale_in}
    */
    readonly scaleIn: number;
    /**
    * The utilization triggering the scale-out operation in percent.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_vmwareengine_cluster#scale_out GoogleVmwareengineCluster#scale_out}
    */
    readonly scaleOut: number;
}
export declare function googleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesStorageThresholdsToTerraform(struct?: GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesStorageThresholdsOutputReference | GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesStorageThresholds): any;
export declare function googleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesStorageThresholdsToHclTerraform(struct?: GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesStorageThresholdsOutputReference | GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesStorageThresholds): any;
export declare class GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesStorageThresholdsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesStorageThresholds | undefined;
    set internalValue(value: GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesStorageThresholds | undefined);
    private _scaleIn?;
    get scaleIn(): number;
    set scaleIn(value: number);
    get scaleInInput(): number | undefined;
    private _scaleOut?;
    get scaleOut(): number;
    set scaleOut(value: number);
    get scaleOutInput(): number | undefined;
}
export interface GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPolicies {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_vmwareengine_cluster#autoscale_policy_id GoogleVmwareengineCluster#autoscale_policy_id}
    */
    readonly autoscalePolicyId: string;
    /**
    * The canonical identifier of the node type to add or remove.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_vmwareengine_cluster#node_type_id GoogleVmwareengineCluster#node_type_id}
    */
    readonly nodeTypeId: string;
    /**
    * Number of nodes to add to a cluster during a scale-out operation.
    * Must be divisible by 2 for stretched clusters.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_vmwareengine_cluster#scale_out_size GoogleVmwareengineCluster#scale_out_size}
    */
    readonly scaleOutSize: number;
    /**
    * consumed_memory_thresholds block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_vmwareengine_cluster#consumed_memory_thresholds GoogleVmwareengineCluster#consumed_memory_thresholds}
    */
    readonly consumedMemoryThresholds?: GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesConsumedMemoryThresholds;
    /**
    * cpu_thresholds block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_vmwareengine_cluster#cpu_thresholds GoogleVmwareengineCluster#cpu_thresholds}
    */
    readonly cpuThresholds?: GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesCpuThresholds;
    /**
    * storage_thresholds block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_vmwareengine_cluster#storage_thresholds GoogleVmwareengineCluster#storage_thresholds}
    */
    readonly storageThresholds?: GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesStorageThresholds;
}
export declare function googleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesToTerraform(struct?: GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPolicies | cdktf.IResolvable): any;
export declare function googleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesToHclTerraform(struct?: GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPolicies | cdktf.IResolvable): any;
export declare class GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPolicies | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPolicies | cdktf.IResolvable | undefined);
    private _autoscalePolicyId?;
    get autoscalePolicyId(): string;
    set autoscalePolicyId(value: string);
    get autoscalePolicyIdInput(): string | undefined;
    private _nodeTypeId?;
    get nodeTypeId(): string;
    set nodeTypeId(value: string);
    get nodeTypeIdInput(): string | undefined;
    private _scaleOutSize?;
    get scaleOutSize(): number;
    set scaleOutSize(value: number);
    get scaleOutSizeInput(): number | undefined;
    private _consumedMemoryThresholds;
    get consumedMemoryThresholds(): GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesConsumedMemoryThresholdsOutputReference;
    putConsumedMemoryThresholds(value: GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesConsumedMemoryThresholds): void;
    resetConsumedMemoryThresholds(): void;
    get consumedMemoryThresholdsInput(): GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesConsumedMemoryThresholds | undefined;
    private _cpuThresholds;
    get cpuThresholds(): GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesCpuThresholdsOutputReference;
    putCpuThresholds(value: GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesCpuThresholds): void;
    resetCpuThresholds(): void;
    get cpuThresholdsInput(): GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesCpuThresholds | undefined;
    private _storageThresholds;
    get storageThresholds(): GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesStorageThresholdsOutputReference;
    putStorageThresholds(value: GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesStorageThresholds): void;
    resetStorageThresholds(): void;
    get storageThresholdsInput(): GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesStorageThresholds | undefined;
}
export declare class GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPolicies[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesOutputReference;
}
export interface GoogleVmwareengineClusterAutoscalingSettings {
    /**
    * The minimum duration between consecutive autoscale operations.
    * It starts once addition or removal of nodes is fully completed.
    * Minimum cool down period is 30m.
    * Cool down period must be in whole minutes (for example, 30m, 31m, 50m).
    * Mandatory for successful addition of autoscaling settings in cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_vmwareengine_cluster#cool_down_period GoogleVmwareengineCluster#cool_down_period}
    */
    readonly coolDownPeriod?: string;
    /**
    * Maximum number of nodes of any type in a cluster.
    * Mandatory for successful addition of autoscaling settings in cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_vmwareengine_cluster#max_cluster_node_count GoogleVmwareengineCluster#max_cluster_node_count}
    */
    readonly maxClusterNodeCount?: number;
    /**
    * Minimum number of nodes of any type in a cluster.
    * Mandatory for successful addition of autoscaling settings in cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_vmwareengine_cluster#min_cluster_node_count GoogleVmwareengineCluster#min_cluster_node_count}
    */
    readonly minClusterNodeCount?: number;
    /**
    * autoscaling_policies block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_vmwareengine_cluster#autoscaling_policies GoogleVmwareengineCluster#autoscaling_policies}
    */
    readonly autoscalingPolicies: GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPolicies[] | cdktf.IResolvable;
}
export declare function googleVmwareengineClusterAutoscalingSettingsToTerraform(struct?: GoogleVmwareengineClusterAutoscalingSettingsOutputReference | GoogleVmwareengineClusterAutoscalingSettings): any;
export declare function googleVmwareengineClusterAutoscalingSettingsToHclTerraform(struct?: GoogleVmwareengineClusterAutoscalingSettingsOutputReference | GoogleVmwareengineClusterAutoscalingSettings): any;
export declare class GoogleVmwareengineClusterAutoscalingSettingsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleVmwareengineClusterAutoscalingSettings | undefined;
    set internalValue(value: GoogleVmwareengineClusterAutoscalingSettings | undefined);
    private _coolDownPeriod?;
    get coolDownPeriod(): string;
    set coolDownPeriod(value: string);
    resetCoolDownPeriod(): void;
    get coolDownPeriodInput(): string | undefined;
    private _maxClusterNodeCount?;
    get maxClusterNodeCount(): number;
    set maxClusterNodeCount(value: number);
    resetMaxClusterNodeCount(): void;
    get maxClusterNodeCountInput(): number | undefined;
    private _minClusterNodeCount?;
    get minClusterNodeCount(): number;
    set minClusterNodeCount(value: number);
    resetMinClusterNodeCount(): void;
    get minClusterNodeCountInput(): number | undefined;
    private _autoscalingPolicies;
    get autoscalingPolicies(): GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPoliciesList;
    putAutoscalingPolicies(value: GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPolicies[] | cdktf.IResolvable): void;
    get autoscalingPoliciesInput(): cdktf.IResolvable | GoogleVmwareengineClusterAutoscalingSettingsAutoscalingPolicies[] | undefined;
}
export interface GoogleVmwareengineClusterNodeTypeConfigs {
    /**
    * Customized number of cores available to each node of the type.
    * This number must always be one of 'nodeType.availableCustomCoreCounts'.
    * If zero is provided max value from 'nodeType.availableCustomCoreCounts' will be used.
    * Once the customer is created then corecount cannot be changed.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_vmwareengine_cluster#custom_core_count GoogleVmwareengineCluster#custom_core_count}
    */
    readonly customCoreCount?: number;
    /**
    * The number of nodes of this type in the cluster.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_vmwareengine_cluster#node_count GoogleVmwareengineCluster#node_count}
    */
    readonly nodeCount: number;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_vmwareengine_cluster#node_type_id GoogleVmwareengineCluster#node_type_id}
    */
    readonly nodeTypeId: string;
}
export declare function googleVmwareengineClusterNodeTypeConfigsToTerraform(struct?: GoogleVmwareengineClusterNodeTypeConfigs | cdktf.IResolvable): any;
export declare function googleVmwareengineClusterNodeTypeConfigsToHclTerraform(struct?: GoogleVmwareengineClusterNodeTypeConfigs | cdktf.IResolvable): any;
export declare class GoogleVmwareengineClusterNodeTypeConfigsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): GoogleVmwareengineClusterNodeTypeConfigs | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleVmwareengineClusterNodeTypeConfigs | cdktf.IResolvable | undefined);
    private _customCoreCount?;
    get customCoreCount(): number;
    set customCoreCount(value: number);
    resetCustomCoreCount(): void;
    get customCoreCountInput(): number | undefined;
    private _nodeCount?;
    get nodeCount(): number;
    set nodeCount(value: number);
    get nodeCountInput(): number | undefined;
    private _nodeTypeId?;
    get nodeTypeId(): string;
    set nodeTypeId(value: string);
    get nodeTypeIdInput(): string | undefined;
}
export declare class GoogleVmwareengineClusterNodeTypeConfigsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: GoogleVmwareengineClusterNodeTypeConfigs[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): GoogleVmwareengineClusterNodeTypeConfigsOutputReference;
}
export interface GoogleVmwareengineClusterTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_vmwareengine_cluster#create GoogleVmwareengineCluster#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_vmwareengine_cluster#delete GoogleVmwareengineCluster#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_vmwareengine_cluster#update GoogleVmwareengineCluster#update}
    */
    readonly update?: string;
}
export declare function googleVmwareengineClusterTimeoutsToTerraform(struct?: GoogleVmwareengineClusterTimeouts | cdktf.IResolvable): any;
export declare function googleVmwareengineClusterTimeoutsToHclTerraform(struct?: GoogleVmwareengineClusterTimeouts | cdktf.IResolvable): any;
export declare class GoogleVmwareengineClusterTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleVmwareengineClusterTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: GoogleVmwareengineClusterTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_vmwareengine_cluster google_vmwareengine_cluster}
*/
export declare class GoogleVmwareengineCluster extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_vmwareengine_cluster";
    /**
    * Generates CDKTF code for importing a GoogleVmwareengineCluster resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GoogleVmwareengineCluster to import
    * @param importFromId The id of the existing GoogleVmwareengineCluster that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_vmwareengine_cluster#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GoogleVmwareengineCluster to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.10.0/docs/resources/google_vmwareengine_cluster google_vmwareengine_cluster} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleVmwareengineClusterConfig
    */
    constructor(scope: Construct, id: string, config: GoogleVmwareengineClusterConfig);
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get management(): cdktf.IResolvable;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _parent?;
    get parent(): string;
    set parent(value: string);
    get parentInput(): string | undefined;
    get state(): string;
    get uid(): string;
    private _autoscalingSettings;
    get autoscalingSettings(): GoogleVmwareengineClusterAutoscalingSettingsOutputReference;
    putAutoscalingSettings(value: GoogleVmwareengineClusterAutoscalingSettings): void;
    resetAutoscalingSettings(): void;
    get autoscalingSettingsInput(): GoogleVmwareengineClusterAutoscalingSettings | undefined;
    private _nodeTypeConfigs;
    get nodeTypeConfigs(): GoogleVmwareengineClusterNodeTypeConfigsList;
    putNodeTypeConfigs(value: GoogleVmwareengineClusterNodeTypeConfigs[] | cdktf.IResolvable): void;
    resetNodeTypeConfigs(): void;
    get nodeTypeConfigsInput(): cdktf.IResolvable | GoogleVmwareengineClusterNodeTypeConfigs[] | undefined;
    private _timeouts;
    get timeouts(): GoogleVmwareengineClusterTimeoutsOutputReference;
    putTimeouts(value: GoogleVmwareengineClusterTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | GoogleVmwareengineClusterTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
